// {{MadCap}} //////////////////////////////////////////////////////////////////
// Copyright: MadCap Software, Inc - www.madcapsoftware.com ////////////////////
////////////////////////////////////////////////////////////////////////////////
// <version>10.0.0.0</version>
////////////////////////////////////////////////////////////////////////////////

//    Syntax:
//    function FMCOpenHelp( id, skinName, searchQuery, firstPick )
//
//    id          - Identifier that was created in Flare. This can be either the identifier name or value. The topic and skin
//                  that is associated with the id will be used. If no skin is associated with the id, skinName will be used.
//                  Alternatively, id may contain a topic path. In this case, the specified topic will be loaded with the skin
//                  that is specified in skinName. Specify null to use the help system's default starting topic.
//    skinName    - This is a string indicating the name of the skin to use when opening the help system. Specify null to use
//                  the default skin or to use the skin that is associated with id. If a skin is associated with id AND a skin
//                  is specified in skinName, skinName will take precedence.
//    searchQuery - This is a string indicating the search query used when opening the help system. If a search query is specified,
//                  the help system will start with the search pane open and the search query executed. Specify null to open
//                  the help system without a search query.
//    firstPick   - This is a boolean indicating whether to automatically open the topic from the first search result that is
//                  returned by the search query (see searchQuery parameter). Use null if no search query was specified.
//
//    Examples:
//
//    In the following example, topic and skin associated with "FILE_NEW" will be used:
//    FMCOpenHelp( 'FILE_NEW', null, null, null );
//
//    In the following example, topic associated with "FILE_NEW" will be used. "BlueSkin" will override the skin associated with "FILE_NEW":
//    FMCOpenHelp( 'FILE_NEW', 'BlueSkin', null, null );
//
//    In the following example, topic and skin associated with identifier value 1 will be used:
//    FMCOpenHelp( 1, null, null, null );
//
//    In the following example, topic associated with identifier value 1 will be used. "BlueSkin" will override the skin associated with identifier value 1:
//    FMCOpenHelp( 1, 'BlueSkin', null, null );
//
//    In the following example, "Company/Employees.htm" will be used with the default skin:
//    FMCOpenHelp( 'Company/Employees.htm', null, null, null );
//
//    In the following example, both the default topic and skin will be used:
//    FMCOpenHelp( null, null, null, null );
//
//    In the following example, the default topic will be used with "BlueSkin":
//    FMCOpenHelp( null, 'BlueSkin', null, null );
//
//    In the following example, both the default topic and skin will be used. The help system will be started with the search pane
//    displaying the search results for the query 'quarterly report'. The topic from the first result will not be opened:
//    FMCOpenHelp( null, null, 'quarterly report', false );
//
//    In the following example, both the default topic and skin will be used. The help system will be started with the search pane
//    displaying the search results for the query 'quarterly report'. The topic from the first result will be opened:
//    FMCOpenHelp( null, null, 'quarterly report', true );

function FMCOpenHelp( id, skinName, searchQuery, firstPick, pathToHelpSystem )
{
    MadCap.OpenHelp(id, skinName, searchQuery, firstPick, pathToHelpSystem);
}

/*!
* Copyright MadCap Software
* http://www.madcapsoftware.com/
*
* v10.0.0.0
*/

/*
 RequireJS 2.1.11 Copyright (c) 2010-2014, The Dojo Foundation All Rights Reserved.
 Available via the MIT or new BSD license.
 see: http://github.com/jrburke/requirejs for details
*/
var requirejs, require, define;
(function (ca) {
    function G(b) { return "[object Function]" === M.call(b) } function H(b) { return "[object Array]" === M.call(b) } function v(b, c) { if (b) { var d; for (d = 0; d < b.length && (!b[d] || !c(b[d], d, b)) ; d += 1); } } function U(b, c) { if (b) { var d; for (d = b.length - 1; -1 < d && (!b[d] || !c(b[d], d, b)) ; d -= 1); } } function s(b, c) { return ga.call(b, c) } function j(b, c) { return s(b, c) && b[c] } function B(b, c) { for (var d in b) if (s(b, d) && c(b[d], d)) break } function V(b, c, d, g) {
        c && B(c, function (c, h) {
            if (d || !s(b, h)) g && "object" === typeof c && c && !H(c) && !G(c) && !(c instanceof
            RegExp) ? (b[h] || (b[h] = {}), V(b[h], c, d, g)) : b[h] = c
        }); return b
    } function t(b, c) { return function () { return c.apply(b, arguments) } } function da(b) { throw b; } function ea(b) { if (!b) return b; var c = ca; v(b.split("."), function (b) { c = c[b] }); return c } function C(b, c, d, g) { c = Error(c + "\nhttp://requirejs.org/docs/errors.html#" + b); c.requireType = b; c.requireModules = g; d && (c.originalError = d); return c } function ha(b) {
        function c(a, e, b) {
            var f, n, c, d, g, h, i, I = e && e.split("/"); n = I; var m = l.map, k = m && m["*"]; if (a && "." === a.charAt(0)) if (e) {
                n =
                I.slice(0, I.length - 1); a = a.split("/"); e = a.length - 1; l.nodeIdCompat && R.test(a[e]) && (a[e] = a[e].replace(R, "")); n = a = n.concat(a); d = n.length; for (e = 0; e < d; e++) if (c = n[e], "." === c) n.splice(e, 1), e -= 1; else if (".." === c) if (1 === e && (".." === n[2] || ".." === n[0])) break; else 0 < e && (n.splice(e - 1, 2), e -= 2); a = a.join("/")
            } else 0 === a.indexOf("./") && (a = a.substring(2)); if (b && m && (I || k)) {
                n = a.split("/"); e = n.length; a: for (; 0 < e; e -= 1) {
                    d = n.slice(0, e).join("/"); if (I) for (c = I.length; 0 < c; c -= 1) if (b = j(m, I.slice(0, c).join("/"))) if (b = j(b, d)) {
                        f = b;
                        g = e; break a
                    } !h && (k && j(k, d)) && (h = j(k, d), i = e)
                } !f && h && (f = h, g = i); f && (n.splice(0, g, f), a = n.join("/"))
            } return (f = j(l.pkgs, a)) ? f : a
        } function d(a) { z && v(document.getElementsByTagName("script"), function (e) { if (e.getAttribute("data-requiremodule") === a && e.getAttribute("data-requirecontext") === i.contextName) return e.parentNode.removeChild(e), !0 }) } function g(a) { var e = j(l.paths, a); if (e && H(e) && 1 < e.length) return e.shift(), i.require.undef(a), i.require([a]), !0 } function u(a) {
            var e; return [e, a];
        } function m(a, e, b, f) { var n, d, g = null, h = e ? e.name : null, l = a, m = !0, k = ""; a || (m = !1, a = "_@r" + (M += 1)); a = u(a); g = a[0]; a = a[1]; g && (g = c(g, h, f), d = j(p, g)); a && (g ? k = d && d.normalize ? d.normalize(a, function (a) { return c(a, h, f) }) : c(a, h, f) : (k = c(a, h, f), a = u(k), g = a[0], k = a[1], b = !0, n = i.nameToUrl(k))); b = g && !d && !b ? "_unnormalized" + (Q += 1) : ""; return { prefix: g, name: k, parentMap: e, unnormalized: !!b, url: n, originalName: l, isDefine: m, id: (g ? g + "!" + k : k) + b } } function q(a) {
            var e = a.id, b = j(k, e); b || (b = k[e] = new i.Module(a));
            return b
        } function r(a, e, b) { var f = a.id, n = j(k, f); if (s(p, f) && (!n || n.defineEmitComplete)) "defined" === e && b(p[f]); else if (n = q(a), n.error && "error" === e) b(n.error); else n.on(e, b) } function w(a, e) { var b = a.requireModules, f = !1; if (e) e(a); else if (v(b, function (e) { if (e = j(k, e)) e.error = a, e.events.error && (f = !0, e.emit("error", a)) }), !f) h.onError(a) } function x() { S.length && (ia.apply(A, [A.length, 0].concat(S)), S = []) } function y(a) { delete k[a]; delete W[a] } function F(a, e, b) {
            var f = a.map.id; a.error ? a.emit("error", a.error) : (e[f] =
            !0, v(a.depMaps, function (f, c) { var d = f.id, g = j(k, d); g && (!a.depMatched[c] && !b[d]) && (j(e, d) ? (a.defineDep(c, p[d]), a.check()) : F(g, e, b)) }), b[f] = !0)
        } function D() {
            var a, e, b = (a = 1E3 * l.waitSeconds) && i.startTime + a < (new Date).getTime(), f = [], c = [], h = !1, k = !0; if (!X) {
                X = !0; B(W, function (a) { var i = a.map, m = i.id; if (a.enabled && (i.isDefine || c.push(a), !a.error)) if (!a.inited && b) g(m) ? h = e = !0 : (f.push(m), d(m)); else if (!a.inited && (a.fetched && i.isDefine) && (h = !0, !i.prefix)) return k = !1 }); if (b && f.length) return a = C("timeout", "Load timeout for modules: " +
                f, null, f), a.contextName = i.contextName, w(a); k && v(c, function (a) { F(a, {}, {}) }); if ((!b || e) && h) if ((z || fa) && !Y) Y = setTimeout(function () { Y = 0; D() }, 50); X = !1
            }
        } function E(a) { s(p, a[0]) || q(m(a[0], null, !0)).init(a[1], a[2]) } function K(a) { var a = a.currentTarget || a.srcElement, e = i.onScriptLoad; a.detachEvent && !Z ? a.detachEvent("onreadystatechange", e) : a.removeEventListener("load", e, !1); e = i.onScriptError; (!a.detachEvent || Z) && a.removeEventListener("error", e, !1); return { node: a, id: a && a.getAttribute("data-requiremodule") } } function L() {
            var a;
            for (x() ; A.length;) { a = A.shift(); if (null === a[0]) return w(C("mismatch", "Mismatched anonymous define() module: " + a[a.length - 1])); E(a) }
        } var X, $, i, N, Y, l = { waitSeconds: 7, baseUrl: "./", paths: {}, bundles: {}, pkgs: {}, shim: {}, config: {} }, k = {}, W = {}, aa = {}, A = [], p = {}, T = {}, ba = {}, M = 1, Q = 1; N = {
            require: function (a) { return a.require ? a.require : a.require = i.makeRequire(a.map) }, exports: function (a) { a.usingExports = !0; if (a.map.isDefine) return a.exports ? p[a.map.id] = a.exports : a.exports = p[a.map.id] = {} }, module: function (a) {
                return a.module ?
                a.module : a.module = { id: a.map.id, uri: a.map.url, config: function () { return j(l.config, a.map.id) || {} }, exports: a.exports || (a.exports = {}) }
            }
        }; $ = function (a) { this.events = j(aa, a.id) || {}; this.map = a; this.shim = j(l.shim, a.id); this.depExports = []; this.depMaps = []; this.depMatched = []; this.pluginMaps = {}; this.depCount = 0 }; $.prototype = {
            init: function (a, e, b, f) {
                f = f || {}; if (!this.inited) {
                    this.factory = e; if (b) this.on("error", b); else this.events.error && (b = t(this, function (a) { this.emit("error", a) })); this.depMaps = a && a.slice(0); this.errback =
                    b; this.inited = !0; this.ignore = f.ignore; f.enabled || this.enabled ? this.enable() : this.check()
                }
            }, defineDep: function (a, e) { this.depMatched[a] || (this.depMatched[a] = !0, this.depCount -= 1, this.depExports[a] = e) }, fetch: function () { if (!this.fetched) { this.fetched = !0; i.startTime = (new Date).getTime(); var a = this.map; if (this.shim) i.makeRequire(this.map, { enableBuildCallback: !0 })(this.shim.deps || [], t(this, function () { return a.prefix ? this.callPlugin() : this.load() })); else return a.prefix ? this.callPlugin() : this.load() } }, load: function () {
                var a =
                this.map.url; T[a] || (T[a] = !0, i.load(this.map.id, a))
            }, check: function () {
                if (this.enabled && !this.enabling) {
                    var a, e, b = this.map.id; e = this.depExports; var f = this.exports, c = this.factory; if (this.inited) if (this.error) this.emit("error", this.error); else {
                        if (!this.defining) {
                            this.defining = !0; if (1 > this.depCount && !this.defined) {
                                if (G(c)) {
                                    if (this.events.error && this.map.isDefine || h.onError !== da) try { f = i.execCb(b, c, e, f) } catch (d) { a = d } else f = i.execCb(b, c, e, f); this.map.isDefine && void 0 === f && ((e = this.module) ? f = e.exports : this.usingExports &&
                                    (f = this.exports)); if (a) return a.requireMap = this.map, a.requireModules = this.map.isDefine ? [this.map.id] : null, a.requireType = this.map.isDefine ? "define" : "require", w(this.error = a)
                                } else f = c; this.exports = f; if (this.map.isDefine && !this.ignore && (p[b] = f, h.onResourceLoad)) h.onResourceLoad(i, this.map, this.depMaps); y(b); this.defined = !0
                            } this.defining = !1; this.defined && !this.defineEmitted && (this.defineEmitted = !0, this.emit("defined", this.exports), this.defineEmitComplete = !0)
                        }
                    } else this.fetch()
                }
            }, callPlugin: function () {
                var a =
                this.map, b = a.id, d = m(a.prefix); this.depMaps.push(d); r(d, "defined", t(this, function (f) {
                    var d, g; g = j(ba, this.map.id); var J = this.map.name, u = this.map.parentMap ? this.map.parentMap.name : null, p = i.makeRequire(a.parentMap, { enableBuildCallback: !0 }); if (this.map.unnormalized) {
                        if (f.normalize && (J = f.normalize(J, function (a) { return c(a, u, !0) }) || ""), f = m(a.prefix + "!" + J, this.map.parentMap), r(f, "defined", t(this, function (a) { this.init([], function () { return a }, null, { enabled: !0, ignore: !0 }) })), g = j(k, f.id)) {
                            this.depMaps.push(f);
                            if (this.events.error) g.on("error", t(this, function (a) { this.emit("error", a) })); g.enable()
                        }
                    } else g ? (this.map.url = i.nameToUrl(g), this.load()) : (d = t(this, function (a) { this.init([], function () { return a }, null, { enabled: !0 }) }), d.error = t(this, function (a) { this.inited = !0; this.error = a; a.requireModules = [b]; B(k, function (a) { 0 === a.map.id.indexOf(b + "_unnormalized") && y(a.map.id) }); w(a) }), d.fromText = t(this, function (f, c) {
                        var g = a.name, J = m(g), k = O; c && (f = c); k && (O = !1); q(J); s(l.config, b) && (l.config[g] = l.config[b]); try { h.exec(f) } catch (j) {
                            return w(C("fromtexteval",
                            "fromText eval for " + b + " failed: " + j, j, [b]))
                        } k && (O = !0); this.depMaps.push(J); i.completeLoad(g); p([g], d)
                    }), f.load(a.name, p, d, l))
                })); i.enable(d, this); this.pluginMaps[d.id] = d
            }, enable: function () {
                W[this.map.id] = this; this.enabling = this.enabled = !0; v(this.depMaps, t(this, function (a, b) {
                    var c, f; if ("string" === typeof a) {
                        a = m(a, this.map.isDefine ? this.map : this.map.parentMap, !1, !this.skipMap); this.depMaps[b] = a; if (c = j(N, a.id)) { this.depExports[b] = c(this); return } this.depCount += 1; r(a, "defined", t(this, function (a) {
                            this.defineDep(b,
                            a); this.check()
                        })); this.errback && r(a, "error", t(this, this.errback))
                    } c = a.id; f = k[c]; !s(N, c) && (f && !f.enabled) && i.enable(a, this)
                })); B(this.pluginMaps, t(this, function (a) { var b = j(k, a.id); b && !b.enabled && i.enable(a, this) })); this.enabling = !1; this.check()
            }, on: function (a, b) { var c = this.events[a]; c || (c = this.events[a] = []); c.push(b) }, emit: function (a, b) { v(this.events[a], function (a) { a(b) }); "error" === a && delete this.events[a] }
        }; i = {
            config: l, contextName: b, registry: k, defined: p, urlFetched: T, defQueue: A, Module: $, makeModuleMap: m,
            nextTick: h.nextTick, onError: w, configure: function (a) {
                a.baseUrl && "/" !== a.baseUrl.charAt(a.baseUrl.length - 1) && (a.baseUrl += "/"); var b = l.shim, c = { paths: !0, bundles: !0, config: !0, map: !0 }; B(a, function (a, b) { c[b] ? (l[b] || (l[b] = {}), V(l[b], a, !0, !0)) : l[b] = a }); a.bundles && B(a.bundles, function (a, b) { v(a, function (a) { a !== b && (ba[a] = b) }) }); a.shim && (B(a.shim, function (a, c) { H(a) && (a = { deps: a }); if ((a.exports || a.init) && !a.exportsFn) a.exportsFn = i.makeShimExports(a); b[c] = a }), l.shim = b); a.packages && v(a.packages, function (a) {
                    var b,
                    a = "string" === typeof a ? { name: a } : a; b = a.name; a.location && (l.paths[b] = a.location); l.pkgs[b] = a.name + "/" + (a.main || "main").replace(ja, "").replace(R, "")
                }); B(k, function (a, b) { !a.inited && !a.map.unnormalized && (a.map = m(b)) }); if (a.deps || a.callback) i.require(a.deps || [], a.callback)
            }, makeShimExports: function (a) { return function () { var b; a.init && (b = a.init.apply(ca, arguments)); return b || a.exports && ea(a.exports) } }, makeRequire: function (a, e) {
                function g(f, c, d) {
                    var j, l; e.enableBuildCallback && (c && G(c)) && (c.__requireJsBuild =
                    !0); if ("string" === typeof f) { if (G(c)) return w(C("requireargs", "Invalid require call"), d); if (a && s(N, f)) return N[f](k[a.id]); if (h.get) return h.get(i, f, a, g); j = m(f, a, !1, !0); j = j.id; return !s(p, j) ? w(C("notloaded", 'Module name "' + j + '" has not been loaded yet for context: ' + b + (a ? "" : ". Use require([])"))) : p[j] } L(); i.nextTick(function () { L(); l = q(m(null, a)); l.skipMap = e.skipMap; l.init(f, c, d, { enabled: !0 }); D() }); return g
                } e = e || {}; V(g, {
                    isBrowser: z, toUrl: function (b) {
                        var e, d = b.lastIndexOf("."), g = b.split("/")[0]; if (-1 !==
                        d && (!("." === g || ".." === g) || 1 < d)) e = b.substring(d, b.length), b = b.substring(0, d); return i.nameToUrl(c(b, a && a.id, !0), e, !0)
                    }, defined: function (b) { return s(p, m(b, a, !1, !0).id) }, specified: function (b) { b = m(b, a, !1, !0).id; return s(p, b) || s(k, b) }
                }); a || (g.undef = function (b) { x(); var c = m(b, a, !0), e = j(k, b); d(b); delete p[b]; delete T[c.url]; delete aa[b]; U(A, function (a, c) { a[0] === b && A.splice(c, 1) }); e && (e.events.defined && (aa[b] = e.events), y(b)) }); return g
            }, enable: function (a) { j(k, a.id) && q(a).enable() }, completeLoad: function (a) {
                var b,
                c, f = j(l.shim, a) || {}, d = f.exports; for (x() ; A.length;) { c = A.shift(); if (null === c[0]) { c[0] = a; if (b) break; b = !0 } else c[0] === a && (b = !0); E(c) } c = j(k, a); if (!b && !s(p, a) && c && !c.inited) { if (l.enforceDefine && (!d || !ea(d))) return g(a) ? void 0 : w(C("nodefine", "No define call for " + a, null, [a])); E([a, f.deps || [], f.exportsFn]) } D()
            }, nameToUrl: function (a, b, c) {
                var f, d, g; (f = j(l.pkgs, a)) && (a = f); if (f = j(ba, a)) return i.nameToUrl(f, b, c); if (h.jsExtRegExp.test(a)) f = a + (b || ""); else {
                    f = l.paths; a = a.split("/"); for (d = a.length; 0 < d; d -= 1) if (g = a.slice(0,
                    d).join("/"), g = j(f, g)) { H(g) && (g = g[0]); a.splice(0, d, g); break } f = a.join("/"); f += b || (/^data\:|\?/.test(f) || c ? "" : ".js"); f = ("/" === f.charAt(0) || f.match(/^[\w\+\.\-]+:/) ? "" : l.baseUrl) + f
                } return l.urlArgs ? f + ((-1 === f.indexOf("?") ? "?" : "&") + l.urlArgs) : f
            }, load: function (a, b) { h.load(i, a, b) }, execCb: function (a, b, c, d) { return b.apply(d, c) }, onScriptLoad: function (a) { if ("load" === a.type || ka.test((a.currentTarget || a.srcElement).readyState)) P = null, a = K(a), i.completeLoad(a.id) }, onScriptError: function (a) {
                var b = K(a); if (!g(b.id)) return w(C("scripterror",
                "Script error for: " + b.id, a, [b.id]))
            }
        }; i.require = i.makeRequire(); return i
    } var h, x, y, D, K, E, P, L, q, Q, la = /(\/\*([\s\S]*?)\*\/|([^:]|^)\/\/(.*)$)/mg, ma = /[^.]\s*require\s*\(\s*["']([^'"\s]+)["']\s*\)/g, R = /\.js$/, ja = /^\.\//; x = Object.prototype; var M = x.toString, ga = x.hasOwnProperty, ia = Array.prototype.splice, z = !!("undefined" !== typeof window && "undefined" !== typeof navigator && window.document), fa = !z && "undefined" !== typeof importScripts, ka = z && "PLAYSTATION 3" === navigator.platform ? /^complete$/ : /^(complete|loaded)$/,
    Z = "undefined" !== typeof opera && "[object Opera]" === opera.toString(), F = {}, r = {}, S = [], O = !1; if ("undefined" === typeof define) {
        if ("undefined" !== typeof requirejs) { if (G(requirejs)) return; r = requirejs; requirejs = void 0 } "undefined" !== typeof require && !G(require) && (r = require, require = void 0); h = requirejs = function (b, c, d, g) { var u, m = "_"; !H(b) && "string" !== typeof b && (u = b, H(c) ? (b = c, c = d, d = g) : b = []); u && u.context && (m = u.context); (g = j(F, m)) || (g = F[m] = h.s.newContext(m)); u && g.configure(u); return g.require(b, c, d) }; h.config = function (b) { return h(b) };
        h.nextTick = "undefined" !== typeof setTimeout ? function (b) { setTimeout(b, 4) } : function (b) { b() }; require || (require = h); h.version = "2.1.11"; h.jsExtRegExp = /^\/|:|\?|\.js$/; h.isBrowser = z; x = h.s = { contexts: F, newContext: ha }; h({}); v(["toUrl", "undef", "defined", "specified"], function (b) { h[b] = function () { var c = F._; return c.require[b].apply(c, arguments) } }); if (z && (y = x.head = document.getElementsByTagName("head")[0], D = document.getElementsByTagName("base")[0])) y = x.head = D.parentNode; h.onError = da; h.createNode = function (b) {
            var c =
            b.xhtml ? document.createElementNS("http://www.w3.org/1999/xhtml", "html:script") : document.createElement("script"); c.type = b.scriptType || "text/javascript"; c.charset = "utf-8"; c.async = !0; return c
        }; h.load = function (b, c, d) {
            var g = b && b.config || {}; if (z) return g = h.createNode(g, c, d), g.setAttribute("data-requirecontext", b.contextName), g.setAttribute("data-requiremodule", c), g.attachEvent && !(g.attachEvent.toString && 0 > g.attachEvent.toString().indexOf("[native code")) && !Z ? (O = !0, g.attachEvent("onreadystatechange", b.onScriptLoad)) :
            (g.addEventListener("load", b.onScriptLoad, !1), g.addEventListener("error", b.onScriptError, !1)), g.src = d, L = g, D ? y.insertBefore(g, D) : y.appendChild(g), L = null, g; if (fa) try { importScripts(d), b.completeLoad(c) } catch (j) { b.onError(C("importscripts", "importScripts failed for " + c + " at " + d, j, [c])) }
        }; z && !r.skipDataMain && U(document.getElementsByTagName("script"), function (b) {
            y || (y = b.parentNode); if (K = b.getAttribute("data-main")) return q = K, r.baseUrl || (E = q.split("/"), q = E.pop(), Q = E.length ? E.join("/") + "/" : "./", r.baseUrl =
            Q), q = q.replace(R, ""), h.jsExtRegExp.test(q) && (q = K), r.deps = r.deps ? r.deps.concat(q) : [q], !0
        }); define = function (b, c, d) {
            var g, h; "string" !== typeof b && (d = c, c = b, b = null); H(c) || (d = c, c = null); !c && G(d) && (c = [], d.length && (d.toString().replace(la, "").replace(ma, function (b, d) { c.push(d) }), c = (1 === d.length ? ["require"] : ["require", "exports", "module"]).concat(c))); if (O) {
                if (!(g = L)) P && "interactive" === P.readyState || U(document.getElementsByTagName("script"), function (b) { if ("interactive" === b.readyState) return P = b }), g = P; g && (b ||
                (b = g.getAttribute("data-requiremodule")), h = F[g.getAttribute("data-requirecontext")])
            } (h ? h.defQueue : S).push([b, c, d])
        }; define.amd = { jQuery: !0 }; h.exec = function (b) { return eval(b) }; h(r)
    }
})(this);/* require end */

/*! jQuery v1.8.3 jquery.com | jquery.org/license */
(function(e,t){function _(e){var t=M[e]={};return v.each(e.split(y),function(e,n){t[n]=!0}),t}function H(e,n,r){if(r===t&&e.nodeType===1){var i="data-"+n.replace(P,"-$1").toLowerCase();r=e.getAttribute(i);if(typeof r=="string"){try{r=r==="true"?!0:r==="false"?!1:r==="null"?null:+r+""===r?+r:D.test(r)?v.parseJSON(r):r}catch(s){}v.data(e,n,r)}else r=t}return r}function B(e){var t;for(t in e){if(t==="data"&&v.isEmptyObject(e[t]))continue;if(t!=="toJSON")return!1}return!0}function et(){return!1}function tt(){return!0}function ut(e){return!e||!e.parentNode||e.parentNode.nodeType===11}function at(e,t){do e=e[t];while(e&&e.nodeType!==1);return e}function ft(e,t,n){t=t||0;if(v.isFunction(t))return v.grep(e,function(e,r){var i=!!t.call(e,r,e);return i===n});if(t.nodeType)return v.grep(e,function(e,r){return e===t===n});if(typeof t=="string"){var r=v.grep(e,function(e){return e.nodeType===1});if(it.test(t))return v.filter(t,r,!n);t=v.filter(t,r)}return v.grep(e,function(e,r){return v.inArray(e,t)>=0===n})}function lt(e){var t=ct.split("|"),n=e.createDocumentFragment();if(n.createElement)while(t.length)n.createElement(t.pop());return n}function Lt(e,t){return e.getElementsByTagName(t)[0]||e.appendChild(e.ownerDocument.createElement(t))}function At(e,t){if(t.nodeType!==1||!v.hasData(e))return;var n,r,i,s=v._data(e),o=v._data(t,s),u=s.events;if(u){delete o.handle,o.events={};for(n in u)for(r=0,i=u[n].length;r<i;r++)v.event.add(t,n,u[n][r])}o.data&&(o.data=v.extend({},o.data))}function Ot(e,t){var n;if(t.nodeType!==1)return;t.clearAttributes&&t.clearAttributes(),t.mergeAttributes&&t.mergeAttributes(e),n=t.nodeName.toLowerCase(),n==="object"?(t.parentNode&&(t.outerHTML=e.outerHTML),v.support.html5Clone&&e.innerHTML&&!v.trim(t.innerHTML)&&(t.innerHTML=e.innerHTML)):n==="input"&&Et.test(e.type)?(t.defaultChecked=t.checked=e.checked,t.value!==e.value&&(t.value=e.value)):n==="option"?t.selected=e.defaultSelected:n==="input"||n==="textarea"?t.defaultValue=e.defaultValue:n==="script"&&t.text!==e.text&&(t.text=e.text),t.removeAttribute(v.expando)}function Mt(e){return typeof e.getElementsByTagName!="undefined"?e.getElementsByTagName("*"):typeof e.querySelectorAll!="undefined"?e.querySelectorAll("*"):[]}function _t(e){Et.test(e.type)&&(e.defaultChecked=e.checked)}function Qt(e,t){if(t in e)return t;var n=t.charAt(0).toUpperCase()+t.slice(1),r=t,i=Jt.length;while(i--){t=Jt[i]+n;if(t in e)return t}return r}function Gt(e,t){return e=t||e,v.css(e,"display")==="none"||!v.contains(e.ownerDocument,e)}function Yt(e,t){var n,r,i=[],s=0,o=e.length;for(;s<o;s++){n=e[s];if(!n.style)continue;i[s]=v._data(n,"olddisplay"),t?(!i[s]&&n.style.display==="none"&&(n.style.display=""),n.style.display===""&&Gt(n)&&(i[s]=v._data(n,"olddisplay",nn(n.nodeName)))):(r=Dt(n,"display"),!i[s]&&r!=="none"&&v._data(n,"olddisplay",r))}for(s=0;s<o;s++){n=e[s];if(!n.style)continue;if(!t||n.style.display==="none"||n.style.display==="")n.style.display=t?i[s]||"":"none"}return e}function Zt(e,t,n){var r=Rt.exec(t);return r?Math.max(0,r[1]-(n||0))+(r[2]||"px"):t}function en(e,t,n,r){var i=n===(r?"border":"content")?4:t==="width"?1:0,s=0;for(;i<4;i+=2)n==="margin"&&(s+=v.css(e,n+$t[i],!0)),r?(n==="content"&&(s-=parseFloat(Dt(e,"padding"+$t[i]))||0),n!=="margin"&&(s-=parseFloat(Dt(e,"border"+$t[i]+"Width"))||0)):(s+=parseFloat(Dt(e,"padding"+$t[i]))||0,n!=="padding"&&(s+=parseFloat(Dt(e,"border"+$t[i]+"Width"))||0));return s}function tn(e,t,n){var r=t==="width"?e.offsetWidth:e.offsetHeight,i=!0,s=v.support.boxSizing&&v.css(e,"boxSizing")==="border-box";if(r<=0||r==null){r=Dt(e,t);if(r<0||r==null)r=e.style[t];if(Ut.test(r))return r;i=s&&(v.support.boxSizingReliable||r===e.style[t]),r=parseFloat(r)||0}return r+en(e,t,n||(s?"border":"content"),i)+"px"}function nn(e){if(Wt[e])return Wt[e];var t=v("<"+e+">").appendTo(i.body),n=t.css("display");t.remove();if(n==="none"||n===""){Pt=i.body.appendChild(Pt||v.extend(i.createElement("iframe"),{frameBorder:0,width:0,height:0}));if(!Ht||!Pt.createElement)Ht=(Pt.contentWindow||Pt.contentDocument).document,Ht.write("<!doctype html><html><body>"),Ht.close();t=Ht.body.appendChild(Ht.createElement(e)),n=Dt(t,"display"),i.body.removeChild(Pt)}return Wt[e]=n,n}function fn(e,t,n,r){var i;if(v.isArray(t))v.each(t,function(t,i){n||sn.test(e)?r(e,i):fn(e+"["+(typeof i=="object"?t:"")+"]",i,n,r)});else if(!n&&v.type(t)==="object")for(i in t)fn(e+"["+i+"]",t[i],n,r);else r(e,t)}function Cn(e){return function(t,n){typeof t!="string"&&(n=t,t="*");var r,i,s,o=t.toLowerCase().split(y),u=0,a=o.length;if(v.isFunction(n))for(;u<a;u++)r=o[u],s=/^\+/.test(r),s&&(r=r.substr(1)||"*"),i=e[r]=e[r]||[],i[s?"unshift":"push"](n)}}function kn(e,n,r,i,s,o){s=s||n.dataTypes[0],o=o||{},o[s]=!0;var u,a=e[s],f=0,l=a?a.length:0,c=e===Sn;for(;f<l&&(c||!u);f++)u=a[f](n,r,i),typeof u=="string"&&(!c||o[u]?u=t:(n.dataTypes.unshift(u),u=kn(e,n,r,i,u,o)));return(c||!u)&&!o["*"]&&(u=kn(e,n,r,i,"*",o)),u}function Ln(e,n){var r,i,s=v.ajaxSettings.flatOptions||{};for(r in n)n[r]!==t&&((s[r]?e:i||(i={}))[r]=n[r]);i&&v.extend(!0,e,i)}function An(e,n,r){var i,s,o,u,a=e.contents,f=e.dataTypes,l=e.responseFields;for(s in l)s in r&&(n[l[s]]=r[s]);while(f[0]==="*")f.shift(),i===t&&(i=e.mimeType||n.getResponseHeader("content-type"));if(i)for(s in a)if(a[s]&&a[s].test(i)){f.unshift(s);break}if(f[0]in r)o=f[0];else{for(s in r){if(!f[0]||e.converters[s+" "+f[0]]){o=s;break}u||(u=s)}o=o||u}if(o)return o!==f[0]&&f.unshift(o),r[o]}function On(e,t){var n,r,i,s,o=e.dataTypes.slice(),u=o[0],a={},f=0;e.dataFilter&&(t=e.dataFilter(t,e.dataType));if(o[1])for(n in e.converters)a[n.toLowerCase()]=e.converters[n];for(;i=o[++f];)if(i!=="*"){if(u!=="*"&&u!==i){n=a[u+" "+i]||a["* "+i];if(!n)for(r in a){s=r.split(" ");if(s[1]===i){n=a[u+" "+s[0]]||a["* "+s[0]];if(n){n===!0?n=a[r]:a[r]!==!0&&(i=s[0],o.splice(f--,0,i));break}}}if(n!==!0)if(n&&e["throws"])t=n(t);else try{t=n(t)}catch(l){return{state:"parsererror",error:n?l:"No conversion from "+u+" to "+i}}}u=i}return{state:"success",data:t}}function Fn(){try{return new e.XMLHttpRequest}catch(t){}}function In(){try{return new e.ActiveXObject("Microsoft.XMLHTTP")}catch(t){}}function $n(){return setTimeout(function(){qn=t},0),qn=v.now()}function Jn(e,t){v.each(t,function(t,n){var r=(Vn[t]||[]).concat(Vn["*"]),i=0,s=r.length;for(;i<s;i++)if(r[i].call(e,t,n))return})}function Kn(e,t,n){var r,i=0,s=0,o=Xn.length,u=v.Deferred().always(function(){delete a.elem}),a=function(){var t=qn||$n(),n=Math.max(0,f.startTime+f.duration-t),r=n/f.duration||0,i=1-r,s=0,o=f.tweens.length;for(;s<o;s++)f.tweens[s].run(i);return u.notifyWith(e,[f,i,n]),i<1&&o?n:(u.resolveWith(e,[f]),!1)},f=u.promise({elem:e,props:v.extend({},t),opts:v.extend(!0,{specialEasing:{}},n),originalProperties:t,originalOptions:n,startTime:qn||$n(),duration:n.duration,tweens:[],createTween:function(t,n,r){var i=v.Tween(e,f.opts,t,n,f.opts.specialEasing[t]||f.opts.easing);return f.tweens.push(i),i},stop:function(t){var n=0,r=t?f.tweens.length:0;for(;n<r;n++)f.tweens[n].run(1);return t?u.resolveWith(e,[f,t]):u.rejectWith(e,[f,t]),this}}),l=f.props;Qn(l,f.opts.specialEasing);for(;i<o;i++){r=Xn[i].call(f,e,l,f.opts);if(r)return r}return Jn(f,l),v.isFunction(f.opts.start)&&f.opts.start.call(e,f),v.fx.timer(v.extend(a,{anim:f,queue:f.opts.queue,elem:e})),f.progress(f.opts.progress).done(f.opts.done,f.opts.complete).fail(f.opts.fail).always(f.opts.always)}function Qn(e,t){var n,r,i,s,o;for(n in e){r=v.camelCase(n),i=t[r],s=e[n],v.isArray(s)&&(i=s[1],s=e[n]=s[0]),n!==r&&(e[r]=s,delete e[n]),o=v.cssHooks[r];if(o&&"expand"in o){s=o.expand(s),delete e[r];for(n in s)n in e||(e[n]=s[n],t[n]=i)}else t[r]=i}}function Gn(e,t,n){var r,i,s,o,u,a,f,l,c,h=this,p=e.style,d={},m=[],g=e.nodeType&&Gt(e);n.queue||(l=v._queueHooks(e,"fx"),l.unqueued==null&&(l.unqueued=0,c=l.empty.fire,l.empty.fire=function(){l.unqueued||c()}),l.unqueued++,h.always(function(){h.always(function(){l.unqueued--,v.queue(e,"fx").length||l.empty.fire()})})),e.nodeType===1&&("height"in t||"width"in t)&&(n.overflow=[p.overflow,p.overflowX,p.overflowY],v.css(e,"display")==="inline"&&v.css(e,"float")==="none"&&(!v.support.inlineBlockNeedsLayout||nn(e.nodeName)==="inline"?p.display="inline-block":p.zoom=1)),n.overflow&&(p.overflow="hidden",v.support.shrinkWrapBlocks||h.done(function(){p.overflow=n.overflow[0],p.overflowX=n.overflow[1],p.overflowY=n.overflow[2]}));for(r in t){s=t[r];if(Un.exec(s)){delete t[r],a=a||s==="toggle";if(s===(g?"hide":"show"))continue;m.push(r)}}o=m.length;if(o){u=v._data(e,"fxshow")||v._data(e,"fxshow",{}),"hidden"in u&&(g=u.hidden),a&&(u.hidden=!g),g?v(e).show():h.done(function(){v(e).hide()}),h.done(function(){var t;v.removeData(e,"fxshow",!0);for(t in d)v.style(e,t,d[t])});for(r=0;r<o;r++)i=m[r],f=h.createTween(i,g?u[i]:0),d[i]=u[i]||v.style(e,i),i in u||(u[i]=f.start,g&&(f.end=f.start,f.start=i==="width"||i==="height"?1:0))}}function Yn(e,t,n,r,i){return new Yn.prototype.init(e,t,n,r,i)}function Zn(e,t){var n,r={height:e},i=0;t=t?1:0;for(;i<4;i+=2-t)n=$t[i],r["margin"+n]=r["padding"+n]=e;return t&&(r.opacity=r.width=e),r}function tr(e){return v.isWindow(e)?e:e.nodeType===9?e.defaultView||e.parentWindow:!1}var n,r,i=e.document,s=e.location,o=e.navigator,u=e.jQuery,a=e.$,f=Array.prototype.push,l=Array.prototype.slice,c=Array.prototype.indexOf,h=Object.prototype.toString,p=Object.prototype.hasOwnProperty,d=String.prototype.trim,v=function(e,t){return new v.fn.init(e,t,n)},m=/[\-+]?(?:\d*\.|)\d+(?:[eE][\-+]?\d+|)/.source,g=/\S/,y=/\s+/,b=/^[\s\uFEFF\xA0]+|[\s\uFEFF\xA0]+$/g,w=/^(?:[^#<]*(<[\w\W]+>)[^>]*$|#([\w\-]*)$)/,E=/^<(\w+)\s*\/?>(?:<\/\1>|)$/,S=/^[\],:{}\s]*$/,x=/(?:^|:|,)(?:\s*\[)+/g,T=/\\(?:["\\\/bfnrt]|u[\da-fA-F]{4})/g,N=/"[^"\\\r\n]*"|true|false|null|-?(?:\d\d*\.|)\d+(?:[eE][\-+]?\d+|)/g,C=/^-ms-/,k=/-([\da-z])/gi,L=function(e,t){return(t+"").toUpperCase()},A=function(){i.addEventListener?(i.removeEventListener("DOMContentLoaded",A,!1),v.ready()):i.readyState==="complete"&&(i.detachEvent("onreadystatechange",A),v.ready())},O={};v.fn=v.prototype={constructor:v,init:function(e,n,r){var s,o,u,a;if(!e)return this;if(e.nodeType)return this.context=this[0]=e,this.length=1,this;if(typeof e=="string"){e.charAt(0)==="<"&&e.charAt(e.length-1)===">"&&e.length>=3?s=[null,e,null]:s=w.exec(e);if(s&&(s[1]||!n)){if(s[1])return n=n instanceof v?n[0]:n,a=n&&n.nodeType?n.ownerDocument||n:i,e=v.parseHTML(s[1],a,!0),E.test(s[1])&&v.isPlainObject(n)&&this.attr.call(e,n,!0),v.merge(this,e);o=i.getElementById(s[2]);if(o&&o.parentNode){if(o.id!==s[2])return r.find(e);this.length=1,this[0]=o}return this.context=i,this.selector=e,this}return!n||n.jquery?(n||r).find(e):this.constructor(n).find(e)}return v.isFunction(e)?r.ready(e):(e.selector!==t&&(this.selector=e.selector,this.context=e.context),v.makeArray(e,this))},selector:"",jquery:"1.8.3",length:0,size:function(){return this.length},toArray:function(){return l.call(this)},get:function(e){return e==null?this.toArray():e<0?this[this.length+e]:this[e]},pushStack:function(e,t,n){var r=v.merge(this.constructor(),e);return r.prevObject=this,r.context=this.context,t==="find"?r.selector=this.selector+(this.selector?" ":"")+n:t&&(r.selector=this.selector+"."+t+"("+n+")"),r},each:function(e,t){return v.each(this,e,t)},ready:function(e){return v.ready.promise().done(e),this},eq:function(e){return e=+e,e===-1?this.slice(e):this.slice(e,e+1)},first:function(){return this.eq(0)},last:function(){return this.eq(-1)},slice:function(){return this.pushStack(l.apply(this,arguments),"slice",l.call(arguments).join(","))},map:function(e){return this.pushStack(v.map(this,function(t,n){return e.call(t,n,t)}))},end:function(){return this.prevObject||this.constructor(null)},push:f,sort:[].sort,splice:[].splice},v.fn.init.prototype=v.fn,v.extend=v.fn.extend=function(){var e,n,r,i,s,o,u=arguments[0]||{},a=1,f=arguments.length,l=!1;typeof u=="boolean"&&(l=u,u=arguments[1]||{},a=2),typeof u!="object"&&!v.isFunction(u)&&(u={}),f===a&&(u=this,--a);for(;a<f;a++)if((e=arguments[a])!=null)for(n in e){r=u[n],i=e[n];if(u===i)continue;l&&i&&(v.isPlainObject(i)||(s=v.isArray(i)))?(s?(s=!1,o=r&&v.isArray(r)?r:[]):o=r&&v.isPlainObject(r)?r:{},u[n]=v.extend(l,o,i)):i!==t&&(u[n]=i)}return u},v.extend({noConflict:function(t){return e.$===v&&(e.$=a),t&&e.jQuery===v&&(e.jQuery=u),v},isReady:!1,readyWait:1,holdReady:function(e){e?v.readyWait++:v.ready(!0)},ready:function(e){if(e===!0?--v.readyWait:v.isReady)return;if(!i.body)return setTimeout(v.ready,1);v.isReady=!0;if(e!==!0&&--v.readyWait>0)return;r.resolveWith(i,[v]),v.fn.trigger&&v(i).trigger("ready").off("ready")},isFunction:function(e){return v.type(e)==="function"},isArray:Array.isArray||function(e){return v.type(e)==="array"},isWindow:function(e){return e!=null&&e==e.window},isNumeric:function(e){return!isNaN(parseFloat(e))&&isFinite(e)},type:function(e){return e==null?String(e):O[h.call(e)]||"object"},isPlainObject:function(e){if(!e||v.type(e)!=="object"||e.nodeType||v.isWindow(e))return!1;try{if(e.constructor&&!p.call(e,"constructor")&&!p.call(e.constructor.prototype,"isPrototypeOf"))return!1}catch(n){return!1}var r;for(r in e);return r===t||p.call(e,r)},isEmptyObject:function(e){var t;for(t in e)return!1;return!0},error:function(e){throw new Error(e)},parseHTML:function(e,t,n){var r;return!e||typeof e!="string"?null:(typeof t=="boolean"&&(n=t,t=0),t=t||i,(r=E.exec(e))?[t.createElement(r[1])]:(r=v.buildFragment([e],t,n?null:[]),v.merge([],(r.cacheable?v.clone(r.fragment):r.fragment).childNodes)))},parseJSON:function(t){if(!t||typeof t!="string")return null;t=v.trim(t);if(e.JSON&&e.JSON.parse)return e.JSON.parse(t);if(S.test(t.replace(T,"@").replace(N,"]").replace(x,"")))return(new Function("return "+t))();v.error("Invalid JSON: "+t)},parseXML:function(n){var r,i;if(!n||typeof n!="string")return null;try{e.DOMParser?(i=new DOMParser,r=i.parseFromString(n,"text/xml")):(r=new ActiveXObject("Microsoft.XMLDOM"),r.async="false",r.loadXML(n))}catch(s){r=t}return(!r||!r.documentElement||r.getElementsByTagName("parsererror").length)&&v.error("Invalid XML: "+n),r},noop:function(){},globalEval:function(t){t&&g.test(t)&&(e.execScript||function(t){e.eval.call(e,t)})(t)},camelCase:function(e){return e.replace(C,"ms-").replace(k,L)},nodeName:function(e,t){return e.nodeName&&e.nodeName.toLowerCase()===t.toLowerCase()},each:function(e,n,r){var i,s=0,o=e.length,u=o===t||v.isFunction(e);if(r){if(u){for(i in e)if(n.apply(e[i],r)===!1)break}else for(;s<o;)if(n.apply(e[s++],r)===!1)break}else if(u){for(i in e)if(n.call(e[i],i,e[i])===!1)break}else for(;s<o;)if(n.call(e[s],s,e[s++])===!1)break;return e},trim:d&&!d.call("\ufeff\u00a0")?function(e){return e==null?"":d.call(e)}:function(e){return e==null?"":(e+"").replace(b,"")},makeArray:function(e,t){var n,r=t||[];return e!=null&&(n=v.type(e),e.length==null||n==="string"||n==="function"||n==="regexp"||v.isWindow(e)?f.call(r,e):v.merge(r,e)),r},inArray:function(e,t,n){var r;if(t){if(c)return c.call(t,e,n);r=t.length,n=n?n<0?Math.max(0,r+n):n:0;for(;n<r;n++)if(n in t&&t[n]===e)return n}return-1},merge:function(e,n){var r=n.length,i=e.length,s=0;if(typeof r=="number")for(;s<r;s++)e[i++]=n[s];else while(n[s]!==t)e[i++]=n[s++];return e.length=i,e},grep:function(e,t,n){var r,i=[],s=0,o=e.length;n=!!n;for(;s<o;s++)r=!!t(e[s],s),n!==r&&i.push(e[s]);return i},map:function(e,n,r){var i,s,o=[],u=0,a=e.length,f=e instanceof v||a!==t&&typeof a=="number"&&(a>0&&e[0]&&e[a-1]||a===0||v.isArray(e));if(f)for(;u<a;u++)i=n(e[u],u,r),i!=null&&(o[o.length]=i);else for(s in e)i=n(e[s],s,r),i!=null&&(o[o.length]=i);return o.concat.apply([],o)},guid:1,proxy:function(e,n){var r,i,s;return typeof n=="string"&&(r=e[n],n=e,e=r),v.isFunction(e)?(i=l.call(arguments,2),s=function(){return e.apply(n,i.concat(l.call(arguments)))},s.guid=e.guid=e.guid||v.guid++,s):t},access:function(e,n,r,i,s,o,u){var a,f=r==null,l=0,c=e.length;if(r&&typeof r=="object"){for(l in r)v.access(e,n,l,r[l],1,o,i);s=1}else if(i!==t){a=u===t&&v.isFunction(i),f&&(a?(a=n,n=function(e,t,n){return a.call(v(e),n)}):(n.call(e,i),n=null));if(n)for(;l<c;l++)n(e[l],r,a?i.call(e[l],l,n(e[l],r)):i,u);s=1}return s?e:f?n.call(e):c?n(e[0],r):o},now:function(){return(new Date).getTime()}}),v.ready.promise=function(t){if(!r){r=v.Deferred();if(i.readyState==="complete")setTimeout(v.ready,1);else if(i.addEventListener)i.addEventListener("DOMContentLoaded",A,!1),e.addEventListener("load",v.ready,!1);else{i.attachEvent("onreadystatechange",A),e.attachEvent("onload",v.ready);var n=!1;try{n=e.frameElement==null&&i.documentElement}catch(s){}n&&n.doScroll&&function o(){if(!v.isReady){try{n.doScroll("left")}catch(e){return setTimeout(o,50)}v.ready()}}()}}return r.promise(t)},v.each("Boolean Number String Function Array Date RegExp Object".split(" "),function(e,t){O["[object "+t+"]"]=t.toLowerCase()}),n=v(i);var M={};v.Callbacks=function(e){e=typeof e=="string"?M[e]||_(e):v.extend({},e);var n,r,i,s,o,u,a=[],f=!e.once&&[],l=function(t){n=e.memory&&t,r=!0,u=s||0,s=0,o=a.length,i=!0;for(;a&&u<o;u++)if(a[u].apply(t[0],t[1])===!1&&e.stopOnFalse){n=!1;break}i=!1,a&&(f?f.length&&l(f.shift()):n?a=[]:c.disable())},c={add:function(){if(a){var t=a.length;(function r(t){v.each(t,function(t,n){var i=v.type(n);i==="function"?(!e.unique||!c.has(n))&&a.push(n):n&&n.length&&i!=="string"&&r(n)})})(arguments),i?o=a.length:n&&(s=t,l(n))}return this},remove:function(){return a&&v.each(arguments,function(e,t){var n;while((n=v.inArray(t,a,n))>-1)a.splice(n,1),i&&(n<=o&&o--,n<=u&&u--)}),this},has:function(e){return v.inArray(e,a)>-1},empty:function(){return a=[],this},disable:function(){return a=f=n=t,this},disabled:function(){return!a},lock:function(){return f=t,n||c.disable(),this},locked:function(){return!f},fireWith:function(e,t){return t=t||[],t=[e,t.slice?t.slice():t],a&&(!r||f)&&(i?f.push(t):l(t)),this},fire:function(){return c.fireWith(this,arguments),this},fired:function(){return!!r}};return c},v.extend({Deferred:function(e){var t=[["resolve","done",v.Callbacks("once memory"),"resolved"],["reject","fail",v.Callbacks("once memory"),"rejected"],["notify","progress",v.Callbacks("memory")]],n="pending",r={state:function(){return n},always:function(){return i.done(arguments).fail(arguments),this},then:function(){var e=arguments;return v.Deferred(function(n){v.each(t,function(t,r){var s=r[0],o=e[t];i[r[1]](v.isFunction(o)?function(){var e=o.apply(this,arguments);e&&v.isFunction(e.promise)?e.promise().done(n.resolve).fail(n.reject).progress(n.notify):n[s+"With"](this===i?n:this,[e])}:n[s])}),e=null}).promise()},promise:function(e){return e!=null?v.extend(e,r):r}},i={};return r.pipe=r.then,v.each(t,function(e,s){var o=s[2],u=s[3];r[s[1]]=o.add,u&&o.add(function(){n=u},t[e^1][2].disable,t[2][2].lock),i[s[0]]=o.fire,i[s[0]+"With"]=o.fireWith}),r.promise(i),e&&e.call(i,i),i},when:function(e){var t=0,n=l.call(arguments),r=n.length,i=r!==1||e&&v.isFunction(e.promise)?r:0,s=i===1?e:v.Deferred(),o=function(e,t,n){return function(r){t[e]=this,n[e]=arguments.length>1?l.call(arguments):r,n===u?s.notifyWith(t,n):--i||s.resolveWith(t,n)}},u,a,f;if(r>1){u=new Array(r),a=new Array(r),f=new Array(r);for(;t<r;t++)n[t]&&v.isFunction(n[t].promise)?n[t].promise().done(o(t,f,n)).fail(s.reject).progress(o(t,a,u)):--i}return i||s.resolveWith(f,n),s.promise()}}),v.support=function(){var t,n,r,s,o,u,a,f,l,c,h,p=i.createElement("div");p.setAttribute("className","t"),p.innerHTML="  <link/><table></table><a href='/a'>a</a><input type='checkbox'/>",n=p.getElementsByTagName("*"),r=p.getElementsByTagName("a")[0];if(!n||!r||!n.length)return{};s=i.createElement("select"),o=s.appendChild(i.createElement("option")),u=p.getElementsByTagName("input")[0],r.style.cssText="top:1px;float:left;opacity:.5",t={leadingWhitespace:p.firstChild.nodeType===3,tbody:!p.getElementsByTagName("tbody").length,htmlSerialize:!!p.getElementsByTagName("link").length,style:/top/.test(r.getAttribute("style")),hrefNormalized:r.getAttribute("href")==="/a",opacity:/^0.5/.test(r.style.opacity),cssFloat:!!r.style.cssFloat,checkOn:u.value==="on",optSelected:o.selected,getSetAttribute:p.className!=="t",enctype:!!i.createElement("form").enctype,html5Clone:i.createElement("nav").cloneNode(!0).outerHTML!=="<:nav></:nav>",boxModel:i.compatMode==="CSS1Compat",submitBubbles:!0,changeBubbles:!0,focusinBubbles:!1,deleteExpando:!0,noCloneEvent:!0,inlineBlockNeedsLayout:!1,shrinkWrapBlocks:!1,reliableMarginRight:!0,boxSizingReliable:!0,pixelPosition:!1},u.checked=!0,t.noCloneChecked=u.cloneNode(!0).checked,s.disabled=!0,t.optDisabled=!o.disabled;try{delete p.test}catch(d){t.deleteExpando=!1}!p.addEventListener&&p.attachEvent&&p.fireEvent&&(p.attachEvent("onclick",h=function(){t.noCloneEvent=!1}),p.cloneNode(!0).fireEvent("onclick"),p.detachEvent("onclick",h)),u=i.createElement("input"),u.value="t",u.setAttribute("type","radio"),t.radioValue=u.value==="t",u.setAttribute("checked","checked"),u.setAttribute("name","t"),p.appendChild(u),a=i.createDocumentFragment(),a.appendChild(p.lastChild),t.checkClone=a.cloneNode(!0).cloneNode(!0).lastChild.checked,t.appendChecked=u.checked,a.removeChild(u),a.appendChild(p);if(p.attachEvent)for(l in{submit:!0,change:!0,focusin:!0})f="on"+l,c=f in p,c||(p.setAttribute(f,"return;"),c=typeof p[f]=="function"),t[l+"Bubbles"]=c;return v(function(){var n,r,s,o,u="padding:0;margin:0;border:0;display:block;overflow:hidden;",a=i.getElementsByTagName("body")[0];if(!a)return;n=i.createElement("div"),n.style.cssText="visibility:hidden;border:0;width:0;height:0;position:static;top:0;margin-top:1px",a.insertBefore(n,a.firstChild),r=i.createElement("div"),n.appendChild(r),r.innerHTML="<table><tr><td></td><td>t</td></tr></table>",s=r.getElementsByTagName("td"),s[0].style.cssText="padding:0;margin:0;border:0;display:none",c=s[0].offsetHeight===0,s[0].style.display="",s[1].style.display="none",t.reliableHiddenOffsets=c&&s[0].offsetHeight===0,r.innerHTML="",r.style.cssText="box-sizing:border-box;-moz-box-sizing:border-box;-webkit-box-sizing:border-box;padding:1px;border:1px;display:block;width:4px;margin-top:1%;position:absolute;top:1%;",t.boxSizing=r.offsetWidth===4,t.doesNotIncludeMarginInBodyOffset=a.offsetTop!==1,e.getComputedStyle&&(t.pixelPosition=(e.getComputedStyle(r,null)||{}).top!=="1%",t.boxSizingReliable=(e.getComputedStyle(r,null)||{width:"4px"}).width==="4px",o=i.createElement("div"),o.style.cssText=r.style.cssText=u,o.style.marginRight=o.style.width="0",r.style.width="1px",r.appendChild(o),t.reliableMarginRight=!parseFloat((e.getComputedStyle(o,null)||{}).marginRight)),typeof r.style.zoom!="undefined"&&(r.innerHTML="",r.style.cssText=u+"width:1px;padding:1px;display:inline;zoom:1",t.inlineBlockNeedsLayout=r.offsetWidth===3,r.style.display="block",r.style.overflow="visible",r.innerHTML="<div></div>",r.firstChild.style.width="5px",t.shrinkWrapBlocks=r.offsetWidth!==3,n.style.zoom=1),a.removeChild(n),n=r=s=o=null}),a.removeChild(p),n=r=s=o=u=a=p=null,t}();var D=/(?:\{[\s\S]*\}|\[[\s\S]*\])$/,P=/([A-Z])/g;v.extend({cache:{},deletedIds:[],uuid:0,expando:"jQuery"+(v.fn.jquery+Math.random()).replace(/\D/g,""),noData:{embed:!0,object:"clsid:D27CDB6E-AE6D-11cf-96B8-444553540000",applet:!0},hasData:function(e){return e=e.nodeType?v.cache[e[v.expando]]:e[v.expando],!!e&&!B(e)},data:function(e,n,r,i){if(!v.acceptData(e))return;var s,o,u=v.expando,a=typeof n=="string",f=e.nodeType,l=f?v.cache:e,c=f?e[u]:e[u]&&u;if((!c||!l[c]||!i&&!l[c].data)&&a&&r===t)return;c||(f?e[u]=c=v.deletedIds.pop()||v.guid++:c=u),l[c]||(l[c]={},f||(l[c].toJSON=v.noop));if(typeof n=="object"||typeof n=="function")i?l[c]=v.extend(l[c],n):l[c].data=v.extend(l[c].data,n);return s=l[c],i||(s.data||(s.data={}),s=s.data),r!==t&&(s[v.camelCase(n)]=r),a?(o=s[n],o==null&&(o=s[v.camelCase(n)])):o=s,o},removeData:function(e,t,n){if(!v.acceptData(e))return;var r,i,s,o=e.nodeType,u=o?v.cache:e,a=o?e[v.expando]:v.expando;if(!u[a])return;if(t){r=n?u[a]:u[a].data;if(r){v.isArray(t)||(t in r?t=[t]:(t=v.camelCase(t),t in r?t=[t]:t=t.split(" ")));for(i=0,s=t.length;i<s;i++)delete r[t[i]];if(!(n?B:v.isEmptyObject)(r))return}}if(!n){delete u[a].data;if(!B(u[a]))return}o?v.cleanData([e],!0):v.support.deleteExpando||u!=u.window?delete u[a]:u[a]=null},_data:function(e,t,n){return v.data(e,t,n,!0)},acceptData:function(e){var t=e.nodeName&&v.noData[e.nodeName.toLowerCase()];return!t||t!==!0&&e.getAttribute("classid")===t}}),v.fn.extend({data:function(e,n){var r,i,s,o,u,a=this[0],f=0,l=null;if(e===t){if(this.length){l=v.data(a);if(a.nodeType===1&&!v._data(a,"parsedAttrs")){s=a.attributes;for(u=s.length;f<u;f++)o=s[f].name,o.indexOf("data-")||(o=v.camelCase(o.substring(5)),H(a,o,l[o]));v._data(a,"parsedAttrs",!0)}}return l}return typeof e=="object"?this.each(function(){v.data(this,e)}):(r=e.split(".",2),r[1]=r[1]?"."+r[1]:"",i=r[1]+"!",v.access(this,function(n){if(n===t)return l=this.triggerHandler("getData"+i,[r[0]]),l===t&&a&&(l=v.data(a,e),l=H(a,e,l)),l===t&&r[1]?this.data(r[0]):l;r[1]=n,this.each(function(){var t=v(this);t.triggerHandler("setData"+i,r),v.data(this,e,n),t.triggerHandler("changeData"+i,r)})},null,n,arguments.length>1,null,!1))},removeData:function(e){return this.each(function(){v.removeData(this,e)})}}),v.extend({queue:function(e,t,n){var r;if(e)return t=(t||"fx")+"queue",r=v._data(e,t),n&&(!r||v.isArray(n)?r=v._data(e,t,v.makeArray(n)):r.push(n)),r||[]},dequeue:function(e,t){t=t||"fx";var n=v.queue(e,t),r=n.length,i=n.shift(),s=v._queueHooks(e,t),o=function(){v.dequeue(e,t)};i==="inprogress"&&(i=n.shift(),r--),i&&(t==="fx"&&n.unshift("inprogress"),delete s.stop,i.call(e,o,s)),!r&&s&&s.empty.fire()},_queueHooks:function(e,t){var n=t+"queueHooks";return v._data(e,n)||v._data(e,n,{empty:v.Callbacks("once memory").add(function(){v.removeData(e,t+"queue",!0),v.removeData(e,n,!0)})})}}),v.fn.extend({queue:function(e,n){var r=2;return typeof e!="string"&&(n=e,e="fx",r--),arguments.length<r?v.queue(this[0],e):n===t?this:this.each(function(){var t=v.queue(this,e,n);v._queueHooks(this,e),e==="fx"&&t[0]!=="inprogress"&&v.dequeue(this,e)})},dequeue:function(e){return this.each(function(){v.dequeue(this,e)})},delay:function(e,t){return e=v.fx?v.fx.speeds[e]||e:e,t=t||"fx",this.queue(t,function(t,n){var r=setTimeout(t,e);n.stop=function(){clearTimeout(r)}})},clearQueue:function(e){return this.queue(e||"fx",[])},promise:function(e,n){var r,i=1,s=v.Deferred(),o=this,u=this.length,a=function(){--i||s.resolveWith(o,[o])};typeof e!="string"&&(n=e,e=t),e=e||"fx";while(u--)r=v._data(o[u],e+"queueHooks"),r&&r.empty&&(i++,r.empty.add(a));return a(),s.promise(n)}});var j,F,I,q=/[\t\r\n]/g,R=/\r/g,U=/^(?:button|input)$/i,z=/^(?:button|input|object|select|textarea)$/i,W=/^a(?:rea|)$/i,X=/^(?:autofocus|autoplay|async|checked|controls|defer|disabled|hidden|loop|multiple|open|readonly|required|scoped|selected)$/i,V=v.support.getSetAttribute;v.fn.extend({attr:function(e,t){return v.access(this,v.attr,e,t,arguments.length>1)},removeAttr:function(e){return this.each(function(){v.removeAttr(this,e)})},prop:function(e,t){return v.access(this,v.prop,e,t,arguments.length>1)},removeProp:function(e){return e=v.propFix[e]||e,this.each(function(){try{this[e]=t,delete this[e]}catch(n){}})},addClass:function(e){var t,n,r,i,s,o,u;if(v.isFunction(e))return this.each(function(t){v(this).addClass(e.call(this,t,this.className))});if(e&&typeof e=="string"){t=e.split(y);for(n=0,r=this.length;n<r;n++){i=this[n];if(i.nodeType===1)if(!i.className&&t.length===1)i.className=e;else{s=" "+i.className+" ";for(o=0,u=t.length;o<u;o++)s.indexOf(" "+t[o]+" ")<0&&(s+=t[o]+" ");i.className=v.trim(s)}}}return this},removeClass:function(e){var n,r,i,s,o,u,a;if(v.isFunction(e))return this.each(function(t){v(this).removeClass(e.call(this,t,this.className))});if(e&&typeof e=="string"||e===t){n=(e||"").split(y);for(u=0,a=this.length;u<a;u++){i=this[u];if(i.nodeType===1&&i.className){r=(" "+i.className+" ").replace(q," ");for(s=0,o=n.length;s<o;s++)while(r.indexOf(" "+n[s]+" ")>=0)r=r.replace(" "+n[s]+" "," ");i.className=e?v.trim(r):""}}}return this},toggleClass:function(e,t){var n=typeof e,r=typeof t=="boolean";return v.isFunction(e)?this.each(function(n){v(this).toggleClass(e.call(this,n,this.className,t),t)}):this.each(function(){if(n==="string"){var i,s=0,o=v(this),u=t,a=e.split(y);while(i=a[s++])u=r?u:!o.hasClass(i),o[u?"addClass":"removeClass"](i)}else if(n==="undefined"||n==="boolean")this.className&&v._data(this,"__className__",this.className),this.className=this.className||e===!1?"":v._data(this,"__className__")||""})},hasClass:function(e){var t=" "+e+" ",n=0,r=this.length;for(;n<r;n++)if(this[n].nodeType===1&&(" "+this[n].className+" ").replace(q," ").indexOf(t)>=0)return!0;return!1},val:function(e){var n,r,i,s=this[0];if(!arguments.length){if(s)return n=v.valHooks[s.type]||v.valHooks[s.nodeName.toLowerCase()],n&&"get"in n&&(r=n.get(s,"value"))!==t?r:(r=s.value,typeof r=="string"?r.replace(R,""):r==null?"":r);return}return i=v.isFunction(e),this.each(function(r){var s,o=v(this);if(this.nodeType!==1)return;i?s=e.call(this,r,o.val()):s=e,s==null?s="":typeof s=="number"?s+="":v.isArray(s)&&(s=v.map(s,function(e){return e==null?"":e+""})),n=v.valHooks[this.type]||v.valHooks[this.nodeName.toLowerCase()];if(!n||!("set"in n)||n.set(this,s,"value")===t)this.value=s})}}),v.extend({valHooks:{option:{get:function(e){var t=e.attributes.value;return!t||t.specified?e.value:e.text}},select:{get:function(e){var t,n,r=e.options,i=e.selectedIndex,s=e.type==="select-one"||i<0,o=s?null:[],u=s?i+1:r.length,a=i<0?u:s?i:0;for(;a<u;a++){n=r[a];if((n.selected||a===i)&&(v.support.optDisabled?!n.disabled:n.getAttribute("disabled")===null)&&(!n.parentNode.disabled||!v.nodeName(n.parentNode,"optgroup"))){t=v(n).val();if(s)return t;o.push(t)}}return o},set:function(e,t){var n=v.makeArray(t);return v(e).find("option").each(function(){this.selected=v.inArray(v(this).val(),n)>=0}),n.length||(e.selectedIndex=-1),n}}},attrFn:{},attr:function(e,n,r,i){var s,o,u,a=e.nodeType;if(!e||a===3||a===8||a===2)return;if(i&&v.isFunction(v.fn[n]))return v(e)[n](r);if(typeof e.getAttribute=="undefined")return v.prop(e,n,r);u=a!==1||!v.isXMLDoc(e),u&&(n=n.toLowerCase(),o=v.attrHooks[n]||(X.test(n)?F:j));if(r!==t){if(r===null){v.removeAttr(e,n);return}return o&&"set"in o&&u&&(s=o.set(e,r,n))!==t?s:(e.setAttribute(n,r+""),r)}return o&&"get"in o&&u&&(s=o.get(e,n))!==null?s:(s=e.getAttribute(n),s===null?t:s)},removeAttr:function(e,t){var n,r,i,s,o=0;if(t&&e.nodeType===1){r=t.split(y);for(;o<r.length;o++)i=r[o],i&&(n=v.propFix[i]||i,s=X.test(i),s||v.attr(e,i,""),e.removeAttribute(V?i:n),s&&n in e&&(e[n]=!1))}},attrHooks:{type:{set:function(e,t){if(U.test(e.nodeName)&&e.parentNode)v.error("type property can't be changed");else if(!v.support.radioValue&&t==="radio"&&v.nodeName(e,"input")){var n=e.value;return e.setAttribute("type",t),n&&(e.value=n),t}}},value:{get:function(e,t){return j&&v.nodeName(e,"button")?j.get(e,t):t in e?e.value:null},set:function(e,t,n){if(j&&v.nodeName(e,"button"))return j.set(e,t,n);e.value=t}}},propFix:{tabindex:"tabIndex",readonly:"readOnly","for":"htmlFor","class":"className",maxlength:"maxLength",cellspacing:"cellSpacing",cellpadding:"cellPadding",rowspan:"rowSpan",colspan:"colSpan",usemap:"useMap",frameborder:"frameBorder",contenteditable:"contentEditable"},prop:function(e,n,r){var i,s,o,u=e.nodeType;if(!e||u===3||u===8||u===2)return;return o=u!==1||!v.isXMLDoc(e),o&&(n=v.propFix[n]||n,s=v.propHooks[n]),r!==t?s&&"set"in s&&(i=s.set(e,r,n))!==t?i:e[n]=r:s&&"get"in s&&(i=s.get(e,n))!==null?i:e[n]},propHooks:{tabIndex:{get:function(e){var n=e.getAttributeNode("tabindex");return n&&n.specified?parseInt(n.value,10):z.test(e.nodeName)||W.test(e.nodeName)&&e.href?0:t}}}}),F={get:function(e,n){var r,i=v.prop(e,n);return i===!0||typeof i!="boolean"&&(r=e.getAttributeNode(n))&&r.nodeValue!==!1?n.toLowerCase():t},set:function(e,t,n){var r;return t===!1?v.removeAttr(e,n):(r=v.propFix[n]||n,r in e&&(e[r]=!0),e.setAttribute(n,n.toLowerCase())),n}},V||(I={name:!0,id:!0,coords:!0},j=v.valHooks.button={get:function(e,n){var r;return r=e.getAttributeNode(n),r&&(I[n]?r.value!=="":r.specified)?r.value:t},set:function(e,t,n){var r=e.getAttributeNode(n);return r||(r=i.createAttribute(n),e.setAttributeNode(r)),r.value=t+""}},v.each(["width","height"],function(e,t){v.attrHooks[t]=v.extend(v.attrHooks[t],{set:function(e,n){if(n==="")return e.setAttribute(t,"auto"),n}})}),v.attrHooks.contenteditable={get:j.get,set:function(e,t,n){t===""&&(t="false"),j.set(e,t,n)}}),v.support.hrefNormalized||v.each(["href","src","width","height"],function(e,n){v.attrHooks[n]=v.extend(v.attrHooks[n],{get:function(e){var r=e.getAttribute(n,2);return r===null?t:r}})}),v.support.style||(v.attrHooks.style={get:function(e){return e.style.cssText.toLowerCase()||t},set:function(e,t){return e.style.cssText=t+""}}),v.support.optSelected||(v.propHooks.selected=v.extend(v.propHooks.selected,{get:function(e){var t=e.parentNode;return t&&(t.selectedIndex,t.parentNode&&t.parentNode.selectedIndex),null}})),v.support.enctype||(v.propFix.enctype="encoding"),v.support.checkOn||v.each(["radio","checkbox"],function(){v.valHooks[this]={get:function(e){return e.getAttribute("value")===null?"on":e.value}}}),v.each(["radio","checkbox"],function(){v.valHooks[this]=v.extend(v.valHooks[this],{set:function(e,t){if(v.isArray(t))return e.checked=v.inArray(v(e).val(),t)>=0}})});var $=/^(?:textarea|input|select)$/i,J=/^([^\.]*|)(?:\.(.+)|)$/,K=/(?:^|\s)hover(\.\S+|)\b/,Q=/^key/,G=/^(?:mouse|contextmenu)|click/,Y=/^(?:focusinfocus|focusoutblur)$/,Z=function(e){return v.event.special.hover?e:e.replace(K,"mouseenter$1 mouseleave$1")};v.event={add:function(e,n,r,i,s){var o,u,a,f,l,c,h,p,d,m,g;if(e.nodeType===3||e.nodeType===8||!n||!r||!(o=v._data(e)))return;r.handler&&(d=r,r=d.handler,s=d.selector),r.guid||(r.guid=v.guid++),a=o.events,a||(o.events=a={}),u=o.handle,u||(o.handle=u=function(e){return typeof v=="undefined"||!!e&&v.event.triggered===e.type?t:v.event.dispatch.apply(u.elem,arguments)},u.elem=e),n=v.trim(Z(n)).split(" ");for(f=0;f<n.length;f++){l=J.exec(n[f])||[],c=l[1],h=(l[2]||"").split(".").sort(),g=v.event.special[c]||{},c=(s?g.delegateType:g.bindType)||c,g=v.event.special[c]||{},p=v.extend({type:c,origType:l[1],data:i,handler:r,guid:r.guid,selector:s,needsContext:s&&v.expr.match.needsContext.test(s),namespace:h.join(".")},d),m=a[c];if(!m){m=a[c]=[],m.delegateCount=0;if(!g.setup||g.setup.call(e,i,h,u)===!1)e.addEventListener?e.addEventListener(c,u,!1):e.attachEvent&&e.attachEvent("on"+c,u)}g.add&&(g.add.call(e,p),p.handler.guid||(p.handler.guid=r.guid)),s?m.splice(m.delegateCount++,0,p):m.push(p),v.event.global[c]=!0}e=null},global:{},remove:function(e,t,n,r,i){var s,o,u,a,f,l,c,h,p,d,m,g=v.hasData(e)&&v._data(e);if(!g||!(h=g.events))return;t=v.trim(Z(t||"")).split(" ");for(s=0;s<t.length;s++){o=J.exec(t[s])||[],u=a=o[1],f=o[2];if(!u){for(u in h)v.event.remove(e,u+t[s],n,r,!0);continue}p=v.event.special[u]||{},u=(r?p.delegateType:p.bindType)||u,d=h[u]||[],l=d.length,f=f?new RegExp("(^|\\.)"+f.split(".").sort().join("\\.(?:.*\\.|)")+"(\\.|$)"):null;for(c=0;c<d.length;c++)m=d[c],(i||a===m.origType)&&(!n||n.guid===m.guid)&&(!f||f.test(m.namespace))&&(!r||r===m.selector||r==="**"&&m.selector)&&(d.splice(c--,1),m.selector&&d.delegateCount--,p.remove&&p.remove.call(e,m));d.length===0&&l!==d.length&&((!p.teardown||p.teardown.call(e,f,g.handle)===!1)&&v.removeEvent(e,u,g.handle),delete h[u])}v.isEmptyObject(h)&&(delete g.handle,v.removeData(e,"events",!0))},customEvent:{getData:!0,setData:!0,changeData:!0},trigger:function(n,r,s,o){if(!s||s.nodeType!==3&&s.nodeType!==8){var u,a,f,l,c,h,p,d,m,g,y=n.type||n,b=[];if(Y.test(y+v.event.triggered))return;y.indexOf("!")>=0&&(y=y.slice(0,-1),a=!0),y.indexOf(".")>=0&&(b=y.split("."),y=b.shift(),b.sort());if((!s||v.event.customEvent[y])&&!v.event.global[y])return;n=typeof n=="object"?n[v.expando]?n:new v.Event(y,n):new v.Event(y),n.type=y,n.isTrigger=!0,n.exclusive=a,n.namespace=b.join("."),n.namespace_re=n.namespace?new RegExp("(^|\\.)"+b.join("\\.(?:.*\\.|)")+"(\\.|$)"):null,h=y.indexOf(":")<0?"on"+y:"";if(!s){u=v.cache;for(f in u)u[f].events&&u[f].events[y]&&v.event.trigger(n,r,u[f].handle.elem,!0);return}n.result=t,n.target||(n.target=s),r=r!=null?v.makeArray(r):[],r.unshift(n),p=v.event.special[y]||{};if(p.trigger&&p.trigger.apply(s,r)===!1)return;m=[[s,p.bindType||y]];if(!o&&!p.noBubble&&!v.isWindow(s)){g=p.delegateType||y,l=Y.test(g+y)?s:s.parentNode;for(c=s;l;l=l.parentNode)m.push([l,g]),c=l;c===(s.ownerDocument||i)&&m.push([c.defaultView||c.parentWindow||e,g])}for(f=0;f<m.length&&!n.isPropagationStopped();f++)l=m[f][0],n.type=m[f][1],d=(v._data(l,"events")||{})[n.type]&&v._data(l,"handle"),d&&d.apply(l,r),d=h&&l[h],d&&v.acceptData(l)&&d.apply&&d.apply(l,r)===!1&&n.preventDefault();return n.type=y,!o&&!n.isDefaultPrevented()&&(!p._default||p._default.apply(s.ownerDocument,r)===!1)&&(y!=="click"||!v.nodeName(s,"a"))&&v.acceptData(s)&&h&&s[y]&&(y!=="focus"&&y!=="blur"||n.target.offsetWidth!==0)&&!v.isWindow(s)&&(c=s[h],c&&(s[h]=null),v.event.triggered=y,s[y](),v.event.triggered=t,c&&(s[h]=c)),n.result}return},dispatch:function(n){n=v.event.fix(n||e.event);var r,i,s,o,u,a,f,c,h,p,d=(v._data(this,"events")||{})[n.type]||[],m=d.delegateCount,g=l.call(arguments),y=!n.exclusive&&!n.namespace,b=v.event.special[n.type]||{},w=[];g[0]=n,n.delegateTarget=this;if(b.preDispatch&&b.preDispatch.call(this,n)===!1)return;if(m&&(!n.button||n.type!=="click"))for(s=n.target;s!=this;s=s.parentNode||this)if(s.disabled!==!0||n.type!=="click"){u={},f=[];for(r=0;r<m;r++)c=d[r],h=c.selector,u[h]===t&&(u[h]=c.needsContext?v(h,this).index(s)>=0:v.find(h,this,null,[s]).length),u[h]&&f.push(c);f.length&&w.push({elem:s,matches:f})}d.length>m&&w.push({elem:this,matches:d.slice(m)});for(r=0;r<w.length&&!n.isPropagationStopped();r++){a=w[r],n.currentTarget=a.elem;for(i=0;i<a.matches.length&&!n.isImmediatePropagationStopped();i++){c=a.matches[i];if(y||!n.namespace&&!c.namespace||n.namespace_re&&n.namespace_re.test(c.namespace))n.data=c.data,n.handleObj=c,o=((v.event.special[c.origType]||{}).handle||c.handler).apply(a.elem,g),o!==t&&(n.result=o,o===!1&&(n.preventDefault(),n.stopPropagation()))}}return b.postDispatch&&b.postDispatch.call(this,n),n.result},props:"attrChange attrName relatedNode srcElement altKey bubbles cancelable ctrlKey currentTarget eventPhase metaKey relatedTarget shiftKey target timeStamp view which".split(" "),fixHooks:{},keyHooks:{props:"char charCode key keyCode".split(" "),filter:function(e,t){return e.which==null&&(e.which=t.charCode!=null?t.charCode:t.keyCode),e}},mouseHooks:{props:"button buttons clientX clientY fromElement offsetX offsetY pageX pageY screenX screenY toElement".split(" "),filter:function(e,n){var r,s,o,u=n.button,a=n.fromElement;return e.pageX==null&&n.clientX!=null&&(r=e.target.ownerDocument||i,s=r.documentElement,o=r.body,e.pageX=n.clientX+(s&&s.scrollLeft||o&&o.scrollLeft||0)-(s&&s.clientLeft||o&&o.clientLeft||0),e.pageY=n.clientY+(s&&s.scrollTop||o&&o.scrollTop||0)-(s&&s.clientTop||o&&o.clientTop||0)),!e.relatedTarget&&a&&(e.relatedTarget=a===e.target?n.toElement:a),!e.which&&u!==t&&(e.which=u&1?1:u&2?3:u&4?2:0),e}},fix:function(e){if(e[v.expando])return e;var t,n,r=e,s=v.event.fixHooks[e.type]||{},o=s.props?this.props.concat(s.props):this.props;e=v.Event(r);for(t=o.length;t;)n=o[--t],e[n]=r[n];return e.target||(e.target=r.srcElement||i),e.target.nodeType===3&&(e.target=e.target.parentNode),e.metaKey=!!e.metaKey,s.filter?s.filter(e,r):e},special:{load:{noBubble:!0},focus:{delegateType:"focusin"},blur:{delegateType:"focusout"},beforeunload:{setup:function(e,t,n){v.isWindow(this)&&(this.onbeforeunload=n)},teardown:function(e,t){this.onbeforeunload===t&&(this.onbeforeunload=null)}}},simulate:function(e,t,n,r){var i=v.extend(new v.Event,n,{type:e,isSimulated:!0,originalEvent:{}});r?v.event.trigger(i,null,t):v.event.dispatch.call(t,i),i.isDefaultPrevented()&&n.preventDefault()}},v.event.handle=v.event.dispatch,v.removeEvent=i.removeEventListener?function(e,t,n){e.removeEventListener&&e.removeEventListener(t,n,!1)}:function(e,t,n){var r="on"+t;e.detachEvent&&(typeof e[r]=="undefined"&&(e[r]=null),e.detachEvent(r,n))},v.Event=function(e,t){if(!(this instanceof v.Event))return new v.Event(e,t);e&&e.type?(this.originalEvent=e,this.type=e.type,this.isDefaultPrevented=e.defaultPrevented||e.returnValue===!1||e.getPreventDefault&&e.getPreventDefault()?tt:et):this.type=e,t&&v.extend(this,t),this.timeStamp=e&&e.timeStamp||v.now(),this[v.expando]=!0},v.Event.prototype={preventDefault:function(){this.isDefaultPrevented=tt;var e=this.originalEvent;if(!e)return;e.preventDefault?e.preventDefault():e.returnValue=!1},stopPropagation:function(){this.isPropagationStopped=tt;var e=this.originalEvent;if(!e)return;e.stopPropagation&&e.stopPropagation(),e.cancelBubble=!0},stopImmediatePropagation:function(){this.isImmediatePropagationStopped=tt,this.stopPropagation()},isDefaultPrevented:et,isPropagationStopped:et,isImmediatePropagationStopped:et},v.each({mouseenter:"mouseover",mouseleave:"mouseout"},function(e,t){v.event.special[e]={delegateType:t,bindType:t,handle:function(e){var n,r=this,i=e.relatedTarget,s=e.handleObj,o=s.selector;if(!i||i!==r&&!v.contains(r,i))e.type=s.origType,n=s.handler.apply(this,arguments),e.type=t;return n}}}),v.support.submitBubbles||(v.event.special.submit={setup:function(){if(v.nodeName(this,"form"))return!1;v.event.add(this,"click._submit keypress._submit",function(e){var n=e.target,r=v.nodeName(n,"input")||v.nodeName(n,"button")?n.form:t;r&&!v._data(r,"_submit_attached")&&(v.event.add(r,"submit._submit",function(e){e._submit_bubble=!0}),v._data(r,"_submit_attached",!0))})},postDispatch:function(e){e._submit_bubble&&(delete e._submit_bubble,this.parentNode&&!e.isTrigger&&v.event.simulate("submit",this.parentNode,e,!0))},teardown:function(){if(v.nodeName(this,"form"))return!1;v.event.remove(this,"._submit")}}),v.support.changeBubbles||(v.event.special.change={setup:function(){if($.test(this.nodeName)){if(this.type==="checkbox"||this.type==="radio")v.event.add(this,"propertychange._change",function(e){e.originalEvent.propertyName==="checked"&&(this._just_changed=!0)}),v.event.add(this,"click._change",function(e){this._just_changed&&!e.isTrigger&&(this._just_changed=!1),v.event.simulate("change",this,e,!0)});return!1}v.event.add(this,"beforeactivate._change",function(e){var t=e.target;$.test(t.nodeName)&&!v._data(t,"_change_attached")&&(v.event.add(t,"change._change",function(e){this.parentNode&&!e.isSimulated&&!e.isTrigger&&v.event.simulate("change",this.parentNode,e,!0)}),v._data(t,"_change_attached",!0))})},handle:function(e){var t=e.target;if(this!==t||e.isSimulated||e.isTrigger||t.type!=="radio"&&t.type!=="checkbox")return e.handleObj.handler.apply(this,arguments)},teardown:function(){return v.event.remove(this,"._change"),!$.test(this.nodeName)}}),v.support.focusinBubbles||v.each({focus:"focusin",blur:"focusout"},function(e,t){var n=0,r=function(e){v.event.simulate(t,e.target,v.event.fix(e),!0)};v.event.special[t]={setup:function(){n++===0&&i.addEventListener(e,r,!0)},teardown:function(){--n===0&&i.removeEventListener(e,r,!0)}}}),v.fn.extend({on:function(e,n,r,i,s){var o,u;if(typeof e=="object"){typeof n!="string"&&(r=r||n,n=t);for(u in e)this.on(u,n,r,e[u],s);return this}r==null&&i==null?(i=n,r=n=t):i==null&&(typeof n=="string"?(i=r,r=t):(i=r,r=n,n=t));if(i===!1)i=et;else if(!i)return this;return s===1&&(o=i,i=function(e){return v().off(e),o.apply(this,arguments)},i.guid=o.guid||(o.guid=v.guid++)),this.each(function(){v.event.add(this,e,i,r,n)})},one:function(e,t,n,r){return this.on(e,t,n,r,1)},off:function(e,n,r){var i,s;if(e&&e.preventDefault&&e.handleObj)return i=e.handleObj,v(e.delegateTarget).off(i.namespace?i.origType+"."+i.namespace:i.origType,i.selector,i.handler),this;if(typeof e=="object"){for(s in e)this.off(s,n,e[s]);return this}if(n===!1||typeof n=="function")r=n,n=t;return r===!1&&(r=et),this.each(function(){v.event.remove(this,e,r,n)})},bind:function(e,t,n){return this.on(e,null,t,n)},unbind:function(e,t){return this.off(e,null,t)},live:function(e,t,n){return v(this.context).on(e,this.selector,t,n),this},die:function(e,t){return v(this.context).off(e,this.selector||"**",t),this},delegate:function(e,t,n,r){return this.on(t,e,n,r)},undelegate:function(e,t,n){return arguments.length===1?this.off(e,"**"):this.off(t,e||"**",n)},trigger:function(e,t){return this.each(function(){v.event.trigger(e,t,this)})},triggerHandler:function(e,t){if(this[0])return v.event.trigger(e,t,this[0],!0)},toggle:function(e){var t=arguments,n=e.guid||v.guid++,r=0,i=function(n){var i=(v._data(this,"lastToggle"+e.guid)||0)%r;return v._data(this,"lastToggle"+e.guid,i+1),n.preventDefault(),t[i].apply(this,arguments)||!1};i.guid=n;while(r<t.length)t[r++].guid=n;return this.click(i)},hover:function(e,t){return this.mouseenter(e).mouseleave(t||e)}}),v.each("blur focus focusin focusout load resize scroll unload click dblclick mousedown mouseup mousemove mouseover mouseout mouseenter mouseleave change select submit keydown keypress keyup error contextmenu".split(" "),function(e,t){v.fn[t]=function(e,n){return n==null&&(n=e,e=null),arguments.length>0?this.on(t,null,e,n):this.trigger(t)},Q.test(t)&&(v.event.fixHooks[t]=v.event.keyHooks),G.test(t)&&(v.event.fixHooks[t]=v.event.mouseHooks)}),function(e,t){function nt(e,t,n,r){n=n||[],t=t||g;var i,s,a,f,l=t.nodeType;if(!e||typeof e!="string")return n;if(l!==1&&l!==9)return[];a=o(t);if(!a&&!r)if(i=R.exec(e))if(f=i[1]){if(l===9){s=t.getElementById(f);if(!s||!s.parentNode)return n;if(s.id===f)return n.push(s),n}else if(t.ownerDocument&&(s=t.ownerDocument.getElementById(f))&&u(t,s)&&s.id===f)return n.push(s),n}else{if(i[2])return S.apply(n,x.call(t.getElementsByTagName(e),0)),n;if((f=i[3])&&Z&&t.getElementsByClassName)return S.apply(n,x.call(t.getElementsByClassName(f),0)),n}return vt(e.replace(j,"$1"),t,n,r,a)}function rt(e){return function(t){var n=t.nodeName.toLowerCase();return n==="input"&&t.type===e}}function it(e){return function(t){var n=t.nodeName.toLowerCase();return(n==="input"||n==="button")&&t.type===e}}function st(e){return N(function(t){return t=+t,N(function(n,r){var i,s=e([],n.length,t),o=s.length;while(o--)n[i=s[o]]&&(n[i]=!(r[i]=n[i]))})})}function ot(e,t,n){if(e===t)return n;var r=e.nextSibling;while(r){if(r===t)return-1;r=r.nextSibling}return 1}function ut(e,t){var n,r,s,o,u,a,f,l=L[d][e+" "];if(l)return t?0:l.slice(0);u=e,a=[],f=i.preFilter;while(u){if(!n||(r=F.exec(u)))r&&(u=u.slice(r[0].length)||u),a.push(s=[]);n=!1;if(r=I.exec(u))s.push(n=new m(r.shift())),u=u.slice(n.length),n.type=r[0].replace(j," ");for(o in i.filter)(r=J[o].exec(u))&&(!f[o]||(r=f[o](r)))&&(s.push(n=new m(r.shift())),u=u.slice(n.length),n.type=o,n.matches=r);if(!n)break}return t?u.length:u?nt.error(e):L(e,a).slice(0)}function at(e,t,r){var i=t.dir,s=r&&t.dir==="parentNode",o=w++;return t.first?function(t,n,r){while(t=t[i])if(s||t.nodeType===1)return e(t,n,r)}:function(t,r,u){if(!u){var a,f=b+" "+o+" ",l=f+n;while(t=t[i])if(s||t.nodeType===1){if((a=t[d])===l)return t.sizset;if(typeof a=="string"&&a.indexOf(f)===0){if(t.sizset)return t}else{t[d]=l;if(e(t,r,u))return t.sizset=!0,t;t.sizset=!1}}}else while(t=t[i])if(s||t.nodeType===1)if(e(t,r,u))return t}}function ft(e){return e.length>1?function(t,n,r){var i=e.length;while(i--)if(!e[i](t,n,r))return!1;return!0}:e[0]}function lt(e,t,n,r,i){var s,o=[],u=0,a=e.length,f=t!=null;for(;u<a;u++)if(s=e[u])if(!n||n(s,r,i))o.push(s),f&&t.push(u);return o}function ct(e,t,n,r,i,s){return r&&!r[d]&&(r=ct(r)),i&&!i[d]&&(i=ct(i,s)),N(function(s,o,u,a){var f,l,c,h=[],p=[],d=o.length,v=s||dt(t||"*",u.nodeType?[u]:u,[]),m=e&&(s||!t)?lt(v,h,e,u,a):v,g=n?i||(s?e:d||r)?[]:o:m;n&&n(m,g,u,a);if(r){f=lt(g,p),r(f,[],u,a),l=f.length;while(l--)if(c=f[l])g[p[l]]=!(m[p[l]]=c)}if(s){if(i||e){if(i){f=[],l=g.length;while(l--)(c=g[l])&&f.push(m[l]=c);i(null,g=[],f,a)}l=g.length;while(l--)(c=g[l])&&(f=i?T.call(s,c):h[l])>-1&&(s[f]=!(o[f]=c))}}else g=lt(g===o?g.splice(d,g.length):g),i?i(null,o,g,a):S.apply(o,g)})}function ht(e){var t,n,r,s=e.length,o=i.relative[e[0].type],u=o||i.relative[" "],a=o?1:0,f=at(function(e){return e===t},u,!0),l=at(function(e){return T.call(t,e)>-1},u,!0),h=[function(e,n,r){return!o&&(r||n!==c)||((t=n).nodeType?f(e,n,r):l(e,n,r))}];for(;a<s;a++)if(n=i.relative[e[a].type])h=[at(ft(h),n)];else{n=i.filter[e[a].type].apply(null,e[a].matches);if(n[d]){r=++a;for(;r<s;r++)if(i.relative[e[r].type])break;return ct(a>1&&ft(h),a>1&&e.slice(0,a-1).join("").replace(j,"$1"),n,a<r&&ht(e.slice(a,r)),r<s&&ht(e=e.slice(r)),r<s&&e.join(""))}h.push(n)}return ft(h)}function pt(e,t){var r=t.length>0,s=e.length>0,o=function(u,a,f,l,h){var p,d,v,m=[],y=0,w="0",x=u&&[],T=h!=null,N=c,C=u||s&&i.find.TAG("*",h&&a.parentNode||a),k=b+=N==null?1:Math.E;T&&(c=a!==g&&a,n=o.el);for(;(p=C[w])!=null;w++){if(s&&p){for(d=0;v=e[d];d++)if(v(p,a,f)){l.push(p);break}T&&(b=k,n=++o.el)}r&&((p=!v&&p)&&y--,u&&x.push(p))}y+=w;if(r&&w!==y){for(d=0;v=t[d];d++)v(x,m,a,f);if(u){if(y>0)while(w--)!x[w]&&!m[w]&&(m[w]=E.call(l));m=lt(m)}S.apply(l,m),T&&!u&&m.length>0&&y+t.length>1&&nt.uniqueSort(l)}return T&&(b=k,c=N),x};return o.el=0,r?N(o):o}function dt(e,t,n){var r=0,i=t.length;for(;r<i;r++)nt(e,t[r],n);return n}function vt(e,t,n,r,s){var o,u,f,l,c,h=ut(e),p=h.length;if(!r&&h.length===1){u=h[0]=h[0].slice(0);if(u.length>2&&(f=u[0]).type==="ID"&&t.nodeType===9&&!s&&i.relative[u[1].type]){t=i.find.ID(f.matches[0].replace($,""),t,s)[0];if(!t)return n;e=e.slice(u.shift().length)}for(o=J.POS.test(e)?-1:u.length-1;o>=0;o--){f=u[o];if(i.relative[l=f.type])break;if(c=i.find[l])if(r=c(f.matches[0].replace($,""),z.test(u[0].type)&&t.parentNode||t,s)){u.splice(o,1),e=r.length&&u.join("");if(!e)return S.apply(n,x.call(r,0)),n;break}}}return a(e,h)(r,t,s,n,z.test(e)),n}function mt(){}var n,r,i,s,o,u,a,f,l,c,h=!0,p="undefined",d=("sizcache"+Math.random()).replace(".",""),m=String,g=e.document,y=g.documentElement,b=0,w=0,E=[].pop,S=[].push,x=[].slice,T=[].indexOf||function(e){var t=0,n=this.length;for(;t<n;t++)if(this[t]===e)return t;return-1},N=function(e,t){return e[d]=t==null||t,e},C=function(){var e={},t=[];return N(function(n,r){return t.push(n)>i.cacheLength&&delete e[t.shift()],e[n+" "]=r},e)},k=C(),L=C(),A=C(),O="[\\x20\\t\\r\\n\\f]",M="(?:\\\\.|[-\\w]|[^\\x00-\\xa0])+",_=M.replace("w","w#"),D="([*^$|!~]?=)",P="\\["+O+"*("+M+")"+O+"*(?:"+D+O+"*(?:(['\"])((?:\\\\.|[^\\\\])*?)\\3|("+_+")|)|)"+O+"*\\]",H=":("+M+")(?:\\((?:(['\"])((?:\\\\.|[^\\\\])*?)\\2|([^()[\\]]*|(?:(?:"+P+")|[^:]|\\\\.)*|.*))\\)|)",B=":(even|odd|eq|gt|lt|nth|first|last)(?:\\("+O+"*((?:-\\d)?\\d*)"+O+"*\\)|)(?=[^-]|$)",j=new RegExp("^"+O+"+|((?:^|[^\\\\])(?:\\\\.)*)"+O+"+$","g"),F=new RegExp("^"+O+"*,"+O+"*"),I=new RegExp("^"+O+"*([\\x20\\t\\r\\n\\f>+~])"+O+"*"),q=new RegExp(H),R=/^(?:#([\w\-]+)|(\w+)|\.([\w\-]+))$/,U=/^:not/,z=/[\x20\t\r\n\f]*[+~]/,W=/:not\($/,X=/h\d/i,V=/input|select|textarea|button/i,$=/\\(?!\\)/g,J={ID:new RegExp("^#("+M+")"),CLASS:new RegExp("^\\.("+M+")"),NAME:new RegExp("^\\[name=['\"]?("+M+")['\"]?\\]"),TAG:new RegExp("^("+M.replace("w","w*")+")"),ATTR:new RegExp("^"+P),PSEUDO:new RegExp("^"+H),POS:new RegExp(B,"i"),CHILD:new RegExp("^:(only|nth|first|last)-child(?:\\("+O+"*(even|odd|(([+-]|)(\\d*)n|)"+O+"*(?:([+-]|)"+O+"*(\\d+)|))"+O+"*\\)|)","i"),needsContext:new RegExp("^"+O+"*[>+~]|"+B,"i")},K=function(e){var t=g.createElement("div");try{return e(t)}catch(n){return!1}finally{t=null}},Q=K(function(e){return e.appendChild(g.createComment("")),!e.getElementsByTagName("*").length}),G=K(function(e){return e.innerHTML="<a href='#'></a>",e.firstChild&&typeof e.firstChild.getAttribute!==p&&e.firstChild.getAttribute("href")==="#"}),Y=K(function(e){e.innerHTML="<select></select>";var t=typeof e.lastChild.getAttribute("multiple");return t!=="boolean"&&t!=="string"}),Z=K(function(e){return e.innerHTML="<div class='hidden e'></div><div class='hidden'></div>",!e.getElementsByClassName||!e.getElementsByClassName("e").length?!1:(e.lastChild.className="e",e.getElementsByClassName("e").length===2)}),et=K(function(e){e.id=d+0,e.innerHTML="<a name='"+d+"'></a><div name='"+d+"'></div>",y.insertBefore(e,y.firstChild);var t=g.getElementsByName&&g.getElementsByName(d).length===2+g.getElementsByName(d+0).length;return r=!g.getElementById(d),y.removeChild(e),t});try{x.call(y.childNodes,0)[0].nodeType}catch(tt){x=function(e){var t,n=[];for(;t=this[e];e++)n.push(t);return n}}nt.matches=function(e,t){return nt(e,null,null,t)},nt.matchesSelector=function(e,t){return nt(t,null,null,[e]).length>0},s=nt.getText=function(e){var t,n="",r=0,i=e.nodeType;if(i){if(i===1||i===9||i===11){if(typeof e.textContent=="string")return e.textContent;for(e=e.firstChild;e;e=e.nextSibling)n+=s(e)}else if(i===3||i===4)return e.nodeValue}else for(;t=e[r];r++)n+=s(t);return n},o=nt.isXML=function(e){var t=e&&(e.ownerDocument||e).documentElement;return t?t.nodeName!=="HTML":!1},u=nt.contains=y.contains?function(e,t){var n=e.nodeType===9?e.documentElement:e,r=t&&t.parentNode;return e===r||!!(r&&r.nodeType===1&&n.contains&&n.contains(r))}:y.compareDocumentPosition?function(e,t){return t&&!!(e.compareDocumentPosition(t)&16)}:function(e,t){while(t=t.parentNode)if(t===e)return!0;return!1},nt.attr=function(e,t){var n,r=o(e);return r||(t=t.toLowerCase()),(n=i.attrHandle[t])?n(e):r||Y?e.getAttribute(t):(n=e.getAttributeNode(t),n?typeof e[t]=="boolean"?e[t]?t:null:n.specified?n.value:null:null)},i=nt.selectors={cacheLength:50,createPseudo:N,match:J,attrHandle:G?{}:{href:function(e){return e.getAttribute("href",2)},type:function(e){return e.getAttribute("type")}},find:{ID:r?function(e,t,n){if(typeof t.getElementById!==p&&!n){var r=t.getElementById(e);return r&&r.parentNode?[r]:[]}}:function(e,n,r){if(typeof n.getElementById!==p&&!r){var i=n.getElementById(e);return i?i.id===e||typeof i.getAttributeNode!==p&&i.getAttributeNode("id").value===e?[i]:t:[]}},TAG:Q?function(e,t){if(typeof t.getElementsByTagName!==p)return t.getElementsByTagName(e)}:function(e,t){var n=t.getElementsByTagName(e);if(e==="*"){var r,i=[],s=0;for(;r=n[s];s++)r.nodeType===1&&i.push(r);return i}return n},NAME:et&&function(e,t){if(typeof t.getElementsByName!==p)return t.getElementsByName(name)},CLASS:Z&&function(e,t,n){if(typeof t.getElementsByClassName!==p&&!n)return t.getElementsByClassName(e)}},relative:{">":{dir:"parentNode",first:!0}," ":{dir:"parentNode"},"+":{dir:"previousSibling",first:!0},"~":{dir:"previousSibling"}},preFilter:{ATTR:function(e){return e[1]=e[1].replace($,""),e[3]=(e[4]||e[5]||"").replace($,""),e[2]==="~="&&(e[3]=" "+e[3]+" "),e.slice(0,4)},CHILD:function(e){return e[1]=e[1].toLowerCase(),e[1]==="nth"?(e[2]||nt.error(e[0]),e[3]=+(e[3]?e[4]+(e[5]||1):2*(e[2]==="even"||e[2]==="odd")),e[4]=+(e[6]+e[7]||e[2]==="odd")):e[2]&&nt.error(e[0]),e},PSEUDO:function(e){var t,n;if(J.CHILD.test(e[0]))return null;if(e[3])e[2]=e[3];else if(t=e[4])q.test(t)&&(n=ut(t,!0))&&(n=t.indexOf(")",t.length-n)-t.length)&&(t=t.slice(0,n),e[0]=e[0].slice(0,n)),e[2]=t;return e.slice(0,3)}},filter:{ID:r?function(e){return e=e.replace($,""),function(t){return t.getAttribute("id")===e}}:function(e){return e=e.replace($,""),function(t){var n=typeof t.getAttributeNode!==p&&t.getAttributeNode("id");return n&&n.value===e}},TAG:function(e){return e==="*"?function(){return!0}:(e=e.replace($,"").toLowerCase(),function(t){return t.nodeName&&t.nodeName.toLowerCase()===e})},CLASS:function(e){var t=k[d][e+" "];return t||(t=new RegExp("(^|"+O+")"+e+"("+O+"|$)"))&&k(e,function(e){return t.test(e.className||typeof e.getAttribute!==p&&e.getAttribute("class")||"")})},ATTR:function(e,t,n){return function(r,i){var s=nt.attr(r,e);return s==null?t==="!=":t?(s+="",t==="="?s===n:t==="!="?s!==n:t==="^="?n&&s.indexOf(n)===0:t==="*="?n&&s.indexOf(n)>-1:t==="$="?n&&s.substr(s.length-n.length)===n:t==="~="?(" "+s+" ").indexOf(n)>-1:t==="|="?s===n||s.substr(0,n.length+1)===n+"-":!1):!0}},CHILD:function(e,t,n,r){return e==="nth"?function(e){var t,i,s=e.parentNode;if(n===1&&r===0)return!0;if(s){i=0;for(t=s.firstChild;t;t=t.nextSibling)if(t.nodeType===1){i++;if(e===t)break}}return i-=r,i===n||i%n===0&&i/n>=0}:function(t){var n=t;switch(e){case"only":case"first":while(n=n.previousSibling)if(n.nodeType===1)return!1;if(e==="first")return!0;n=t;case"last":while(n=n.nextSibling)if(n.nodeType===1)return!1;return!0}}},PSEUDO:function(e,t){var n,r=i.pseudos[e]||i.setFilters[e.toLowerCase()]||nt.error("unsupported pseudo: "+e);return r[d]?r(t):r.length>1?(n=[e,e,"",t],i.setFilters.hasOwnProperty(e.toLowerCase())?N(function(e,n){var i,s=r(e,t),o=s.length;while(o--)i=T.call(e,s[o]),e[i]=!(n[i]=s[o])}):function(e){return r(e,0,n)}):r}},pseudos:{not:N(function(e){var t=[],n=[],r=a(e.replace(j,"$1"));return r[d]?N(function(e,t,n,i){var s,o=r(e,null,i,[]),u=e.length;while(u--)if(s=o[u])e[u]=!(t[u]=s)}):function(e,i,s){return t[0]=e,r(t,null,s,n),!n.pop()}}),has:N(function(e){return function(t){return nt(e,t).length>0}}),contains:N(function(e){return function(t){return(t.textContent||t.innerText||s(t)).indexOf(e)>-1}}),enabled:function(e){return e.disabled===!1},disabled:function(e){return e.disabled===!0},checked:function(e){var t=e.nodeName.toLowerCase();return t==="input"&&!!e.checked||t==="option"&&!!e.selected},selected:function(e){return e.parentNode&&e.parentNode.selectedIndex,e.selected===!0},parent:function(e){return!i.pseudos.empty(e)},empty:function(e){var t;e=e.firstChild;while(e){if(e.nodeName>"@"||(t=e.nodeType)===3||t===4)return!1;e=e.nextSibling}return!0},header:function(e){return X.test(e.nodeName)},text:function(e){var t,n;return e.nodeName.toLowerCase()==="input"&&(t=e.type)==="text"&&((n=e.getAttribute("type"))==null||n.toLowerCase()===t)},radio:rt("radio"),checkbox:rt("checkbox"),file:rt("file"),password:rt("password"),image:rt("image"),submit:it("submit"),reset:it("reset"),button:function(e){var t=e.nodeName.toLowerCase();return t==="input"&&e.type==="button"||t==="button"},input:function(e){return V.test(e.nodeName)},focus:function(e){var t=e.ownerDocument;return e===t.activeElement&&(!t.hasFocus||t.hasFocus())&&!!(e.type||e.href||~e.tabIndex)},active:function(e){return e===e.ownerDocument.activeElement},first:st(function(){return[0]}),last:st(function(e,t){return[t-1]}),eq:st(function(e,t,n){return[n<0?n+t:n]}),even:st(function(e,t){for(var n=0;n<t;n+=2)e.push(n);return e}),odd:st(function(e,t){for(var n=1;n<t;n+=2)e.push(n);return e}),lt:st(function(e,t,n){for(var r=n<0?n+t:n;--r>=0;)e.push(r);return e}),gt:st(function(e,t,n){for(var r=n<0?n+t:n;++r<t;)e.push(r);return e})}},f=y.compareDocumentPosition?function(e,t){return e===t?(l=!0,0):(!e.compareDocumentPosition||!t.compareDocumentPosition?e.compareDocumentPosition:e.compareDocumentPosition(t)&4)?-1:1}:function(e,t){if(e===t)return l=!0,0;if(e.sourceIndex&&t.sourceIndex)return e.sourceIndex-t.sourceIndex;var n,r,i=[],s=[],o=e.parentNode,u=t.parentNode,a=o;if(o===u)return ot(e,t);if(!o)return-1;if(!u)return 1;while(a)i.unshift(a),a=a.parentNode;a=u;while(a)s.unshift(a),a=a.parentNode;n=i.length,r=s.length;for(var f=0;f<n&&f<r;f++)if(i[f]!==s[f])return ot(i[f],s[f]);return f===n?ot(e,s[f],-1):ot(i[f],t,1)},[0,0].sort(f),h=!l,nt.uniqueSort=function(e){var t,n=[],r=1,i=0;l=h,e.sort(f);if(l){for(;t=e[r];r++)t===e[r-1]&&(i=n.push(r));while(i--)e.splice(n[i],1)}return e},nt.error=function(e){throw new Error("Syntax error, unrecognized expression: "+e)},a=nt.compile=function(e,t){var n,r=[],i=[],s=A[d][e+" "];if(!s){t||(t=ut(e)),n=t.length;while(n--)s=ht(t[n]),s[d]?r.push(s):i.push(s);s=A(e,pt(i,r))}return s},g.querySelectorAll&&function(){var e,t=vt,n=/'|\\/g,r=/\=[\x20\t\r\n\f]*([^'"\]]*)[\x20\t\r\n\f]*\]/g,i=[":focus"],s=[":active"],u=y.matchesSelector||y.mozMatchesSelector||y.webkitMatchesSelector||y.oMatchesSelector||y.msMatchesSelector;K(function(e){e.innerHTML="<select><option selected=''></option></select>",e.querySelectorAll("[selected]").length||i.push("\\["+O+"*(?:checked|disabled|ismap|multiple|readonly|selected|value)"),e.querySelectorAll(":checked").length||i.push(":checked")}),K(function(e){e.innerHTML="<p test=''></p>",e.querySelectorAll("[test^='']").length&&i.push("[*^$]="+O+"*(?:\"\"|'')"),e.innerHTML="<input type='hidden'/>",e.querySelectorAll(":enabled").length||i.push(":enabled",":disabled")}),i=new RegExp(i.join("|")),vt=function(e,r,s,o,u){if(!o&&!u&&!i.test(e)){var a,f,l=!0,c=d,h=r,p=r.nodeType===9&&e;if(r.nodeType===1&&r.nodeName.toLowerCase()!=="object"){a=ut(e),(l=r.getAttribute("id"))?c=l.replace(n,"\\$&"):r.setAttribute("id",c),c="[id='"+c+"'] ",f=a.length;while(f--)a[f]=c+a[f].join("");h=z.test(e)&&r.parentNode||r,p=a.join(",")}if(p)try{return S.apply(s,x.call(h.querySelectorAll(p),0)),s}catch(v){}finally{l||r.removeAttribute("id")}}return t(e,r,s,o,u)},u&&(K(function(t){e=u.call(t,"div");try{u.call(t,"[test!='']:sizzle"),s.push("!=",H)}catch(n){}}),s=new RegExp(s.join("|")),nt.matchesSelector=function(t,n){n=n.replace(r,"='$1']");if(!o(t)&&!s.test(n)&&!i.test(n))try{var a=u.call(t,n);if(a||e||t.document&&t.document.nodeType!==11)return a}catch(f){}return nt(n,null,null,[t]).length>0})}(),i.pseudos.nth=i.pseudos.eq,i.filters=mt.prototype=i.pseudos,i.setFilters=new mt,nt.attr=v.attr,v.find=nt,v.expr=nt.selectors,v.expr[":"]=v.expr.pseudos,v.unique=nt.uniqueSort,v.text=nt.getText,v.isXMLDoc=nt.isXML,v.contains=nt.contains}(e);var nt=/Until$/,rt=/^(?:parents|prev(?:Until|All))/,it=/^.[^:#\[\.,]*$/,st=v.expr.match.needsContext,ot={children:!0,contents:!0,next:!0,prev:!0};v.fn.extend({find:function(e){var t,n,r,i,s,o,u=this;if(typeof e!="string")return v(e).filter(function(){for(t=0,n=u.length;t<n;t++)if(v.contains(u[t],this))return!0});o=this.pushStack("","find",e);for(t=0,n=this.length;t<n;t++){r=o.length,v.find(e,this[t],o);if(t>0)for(i=r;i<o.length;i++)for(s=0;s<r;s++)if(o[s]===o[i]){o.splice(i--,1);break}}return o},has:function(e){var t,n=v(e,this),r=n.length;return this.filter(function(){for(t=0;t<r;t++)if(v.contains(this,n[t]))return!0})},not:function(e){return this.pushStack(ft(this,e,!1),"not",e)},filter:function(e){return this.pushStack(ft(this,e,!0),"filter",e)},is:function(e){return!!e&&(typeof e=="string"?st.test(e)?v(e,this.context).index(this[0])>=0:v.filter(e,this).length>0:this.filter(e).length>0)},closest:function(e,t){var n,r=0,i=this.length,s=[],o=st.test(e)||typeof e!="string"?v(e,t||this.context):0;for(;r<i;r++){n=this[r];while(n&&n.ownerDocument&&n!==t&&n.nodeType!==11){if(o?o.index(n)>-1:v.find.matchesSelector(n,e)){s.push(n);break}n=n.parentNode}}return s=s.length>1?v.unique(s):s,this.pushStack(s,"closest",e)},index:function(e){return e?typeof e=="string"?v.inArray(this[0],v(e)):v.inArray(e.jquery?e[0]:e,this):this[0]&&this[0].parentNode?this.prevAll().length:-1},add:function(e,t){var n=typeof e=="string"?v(e,t):v.makeArray(e&&e.nodeType?[e]:e),r=v.merge(this.get(),n);return this.pushStack(ut(n[0])||ut(r[0])?r:v.unique(r))},addBack:function(e){return this.add(e==null?this.prevObject:this.prevObject.filter(e))}}),v.fn.andSelf=v.fn.addBack,v.each({parent:function(e){var t=e.parentNode;return t&&t.nodeType!==11?t:null},parents:function(e){return v.dir(e,"parentNode")},parentsUntil:function(e,t,n){return v.dir(e,"parentNode",n)},next:function(e){return at(e,"nextSibling")},prev:function(e){return at(e,"previousSibling")},nextAll:function(e){return v.dir(e,"nextSibling")},prevAll:function(e){return v.dir(e,"previousSibling")},nextUntil:function(e,t,n){return v.dir(e,"nextSibling",n)},prevUntil:function(e,t,n){return v.dir(e,"previousSibling",n)},siblings:function(e){return v.sibling((e.parentNode||{}).firstChild,e)},children:function(e){return v.sibling(e.firstChild)},contents:function(e){return v.nodeName(e,"iframe")?e.contentDocument||e.contentWindow.document:v.merge([],e.childNodes)}},function(e,t){v.fn[e]=function(n,r){var i=v.map(this,t,n);return nt.test(e)||(r=n),r&&typeof r=="string"&&(i=v.filter(r,i)),i=this.length>1&&!ot[e]?v.unique(i):i,this.length>1&&rt.test(e)&&(i=i.reverse()),this.pushStack(i,e,l.call(arguments).join(","))}}),v.extend({filter:function(e,t,n){return n&&(e=":not("+e+")"),t.length===1?v.find.matchesSelector(t[0],e)?[t[0]]:[]:v.find.matches(e,t)},dir:function(e,n,r){var i=[],s=e[n];while(s&&s.nodeType!==9&&(r===t||s.nodeType!==1||!v(s).is(r)))s.nodeType===1&&i.push(s),s=s[n];return i},sibling:function(e,t){var n=[];for(;e;e=e.nextSibling)e.nodeType===1&&e!==t&&n.push(e);return n}});var ct="abbr|article|aside|audio|bdi|canvas|data|datalist|details|figcaption|figure|footer|header|hgroup|mark|meter|nav|output|progress|section|summary|time|video",ht=/ jQuery\d+="(?:null|\d+)"/g,pt=/^\s+/,dt=/<(?!area|br|col|embed|hr|img|input|link|meta|param)(([\w:]+)[^>]*)\/>/gi,vt=/<([\w:]+)/,mt=/<tbody/i,gt=/<|&#?\w+;/,yt=/<(?:script|style|link)/i,bt=/<(?:script|object|embed|option|style)/i,wt=new RegExp("<(?:"+ct+")[\\s/>]","i"),Et=/^(?:checkbox|radio)$/,St=/checked\s*(?:[^=]|=\s*.checked.)/i,xt=/\/(java|ecma)script/i,Tt=/^\s*<!(?:\[CDATA\[|\-\-)|[\]\-]{2}>\s*$/g,Nt={option:[1,"<select multiple='multiple'>","</select>"],legend:[1,"<fieldset>","</fieldset>"],thead:[1,"<table>","</table>"],tr:[2,"<table><tbody>","</tbody></table>"],td:[3,"<table><tbody><tr>","</tr></tbody></table>"],col:[2,"<table><tbody></tbody><colgroup>","</colgroup></table>"],area:[1,"<map>","</map>"],_default:[0,"",""]},Ct=lt(i),kt=Ct.appendChild(i.createElement("div"));Nt.optgroup=Nt.option,Nt.tbody=Nt.tfoot=Nt.colgroup=Nt.caption=Nt.thead,Nt.th=Nt.td,v.support.htmlSerialize||(Nt._default=[1,"X<div>","</div>"]),v.fn.extend({text:function(e){return v.access(this,function(e){return e===t?v.text(this):this.empty().append((this[0]&&this[0].ownerDocument||i).createTextNode(e))},null,e,arguments.length)},wrapAll:function(e){if(v.isFunction(e))return this.each(function(t){v(this).wrapAll(e.call(this,t))});if(this[0]){var t=v(e,this[0].ownerDocument).eq(0).clone(!0);this[0].parentNode&&t.insertBefore(this[0]),t.map(function(){var e=this;while(e.firstChild&&e.firstChild.nodeType===1)e=e.firstChild;return e}).append(this)}return this},wrapInner:function(e){return v.isFunction(e)?this.each(function(t){v(this).wrapInner(e.call(this,t))}):this.each(function(){var t=v(this),n=t.contents();n.length?n.wrapAll(e):t.append(e)})},wrap:function(e){var t=v.isFunction(e);return this.each(function(n){v(this).wrapAll(t?e.call(this,n):e)})},unwrap:function(){return this.parent().each(function(){v.nodeName(this,"body")||v(this).replaceWith(this.childNodes)}).end()},append:function(){return this.domManip(arguments,!0,function(e){(this.nodeType===1||this.nodeType===11)&&this.appendChild(e)})},prepend:function(){return this.domManip(arguments,!0,function(e){(this.nodeType===1||this.nodeType===11)&&this.insertBefore(e,this.firstChild)})},before:function(){if(!ut(this[0]))return this.domManip(arguments,!1,function(e){this.parentNode.insertBefore(e,this)});if(arguments.length){var e=v.clean(arguments);return this.pushStack(v.merge(e,this),"before",this.selector)}},after:function(){if(!ut(this[0]))return this.domManip(arguments,!1,function(e){this.parentNode.insertBefore(e,this.nextSibling)});if(arguments.length){var e=v.clean(arguments);return this.pushStack(v.merge(this,e),"after",this.selector)}},remove:function(e,t){var n,r=0;for(;(n=this[r])!=null;r++)if(!e||v.filter(e,[n]).length)!t&&n.nodeType===1&&(v.cleanData(n.getElementsByTagName("*")),v.cleanData([n])),n.parentNode&&n.parentNode.removeChild(n);return this},empty:function(){var e,t=0;for(;(e=this[t])!=null;t++){e.nodeType===1&&v.cleanData(e.getElementsByTagName("*"));while(e.firstChild)e.removeChild(e.firstChild)}return this},clone:function(e,t){return e=e==null?!1:e,t=t==null?e:t,this.map(function(){return v.clone(this,e,t)})},html:function(e){return v.access(this,function(e){var n=this[0]||{},r=0,i=this.length;if(e===t)return n.nodeType===1?n.innerHTML.replace(ht,""):t;if(typeof e=="string"&&!yt.test(e)&&(v.support.htmlSerialize||!wt.test(e))&&(v.support.leadingWhitespace||!pt.test(e))&&!Nt[(vt.exec(e)||["",""])[1].toLowerCase()]){e=e.replace(dt,"<$1></$2>");try{for(;r<i;r++)n=this[r]||{},n.nodeType===1&&(v.cleanData(n.getElementsByTagName("*")),n.innerHTML=e);n=0}catch(s){}}n&&this.empty().append(e)},null,e,arguments.length)},replaceWith:function(e){return ut(this[0])?this.length?this.pushStack(v(v.isFunction(e)?e():e),"replaceWith",e):this:v.isFunction(e)?this.each(function(t){var n=v(this),r=n.html();n.replaceWith(e.call(this,t,r))}):(typeof e!="string"&&(e=v(e).detach()),this.each(function(){var t=this.nextSibling,n=this.parentNode;v(this).remove(),t?v(t).before(e):v(n).append(e)}))},detach:function(e){return this.remove(e,!0)},domManip:function(e,n,r){e=[].concat.apply([],e);var i,s,o,u,a=0,f=e[0],l=[],c=this.length;if(!v.support.checkClone&&c>1&&typeof f=="string"&&St.test(f))return this.each(function(){v(this).domManip(e,n,r)});if(v.isFunction(f))return this.each(function(i){var s=v(this);e[0]=f.call(this,i,n?s.html():t),s.domManip(e,n,r)});if(this[0]){i=v.buildFragment(e,this,l),o=i.fragment,s=o.firstChild,o.childNodes.length===1&&(o=s);if(s){n=n&&v.nodeName(s,"tr");for(u=i.cacheable||c-1;a<c;a++)r.call(n&&v.nodeName(this[a],"table")?Lt(this[a],"tbody"):this[a],a===u?o:v.clone(o,!0,!0))}o=s=null,l.length&&v.each(l,function(e,t){t.src?v.ajax?v.ajax({url:t.src,type:"GET",dataType:"script",async:!1,global:!1,"throws":!0}):v.error("no ajax"):v.globalEval((t.text||t.textContent||t.innerHTML||"").replace(Tt,"")),t.parentNode&&t.parentNode.removeChild(t)})}return this}}),v.buildFragment=function(e,n,r){var s,o,u,a=e[0];return n=n||i,n=!n.nodeType&&n[0]||n,n=n.ownerDocument||n,e.length===1&&typeof a=="string"&&a.length<512&&n===i&&a.charAt(0)==="<"&&!bt.test(a)&&(v.support.checkClone||!St.test(a))&&(v.support.html5Clone||!wt.test(a))&&(o=!0,s=v.fragments[a],u=s!==t),s||(s=n.createDocumentFragment(),v.clean(e,n,s,r),o&&(v.fragments[a]=u&&s)),{fragment:s,cacheable:o}},v.fragments={},v.each({appendTo:"append",prependTo:"prepend",insertBefore:"before",insertAfter:"after",replaceAll:"replaceWith"},function(e,t){v.fn[e]=function(n){var r,i=0,s=[],o=v(n),u=o.length,a=this.length===1&&this[0].parentNode;if((a==null||a&&a.nodeType===11&&a.childNodes.length===1)&&u===1)return o[t](this[0]),this;for(;i<u;i++)r=(i>0?this.clone(!0):this).get(),v(o[i])[t](r),s=s.concat(r);return this.pushStack(s,e,o.selector)}}),v.extend({clone:function(e,t,n){var r,i,s,o;v.support.html5Clone||v.isXMLDoc(e)||!wt.test("<"+e.nodeName+">")?o=e.cloneNode(!0):(kt.innerHTML=e.outerHTML,kt.removeChild(o=kt.firstChild));if((!v.support.noCloneEvent||!v.support.noCloneChecked)&&(e.nodeType===1||e.nodeType===11)&&!v.isXMLDoc(e)){Ot(e,o),r=Mt(e),i=Mt(o);for(s=0;r[s];++s)i[s]&&Ot(r[s],i[s])}if(t){At(e,o);if(n){r=Mt(e),i=Mt(o);for(s=0;r[s];++s)At(r[s],i[s])}}return r=i=null,o},clean:function(e,t,n,r){var s,o,u,a,f,l,c,h,p,d,m,g,y=t===i&&Ct,b=[];if(!t||typeof t.createDocumentFragment=="undefined")t=i;for(s=0;(u=e[s])!=null;s++){typeof u=="number"&&(u+="");if(!u)continue;if(typeof u=="string")if(!gt.test(u))u=t.createTextNode(u);else{y=y||lt(t),c=t.createElement("div"),y.appendChild(c),u=u.replace(dt,"<$1></$2>"),a=(vt.exec(u)||["",""])[1].toLowerCase(),f=Nt[a]||Nt._default,l=f[0],c.innerHTML=f[1]+u+f[2];while(l--)c=c.lastChild;if(!v.support.tbody){h=mt.test(u),p=a==="table"&&!h?c.firstChild&&c.firstChild.childNodes:f[1]==="<table>"&&!h?c.childNodes:[];for(o=p.length-1;o>=0;--o)v.nodeName(p[o],"tbody")&&!p[o].childNodes.length&&p[o].parentNode.removeChild(p[o])}!v.support.leadingWhitespace&&pt.test(u)&&c.insertBefore(t.createTextNode(pt.exec(u)[0]),c.firstChild),u=c.childNodes,c.parentNode.removeChild(c)}u.nodeType?b.push(u):v.merge(b,u)}c&&(u=c=y=null);if(!v.support.appendChecked)for(s=0;(u=b[s])!=null;s++)v.nodeName(u,"input")?_t(u):typeof u.getElementsByTagName!="undefined"&&v.grep(u.getElementsByTagName("input"),_t);if(n){m=function(e){if(!e.type||xt.test(e.type))return r?r.push(e.parentNode?e.parentNode.removeChild(e):e):n.appendChild(e)};for(s=0;(u=b[s])!=null;s++)if(!v.nodeName(u,"script")||!m(u))n.appendChild(u),typeof u.getElementsByTagName!="undefined"&&(g=v.grep(v.merge([],u.getElementsByTagName("script")),m),b.splice.apply(b,[s+1,0].concat(g)),s+=g.length)}return b},cleanData:function(e,t){var n,r,i,s,o=0,u=v.expando,a=v.cache,f=v.support.deleteExpando,l=v.event.special;for(;(i=e[o])!=null;o++)if(t||v.acceptData(i)){r=i[u],n=r&&a[r];if(n){if(n.events)for(s in n.events)l[s]?v.event.remove(i,s):v.removeEvent(i,s,n.handle);a[r]&&(delete a[r],f?delete i[u]:i.removeAttribute?i.removeAttribute(u):i[u]=null,v.deletedIds.push(r))}}}}),function(){var e,t;v.uaMatch=function(e){e=e.toLowerCase();var t=/(chrome)[ \/]([\w.]+)/.exec(e)||/(webkit)[ \/]([\w.]+)/.exec(e)||/(opera)(?:.*version|)[ \/]([\w.]+)/.exec(e)||/(msie) ([\w.]+)/.exec(e)||e.indexOf("compatible")<0&&/(mozilla)(?:.*? rv:([\w.]+)|)/.exec(e)||[];return{browser:t[1]||"",version:t[2]||"0"}},e=v.uaMatch(o.userAgent),t={},e.browser&&(t[e.browser]=!0,t.version=e.version),t.chrome?t.webkit=!0:t.webkit&&(t.safari=!0),v.browser=t,v.sub=function(){function e(t,n){return new e.fn.init(t,n)}v.extend(!0,e,this),e.superclass=this,e.fn=e.prototype=this(),e.fn.constructor=e,e.sub=this.sub,e.fn.init=function(r,i){return i&&i instanceof v&&!(i instanceof e)&&(i=e(i)),v.fn.init.call(this,r,i,t)},e.fn.init.prototype=e.fn;var t=e(i);return e}}();var Dt,Pt,Ht,Bt=/alpha\([^)]*\)/i,jt=/opacity=([^)]*)/,Ft=/^(top|right|bottom|left)$/,It=/^(none|table(?!-c[ea]).+)/,qt=/^margin/,Rt=new RegExp("^("+m+")(.*)$","i"),Ut=new RegExp("^("+m+")(?!px)[a-z%]+$","i"),zt=new RegExp("^([-+])=("+m+")","i"),Wt={BODY:"block"},Xt={position:"absolute",visibility:"hidden",display:"block"},Vt={letterSpacing:0,fontWeight:400},$t=["Top","Right","Bottom","Left"],Jt=["Webkit","O","Moz","ms"],Kt=v.fn.toggle;v.fn.extend({css:function(e,n){return v.access(this,function(e,n,r){return r!==t?v.style(e,n,r):v.css(e,n)},e,n,arguments.length>1)},show:function(){return Yt(this,!0)},hide:function(){return Yt(this)},toggle:function(e,t){var n=typeof e=="boolean";return v.isFunction(e)&&v.isFunction(t)?Kt.apply(this,arguments):this.each(function(){(n?e:Gt(this))?v(this).show():v(this).hide()})}}),v.extend({cssHooks:{opacity:{get:function(e,t){if(t){var n=Dt(e,"opacity");return n===""?"1":n}}}},cssNumber:{fillOpacity:!0,fontWeight:!0,lineHeight:!0,opacity:!0,orphans:!0,widows:!0,zIndex:!0,zoom:!0},cssProps:{"float":v.support.cssFloat?"cssFloat":"styleFloat"},style:function(e,n,r,i){if(!e||e.nodeType===3||e.nodeType===8||!e.style)return;var s,o,u,a=v.camelCase(n),f=e.style;n=v.cssProps[a]||(v.cssProps[a]=Qt(f,a)),u=v.cssHooks[n]||v.cssHooks[a];if(r===t)return u&&"get"in u&&(s=u.get(e,!1,i))!==t?s:f[n];o=typeof r,o==="string"&&(s=zt.exec(r))&&(r=(s[1]+1)*s[2]+parseFloat(v.css(e,n)),o="number");if(r==null||o==="number"&&isNaN(r))return;o==="number"&&!v.cssNumber[a]&&(r+="px");if(!u||!("set"in u)||(r=u.set(e,r,i))!==t)try{f[n]=r}catch(l){}},css:function(e,n,r,i){var s,o,u,a=v.camelCase(n);return n=v.cssProps[a]||(v.cssProps[a]=Qt(e.style,a)),u=v.cssHooks[n]||v.cssHooks[a],u&&"get"in u&&(s=u.get(e,!0,i)),s===t&&(s=Dt(e,n)),s==="normal"&&n in Vt&&(s=Vt[n]),r||i!==t?(o=parseFloat(s),r||v.isNumeric(o)?o||0:s):s},swap:function(e,t,n){var r,i,s={};for(i in t)s[i]=e.style[i],e.style[i]=t[i];r=n.call(e);for(i in t)e.style[i]=s[i];return r}}),e.getComputedStyle?Dt=function(t,n){var r,i,s,o,u=e.getComputedStyle(t,null),a=t.style;return u&&(r=u.getPropertyValue(n)||u[n],r===""&&!v.contains(t.ownerDocument,t)&&(r=v.style(t,n)),Ut.test(r)&&qt.test(n)&&(i=a.width,s=a.minWidth,o=a.maxWidth,a.minWidth=a.maxWidth=a.width=r,r=u.width,a.width=i,a.minWidth=s,a.maxWidth=o)),r}:i.documentElement.currentStyle&&(Dt=function(e,t){var n,r,i=e.currentStyle&&e.currentStyle[t],s=e.style;return i==null&&s&&s[t]&&(i=s[t]),Ut.test(i)&&!Ft.test(t)&&(n=s.left,r=e.runtimeStyle&&e.runtimeStyle.left,r&&(e.runtimeStyle.left=e.currentStyle.left),s.left=t==="fontSize"?"1em":i,i=s.pixelLeft+"px",s.left=n,r&&(e.runtimeStyle.left=r)),i===""?"auto":i}),v.each(["height","width"],function(e,t){v.cssHooks[t]={get:function(e,n,r){if(n)return e.offsetWidth===0&&It.test(Dt(e,"display"))?v.swap(e,Xt,function(){return tn(e,t,r)}):tn(e,t,r)},set:function(e,n,r){return Zt(e,n,r?en(e,t,r,v.support.boxSizing&&v.css(e,"boxSizing")==="border-box"):0)}}}),v.support.opacity||(v.cssHooks.opacity={get:function(e,t){return jt.test((t&&e.currentStyle?e.currentStyle.filter:e.style.filter)||"")?.01*parseFloat(RegExp.$1)+"":t?"1":""},set:function(e,t){var n=e.style,r=e.currentStyle,i=v.isNumeric(t)?"alpha(opacity="+t*100+")":"",s=r&&r.filter||n.filter||"";n.zoom=1;if(t>=1&&v.trim(s.replace(Bt,""))===""&&n.removeAttribute){n.removeAttribute("filter");if(r&&!r.filter)return}n.filter=Bt.test(s)?s.replace(Bt,i):s+" "+i}}),v(function(){v.support.reliableMarginRight||(v.cssHooks.marginRight={get:function(e,t){return v.swap(e,{display:"inline-block"},function(){if(t)return Dt(e,"marginRight")})}}),!v.support.pixelPosition&&v.fn.position&&v.each(["top","left"],function(e,t){v.cssHooks[t]={get:function(e,n){if(n){var r=Dt(e,t);return Ut.test(r)?v(e).position()[t]+"px":r}}}})}),v.expr&&v.expr.filters&&(v.expr.filters.hidden=function(e){return e.offsetWidth===0&&e.offsetHeight===0||!v.support.reliableHiddenOffsets&&(e.style&&e.style.display||Dt(e,"display"))==="none"},v.expr.filters.visible=function(e){return!v.expr.filters.hidden(e)}),v.each({margin:"",padding:"",border:"Width"},function(e,t){v.cssHooks[e+t]={expand:function(n){var r,i=typeof n=="string"?n.split(" "):[n],s={};for(r=0;r<4;r++)s[e+$t[r]+t]=i[r]||i[r-2]||i[0];return s}},qt.test(e)||(v.cssHooks[e+t].set=Zt)});var rn=/%20/g,sn=/\[\]$/,on=/\r?\n/g,un=/^(?:color|date|datetime|datetime-local|email|hidden|month|number|password|range|search|tel|text|time|url|week)$/i,an=/^(?:select|textarea)/i;v.fn.extend({serialize:function(){return v.param(this.serializeArray())},serializeArray:function(){return this.map(function(){return this.elements?v.makeArray(this.elements):this}).filter(function(){return this.name&&!this.disabled&&(this.checked||an.test(this.nodeName)||un.test(this.type))}).map(function(e,t){var n=v(this).val();return n==null?null:v.isArray(n)?v.map(n,function(e,n){return{name:t.name,value:e.replace(on,"\r\n")}}):{name:t.name,value:n.replace(on,"\r\n")}}).get()}}),v.param=function(e,n){var r,i=[],s=function(e,t){t=v.isFunction(t)?t():t==null?"":t,i[i.length]=encodeURIComponent(e)+"="+encodeURIComponent(t)};n===t&&(n=v.ajaxSettings&&v.ajaxSettings.traditional);if(v.isArray(e)||e.jquery&&!v.isPlainObject(e))v.each(e,function(){s(this.name,this.value)});else for(r in e)fn(r,e[r],n,s);return i.join("&").replace(rn,"+")};var ln,cn,hn=/#.*$/,pn=/^(.*?):[ \t]*([^\r\n]*)\r?$/mg,dn=/^(?:about|app|app\-storage|.+\-extension|file|res|widget):$/,vn=/^(?:GET|HEAD)$/,mn=/^\/\//,gn=/\?/,yn=/<script\b[^<]*(?:(?!<\/script>)<[^<]*)*<\/script>/gi,bn=/([?&])_=[^&]*/,wn=/^([\w\+\.\-]+:)(?:\/\/([^\/?#:]*)(?::(\d+)|)|)/,En=v.fn.load,Sn={},xn={},Tn=["*/"]+["*"];try{cn=s.href}catch(Nn){cn=i.createElement("a"),cn.href="",cn=cn.href}ln=wn.exec(cn.toLowerCase())||[],v.fn.load=function(e,n,r){if(typeof e!="string"&&En)return En.apply(this,arguments);if(!this.length)return this;var i,s,o,u=this,a=e.indexOf(" ");return a>=0&&(i=e.slice(a,e.length),e=e.slice(0,a)),v.isFunction(n)?(r=n,n=t):n&&typeof n=="object"&&(s="POST"),v.ajax({url:e,type:s,dataType:"html",data:n,complete:function(e,t){r&&u.each(r,o||[e.responseText,t,e])}}).done(function(e){o=arguments,u.html(i?v("<div>").append(e.replace(yn,"")).find(i):e)}),this},v.each("ajaxStart ajaxStop ajaxComplete ajaxError ajaxSuccess ajaxSend".split(" "),function(e,t){v.fn[t]=function(e){return this.on(t,e)}}),v.each(["get","post"],function(e,n){v[n]=function(e,r,i,s){return v.isFunction(r)&&(s=s||i,i=r,r=t),v.ajax({type:n,url:e,data:r,success:i,dataType:s})}}),v.extend({getScript:function(e,n){return v.get(e,t,n,"script")},getJSON:function(e,t,n){return v.get(e,t,n,"json")},ajaxSetup:function(e,t){return t?Ln(e,v.ajaxSettings):(t=e,e=v.ajaxSettings),Ln(e,t),e},ajaxSettings:{url:cn,isLocal:dn.test(ln[1]),global:!0,type:"GET",contentType:"application/x-www-form-urlencoded; charset=UTF-8",processData:!0,async:!0,accepts:{xml:"application/xml, text/xml",html:"text/html",text:"text/plain",json:"application/json, text/javascript","*":Tn},contents:{xml:/xml/,html:/html/,json:/json/},responseFields:{xml:"responseXML",text:"responseText"},converters:{"* text":e.String,"text html":!0,"text json":v.parseJSON,"text xml":v.parseXML},flatOptions:{context:!0,url:!0}},ajaxPrefilter:Cn(Sn),ajaxTransport:Cn(xn),ajax:function(e,n){function T(e,n,s,a){var l,y,b,w,S,T=n;if(E===2)return;E=2,u&&clearTimeout(u),o=t,i=a||"",x.readyState=e>0?4:0,s&&(w=An(c,x,s));if(e>=200&&e<300||e===304)c.ifModified&&(S=x.getResponseHeader("Last-Modified"),S&&(v.lastModified[r]=S),S=x.getResponseHeader("Etag"),S&&(v.etag[r]=S)),e===304?(T="notmodified",l=!0):(l=On(c,w),T=l.state,y=l.data,b=l.error,l=!b);else{b=T;if(!T||e)T="error",e<0&&(e=0)}x.status=e,x.statusText=(n||T)+"",l?d.resolveWith(h,[y,T,x]):d.rejectWith(h,[x,T,b]),x.statusCode(g),g=t,f&&p.trigger("ajax"+(l?"Success":"Error"),[x,c,l?y:b]),m.fireWith(h,[x,T]),f&&(p.trigger("ajaxComplete",[x,c]),--v.active||v.event.trigger("ajaxStop"))}typeof e=="object"&&(n=e,e=t),n=n||{};var r,i,s,o,u,a,f,l,c=v.ajaxSetup({},n),h=c.context||c,p=h!==c&&(h.nodeType||h instanceof v)?v(h):v.event,d=v.Deferred(),m=v.Callbacks("once memory"),g=c.statusCode||{},b={},w={},E=0,S="canceled",x={readyState:0,setRequestHeader:function(e,t){if(!E){var n=e.toLowerCase();e=w[n]=w[n]||e,b[e]=t}return this},getAllResponseHeaders:function(){return E===2?i:null},getResponseHeader:function(e){var n;if(E===2){if(!s){s={};while(n=pn.exec(i))s[n[1].toLowerCase()]=n[2]}n=s[e.toLowerCase()]}return n===t?null:n},overrideMimeType:function(e){return E||(c.mimeType=e),this},abort:function(e){return e=e||S,o&&o.abort(e),T(0,e),this}};d.promise(x),x.success=x.done,x.error=x.fail,x.complete=m.add,x.statusCode=function(e){if(e){var t;if(E<2)for(t in e)g[t]=[g[t],e[t]];else t=e[x.status],x.always(t)}return this},c.url=((e||c.url)+"").replace(hn,"").replace(mn,ln[1]+"//"),c.dataTypes=v.trim(c.dataType||"*").toLowerCase().split(y),c.crossDomain==null&&(a=wn.exec(c.url.toLowerCase()),c.crossDomain=!(!a||a[1]===ln[1]&&a[2]===ln[2]&&(a[3]||(a[1]==="http:"?80:443))==(ln[3]||(ln[1]==="http:"?80:443)))),c.data&&c.processData&&typeof c.data!="string"&&(c.data=v.param(c.data,c.traditional)),kn(Sn,c,n,x);if(E===2)return x;f=c.global,c.type=c.type.toUpperCase(),c.hasContent=!vn.test(c.type),f&&v.active++===0&&v.event.trigger("ajaxStart");if(!c.hasContent){c.data&&(c.url+=(gn.test(c.url)?"&":"?")+c.data,delete c.data),r=c.url;if(c.cache===!1){var N=v.now(),C=c.url.replace(bn,"$1_="+N);c.url=C+(C===c.url?(gn.test(c.url)?"&":"?")+"_="+N:"")}}(c.data&&c.hasContent&&c.contentType!==!1||n.contentType)&&x.setRequestHeader("Content-Type",c.contentType),c.ifModified&&(r=r||c.url,v.lastModified[r]&&x.setRequestHeader("If-Modified-Since",v.lastModified[r]),v.etag[r]&&x.setRequestHeader("If-None-Match",v.etag[r])),x.setRequestHeader("Accept",c.dataTypes[0]&&c.accepts[c.dataTypes[0]]?c.accepts[c.dataTypes[0]]+(c.dataTypes[0]!=="*"?", "+Tn+"; q=0.01":""):c.accepts["*"]);for(l in c.headers)x.setRequestHeader(l,c.headers[l]);if(!c.beforeSend||c.beforeSend.call(h,x,c)!==!1&&E!==2){S="abort";for(l in{success:1,error:1,complete:1})x[l](c[l]);o=kn(xn,c,n,x);if(!o)T(-1,"No Transport");else{x.readyState=1,f&&p.trigger("ajaxSend",[x,c]),c.async&&c.timeout>0&&(u=setTimeout(function(){x.abort("timeout")},c.timeout));try{E=1,o.send(b,T)}catch(k){if(!(E<2))throw k;T(-1,k)}}return x}return x.abort()},active:0,lastModified:{},etag:{}});var Mn=[],_n=/\?/,Dn=/(=)\?(?=&|$)|\?\?/,Pn=v.now();v.ajaxSetup({jsonp:"callback",jsonpCallback:function(){var e=Mn.pop()||v.expando+"_"+Pn++;return this[e]=!0,e}}),v.ajaxPrefilter("json jsonp",function(n,r,i){var s,o,u,a=n.data,f=n.url,l=n.jsonp!==!1,c=l&&Dn.test(f),h=l&&!c&&typeof a=="string"&&!(n.contentType||"").indexOf("application/x-www-form-urlencoded")&&Dn.test(a);if(n.dataTypes[0]==="jsonp"||c||h)return s=n.jsonpCallback=v.isFunction(n.jsonpCallback)?n.jsonpCallback():n.jsonpCallback,o=e[s],c?n.url=f.replace(Dn,"$1"+s):h?n.data=a.replace(Dn,"$1"+s):l&&(n.url+=(_n.test(f)?"&":"?")+n.jsonp+"="+s),n.converters["script json"]=function(){return u||v.error(s+" was not called"),u[0]},n.dataTypes[0]="json",e[s]=function(){u=arguments},i.always(function(){e[s]=o,n[s]&&(n.jsonpCallback=r.jsonpCallback,Mn.push(s)),u&&v.isFunction(o)&&o(u[0]),u=o=t}),"script"}),v.ajaxSetup({accepts:{script:"text/javascript, application/javascript, application/ecmascript, application/x-ecmascript"},contents:{script:/javascript|ecmascript/},converters:{"text script":function(e){return v.globalEval(e),e}}}),v.ajaxPrefilter("script",function(e){e.cache===t&&(e.cache=!1),e.crossDomain&&(e.type="GET",e.global=!1)}),v.ajaxTransport("script",function(e){if(e.crossDomain){var n,r=i.head||i.getElementsByTagName("head")[0]||i.documentElement;return{send:function(s,o){n=i.createElement("script"),n.async="async",e.scriptCharset&&(n.charset=e.scriptCharset),n.src=e.url,n.onload=n.onreadystatechange=function(e,i){if(i||!n.readyState||/loaded|complete/.test(n.readyState))n.onload=n.onreadystatechange=null,r&&n.parentNode&&r.removeChild(n),n=t,i||o(200,"success")},r.insertBefore(n,r.firstChild)},abort:function(){n&&n.onload(0,1)}}}});var Hn,Bn=e.ActiveXObject?function(){for(var e in Hn)Hn[e](0,1)}:!1,jn=0;v.ajaxSettings.xhr=e.ActiveXObject?function(){return!this.isLocal&&Fn()||In()}:Fn,function(e){v.extend(v.support,{ajax:!!e,cors:!!e&&"withCredentials"in e})}(v.ajaxSettings.xhr()),v.support.ajax&&v.ajaxTransport(function(n){if(!n.crossDomain||v.support.cors){var r;return{send:function(i,s){var o,u,a=n.xhr();n.username?a.open(n.type,n.url,n.async,n.username,n.password):a.open(n.type,n.url,n.async);if(n.xhrFields)for(u in n.xhrFields)a[u]=n.xhrFields[u];n.mimeType&&a.overrideMimeType&&a.overrideMimeType(n.mimeType),!n.crossDomain&&!i["X-Requested-With"]&&(i["X-Requested-With"]="XMLHttpRequest");try{for(u in i)a.setRequestHeader(u,i[u])}catch(f){}a.send(n.hasContent&&n.data||null),r=function(e,i){var u,f,l,c,h;try{if(r&&(i||a.readyState===4)){r=t,o&&(a.onreadystatechange=v.noop,Bn&&delete Hn[o]);if(i)a.readyState!==4&&a.abort();else{u=a.status,l=a.getAllResponseHeaders(),c={},h=a.responseXML,h&&h.documentElement&&(c.xml=h);try{c.text=a.responseText}catch(p){}try{f=a.statusText}catch(p){f=""}!u&&n.isLocal&&!n.crossDomain?u=c.text?200:404:u===1223&&(u=204)}}}catch(d){i||s(-1,d)}c&&s(u,f,c,l)},n.async?a.readyState===4?setTimeout(r,0):(o=++jn,Bn&&(Hn||(Hn={},v(e).unload(Bn)),Hn[o]=r),a.onreadystatechange=r):r()},abort:function(){r&&r(0,1)}}}});var qn,Rn,Un=/^(?:toggle|show|hide)$/,zn=new RegExp("^(?:([-+])=|)("+m+")([a-z%]*)$","i"),Wn=/queueHooks$/,Xn=[Gn],Vn={"*":[function(e,t){var n,r,i=this.createTween(e,t),s=zn.exec(t),o=i.cur(),u=+o||0,a=1,f=20;if(s){n=+s[2],r=s[3]||(v.cssNumber[e]?"":"px");if(r!=="px"&&u){u=v.css(i.elem,e,!0)||n||1;do a=a||".5",u/=a,v.style(i.elem,e,u+r);while(a!==(a=i.cur()/o)&&a!==1&&--f)}i.unit=r,i.start=u,i.end=s[1]?u+(s[1]+1)*n:n}return i}]};v.Animation=v.extend(Kn,{tweener:function(e,t){v.isFunction(e)?(t=e,e=["*"]):e=e.split(" ");var n,r=0,i=e.length;for(;r<i;r++)n=e[r],Vn[n]=Vn[n]||[],Vn[n].unshift(t)},prefilter:function(e,t){t?Xn.unshift(e):Xn.push(e)}}),v.Tween=Yn,Yn.prototype={constructor:Yn,init:function(e,t,n,r,i,s){this.elem=e,this.prop=n,this.easing=i||"swing",this.options=t,this.start=this.now=this.cur(),this.end=r,this.unit=s||(v.cssNumber[n]?"":"px")},cur:function(){var e=Yn.propHooks[this.prop];return e&&e.get?e.get(this):Yn.propHooks._default.get(this)},run:function(e){var t,n=Yn.propHooks[this.prop];return this.options.duration?this.pos=t=v.easing[this.easing](e,this.options.duration*e,0,1,this.options.duration):this.pos=t=e,this.now=(this.end-this.start)*t+this.start,this.options.step&&this.options.step.call(this.elem,this.now,this),n&&n.set?n.set(this):Yn.propHooks._default.set(this),this}},Yn.prototype.init.prototype=Yn.prototype,Yn.propHooks={_default:{get:function(e){var t;return e.elem[e.prop]==null||!!e.elem.style&&e.elem.style[e.prop]!=null?(t=v.css(e.elem,e.prop,!1,""),!t||t==="auto"?0:t):e.elem[e.prop]},set:function(e){v.fx.step[e.prop]?v.fx.step[e.prop](e):e.elem.style&&(e.elem.style[v.cssProps[e.prop]]!=null||v.cssHooks[e.prop])?v.style(e.elem,e.prop,e.now+e.unit):e.elem[e.prop]=e.now}}},Yn.propHooks.scrollTop=Yn.propHooks.scrollLeft={set:function(e){e.elem.nodeType&&e.elem.parentNode&&(e.elem[e.prop]=e.now)}},v.each(["toggle","show","hide"],function(e,t){var n=v.fn[t];v.fn[t]=function(r,i,s){return r==null||typeof r=="boolean"||!e&&v.isFunction(r)&&v.isFunction(i)?n.apply(this,arguments):this.animate(Zn(t,!0),r,i,s)}}),v.fn.extend({fadeTo:function(e,t,n,r){return this.filter(Gt).css("opacity",0).show().end().animate({opacity:t},e,n,r)},animate:function(e,t,n,r){var i=v.isEmptyObject(e),s=v.speed(t,n,r),o=function(){var t=Kn(this,v.extend({},e),s);i&&t.stop(!0)};return i||s.queue===!1?this.each(o):this.queue(s.queue,o)},stop:function(e,n,r){var i=function(e){var t=e.stop;delete e.stop,t(r)};return typeof e!="string"&&(r=n,n=e,e=t),n&&e!==!1&&this.queue(e||"fx",[]),this.each(function(){var t=!0,n=e!=null&&e+"queueHooks",s=v.timers,o=v._data(this);if(n)o[n]&&o[n].stop&&i(o[n]);else for(n in o)o[n]&&o[n].stop&&Wn.test(n)&&i(o[n]);for(n=s.length;n--;)s[n].elem===this&&(e==null||s[n].queue===e)&&(s[n].anim.stop(r),t=!1,s.splice(n,1));(t||!r)&&v.dequeue(this,e)})}}),v.each({slideDown:Zn("show"),slideUp:Zn("hide"),slideToggle:Zn("toggle"),fadeIn:{opacity:"show"},fadeOut:{opacity:"hide"},fadeToggle:{opacity:"toggle"}},function(e,t){v.fn[e]=function(e,n,r){return this.animate(t,e,n,r)}}),v.speed=function(e,t,n){var r=e&&typeof e=="object"?v.extend({},e):{complete:n||!n&&t||v.isFunction(e)&&e,duration:e,easing:n&&t||t&&!v.isFunction(t)&&t};r.duration=v.fx.off?0:typeof r.duration=="number"?r.duration:r.duration in v.fx.speeds?v.fx.speeds[r.duration]:v.fx.speeds._default;if(r.queue==null||r.queue===!0)r.queue="fx";return r.old=r.complete,r.complete=function(){v.isFunction(r.old)&&r.old.call(this),r.queue&&v.dequeue(this,r.queue)},r},v.easing={linear:function(e){return e},swing:function(e){return.5-Math.cos(e*Math.PI)/2}},v.timers=[],v.fx=Yn.prototype.init,v.fx.tick=function(){var e,n=v.timers,r=0;qn=v.now();for(;r<n.length;r++)e=n[r],!e()&&n[r]===e&&n.splice(r--,1);n.length||v.fx.stop(),qn=t},v.fx.timer=function(e){e()&&v.timers.push(e)&&!Rn&&(Rn=setInterval(v.fx.tick,v.fx.interval))},v.fx.interval=13,v.fx.stop=function(){clearInterval(Rn),Rn=null},v.fx.speeds={slow:600,fast:200,_default:400},v.fx.step={},v.expr&&v.expr.filters&&(v.expr.filters.animated=function(e){return v.grep(v.timers,function(t){return e===t.elem}).length});var er=/^(?:body|html)$/i;v.fn.offset=function(e){if(arguments.length)return e===t?this:this.each(function(t){v.offset.setOffset(this,e,t)});var n,r,i,s,o,u,a,f={top:0,left:0},l=this[0],c=l&&l.ownerDocument;if(!c)return;return(r=c.body)===l?v.offset.bodyOffset(l):(n=c.documentElement,v.contains(n,l)?(typeof l.getBoundingClientRect!="undefined"&&(f=l.getBoundingClientRect()),i=tr(c),s=n.clientTop||r.clientTop||0,o=n.clientLeft||r.clientLeft||0,u=i.pageYOffset||n.scrollTop,a=i.pageXOffset||n.scrollLeft,{top:f.top+u-s,left:f.left+a-o}):f)},v.offset={bodyOffset:function(e){var t=e.offsetTop,n=e.offsetLeft;return v.support.doesNotIncludeMarginInBodyOffset&&(t+=parseFloat(v.css(e,"marginTop"))||0,n+=parseFloat(v.css(e,"marginLeft"))||0),{top:t,left:n}},setOffset:function(e,t,n){var r=v.css(e,"position");r==="static"&&(e.style.position="relative");var i=v(e),s=i.offset(),o=v.css(e,"top"),u=v.css(e,"left"),a=(r==="absolute"||r==="fixed")&&v.inArray("auto",[o,u])>-1,f={},l={},c,h;a?(l=i.position(),c=l.top,h=l.left):(c=parseFloat(o)||0,h=parseFloat(u)||0),v.isFunction(t)&&(t=t.call(e,n,s)),t.top!=null&&(f.top=t.top-s.top+c),t.left!=null&&(f.left=t.left-s.left+h),"using"in t?t.using.call(e,f):i.css(f)}},v.fn.extend({position:function(){if(!this[0])return;var e=this[0],t=this.offsetParent(),n=this.offset(),r=er.test(t[0].nodeName)?{top:0,left:0}:t.offset();return n.top-=parseFloat(v.css(e,"marginTop"))||0,n.left-=parseFloat(v.css(e,"marginLeft"))||0,r.top+=parseFloat(v.css(t[0],"borderTopWidth"))||0,r.left+=parseFloat(v.css(t[0],"borderLeftWidth"))||0,{top:n.top-r.top,left:n.left-r.left}},offsetParent:function(){return this.map(function(){var e=this.offsetParent||i.body;while(e&&!er.test(e.nodeName)&&v.css(e,"position")==="static")e=e.offsetParent;return e||i.body})}}),v.each({scrollLeft:"pageXOffset",scrollTop:"pageYOffset"},function(e,n){var r=/Y/.test(n);v.fn[e]=function(i){return v.access(this,function(e,i,s){var o=tr(e);if(s===t)return o?n in o?o[n]:o.document.documentElement[i]:e[i];o?o.scrollTo(r?v(o).scrollLeft():s,r?s:v(o).scrollTop()):e[i]=s},e,i,arguments.length,null)}}),v.each({Height:"height",Width:"width"},function(e,n){v.each({padding:"inner"+e,content:n,"":"outer"+e},function(r,i){v.fn[i]=function(i,s){var o=arguments.length&&(r||typeof i!="boolean"),u=r||(i===!0||s===!0?"margin":"border");return v.access(this,function(n,r,i){var s;return v.isWindow(n)?n.document.documentElement["client"+e]:n.nodeType===9?(s=n.documentElement,Math.max(n.body["scroll"+e],s["scroll"+e],n.body["offset"+e],s["offset"+e],s["client"+e])):i===t?v.css(n,r,i,u):v.style(n,r,i,u)},n,o?i:t,o,null)}})}),e.jQuery=e.$=v,typeof define=="function"&&define.amd&&define.amd.jQuery&&define("jquery",[],function(){return v})})(window);

/*
* Copyright MadCap Software
* http://www.madcapsoftware.com/
*
* v10.2.2.0
*/
var MadCap={};MadCap.CreateNamespace=function(b){var d=b.split(".");var e=MadCap;for(var a=0,c=d.length;a<c;a++){var b=d[a];if(b=="MadCap"){continue}if(typeof(e[b])!="undefined"){e=e[b];continue}e[b]={};e=e[b]}return e};if(!Object.create){Object.create=function(b){if(arguments.length>1){throw new Error("Object.create implementation only accepts the first parameter.")}function a(){}a.prototype=b;return new a()}}MadCap.Extend=function(a,b){b.prototype=Object.create(a.prototype);b.prototype.constructor=b;b.prototype.base=a.prototype};MadCap.Exception=function(b,a){this.Number=b;this.Message=a};MadCap.IsIOS=function(){return MadCap.String.Contains(navigator.userAgent,"iphone")||MadCap.String.Contains(navigator.userAgent,"ipad")};MadCap.IsSafari=function(){return MadCap.String.Contains(navigator.userAgent,"safari")&&!MadCap.String.Contains(navigator.userAgent,"chrome")};(function(){var a=MadCap.CreateNamespace("String");a.IsNullOrEmpty=function(b){if(b==null){return true}if(b.length==0){return true}return false};a.StartsWith=function(f,e,c){if(e==null){return false}if(f.length<e.length){return false}var d=f;var b=e;if(!c){d=d.toLowerCase();b=b.toLowerCase()}if(d.substring(0,b.length)==b){return true}else{return false}};a.EndsWith=function(f,e,c){if(e==null){return false}if(f.length<e.length){return false}var d=f;var b=e;if(!c){d=d.toLowerCase();b=b.toLowerCase()}if(d.substring(d.length-b.length)==b){return true}else{return false}};a.Contains=function(h,g,c){var d=c?h:h.toLowerCase();if($.isArray(g)){for(var e=0,f=g.length;e<f;e++){var b=c?g[e]:g[e].toLowerCase();if(d.indexOf(b)!=-1){return true}}return false}var b=c?g:g.toLowerCase();return d.indexOf(b)!=-1};a.Trim=function(b){return a.TrimRight(a.TrimLeft(b))};a.TrimLeft=function(d){var b=0;var c=d.length;for(b=0;b<c&&d.charAt(b)==" ";b++){}return d.substring(b,d.length)};a.TrimRight=function(c){var b=0;for(b=c.length-1;b>=0&&c.charAt(b)==" ";b--){}return c.substring(0,b+1)};a.ToBool=function(e,c){var b=c;if(e!=null){var d=e.toLowerCase();if(d!="true"&&d!="false"&&d!="1"&&d!="0"&&d!="yes"&&d!="no"){throw new MadCap.Exception(-1,"The string can not be converted to a boolean value.")}b=d=="true"||d=="1"||d=="yes"}return b};a.ToInt=function(d,b){var c=b;if(d!=null){c=parseInt(d)}return c};a.ToDashed=function(b){return b.replace(/([A-Z])/g,function(c){return"-"+c.toLowerCase()})}})();(function(){MadCap.CreateNamespace("DEBUG");var a=MadCap.DEBUG;a.Log={};a.Log.Create=function(){var e=document.createElement("div");e.setAttribute("id","DEBUG_Log");var f=document.createElement("div");$(f).addClass("MCDebugLogHeader");f.appendChild(document.createTextNode("Log Console"));e.appendChild(f);var d=document.createElement("div");$(d).addClass("MCDebugLogBody");e.appendChild(d);var c=document.createElement("div");$(c).addClass("MCDebugLogFooter");e.appendChild(c);document.body.appendChild(e);var b=new MadCap.DragDrop(e,f)};a.Log._LoadTime=new Date();a.Log.AddLine=function(d){if(parent!=window){MadCap.Utilities.CrossFrame.PostMessageRequest(parent,"DEBUG-AddLine",[d],null);return}var f=document.getElementById("DEBUG_Log");if(f==null){return}var c=new Date();var h=c-a.Log._LoadTime;var e=document.createElement("p");$(e).addClass("MCDebugLogEntryTime");e.appendChild(document.createTextNode(h+"ms "+c.toLocaleTimeString()));var b=document.createElement("div");$(b).addClass("MCDebugLogEntry");b.appendChild(e);b.appendChild(document.createTextNode(d));var g=MadCap.Dom.GetElementsByClassName("MCDebugLogBody","div",f)[0];g.insertBefore(b,g.firstChild)}})();/*
* Copyright MadCap Software
* http://www.madcapsoftware.com/
*
* v10.0.0.0
*/
(function(){MadCap.CreateNamespace("Dom");var a=MadCap.Dom;a.Dataset=function(c,b){return c.getAttribute("data-"+MadCap.String.ToDashed(b))};a.GetElementsByClassName=function(g,b,c){b=b||"*";c=c||document;var d=new Array();var j=c.getElementsByTagName(b);for(var e=0,h=j.length;e<h;e++){var f=j[e];if($(f).hasClass(g)){d[d.length]=f}}return d};a.GetElementsByAttribute=function(h,k,l,j){l=l||"*";j=j||document;var c=new Array();var b=j.getElementsByTagName(l);for(var g=0,e=b.length;g<e;g++){var d=b[g];var f=a.GetAttribute(d,h);if(f==k){c[c.length]=d}}return c};a.GetChildNodeByTagName=function(d,f,e){var c=null;var g=-1;for(var b=d.firstChild;b!=null;b=b.nextSibling){if(b.nodeName.toLowerCase()==f.toLowerCase()){g++;if(g==e){c=b;break}}}return c};a.GetAncestorNodeByTagName=function(d,e,f){f=f||document.body;var c=null;var b=d.parentNode;while(b!=null&&b!=f){if(b.nodeName.toLowerCase()==e.toLowerCase()){c=b;break}b=b.parentNode}return c};a.GetAttribute=function(b,e){var d=b.getAttribute(e);if(d==null){d=b.getAttribute(e.toLowerCase());if(d==null){var c=e.indexOf(":");if(c!=-1){d=b.getAttribute(e.substring(c+1,e.length))}}}return d};a.GetAttributeInt=function(e,c,b){var d=b;var f=a.GetAttribute(e,c);if(f!=null){d=parseInt(f)}return d};a.GetAttributeBool=function(e,d,c){var b=null;var f=a.GetAttribute(e,d);if(f!=null){b=MadCap.String.ToBool(f,c)}return b};a.GetScrollPosition=function(){var b=0;var c=0;if(typeof(window.pageYOffset)!="undefined"){b=window.pageXOffset;c=window.pageYOffset}else{if(typeof(document.documentElement.scrollTop)!="undefined"&&document.documentElement.scrollTop>0){b=document.documentElement.scrollLeft;c=document.documentElement.scrollTop}}return{X:b,Y:c}}})();/*
* Copyright MadCap Software
* http://www.madcapsoftware.com/
*
* v10.0.0.0
*/
(function(){MadCap.CreateNamespace("Utilities");MadCap.Utilities.Dictionary=function(f){this._Map=new Object();this._Overflows=new Array();this._Length=0;this._IgnoreCase=f==true};var a=MadCap.Utilities.Dictionary;a.prototype.GetLength=function(f){return this._Length};a.prototype.ForEach=function(j){var f=this._Map;for(var n in f){var m=f[n];var l=j(n,m);if(l!=undefined&&!l){return}}var h=this._Overflows;for(var k=0,g=h.length;k<g;k++){var o=h[k];var l=j(o.Key,o.Value);if(l!=undefined&&!l){return}}};a.prototype.GetItem=function(g){if(this._IgnoreCase){g=g.toLowerCase()}var h=null;if(typeof(this._Map[g])=="function"){var f=this.GetItemOverflowIndex(g);if(f>=0){h=this._Overflows[f].Value}}else{h=this._Map[g];if(typeof(h)=="undefined"){h=null}}return h};a.prototype.GetItemOverflowIndex=function(g){if(this._IgnoreCase){g=g.toLowerCase()}var j=this._Overflows;for(var f=0,h=j.length;f<h;f++){if(j[f].Key==g){return f}}return -1};a.prototype.Remove=function(g){if(this._IgnoreCase){g=g.toLowerCase()}if(typeof(this._Map[g])=="function"){var f=this.GetItemOverflowIndex(g);if(f>=0){this._Overflows.splice(f,1);this._Length--}}else{if(typeof(this._Map[g])!="undefined"){delete (this._Map[g]);this._Length--}}};a.prototype.Add=function(f,h){if(this._IgnoreCase){f=f.toLowerCase()}if(typeof(this._Map[f])=="function"){var g=this.GetItem(f);if(g!=null){this.Remove(f)}this._Overflows[this._Overflows.length]={Key:f,Value:h}}else{this._Map[f]=h}this._Length++};a.prototype.AddUnique=function(f,h){if(this._IgnoreCase){f=f.toLowerCase()}var g=this.GetItem(f);if(typeof(g)=="undefined"||!g){this.Add(f,h)}};MadCap.Utilities.DateTime=function(h){var g=/\/Date\(([0-9]+)\)\//i;var f=g.exec(h);if(f!=null){this.Date=new Date(parseInt(f[1]))}else{this.Date=new Date(h)}};var c=MadCap.Utilities.DateTime;c.Months=["Jan","Feb","Mar","Apr","May","Jun","Jul","Aug","Sep","Oct","Nov","Dec"];MadCap.Utilities.TimeSpan=function(g,f){if(typeof g=="undefined"){g=new Date()}if(typeof f=="undefined"){f=new Date()}if(g>f){this.FromDate=f;this.ToDate=g}else{this.FromDate=g;this.ToDate=f}this.Ticks=this.ToDate-this.FromDate;this.Seconds=this.Ticks/1000;this.Minutes=this.Seconds/60;this.Hours=this.Minutes/60;this.Days=this.Hours/24};var b=MadCap.Utilities.TimeSpan;b.prototype.ToDurationString=function(){if(this.Minutes<1){return"Just now"}if(this.Hours<1){return parseInt(this.Minutes)+" minutes ago"}if(this.Days<1){return parseInt(this.Hours)+" hours ago"}if(this.Days<30){return parseInt(this.Days)+" days ago"}var f=c.Months[this.FromDate.getMonth()]+" "+this.FromDate.getDate();if(this.FromDate.getFullYear()!=this.ToDate.getFullYear()){f+=", "+this.FromDate.getFullYear()}return f};MadCap.Utilities.Url=function(g){var f=this;this._Segments=[];this.FullPath=null;this.Path=null;this.PlainPath=null;this.Name=null;this.Extension=null;this.NameWithExtension=null;this.Fragment=null;this.Query=null;this.IsAbsolute=false;this.IsFolder=false;this.QueryMap=new MadCap.Utilities.Dictionary(true);this.HashMap=new MadCap.Utilities.Dictionary(true);(function(){var p="";var s="";var q=g.indexOf("#");var n=g.indexOf("?");if(q!=-1){if(q>n){p=g.substring(q)}else{p=g.substring(q,n)}}if(n!=-1){if(n>q){s=g.substring(n)}else{s=g.substring(n,q)}}var t=q>-1?(n>-1?Math.min(q,n):q):n;var o=g.substring(0,t==-1?g.length:t);t=o.lastIndexOf("/");var v=o.substring(0,t+1);var m=o.substring(t+1);t=m.lastIndexOf(".");var h=m.substring(0,t);var k=m.substring(t+1);var j="";t=g.indexOf(":");if(t>=0){j=g.substring(0,t)}if(!MadCap.String.IsNullOrEmpty(g)){var r=g;if(MadCap.String.EndsWith(r,"/")){r=r.substring(0,r.length-1)}f._Segments=r.split("/")}f.FullPath=g;f.Path=v;f.PlainPath=o;f.Name=h;f.Extension=k;f.NameWithExtension=m;f.Scheme=j;f.IsAbsolute=!MadCap.String.IsNullOrEmpty(j);f.IsFolder=MadCap.String.EndsWith(o,"/");f.Fragment=p;f.Query=s;var u=f.Query;if(!MadCap.String.IsNullOrEmpty(u)){u=u.substring(1);u=u.replace(/\+/g," ");i(u,"&",f.QueryMap)}var l=f.Fragment;if(!MadCap.String.IsNullOrEmpty(l)){l=l.substring(1);i(l,"|",f.HashMap)}function i(F,x,w){var C=F.split(x);for(var A=0,y=C.length;A<y;A++){var z=C[A];var B=z.indexOf("=");var E=null;var D=null;if(B>=0){E=decodeURIComponent(z.substring(0,B));D=decodeURIComponent(z.substring(B+1))}else{E=z}w.Add(E,D)}}})()};var e=MadCap.Utilities.Url;e.StripInvalidCharacters=function(f){return f.replace(/(javascript:|data:|[<>])/gi,"")};e.prototype.AddFile=function(i){if(typeof(i)=="string"){i=new e(i)}if(i.IsAbsolute){return i}var h=i.FullPath;if(h.charAt(0)=="/"){var j=document.location;var k=j.href.lastIndexOf(j.pathname);var g=j.href.substring(0,k);return new e(g+h)}var f=this.FullPath;if(!MadCap.String.EndsWith(f,"/")){f=f+"/"}return new e(f+h)};e.prototype.CombinePath=function(l){if(typeof(l)=="string"){l=new e(l)}if(l.IsAbsolute){throw new MadCap.Exception(-1,"Cannot combine two absolute paths.")}var j=l.FullPath;var k=l.FullPath.split("/");var o=this.FullPath;var m="";if(this.Scheme=="mk"){var n=o.indexOf("::");m=o.substring(0,n+"::".length);o=o.substring(n+"::".length)}for(var h=0,f=k.length;h<f;h++){var g=k[h];if(o.length>1&&MadCap.String.EndsWith(o,"/")){o=o.substring(0,o.length-1)}if(g=="."){o+="/"}else{if(g==".."){o=o.substring(0,o.lastIndexOf("/")+1)}else{if(o!=""&&!MadCap.String.EndsWith(o,"/")){o+="/"}o+=g}}}o=m+o;return new e(o)};e.prototype.ToQuery=function(g){var f=this.PlainPath+"?"+g+this.Fragment;return new e(f)};e.prototype.ToFolder=function(){var f=this.PlainPath;if(MadCap.String.EndsWith(f,"/")){f=f.substring(0,f.length-1)}var h=f.lastIndexOf("/");var g=f.substring(0,h+1);return new e(g)};e.prototype.ToRelative=function(n){if(typeof(n)=="string"){n=new e(n)}if(this.IsAbsolute!=n.IsAbsolute){return this}var k=0;var l=n._Segments.length;for(;k<l;k++){var g=this._Segments[k];var f=n._Segments[k];if(g!=f){break}}var m="";var o=MadCap.String.EndsWith(n.FullPath,"/")?0:1;for(var h=0;h<l-k-o;h++){m+="../"}for(var h=k;h<this._Segments.length;h++){if(h>k){m+="/"}m+=this._Segments[h]}return new e(m)};e.prototype.ToExtension=function(j){var h=this.FullPath;var i=h.lastIndexOf(".");var g=h.substring(0,i);var f=g+"."+j;return new e(f)};e.prototype.ToScheme=function(f){var h=this.FullPath;pos=h.indexOf(":");if(pos<0){return this}var g=f+":"+h.substring(pos);return new e(g)};e.prototype.ToPath=function(){return new e(this.Path)};e.prototype.ToPlainPath=function(){return new e(this.PlainPath)};e.prototype.ToNoQuery=function(){return new e(this.PlainPath+this.Fragment)};MadCap.Utilities.CrossFrame={};var d=MadCap.Utilities.CrossFrame;d.MESSAGE_SEPARATOR="%%%%%";d.DATA_SEPARATOR="^^^^^";d._MessageID=0;d._MessageInfos=new Array();d._MessageHandlerFuncs=new Array();d._PostMessage=function(h,f){if(typeof h=="undefined"){return}if(h.postMessage!=null){h.postMessage(f,"*");return}var g={data:f,source:window};h.MadCap.Utilities.CrossFrame.OnMessage(g)};d.AddMessageHandler=function(h,g){var f=d._MessageHandlerFuncs.length;d._MessageHandlerFuncs[f]={HandlerFunc:h,ContextObj:g}};d.PostMessageRequest=function(n,k,l,f){d._MessageInfos[d._MessageID]=f;var h="";if(l!=null){for(var g=0,j=l.length;g<j;g++){if(g>0){h+=d.DATA_SEPARATOR}h+=l[g]}}var m="request"+d.MESSAGE_SEPARATOR+k+d.MESSAGE_SEPARATOR+h+d.MESSAGE_SEPARATOR+d._MessageID;d._PostMessage(n,m);d._MessageID++};d._PostMessageResponse=function(n,k,l,f){var h="";if(l!=null){for(var g=0,j=l.length;g<j;g++){if(g>0){h+=d.DATA_SEPARATOR}h+=l[g]}}var m="response"+d.MESSAGE_SEPARATOR+k+d.MESSAGE_SEPARATOR+h+d.MESSAGE_SEPARATOR+f;d._PostMessage(n,m);d._MessageID++};d.OnMessage=function(t){var s=t.originalEvent;var o=s.data.split(d.MESSAGE_SEPARATOR);var m=o[0];var l=o[1];var j=o[2];var f=parseInt(o[3]);var h=null;if(!MadCap.String.IsNullOrEmpty(j)){h=j.split(d.DATA_SEPARATOR);for(var p=0,g=h.length;p<g;p++){if(h[p]=="null"){h[p]=null}}}if(m=="request"){var k=false;var x=true;var v=new Array();for(var p=0,g=d._MessageHandlerFuncs.length;p<g;p++){var w=d._MessageHandlerFuncs[p];var u=w.HandlerFunc;var q=w.ContextObj;var r=null;if(q!=null){r=u.call(q,l,h,v,s.source,f)}else{r=u(l,h,v,s.source,f)}k=r.Handled;x=r.FireResponse;if(k){break}}if(!k){if(l=="DEBUG-AddLine"){var l=h[0];MadCap.DEBUG.Log.AddLine(l);k=true}else{if(l=="url"){v[v.length]=document.location.href;k=true}else{if(l=="get-title"){v[v.length]=document.title;k=true}else{if(l=="navigate"){var n=h[0];document.location.href=n;k=true}}}}}if(x){d._PostMessageResponse(s.source,l,v.length>0?v:null,f)}}else{if(m=="response"){if(d._MessageInfos[f]!=null){d._MessageInfos[f](h)}}}};if(window.postMessage!="undefined"){$(window).bind("message",d.OnMessage)}else{}MadCap.Utilities.PreventDefault=function(f){f.preventDefault?f.preventDefault():event.returnValue=false};MadCap.Utilities.LoadScript=function(i,h,g){var f=document.createElement("script");f.src=i;f.type="text/javascript";if(f.addEventListener){$(f).error(g);$(f).load(h)}else{if(f.readyState){f.onreadystatechange=function(){if(f.readyState=="loaded"||f.readyState=="complete"){h()}}}}document.getElementsByTagName("head")[0].appendChild(f)};MadCap.Utilities.AsyncForeach=function(i,g,h){i=i.slice(0);function f(){var j=i.shift();g(j,function(k){if(i.length>0){f()}else{h()}})}if(i.length>0){f()}else{h()}};MadCap.Utilities.CreateStylesheet=function(i,j){var g=i||document,f;var h=g.createElement("style");if(j){h.setAttribute("media",j)}g.getElementsByTagName("head")[0].appendChild(h);f=g.styleSheets[g.styleSheets.length-1];return f};MadCap.Utilities.AsyncForeachParallel=function(l,j,k){var h=0;if(l.length===0){k()}var f=l.length;for(var g=0;g<f;g++){j(l[g],function(){h++;if(h===l.length){k()}})}};MadCap.Utilities.Store=(function(){if(window.localStorage){return window.localStorage}var g="MadCap";var h=document.createElement("div");h.style.display="none";document.getElementsByTagName("head")[0].appendChild(h);if(h.addBehavior){h.addBehavior("#default#userdata");h.load(g);return{getItem:function(i){return h.XMLDocument.documentElement.getAttribute(i)},setItem:function(i,j){h.XMLDocument.documentElement.setAttribute(i,j);h.save(g)},removeItem:function(i){h.removeAttribute(i);h.save(g)}}}var f="data-"+g+"-";return{getItem:function(i){var j=h.getAttribute(f+i);return j?decodeURIComponent(j):j},setItem:function(i,j){h.setAttribute(f+i,j?encodeURIComponent(j):null)},removeItem:function(i){h.removeAttribute(f+i)}}})()})();Array.prototype.Remove=function(a){if(a<0||a>this.length){throw"Index out of bounds."}this.splice(a,1)};Array.prototype.RemoveValue=function(b){for(var a=this.length-1;a>=0;a--){if(this[a]==b){this.Remove(a)}}};/*
* Copyright MadCap Software
* http://www.madcapsoftware.com/
*
* v10.0.0.0
*/
(function(){MadCap.Utilities.Xhr=function(d,b,c){var e=this;this._XmlDoc=null;this._XmlHttp=null;this._Args=d;this._LoadFunc=b;this._LoadContextObj=c;this.OnreadystatechangeLocal=function(){if(e._XmlDoc.readyState==4){e._XmlDoc.onreadystatechange=a._Noop;var f=null;if(e._XmlDoc.documentElement!=null){f=e._XmlDoc}if(e._LoadContextObj==null){e._LoadFunc(f,e._Args)}else{e._LoadFunc.call(e._LoadContextObj,f,e._Args)}}};this.OnreadystatechangeRemote=function(){if(e._XmlHttp.readyState==4){e._XmlHttp.onreadystatechange=a._Noop;var f=null;if(e._XmlHttp.responseXML!=null&&e._XmlHttp.responseXML.documentElement!=null){f=e._XmlHttp.responseXML}if(e._LoadContextObj==null){e._LoadFunc(f,e._Args)}else{e._LoadFunc.call(e._LoadContextObj,f,e._Args)}}}};var a=MadCap.Utilities.Xhr;a.prototype._LoadLocal=function(b,c){if(window.ActiveXObject){this._XmlDoc=a._GetMicrosoftXmlDomObject();this._XmlDoc.async=c;if(this._LoadFunc){this._XmlDoc.onreadystatechange=this.OnreadystatechangeLocal}try{if(!this._XmlDoc.load(b)){this._XmlDoc=null}}catch(d){this._XmlDoc=null}}else{if(window.XMLHttpRequest){this._LoadRemote(b,c)}}return this._XmlDoc};a.prototype._LoadRemote=function(b,c){this._XmlHttp=a._GetXhrObject();if(this._LoadFunc){this._XmlHttp.onreadystatechange=this.OnreadystatechangeRemote}try{this._XmlHttp.open("GET",b,c);this._XmlHttp.send(null);if(!c&&(this._XmlHttp.status==0||this._XmlHttp.status==200)){this._XmlDoc=this._XmlHttp.responseXML}}catch(d){this._XmlHttp.abort();if(this._LoadFunc){if(this._LoadContextObj==null){this._LoadFunc(null,this._Args)}else{this._LoadFunc.call(this._LoadContextObj,null,this._Args)}}}return this._XmlDoc};a.prototype.Load=function(b,d){var e=null;var c=document.location.protocol;if(c=="file:"||c=="mk:"||c=="ms-its:"||c=="app:"){e=this._LoadLocal(b,d)}else{if(c=="http:"||c=="https:"){e=this._LoadRemote(b,d)}}return e};a.LoadXmlString=function(c){var b=null;if(window.ActiveXObject){b=a._GetMicrosoftXmlDomObject();b.async=false;b.loadXML(c)}else{if(DOMParser){var d=new DOMParser();b=d.parseFromString(c,"text/xml")}}return b};a.CreateXmlDocument=function(b){var c="<"+b+" />";var d=a.LoadXmlString(c);return d};a.GetOuterXml=function(d){var b=null;if(window.ActiveXObject){b=d.xml}else{if(window.XMLSerializer){var c=new XMLSerializer();b=c.serializeToString(d)}}return b};a.ImportNode=function(c,b){if(typeof(c.importNode)=="function"){return c.importNode(b,true)}return b.cloneNode(true)};a.CallWebService=function(e,d,f,b){var c=new a(b,f,null);var g=c.Load(e,d);return g};a._MicrosoftXmlDomProgIDs=["Msxml2.DOMDocument.6.0","Msxml2.DOMDocument","Microsoft.XMLDOM"];a._MicrosoftXmlHttpProgIDs=["Msxml2.XMLHTTP.6.0","Msxml2.XMLHTTP","Microsoft.XMLHTTP"];a._MicrosoftXmlDomProgID=null;a._MicrosoftXmlHttpProgID=null;a._FilePathToXmlStringMap=new MadCap.Utilities.Dictionary();a._LoadingFilesPathMap=new MadCap.Utilities.Dictionary();a._LoadingFromQueue=false;a.ForceUseJS=false;a.Load=function(g,e,b,h,c){function l(){a._LoadingFilesPathMap.Remove(j.FullPath);var n=a._FilePathToXmlStringMap.GetItem(j.Name);if(n!=null){a._FilePathToXmlStringMap.Remove(j.Name);m=a.LoadXmlString(n)}a._LoadingFilesPathMap.ForEach(function(q,r){var p=new MadCap.Utilities.Url(q);var o=r;if(p.Name==f&&p.FullPath!=j.FullPath){a._LoadingFilesPathMap.Remove(p.FullPath);a._LoadingFromQueue=true;a.Load(p.FullPath,o.async,o.LoadFunc,o.args,o.loadContextObj);return false}return true});if(c==null){b(m,h)}else{b.call(c,m,h)}}var m=null;if(a.ForceUseJS||(Boolean(!window.ActiveXObject)&&MadCap.String.StartsWith(document.location.protocol,"file"))){var i=new MadCap.Utilities.Url(g);var j=i.ToExtension("js");var f=j.Name;a._LoadingFilesPathMap.Add(j.FullPath,{async:e,LoadFunc:b,args:h,loadContextObj:c});var k=false;a._LoadingFilesPathMap.ForEach(function(p,q){var o=new MadCap.Utilities.Url(p);var n=q;if(o.Name==f&&o.FullPath!=j.FullPath){k=true;return false}return true});if(a._LoadingFromQueue||!k){a._LoadingFromQueue=false;MadCap.Utilities.LoadScript(j.FullPath,l,l)}}else{var d=new a(h,b,c);m=d.Load(g,e)}return m};a._Noop=function(){};a._GetMicrosoftXmlDomObject=function(){var e=null;if(a._MicrosoftXmlDomProgID==null){for(var c=0;c<a._MicrosoftXmlDomProgIDs.length;c++){var d=a._MicrosoftXmlDomProgIDs[c];try{e=new ActiveXObject(d);a._MicrosoftXmlDomProgID=d;break}catch(b){}}}else{e=new ActiveXObject(a._MicrosoftXmlDomProgID)}return e};a._GetXhrObject=function(){if(window.XMLHttpRequest){return function(){return new window.XMLHttpRequest()}}else{if(window.ActiveXObject){return function(){var e=null;if(a._MicrosoftXmlHttpProgID==null){for(var c=0;c<a._MicrosoftXmlHttpProgIDs.length;c++){var d=a._MicrosoftXmlHttpProgIDs[c];try{e=new ActiveXObject(d);a._MicrosoftXmlHttpProgID=d;break}catch(b){}}}else{e=new ActiveXObject(a._MicrosoftXmlHttpProgID)}return e}}}}()})();/*
* Copyright MadCap Software
* http://www.madcapsoftware.com/
*
* v10.0.0.0
*/
(function(){MadCap.CreateNamespace("TopicHelpers");var a=MadCap.TopicHelpers;a.TextEffectControl=function(d,c){if(this._rootEl==null){this._rootEl=d}this._hotSpotEl=null;this._bodyEls=null;this._className=c;a.TextEffectControl.Controls[a.TextEffectControl.Controls.length]=this;var b=this;(function(){b._hotSpotEl=MadCap.Dom.GetElementsByClassName(b._className+"HotSpot",null,b._rootEl)[0];b._bodyEls=MadCap.Dom.GetElementsByClassName(b._className+"Body",null,b._rootEl);$(b._hotSpotEl).click(function(f){b.Toggle.call(b)})})()};a.TextEffectControl.Controls=new Array();a.TextEffectControl.FindControl=function(c){for(var b=0;b<a.TextEffectControl.Controls.length;b++){if(a.TextEffectControl.Controls[b]._rootEl==c){return a.TextEffectControl.Controls[b]}}return null};a.TextEffectControl.ExpandAll=function(b){for(var c=0,d=a.TextEffectControl.Controls.length;c<d;c++){var e=a.TextEffectControl.Controls[c];if(b=="open"){e.Open(false)}else{if(b=="close"){e.Close(false)}}}};a.TextEffectControl.prototype.Open=function(){var d=$(this._rootEl);d.removeClass(this._className+"_Closed");d.addClass(this._className+"_Open");var c=null;if(d.hasClass("MCToggler")){c=$(".MCToggler_Image_Icon")}else{if(d.hasClass("MCDropDown")){c=$(".MCDropDown_Image_Icon")}else{if(d.hasClass("MCExpanding")){c=$(".MCExpanding_Image_Icon")}}}var b=d.find(c);this.ToggleAltText(b[0],d,"closed");d.attr("data-mc-state","open")};a.TextEffectControl.prototype.Close=function(){var d=$(this._rootEl);d.removeClass(this._className+"_Open");d.addClass(this._className+"_Closed");var c=null;if(d.hasClass("MCToggler")){c=$(".MCToggler_Image_Icon")}else{if(d.hasClass("MCDropDown")){c=$(".MCDropDown_Image_Icon")}else{if(d.hasClass("MCExpanding")){c=$(".MCExpanding_Image_Icon")}}}var b=d.find(c);this.ToggleAltText(b[0],d,"open");d.attr("data-mc-state","closed")};a.TextEffectControl.prototype.ToggleAltText=function(g,c,d){if(g!=null){var b=$(g);var f=b.attr("data-mc-alt2");var e=b.attr("alt");if(c!=null&&c.attr("data-mc-state")==d){b.attr("alt",f);b.attr("data-mc-alt2",e)}}};a.TextEffectControl.prototype.Toggle=function(){var d=$(this._rootEl);var b=d.attr("data-mc-state")||"closed";var c=null;if(b=="open"){this.Close(true)}else{if(b=="closed"){this.Open(true)}}$(d.find("a")[0]).focus()};$(function(){var c=$(".MCExpanding");for(var b=0,d=c.length;b<d;b++){var f=c[b];var e=new MadCap.TopicHelpers.ExpandingControl(f);e.Init()}});a.ExpandingControl=function(b){a.TextEffectControl.call(this,b,"MCExpanding")};MadCap.Extend(a.TextEffectControl,a.ExpandingControl);a.ExpandingControl.prototype.Init=function(){this.Close(false)};a.ExpandingControl.prototype.Open=function(b){this.base.Open.call(this);var c=$(this._bodyEls[0]);c.css({"white-space":"nowrap"});if(b){c.hide().animate({width:"show"},function(){$(this).css({"white-space":"normal"})})}else{c.show()}};a.ExpandingControl.prototype.Close=function(c){if(!c){$(this._bodyEls[0]).hide();this.base.Close.call(this);return}var b=this;$(this._bodyEls[0]).css({"white-space":"nowrap"}).animate({width:"hide"},function(){$(this).css({"white-space":"normal"});b.base.Close.call(b)})};$(function(){var d=$(".MCDropDown");for(var c=0,e=d.length;c<e;c++){var b=d[c];var f=new MadCap.TopicHelpers.DropDownControl(b);f.Init(false)}});a.DropDownControl=function(b){a.TextEffectControl.call(this,b,"MCDropDown")};MadCap.Extend(a.TextEffectControl,a.DropDownControl);a.DropDownControl.prototype.Init=function(){this.Close(false)};a.DropDownControl.prototype.Open=function(b){this.base.Open.call(this);var c=$(this._bodyEls[0]);if(b){c.hide().slideDown()}else{c.show()}};a.DropDownControl.prototype.Close=function(c){if(!c){$(this._bodyEls[0]).hide();this.base.Close.call(this);return}var b=this;$(this._bodyEls[0]).slideUp(function(){b.base.Close.call(b)})};$(function(){var d=$(".MCToggler");for(var b=0,c=d.length;b<c;b++){var f=d[b];var e=new MadCap.TopicHelpers.TogglerControl(f);e.Init()}});a.TogglerControl=function(c){this._rootEl=c;this._hotSpotEl=c;this._bodyEls=new Array();this._className="MCToggler";a.TextEffectControl.Controls[a.TextEffectControl.Controls.length]=this;var b=this;(function(){var h=MadCap.Dom.Dataset(b._rootEl,"mcTargets");var d=h.split(";");for(var f=0,g=d.length;f<g;f++){var j=d[f];var e=MadCap.Dom.GetElementsByAttribute("data-mc-target-name",j,null,document.body);b._bodyEls=b._bodyEls.concat(e)}$(b._hotSpotEl).click(function(i){b.Toggle.call(b)})})()};MadCap.Extend(a.TextEffectControl,a.TogglerControl);a.TogglerControl.prototype.Init=function(){this.Close(false)};a.TogglerControl.prototype.Open=function(b){this.base.Open.call(this);for(var c=0,d=this._bodyEls.length;c<d;c++){if(b){$(this._bodyEls[c]).css({opacity:0,display:""});$(this._bodyEls[c]).animate({opacity:1},200)}else{$(this._bodyEls[c]).css({opacity:1,display:""})}}};a.TogglerControl.prototype.Close=function(c){this.base.Close.call(this);function f(g){$(g).css("display","none")}for(var d=0,e=this._bodyEls.length;d<e;d++){var b=this;if(c){$(this._bodyEls[d]).animate({opacity:0},200,function(){f(this)})}else{f(this._bodyEls[d])}}};$(function(){var b=$(".MCTextPopup");for(var c=0,e=b.length;c<e;c++){var f=b[c];var d=new MadCap.TopicHelpers.TextPopupControl(f);d.Init()}});a.TextPopupControl=function(c){this._rootEl=c;this._hotSpotEl=c;this._bodyEls=null;this._className="MCTextPopup";var b=this;(function(){b._bodyEls=$("."+b._className+"Body",b._rootEl).toArray();$(b._hotSpotEl).mouseover(function(d){b.Open()});$(b._hotSpotEl).mouseleave(function(d){b.Close()})})()};MadCap.Extend(a.TextEffectControl,a.TextPopupControl);a.TextPopupControl.prototype.Init=function(){this.Close(false)};a.TextPopupControl.prototype.Open=function(){this.base.Open.call(this);var y=$(this._rootEl);var j=$(this._bodyEls[0]);var e=$(".MCTextPopupArrow",y);var s=$(window);j.css("top","0");j.css("left","0");j.css("height","auto");var h=13;var m=j.offset().top;var n=j.offset().left;var v=y.offset().top-m;var k=y.offset().left-n;var l=v+this._rootEl.offsetHeight;var u=j[0].offsetWidth;var o=j[0].offsetHeight;var A=k+(y[0].offsetWidth/2);var f=A-(u/2);var x=f+u;var r=l+h;var d=s.scrollTop();var t=s.scrollLeft();var c=-e[0].offsetWidth/2;var b=s.width();var q=d+s.height()-l;if((o+h)>q){var z=v-d;if((o+h)>z){r=l;var p=parseInt(j.css("border-top-width"));var g=parseInt(j.css("border-bottom-width"));var w=parseInt(j.css("padding-top"));var i=parseInt(j.css("padding-bottom"));j.css("height",(q-p-g-w-i)+"px");j.css("overflow","auto")}else{j.addClass("MCTextPopupBodyBottom");r=v-o-h}}else{j.removeClass("MCTextPopupBodyBottom")}j.css("top",r+"px");if(x>=b+t){c+=(x-b-t)}if(f<t){c+=(f-t)}f=Math.min(f,t+b-u);f=Math.max(f,t);j.css("left",f+"px");e.css("margin-left",c+"px");j.animate({opacity:1},200)};a.TextPopupControl.prototype.Close=function(){this.base.Close.call(this);var b=$(this._bodyEls[0]);b.css("opacity",0)};$(function(){var f=$(".MCTopicPopup");for(var c=0,d=f.length;c<d;c++){var b=f[c];var e=new MadCap.TopicHelpers.TopicPopupControl(b);e.Init()}});a.TopicPopupControl=function(c){this._rootEl=c;this._hotSpotEl=c;this._bodyEls=null;this._className="MCTopicPopup";var b=this;(function(){b._bodyEls=$("."+b._className+"Body",b._rootEl).toArray();$(b._hotSpotEl).click(function(d){b.Open();$(document.documentElement).click(function(f){b.Close();$(document.documentElement).off("click",arguments.callee)});d.stopPropagation();MadCap.Utilities.PreventDefault(d)})})()};MadCap.Extend(a.TextEffectControl,a.TopicPopupControl);a.TopicPopupControl.prototype.Init=function(){this.Close(false)};a.TopicPopupControl.prototype.Open=function(){this.base.Open.call(this);var f=$("<div></div>");f.addClass("MCTopicPopupContainer needs-pie");var b=MadCap.Dom.GetAttribute(this._hotSpotEl,"href");var i=document.createElement("iframe");$(i).addClass("MCTopicPopupBody");i.setAttribute("src",b);i.setAttribute("name","MCPopup");f.append(i);f.appendTo(document.body);var g=$(this._rootEl);var c=g.attr("data-mc-width");var m=g.attr("data-mc-height");if(c!=null||m!=null){f.css({top:"50%",left:"50%",width:c,height:m});var e=f.width();var h=f.height();var d=$(window);var l=d.width()-100;var k=d.height()-100;if(e>l){f.css({width:l+"px"});e=l}if(h>k){f.css({height:k+"px"});h=k}f.css({"margin-top":(-h/2)+"px","margin-left":(-e/2)+"px"})}$(i).css("height",f.height());f.animate({opacity:1},200);var j=a.AddBackgroundTint("dark");$(j).animate({opacity:0.5},200)};a.TopicPopupControl.prototype.Close=function(){this.base.Close.call(this);var b=$(".MCTopicPopupContainer");b.remove();a.RemoveBackgroundTint()};a.CreateLinkListTree=function(q,h,e,g,o){a.RemoveLinkListTrees();if(!g){g=""}var b=$("<ul class='responsive-link-list tree inner'></ul>");var j=$(e).attr("target");for(var f=0,c=q.length;f<c;f++){var p=q[f];var m=$("<li class='IndexEntry IndexEntryLink tree-node tree-node-leaf'></li>").appendTo(b);var l=$("<div class='IndexTerm'></div>").appendTo(m);var k=$("<span class='label'></span>").appendTo(l);var d=$("<a/>").appendTo(k);d.text(p.Title);var n=p.Link;d.attr("href",g+n);m.click(o)}b.appendTo(h)};a.CreateLinkListPopup=function(k,h,p,g,w,t){a.RemoveLinkListPopups();if(!t){t=""}var j=$("<div class='link-list-popup needs-pie'><ul></ul></div>");var q=j.children("ul");var x=$(w).attr("target");for(var u=0,f=k.length;u<f;u++){var v=k[u];var m=$("<li><a></a></li>").appendTo(q);var e=$("a",m);e.attr("target",x);if(x=="_popup"){e.click(MadCap.TopicHelpers.TopicPopup_Click)}e.text(v.Title);var l=v.Link;e.attr("href",t+l);m.click(a.Item_Click)}j.appendTo(h);var o=j.closest(".popup-container");if(o.length==0){o=$(window)}var b=o.width();var d=o.height();var c=o.scrollTop();var s=o.scrollLeft();var r=j[0].offsetWidth;var n=j[0].offsetHeight;p=Math.min(p,c+d-n);p=Math.max(p,c);g=Math.min(g,s+b-r);g=Math.max(g,s);if(p==0&&g==0){g=$(w).offset().left+$(w).width();p=$(w).offset().top+$(w).height()}j.css("top",p);j.css("left",g);j.hide().fadeIn(200);$([document,w]).click(function(i){j.remove();$([document,w]).off("click",arguments.callee)});$([document,w]).keydown(function(i){var i=i||windows.event;if(i.keyCode!=27&&i.keyCode!=13){return}if(!j.is(":focus")){return}j.remove();$([document,w]).off("keydown",arguments.callee)});j.attr("tabindex",0);j.focus()};a.Item_Click=function(d){var c=$("a",this);var b=c.attr("href");var f=c.attr("target");if(b&&!MadCap.String.IsNullOrEmpty(b)){if(f){window.open(b,f)}else{document.location.href=b}}MadCap.Utilities.PreventDefault(d)};a.RemoveLinkListTrees=function(){$(".responsive-link-list").remove()};a.RemoveLinkListPopups=function(){$(".link-list-popup").remove()};a.AddBackgroundTint=function(c){var b=$("<div id='mc-background-tint'></div>");b.addClass(c);b.appendTo(document.body);return b[0]};a.RemoveBackgroundTint=function(){$("#mc-background-tint").remove()}})();/*
* Copyright MadCap Software
* http://www.madcapsoftware.com/
*
* v10.0.0.0
*/
(function(a){a.fn.fitVids=function(c){var e={customSelector:null};var d=document.createElement("div"),b=document.getElementsByTagName("base")[0]||document.getElementsByTagName("script")[0];d.className="fit-vids-style";d.innerHTML="&shy;<style>.fluid-width-video-wrapper {width: 100%;position: relative;padding: 0;} .fluid-width-video-wrapper iframe { position: absolute; top: 0; left: 0; width: 100%; height: 100%; } </style>";b.parentNode.insertBefore(d,b);if(c){a.extend(e,c)}return this.each(function(){var f=["iframe[src*='player.vimeo.com']","iframe[src*='www.youtube.com']","iframe[src*='www.kickstarter.com']"];if(e.customSelector){f.push(e.customSelector)}var g=a(this).find(f.join(","));g.each(function(){var j=a(this);if(j.parent(".fluid-width-video-wrapper").length){return}var m=j.attr("height")&&!isNaN(parseInt(j.attr("height"),10))?parseInt(j.attr("height"),10):j.height(),l=!isNaN(parseInt(j.attr("width"),10))?parseInt(j.attr("width"),10):j.width(),h=m/l;if(!j.attr("id")){var k="fitvid"+Math.floor(Math.random()*999999);j.attr("id",k)}j.wrap('<div class="fluid-width-video-wrapper"></div>').parent(".fluid-width-video-wrapper").css("padding-top",h*100+"%");j.removeAttr("height").removeAttr("width")})})}})(jQuery);!function(a){var c={},b={mode:"horizontal",slideSelector:"",infiniteLoop:!0,hideControlOnEnd:!1,speed:500,easing:null,slideMargin:0,startSlide:0,randomStart:!1,captions:!1,ticker:!1,tickerHover:!1,adaptiveHeight:!1,adaptiveHeightSpeed:500,video:!1,useCSS:!0,preloadImages:"visible",responsive:!0,touchEnabled:!0,swipeThreshold:50,oneToOneTouch:!0,preventDefaultSwipeX:!0,preventDefaultSwipeY:!1,pager:!0,pagerType:"full",pagerShortSeparator:" / ",pagerSelector:null,buildPager:null,pagerCustom:null,controls:!0,nextText:"Next",prevText:"Prev",nextSelector:null,prevSelector:null,autoControls:!1,startText:"Start",stopText:"Stop",autoControlsCombine:!1,autoControlsSelector:null,auto:!1,pause:4000,autoStart:!0,autoDirection:"next",autoHover:!1,autoDelay:0,minSlides:1,maxSlides:1,moveSlides:0,slideWidth:0,onSliderLoad:function(){},onSlideBefore:function(){},onSlideAfter:function(){},onSlideNext:function(){},onSlidePrev:function(){},slideshowClass:""};a.fn.MCSlider=function(aq){if(0==this.length){return this}if(this.length>1){return this.each(function(){a(this).MCSlider(aq)}),this}var ap={},am=this;c.el=this;var aB=a(window).width(),at=a(window).height(),ay=function(){ap.settings=a.extend({},b,aq),ap.settings.slideWidth=parseInt(ap.settings.slideWidth),ap.children=am.children(ap.settings.slideSelector),ap.children.length<ap.settings.minSlides&&(ap.settings.minSlides=ap.children.length),ap.children.length<ap.settings.maxSlides&&(ap.settings.maxSlides=ap.children.length),ap.settings.randomStart&&(ap.settings.startSlide=Math.floor(Math.random()*ap.children.length)),ap.active={index:ap.settings.startSlide},ap.carousel=ap.settings.minSlides>1||ap.settings.maxSlides>1,ap.carousel&&(ap.settings.preloadImages="all"),ap.minThreshold=ap.settings.minSlides*ap.settings.slideWidth+(ap.settings.minSlides-1)*ap.settings.slideMargin,ap.maxThreshold=ap.settings.maxSlides*ap.settings.slideWidth+(ap.settings.maxSlides-1)*ap.settings.slideMargin,ap.working=!1,ap.controls={},ap.interval=null,ap.animProp="vertical"==ap.settings.mode?"top":"left",ap.usingCSS=ap.settings.useCSS&&"fade"!=ap.settings.mode&&function(){var f=document.createElement("div"),g=["WebkitPerspective","MozPerspective","OPerspective","msPerspective"];for(var d in g){if(void 0!==f.style[g[d]]){return ap.cssPrefix=g[d].replace("Perspective","").toLowerCase(),ap.animProp="-"+ap.cssPrefix+"-transform",!0}}return !1}(),"vertical"==ap.settings.mode&&(ap.settings.maxSlides=ap.settings.minSlides),am.data("origStyle",am.attr("style")),am.children(ap.settings.slideSelector).each(function(){a(this).data("origStyle",a(this).attr("style"))}),az()},az=function(){am.wrap('<div class="mc-wrapper"><div class="mc-viewport '+ap.settings.slideshowClass+'"></div></div>'),ap.viewport=am.parent(),ap.loader=a('<div class="mc-loading" />'),ap.viewport.prepend(ap.loader),am.css({width:"horizontal"==ap.settings.mode?100*ap.children.length+215+"%":"auto",position:"relative"}),ap.usingCSS&&ap.settings.easing?am.css("-"+ap.cssPrefix+"-transition-timing-function",ap.settings.easing):ap.settings.easing||(ap.settings.easing="swing"),ax(),ap.viewport.css({width:"100%",overflow:"hidden",position:"relative"}),ap.viewport.parent().css({maxWidth:ak()}),ap.settings.pager||ap.viewport.parent().css({margin:"0 auto 0px"}),ap.children.css({"float":"horizontal"==ap.settings.mode?"left":"none",listStyle:"none",position:"relative"}),ap.children.css("width",al()),"horizontal"==ap.settings.mode&&ap.settings.slideMargin>0&&ap.children.css("marginRight",ap.settings.slideMargin),"vertical"==ap.settings.mode&&ap.settings.slideMargin>0&&ap.children.css("marginBottom",ap.settings.slideMargin),"fade"==ap.settings.mode&&(ap.children.css({position:"absolute",zIndex:0,display:"none"}),ap.children.eq(ap.settings.startSlide).css({zIndex:50,display:"block"})),ap.controls.el=a('<div class="mc-controls" />'),ap.settings.captions&&J(),ap.active.last=ap.settings.startSlide==ai()-1,ap.settings.video&&am.fitVids();var d=ap.children.eq(ap.settings.startSlide);"all"==ap.settings.preloadImages&&(d=ap.children),ap.settings.ticker?ap.settings.pager=!1:(ap.settings.pager&&F(),ap.settings.controls&&ad(),ap.settings.auto&&ap.settings.autoControls&&ab(),(ap.settings.controls||ap.settings.autoControls||ap.settings.pager)&&ap.viewport.after(ap.controls.el)),aw(d,av)},aw=function(g,d){var f=g.find("img, iframe").length;if(0==f){return d(),void 0}var h=0;g.find("img, iframe").each(function(){a(this).one("load",function(){++h==f&&d()}).each(function(){this.complete&&a(this).load()})})},av=function(){if(ap.settings.infiniteLoop&&"fade"!=ap.settings.mode&&!ap.settings.ticker){var g="vertical"==ap.settings.mode?ap.settings.minSlides:ap.settings.maxSlides,d=ap.children.slice(0,g).clone().addClass("mc-clone"),f=ap.children.slice(-g).clone().addClass("mc-clone");am.append(d).prepend(f)}ap.loader.remove(),G(),"vertical"==ap.settings.mode&&(ap.settings.adaptiveHeight=!0),ap.viewport.height(ao()),am.redrawSlider(),ap.settings.onSliderLoad(ap.active.index),ap.initialized=!0,ap.settings.responsive&&a(window).bind("resize",ae),ap.settings.auto&&ap.settings.autoStart&&aa(),ap.settings.ticker&&U(),ap.settings.pager&&Z(ap.settings.startSlide),ap.settings.controls&&s(),ap.settings.touchEnabled&&!ap.settings.ticker&&K()},ao=function(){var f=0,d=a();if("vertical"==ap.settings.mode||ap.settings.adaptiveHeight){if(ap.carousel){var g=1==ap.settings.moveSlides?ap.active.index:ap.active.index*ar();for(d=ap.children.eq(g),i=1;i<=ap.settings.maxSlides-1;i++){d=g+i>=ap.children.length?d.add(ap.children.eq(i-1)):d.add(ap.children.eq(g+i))}}else{d=ap.children.eq(ap.active.index)}}else{d=ap.children}return"vertical"==ap.settings.mode?(d.each(function(){f+=a(this).outerHeight()}),ap.settings.slideMargin>0&&(f+=ap.settings.slideMargin*(ap.settings.minSlides-1))):f=Math.max.apply(Math,d.map(function(){return a(this).outerHeight(!1)}).get()),f},ak=function(){var d="100%";return ap.settings.slideWidth>0&&(d="horizontal"==ap.settings.mode?ap.settings.maxSlides*ap.settings.slideWidth+(ap.settings.maxSlides-1)*ap.settings.slideMargin:ap.settings.slideWidth),d},al=function(){var d=ap.settings.slideWidth,f=ap.viewport.width();return 0==ap.settings.slideWidth||ap.settings.slideWidth>f&&!ap.carousel||"vertical"==ap.settings.mode?d=f:ap.settings.maxSlides>1&&"horizontal"==ap.settings.mode&&(f>ap.maxThreshold||f<ap.minThreshold&&(d=(f-ap.settings.slideMargin*(ap.settings.minSlides-1))/ap.settings.minSlides)),d},ax=function(){var d=1;if("horizontal"==ap.settings.mode&&ap.settings.slideWidth>0){if(ap.viewport.width()<ap.minThreshold){d=ap.settings.minSlides}else{if(ap.viewport.width()>ap.maxThreshold){d=ap.settings.maxSlides}else{var f=ap.children.first().width();d=Math.floor(ap.viewport.width()/f)}}}else{"vertical"==ap.settings.mode&&(d=ap.settings.minSlides)}return d},ai=function(){var f=0;if(ap.settings.moveSlides>0){if(ap.settings.infiniteLoop){f=ap.children.length/ar()}else{for(var g=0,d=0;g<ap.children.length;){++f,g=d+ax(),d+=ap.settings.moveSlides<=ax()?ap.settings.moveSlides:ax()}}}else{f=Math.ceil(ap.children.length/ax())}return f},ar=function(){return ap.settings.moveSlides>0&&ap.settings.moveSlides<=ax()?ap.settings.moveSlides:ax()},G=function(){if(ap.children.length>ap.settings.maxSlides&&ap.active.last&&!ap.settings.infiniteLoop){if("horizontal"==ap.settings.mode){var f=ap.children.last(),g=f.position();aA(-(g.left-(ap.viewport.width()-f.width())),"reset",0)}else{if("vertical"==ap.settings.mode){var d=ap.children.length-ap.settings.minSlides,g=ap.children.eq(d).position();aA(-g.top,"reset",0)}}}else{var g=ap.children.eq(ap.active.index*ar()).position();ap.active.index==ai()-1&&(ap.active.last=!0),void 0!=g&&("horizontal"==ap.settings.mode?aA(-g.left,"reset",0):"vertical"==ap.settings.mode&&aA(-g.top,"reset",0))}},aA=function(g,k,f,h){if(ap.usingCSS){var l="vertical"==ap.settings.mode?"translate3d(0, "+g+"px, 0)":"translate3d("+g+"px, 0, 0)";am.css("-"+ap.cssPrefix+"-transition-duration",f/1000+"s"),"slide"==k?(am.css(ap.animProp,l),am.bind("transitionend webkitTransitionEnd oTransitionEnd MSTransitionEnd",function(){am.unbind("transitionend webkitTransitionEnd oTransitionEnd MSTransitionEnd"),ac()})):"reset"==k?am.css(ap.animProp,l):"ticker"==k&&(am.css("-"+ap.cssPrefix+"-transition-timing-function","linear"),am.css(ap.animProp,l),am.bind("transitionend webkitTransitionEnd oTransitionEnd MSTransitionEnd",function(){am.unbind("transitionend webkitTransitionEnd oTransitionEnd MSTransitionEnd"),aA(h.resetValue,"reset",0),Q()}))}else{var d={};d[ap.animProp]=g,"slide"==k?am.animate(d,f,ap.settings.easing,function(){ac()}):"reset"==k?am.css(ap.animProp,g):"ticker"==k&&am.animate(d,speed,"linear",function(){aA(h.resetValue,"reset",0),Q()})}},aj=function(){for(var g="",d=ai(),f=0;d>f;f++){var h="";ap.settings.buildPager&&a.isFunction(ap.settings.buildPager)?(h=ap.settings.buildPager(f),ap.pagerEl.addClass("mc-custom-pager")):(h=f+1,ap.pagerEl.addClass("mc-default-pager")),g+='<div class="mc-pager-item"><a data-slide-index="'+f+'" class="mc-pager-link">'+h+"</a></div>"}ap.pagerEl.html(g)},F=function(){ap.settings.pagerCustom?ap.pagerEl=a(ap.settings.pagerCustom):(ap.pagerEl=a('<div class="mc-pager" />'),ap.settings.pagerSelector?a(ap.settings.pagerSelector).html(ap.pagerEl):ap.controls.el.addClass("mc-has-pager").append(ap.pagerEl),aj()),ap.pagerEl.delegate("a","click",an)},ad=function(){ap.controls.next=a('<a class="mc-next">'+ap.settings.nextText+"</a>"),ap.controls.prev=a('<a class="mc-prev">'+ap.settings.prevText+"</a>"),ap.controls.next.bind("click",ah),ap.controls.prev.bind("click",ag),ap.settings.nextSelector&&a(ap.settings.nextSelector).append(ap.controls.next),ap.settings.prevSelector&&a(ap.settings.prevSelector).append(ap.controls.prev),ap.settings.nextSelector||ap.settings.prevSelector||(ap.controls.directionEl=a('<div class="mc-controls-direction" />'),ap.controls.directionEl.append(ap.controls.prev).append(ap.controls.next),ap.controls.el.addClass("mc-has-controls-direction").append(ap.controls.directionEl))},ab=function(){ap.controls.start=a('<div class="mc-controls-auto-item"><a class="mc-start">'+ap.settings.startText+"</a></div>"),ap.controls.stop=a('<div class="mc-controls-auto-item"><a class="mc-stop">'+ap.settings.stopText+"</a></div>"),ap.controls.autoEl=a('<div class="mc-controls-auto" />'),ap.controls.autoEl.delegate(".mc-start","click",au),ap.controls.autoEl.delegate(".mc-stop","click",R),ap.settings.autoControlsCombine?ap.controls.autoEl.append(ap.controls.start):ap.controls.autoEl.append(ap.controls.start).append(ap.controls.stop),ap.settings.autoControlsSelector?a(ap.settings.autoControlsSelector).html(ap.controls.autoEl):ap.controls.el.addClass("mc-has-controls-auto").append(ap.controls.autoEl),af(ap.settings.autoStart?"stop":"start")},J=function(){ap.children.each(function(){var d=a(this).attr("title");void 0!=d&&(""+d).length&&a(this).append('<div class="mc-caption"><span>'+d+"</span></div>")})},ah=function(d){ap.settings.auto&&am.stopAuto(),am.goToNextSlide(),d.preventDefault()},ag=function(d){ap.settings.auto&&am.stopAuto(),am.goToPrevSlide(),d.preventDefault()},au=function(d){am.startAuto(),d.preventDefault()},R=function(d){am.stopAuto(),d.preventDefault()},an=function(g){ap.settings.auto&&am.stopAuto();var d=a(g.currentTarget),f=parseInt(d.attr("data-slide-index"));f!=ap.active.index&&am.goToSlide(f),g.preventDefault()},Z=function(f){var d=ap.children.length;return"short"==ap.settings.pagerType?(ap.settings.maxSlides>1&&(d=Math.ceil(ap.children.length/ap.settings.maxSlides)),ap.pagerEl.html(f+1+ap.settings.pagerShortSeparator+d),void 0):(ap.pagerEl.find("a").removeClass("active"),ap.pagerEl.each(function(g,h){a(h).find("a").eq(f).addClass("active")}),void 0)},ac=function(){if(ap.settings.infiniteLoop){var d="";0==ap.active.index?d=ap.children.eq(0).position():ap.active.index==ai()-1&&ap.carousel?d=ap.children.eq((ai()-1)*ar()).position():ap.active.index==ap.children.length-1&&(d=ap.children.eq(ap.children.length-1).position()),"horizontal"==ap.settings.mode?aA(-d.left,"reset",0):"vertical"==ap.settings.mode&&aA(-d.top,"reset",0)}ap.working=!1,ap.settings.onSlideAfter(ap.children.eq(ap.active.index),ap.oldIndex,ap.active.index)},af=function(d){ap.settings.autoControlsCombine?ap.controls.autoEl.html(ap.controls[d]):(ap.controls.autoEl.find("a").removeClass("active"),ap.controls.autoEl.find("a:not(.mc-"+d+")").addClass("active"))},s=function(){1==ai()?(ap.controls.prev.addClass("disabled"),ap.controls.next.addClass("disabled")):!ap.settings.infiniteLoop&&ap.settings.hideControlOnEnd&&(0==ap.active.index?(ap.controls.prev.addClass("disabled"),ap.controls.next.removeClass("disabled")):ap.active.index==ai()-1?(ap.controls.next.addClass("disabled"),ap.controls.prev.removeClass("disabled")):(ap.controls.prev.removeClass("disabled"),ap.controls.next.removeClass("disabled")))},aa=function(){ap.settings.autoDelay>0?setTimeout(am.startAuto,ap.settings.autoDelay):am.startAuto(),ap.settings.autoHover&&am.hover(function(){ap.interval&&(am.stopAuto(!0),ap.autoPaused=!0)},function(){ap.autoPaused&&(am.startAuto(!0),ap.autoPaused=null)})},U=function(){var f=0;if("next"==ap.settings.autoDirection){am.append(ap.children.clone().addClass("mc-clone"))}else{am.prepend(ap.children.clone().addClass("mc-clone"));var d=ap.children.first().position();f="horizontal"==ap.settings.mode?-d.left:-d.top}aA(f,"reset",0),ap.settings.pager=!1,ap.settings.controls=!1,ap.settings.autoControls=!1,ap.settings.tickerHover&&!ap.usingCSS&&ap.viewport.hover(function(){am.stop()},function(){var k=0;ap.children.each(function(){k+="horizontal"==ap.settings.mode?a(this).outerWidth(!0):a(this).outerHeight(!0)});var g=ap.settings.speed/k,h="horizontal"==ap.settings.mode?"left":"top",l=g*(k-Math.abs(parseInt(am.css(h))));Q(l)}),Q()},Q=function(g){speed=g?g:ap.settings.speed;var k={left:0,top:0},f={left:0,top:0};"next"==ap.settings.autoDirection?k=am.find(".mc-clone").first().position():f=ap.children.first().position();var h="horizontal"==ap.settings.mode?-k.left:-k.top,l="horizontal"==ap.settings.mode?-f.left:-f.top,d={resetValue:l};aA(h,"ticker",speed,d)},K=function(){ap.touch={start:{x:0,y:0},end:{x:0,y:0}},ap.viewport.bind("touchstart",j)},j=function(d){if(ap.working){d.preventDefault()}else{ap.touch.originalPos=am.position();var f=d.originalEvent;ap.touch.start.x=f.changedTouches[0].pageX,ap.touch.start.y=f.changedTouches[0].pageY,ap.viewport.bind("touchmove",e),ap.viewport.bind("touchend",t)}},e=function(f){var k=f.originalEvent,d=Math.abs(k.changedTouches[0].pageX-ap.touch.start.x),g=Math.abs(k.changedTouches[0].pageY-ap.touch.start.y);if(3*d>g&&ap.settings.preventDefaultSwipeX?f.preventDefault():3*g>d&&ap.settings.preventDefaultSwipeY&&f.preventDefault(),"fade"!=ap.settings.mode&&ap.settings.oneToOneTouch){var l=0;if("horizontal"==ap.settings.mode){var h=k.changedTouches[0].pageX-ap.touch.start.x;l=ap.touch.originalPos.left+h}else{var h=k.changedTouches[0].pageY-ap.touch.start.y;l=ap.touch.originalPos.top+h}aA(l,"reset",0)}},t=function(f){ap.viewport.unbind("touchmove",e);var h=f.originalEvent,d=0;if(ap.touch.end.x=h.changedTouches[0].pageX,ap.touch.end.y=h.changedTouches[0].pageY,"fade"==ap.settings.mode){var g=Math.abs(ap.touch.start.x-ap.touch.end.x);g>=ap.settings.swipeThreshold&&(ap.touch.start.x>ap.touch.end.x?am.goToNextSlide():am.goToPrevSlide(),am.stopAuto())}else{var g=0;"horizontal"==ap.settings.mode?(g=ap.touch.end.x-ap.touch.start.x,d=ap.touch.originalPos.left):(g=ap.touch.end.y-ap.touch.start.y,d=ap.touch.originalPos.top),!ap.settings.infiniteLoop&&(0==ap.active.index&&g>0||ap.active.last&&0>g)?aA(d,"reset",200):Math.abs(g)>=ap.settings.swipeThreshold?(0>g?am.goToNextSlide():am.goToPrevSlide(),am.stopAuto()):aA(d,"reset",200)}ap.viewport.unbind("touchend",t)},ae=function(){var f=a(window).width(),d=a(window).height();if(!(/Android|webOS|iPhone|iPad|iPod|BlackBerry|IEMobile|Opera Mini/i.test(navigator.userAgent))){(aB!=f||at!=d)&&(aB=f,at=d,am.redrawSlider())}};return am.goToSlide=function(o,k){if(!ap.working&&ap.active.index!=o){if(ap.working=!0,ap.oldIndex=ap.active.index,ap.active.index=0>o?ai()-1:o>=ai()?0:o,ap.settings.onSlideBefore(ap.children.eq(ap.active.index),ap.oldIndex,ap.active.index),"next"==k?ap.settings.onSlideNext(ap.children.eq(ap.active.index),ap.oldIndex,ap.active.index):"prev"==k&&ap.settings.onSlidePrev(ap.children.eq(ap.active.index),ap.oldIndex,ap.active.index),ap.active.last=ap.active.index>=ai()-1,ap.settings.pager&&Z(ap.active.index),ap.settings.controls&&s(),"fade"==ap.settings.mode){ap.settings.adaptiveHeight&&ap.viewport.height()!=ao()&&ap.viewport.animate({height:ao()},ap.settings.adaptiveHeightSpeed),ap.children.filter(":visible").fadeOut(ap.settings.speed).css({zIndex:0}),ap.children.eq(ap.active.index).css("zIndex",51).fadeIn(ap.settings.speed,function(){a(this).css("zIndex",50),ac()})}else{ap.settings.adaptiveHeight&&ap.viewport.height()!=ao()&&ap.viewport.animate({height:ao()},ap.settings.adaptiveHeightSpeed);var u=0,f={left:0,top:0};if(!ap.settings.infiniteLoop&&ap.carousel&&ap.active.last){if("horizontal"==ap.settings.mode){var r=ap.children.eq(ap.children.length-1);f=r.position(),u=ap.viewport.width()-r.outerWidth()}else{var h=ap.children.length-ap.settings.minSlides;f=ap.children.eq(h).position()}}else{if(ap.carousel&&ap.active.last&&"prev"==k){var p=1==ap.settings.moveSlides?ap.settings.maxSlides-ar():(ai()-1)*ar()-(ap.children.length-ap.settings.maxSlides),r=am.children(".mc-clone").eq(p);f=r.position()}else{if("next"==k&&0==ap.active.index){f=am.find("> .mc-clone").eq(ap.settings.maxSlides).position(),ap.active.last=!1}else{if(o>=0){var q=o*ar();f=ap.children.eq(q).position()}}}}if("undefined"!=typeof f){var m="horizontal"==ap.settings.mode?-(f.left-u):-f.top;aA(m,"slide",ap.settings.speed)}}}},am.goToNextSlide=function(){if(ap.settings.infiniteLoop||!ap.active.last){var d=parseInt(ap.active.index)+1;am.goToSlide(d,"next")}},am.goToPrevSlide=function(){if(ap.settings.infiniteLoop||0!=ap.active.index){var d=parseInt(ap.active.index)-1;am.goToSlide(d,"prev")}},am.startAuto=function(d){ap.interval||(ap.interval=setInterval(function(){"next"==ap.settings.autoDirection?am.goToNextSlide():am.goToPrevSlide()},ap.settings.pause),ap.settings.autoControls&&1!=d&&af("stop"))},am.stopAuto=function(d){ap.interval&&(clearInterval(ap.interval),ap.interval=null,ap.settings.autoControls&&1!=d&&af("start"))},am.getCurrentSlide=function(){return ap.active.index},am.getSlideCount=function(){return ap.children.length},am.redrawSlider=function(){ap.children.add(am.find(".mc-clone")).outerWidth(al()),ap.viewport.css("height",ao()),ap.settings.ticker||G(),ap.active.last&&(ap.active.index=ai()-1),ap.active.index>=ai()&&(ap.active.last=!0),ap.settings.pager&&!ap.settings.pagerCustom&&(aj(),Z(ap.active.index))},am.destroySlider=function(){ap.initialized&&(ap.initialized=!1,a(".mc-clone",this).remove(),ap.children.each(function(){void 0!=a(this).data("origStyle")?a(this).attr("style",a(this).data("origStyle")):a(this).removeAttr("style")}),void 0!=a(this).data("origStyle")?this.attr("style",a(this).data("origStyle")):a(this).removeAttr("style"),a(this).unwrap().unwrap(),ap.controls.el&&ap.controls.el.remove(),ap.controls.next&&ap.controls.next.remove(),ap.controls.prev&&ap.controls.prev.remove(),ap.pagerEl&&ap.pagerEl.remove(),a(".mc-caption",this).remove(),ap.controls.autoEl&&ap.controls.autoEl.remove(),clearInterval(ap.interval),ap.settings.responsive&&a(window).unbind("resize",ae))},am.reloadSlider=function(d){void 0!=d&&(aq=d),am.destroySlider(),ay()},ay(),this}}(jQuery);(function(){var a=MadCap.CreateNamespace("Slideshow");a.Init=function(){var b;if($("html").attr("data-mc-target-type")){b=function(d,c){return d.attr("data-mc-"+c)}}else{b=function(d,c){return d.attr("madcap:"+c.replace("-",""))}}$(".MCSlider").each(function(n,f){var C=$(f);var j={};var r=f.className;var e=b(C,"random-start");var v=b(C,"infinite-loop");var o=b(C,"show-captions");var s=b(C,"controls");var u=b(C,"slide-width");var t=b(C,"adaptive-height");var h=b(C,"responsive");var g=b(C,"navigation");var p=true;var d=false;j.pagerCustom=null;if(g){if(g=="Thumbnails"){d=true;j.pagerCustom="#mc-pager"+(n+1).toString()}if(g=="None"){p=false}}var A=b(C,"auto-hover");var k=b(C,"auto-start");var B=b(C,"auto-controls");var c=b(C,"combine-controls");var y=b(C,"auto-direction");var z=b(C,"auto-delay");var q=b(C,"mode");var w=b(C,"speed");var l=b(C,"pause");var x=b(C,"video");if(r){j.slideshowClass=r}if(e){if("true"==e.toString().toLowerCase()){j.randomStart=true}else{if("false"==e.toString().toLowerCase()){j.randomStart=false}}}if(v){if("true"==v.toString().toLowerCase()){j.infiniteLoop=true}else{if("false"==v.toString().toLowerCase()){j.infiniteLoop=false;j.hideControlOnEnd=true}}}if(o){if("true"==o.toString().toLowerCase()){j.captions=true}else{if("false"==o.toString().toLowerCase()){j.captions=false}}}if(s){if("true"==s.toString().toLowerCase()){j.controls=true}else{if("false"==s.toString().toLowerCase()){j.controls=false}}}j.pager=p;j.thumbnails=d;if(u){j.slideWidth=u}if(t){if("true"==t.toString().toLowerCase()){j.adaptiveHeight=true}else{if("false"==t.toString().toLowerCase()){j.adaptiveHeight=false}}}if(h){if("true"==h.toString().toLowerCase()){j.responsive=true}else{if("false"==h.toString().toLowerCase()){j.responsive=false}}}var m=false;if(A){if("true"==A.toString().toLowerCase()){j.autoHover=true;m=true}else{if("false"==A.toString().toLowerCase()){j.autoHover=false}}}if(k){if("true"==k.toString().toLowerCase()){j.autoStart=true;m=true}else{if("false"==k.toString().toLowerCase()){j.autoStart=false}}}if(B){if("true"==B.toString().toLowerCase()){j.autoControls=true;j.autoControlsCombine=true;m=true}else{if("false"==B.toString().toLowerCase()){j.autoControls=false;j.autoControlsCombine=false}}}if(m){j.auto=true}if(y){j.autoDirection=y}if(z){j.autoDelay=z}if(q){j.mode=q}if(w){j.speed=w}if(l){j.pause=l}if(navigator.userAgent.indexOf("MSIE")!==-1){j.preloadImages="all"}j.video=true;j.useCSS=false;if(x){j.video=false}C.MCSlider(j)})}})();/*
* Copyright MadCap Software
* http://www.madcapsoftware.com/
*
* v10.0.0.0
*/
(function(){MadCap.WebHelp=MadCap.CreateNamespace("WebHelp");MadCap.WebHelp.FeedbackController=function(i){if(MadCap.WebHelp.FeedbackController.Shared!=null){return MadCap.WebHelp.FeedbackController.Shared}MadCap.WebHelp.FeedbackController.Shared=this;var d=false;var h=false;var f=new Array();var k=0;var b=this;var g=3000;this.Server=i;this.FeedbackServer=j(i);this.Version=-1;this.FeedbackActive=false;this.PulseServer=null;this.PulseEnabled=false;this.PulseActive=false;this.PulseUserGuid=null;function c(){for(var m=0;m<f.length;m++){f[m](b)}d=true}function j(o,n){if(o==null){return null}if(typeof n=="undefined"){n=""}var m=new MadCap.Utilities.Url(o);m=m.CombinePath(n+"Service.FeedbackExplorer/FeedbackJsonService.asmx/");return m.FullPath}function l(A,z,s,o){var D=document.createElement("script");var p=document.getElementsByTagName("head")[0];var w="MCLiveHelpScript_"+k++;var q=b.FeedbackServer+A+"?";q+="OnComplete="+z+"&ScriptID="+w+"&UniqueID="+(new Date()).getTime();if(s!=null){for(var B=0,n=s.length;B<n;B++){var x=s[B];var F=x[0];var y=encodeURIComponent(x[1]);q+=("&"+F+"="+y)}}if(document.body.currentStyle!=null){var u=2083;if(q.length>u){var v=q.length-u;var E={ExceedAmount:v};var C=new MadCap.FeedbackException(-1,"URL limit exceeded.",E);throw C}}var r=2048;var t=q.indexOf("?");var m=q.substring(t+1).length;if(m>r){var v=m-r;var E={ExceedAmount:v};var C=new MadCap.FeedbackException(-1,"Query string limit exceeded.",E);throw C}D.id=w;D.setAttribute("type","text/javascript");D.setAttribute("src",q);p.appendChild(D);return w}function e(m){window.setTimeout(function(){var n=document.getElementById(m);n.parentNode.removeChild(n)},10)}this.Init=function(m){if(d){m(this);return}if(m!=null){f.push(m)}if(h){return}h=true;b.GetVersion(function(){if(b.PulseEnabled){b.GetPulseServerActivated(function(n){b.PulseActive=n&&n.toLowerCase()==="true";c()})}else{c()}});window.setTimeout(function(){if(!d){c()}},g)};this.GetUserGuid=function(){return b.PulseEnabled?b.PulseUserGuid:MadCap.Utilities.Store.getItem("LiveHelpUserGuid")};this.LogTopic=function(n,o,m){this.LogTopicOnComplete=function(p){if(m!=null){m()}e(p);this.LogTopicOnComplete=null};this.GetVersion(function(p){if(p==1){l("LogTopic","MadCap.WebHelp.FeedbackController.Shared.LogTopicOnComplete",[["TopicID",n]])}else{l("LogTopic2","MadCap.WebHelp.FeedbackController.Shared.LogTopicOnComplete",[["TopicID",n],["CSHID",o]])}})};this.LogSearch=function(m,p,n,q,o){this.LogSearchOnComplete=function(r){e(r);this.LogSearchOnComplete=null};l("LogSearch","MadCap.WebHelp.FeedbackController.Shared.LogSearchOnComplete",[["ProjectID",m],["UserGuid",p],["ResultCount",n],["Language",q],["Query",o]])};this.AddComment=function(o,q,p,n,s,r,m){this.AddCommentOnComplete=function(t){if(m!=null){m()}e(t);this.AddCommentOnComplete=null};l("AddComment","MadCap.WebHelp.FeedbackController.Shared.AddCommentOnComplete",[["TopicID",o],["UserGuid",q],["Username",p],["Subject",n],["Comment",s],["ParentCommentID",r]])};this.GetAverageRating=function(o,m,n){this.GetAverageRatingOnComplete=function(r,q,p){if(m!=null){m(q,p,n)}e(r);this.GetAverageRatingOnComplete=null};l("GetAverageRating","MadCap.WebHelp.FeedbackController.Shared.GetAverageRatingOnComplete",[["TopicID",o]])};this.SubmitRating=function(o,p,r,m,n){this.SubmitRatingOnComplete=function(s){if(m!=null){m(n)}e(s);this.SubmitRatingOnComplete=null};var q=l("SubmitRating","MadCap.WebHelp.FeedbackController.Shared.SubmitRatingOnComplete",[["TopicID",o],["Rating",p],["Comment",r]])};this.GetTopicComments=function(o,q,p,m,n){this.GetTopicCommentsOnComplete=function(t,s){if(m!=null){m(s,n)}e(t);this.GetTopicCommentsOnComplete=null};var r=l("GetTopicComments","MadCap.WebHelp.FeedbackController.Shared.GetTopicCommentsOnComplete",[["TopicID",o],["UserGuid",q],["Username",p]])};this.GetAnonymousEnabled=function(n,m,o){this.GetAnonymousEnabledOnComplete=function(q,p){if(m!=null){m(p,o)}e(q);this.GetAnonymousEnabledOnComplete=null};l("GetAnonymousEnabled","MadCap.WebHelp.FeedbackController.Shared.GetAnonymousEnabledOnComplete",[["ProjectID",n]])};this.StartActivateUser=function(r,w,u){this.StartActivateUserOnComplete=function(F,E){if(w!=null){w(E,u)}e(F);this.StartActivateUserOnComplete=null};var D=FMCGetChildNodeByAttribute(r.documentElement,"Name","Username");var o=FMCGetAttribute(D,"Value");var s=FMCGetChildNodeByAttribute(r.documentElement,"Name","EmailAddress");var n=FMCGetAttribute(s,"Value");var y=FMCGetChildNodeByAttribute(r.documentElement,"Name","FirstName");var m=FMCGetAttribute(y,"Value");var C=FMCGetChildNodeByAttribute(r.documentElement,"Name","LastName");var x=FMCGetAttribute(C,"Value");var B=FMCGetChildNodeByAttribute(r.documentElement,"Name","Country");var A=FMCGetAttribute(B,"Value");var z=FMCGetChildNodeByAttribute(r.documentElement,"Name","PostalCode");var t=FMCGetAttribute(z,"Value");var p=FMCGetChildNodeByAttribute(r.documentElement,"Name","Gender");var v=FMCGetAttribute(p,"Value");var q="";l("StartActivateUser","MadCap.WebHelp.FeedbackController.Shared.StartActivateUserOnComplete",[["Username",o],["EmailAddress",n],["FirstName",m],["LastName",x],["Country",A],["Zip",t],["Gender",v],["UILanguageOrder",q]])};this.StartActivateUser2=function(p,m,o,q){var n=MadCap.Utilities.Xhr.GetOuterXml(p);this.StartActivateUser2OnComplete=function(s,r){if(m!=null){if(q!=null){m.call(q,r,o)}else{m(r,o)}}e(s);this.StartActivateUser2OnComplete=null};l("StartActivateUser2","MadCap.WebHelp.FeedbackController.Shared.StartActivateUser2OnComplete",[["Xml",n]])};this.UpdateUserProfile=function(p,q,m,o,r){var n=MadCap.Utilities.Xhr.GetOuterXml(q);this.UpdateUserProfileOnComplete=function(t,s){if(m!=null){if(r!=null){m.call(r,s,o)}else{m(s,o)}}e(t);this.UpdateUserProfileOnComplete=null};l("UpdateUserProfile","MadCap.WebHelp.FeedbackController.Shared.UpdateUserProfileOnComplete",[["Guid",p],["Xml",n]])};this.GetUserProfile=function(o,m,n,p){this.GetUserProfileOnComplete=function(r,q){if(m!=null){if(p!=null){m.call(p,q,n)}else{m(q,n)}}e(r);this.GetUserProfileOnComplete=null};l("GetUserProfile","MadCap.WebHelp.FeedbackController.Shared.GetUserProfileOnComplete",[["Guid",o]])};this.CheckUserStatus=function(o,m,n){this.CheckUserStatusOnComplete=function(q,p){if(m!=null){m(p,n)}e(q);this.CheckUserStatusOnComplete=null};l("CheckUserStatus","MadCap.WebHelp.FeedbackController.Shared.CheckUserStatusOnComplete",[["PendingGuid",o]])};this.GetSynonymsFile=function(n,p,m,o){this.GetSynonymsFileOnComplete=function(r,q){if(m!=null){m(q,o)}e(r)};l("GetSynonymsFile","MadCap.WebHelp.FeedbackController.Shared.GetSynonymsFileOnComplete",[["ProjectID",n],["UpdatedSince",p]])};this.GetVersion=function(m,n,o){this.GetVersionOnComplete=function(q,p){if(p==null){b.Version=1}else{if(b.Version==-1&&p>4){b.FeedbackServer=j(b.Server,"Feedback/");b.PulseServer=b.Server;b.PulseEnabled=true}b.FeedbackActive=true;b.Version=p}if(m!=null){if(o!=null){m.call(o,b.Version,n)}else{m(b.Version,n)}}if(q!=null){e(q)}this.GetVersionOnComplete=null};if(b.Version==-1){l("GetVersion","MadCap.WebHelp.FeedbackController.Shared.GetVersionOnComplete")}else{this.GetVersionOnComplete(null,b.Version)}};this.GetPulseServerActivated=function(n,m,o){this.GetPulseServerActivatedOnComplete=function(q,p){if(n!=null){if(o!=null){n.call(o,p,m)}else{n(p,m)}}if(q!=null){e(q)}this.GetPulseServerActivatedOnComplete=null};l("GetPulseServerActivated","MadCap.WebHelp.FeedbackController.Shared.GetPulseServerActivatedOnComplete")};this.GetPulseStreamID=function(n,o,m,p){this.GetPulseStreamIDOnComplete=function(r,q){if(o!=null){if(p!=null){o.call(p,q,m)}else{o(q,m)}}if(r!=null){e(r)}this.GetPulseStreamIDOnComplete=null};l("GetPulseStreamID","MadCap.WebHelp.FeedbackController.Shared.GetPulseStreamIDOnComplete",[["TopicID",n]])};this.GetTopicPathByStreamID=function(o,n,m,p){this.GetTopicPathByStreamIDOnComplete=function(q,r){if(n!=null){if(p!=null){n.call(p,r,m)}else{n(r,m)}}if(q!=null){e(q)}this.GetTopicPathByStreamIDOnComplete=null};l("GetTopicPathByStreamID","MadCap.WebHelp.FeedbackController.Shared.GetTopicPathByStreamIDOnComplete",[["StreamID",o]])};this.GetTopicPathByPageID=function(m,o,n,p){this.GetTopicPathByPageIDOnComplete=function(q,r){if(o!=null){if(p!=null){o.call(p,r,n)}else{o(r,n)}}if(q!=null){e(q)}this.GetTopicPathByPageIDOnComplete=null};l("GetTopicPathByPageID","MadCap.WebHelp.FeedbackController.Shared.GetTopicPathByPageIDOnComplete",[["PageID",m]])};this.GetPulseSearchResults=function(o,r,n,m,q,p,s){this.GetPulseSearchResultsOnComplete=function(u,t){if(q!=null){if(s!=null){q.call(s,t,p)}else{q(t,p)}}if(u!=null){e(u)}this.GetPulseSearchResultsOnComplete=null};l("GetPulseSearchResults","MadCap.WebHelp.FeedbackController.Shared.GetPulseSearchResultsOnComplete",[["ProjectID",o],["SearchQuery",r],["PageSize",n],["PageIndex",m]])}};MadCap.WebHelp.FeedbackController.Shared=null;MadCap.CreateNamespace("Feedback");MadCap.Feedback.LoginDialog=function(c,b){this._FeedbackController=c;this._TimeoutID=-1;this._Mode=b;this._UserGuid=null;this._El=null};var a=MadCap.Feedback.LoginDialog;a.prototype._Init=function(){var c=this;this._El=$(".login-dialog");$(".login-dialog-buttons .submit-button").click(function(d){c.Submit()});$(".login-dialog-buttons .cancel-button").click(function(d){c.Hide(false)});if(this._Mode=="edit"){this._UserGuid=this._FeedbackController.GetUserGuid();this._FeedbackController.GetUserProfile(this._UserGuid,function(f,d){var e=MadCap.Utilities.Xhr.LoadXmlString(f);$(e.documentElement).children("Item").each(function(h,i){var k=$(this);var g=k.attr("Name");var j=k.attr("Value");var m=$(".login-dialog input[name='"+g+"']");if(m.attr("type")=="checkbox"){var l=MadCap.String.ToBool(j,false);m.prop("checked",l)}else{m.val(j)}})},null,this)}else{if(this._Mode=="pulse"){var b=$("#pulse-login-frame");if(b.length==0){c._El.addClass("pulse");c._El.empty();c._El.append('<iframe id="pulse-login-frame" name="pulse-login-html5" style="visibility:hidden;" onload="this.style.visibility=\'visible\';"></iframe>');c._El.append('<button class="close-dialog"></button>');$(".close-dialog",c._El).click(function(d){c.Hide(true)});$("#pulse-login-frame").attr("src",c._FeedbackController.PulseServer+"Login")}}}};a.prototype._Cleanup=function(){$(".login-dialog-buttons .submit-button").off("click");$(".login-dialog-buttons .cancel-button").off("click");$(".submit-button").attr("disabled",null);$(".status-message-box").hide();$(".profile-item-wrapper.error").removeClass("error");window.clearTimeout(this._TimeoutID)};a.prototype.Show=function(){this._Init();var b=MadCap.TopicHelpers.AddBackgroundTint("light");$(b).animate({opacity:0.5},200);this._El.fadeIn(200)};a.prototype.Hide=function(b){this._Cleanup();MadCap.TopicHelpers.RemoveBackgroundTint();if(b){this._El.fadeOut()}else{this._El.hide()}$(this).trigger("closed")};a.prototype.Submit=function(){$(".status-message-box").hide();$(".profile-item-wrapper.error").removeClass("error");if(this._CheckErrors()){this._SetStatusMessage("required-fields-missing-message","error");return}var c=this._LoginItemsToXml();var b=this;if(this._Mode=="new"){this._FeedbackController.StartActivateUser2(c,function(d){b._CheckUserStatus(d)});this._SetStatusMessage("verification-email-sent-message")}else{if(this._Mode=="edit"){this._FeedbackController.UpdateUserProfile(this._UserGuid,c,function(d){if(d=="00000000-0000-0000-0000-000000000000"){b.Hide(true)}else{b._CheckUserStatus(d);b._SetStatusMessage("verification-email-sent-message")}})}}$(".submit-button").attr("disabled","disabled")};a.prototype._CheckUserStatus=function(c){var b=this;this._FeedbackController.CheckUserStatus(c,function(d){if(d=="Pending"){b._TimeoutID=setTimeout(function(){b._CheckUserStatus(c)},5000)}else{MadCap.Utilities.Store.setItem("LiveHelpUserGuid",d);b.Hide(true)}})};a.prototype._CheckErrors=function(){var e=false;var d=$(".login-dialog .profile-item-wrapper input, .login-dialog .profile-item-wrapper select");for(var c=0,f=d.length;c<f;c++){var b=d[c];var j=$(b);var g=j.val();var h=MadCap.String.ToBool(MadCap.Dom.Dataset(b,"required"),false);if(h&&MadCap.String.IsNullOrEmpty(g)){j.closest(".profile-item-wrapper").addClass("error");e=true}}return e};a.prototype._LoginItemsToXml=function(){var m=MadCap.Utilities.Xhr.CreateXmlDocument("FeedbackUserProfile");var h=m.documentElement;var b=$(".login-dialog .profile-item-wrapper input");for(var e=0,d=b.length;e<d;e++){var j=b[e];var g=$(j);var c=g.attr("name");var f=g.attr("type");var k=f=="checkbox"?j.checked:g.val();var l=m.createElement("Item");l.setAttribute("Name",c);l.setAttribute("Value",k.toString());h.appendChild(l)}return m};a.prototype._SetStatusMessage=function(b,c){var d=$(".status-message-box");if(c=="error"){d.addClass("error")}else{d.removeClass("error")}$(".message").hide();$("."+b).show();d.fadeIn()};MadCap.FeedbackException=function(c,b,d){MadCap.Exception.call(this,c,b);this.Data=d};MadCap.FeedbackException.prototype=new MadCap.Exception();MadCap.FeedbackException.prototype.constructor=MadCap.FeedbackException;MadCap.FeedbackException.prototype.base=MadCap.Exception.prototype})();/*
* Copyright MadCap Software
* http://www.madcapsoftware.com/
*
* v10.0.0.0
*/
MadCap.WebHelp=MadCap.CreateNamespace("WebHelp");MadCap.WebHelp.HelpSystem=function(v,m,n,b,D){var d=this;var r=v;var e=new MadCap.Utilities.Url(n).ToFolder().ToFolder().FullPath;var o=null;var l=new Array();var w=b;var k=D;var q=null;var t=new MadCap.Utilities.Dictionary();var A=null;var F=new MadCap.Utilities.Dictionary();var c=false;var p=new MadCap.WebHelp.AliasFile(e+"Data/Alias.xml",this);var G=new MadCap.WebHelp.TocFile(this,MadCap.WebHelp.TocFile.TocType.Toc);var h=null;var s=new MadCap.WebHelp.TocFile(this,MadCap.WebHelp.TocFile.TocType.BrowseSequence);var u=new MadCap.Utilities.Dictionary();this.TargetType=null;this.DefaultStartTopic=null;this.InPreviewMode=null;this.LiveHelpOutputId=null;this.LiveHelpServer=null;this.LiveHelpEnabled=false;this.IsWebHelpPlus=false;this.ContentFolder=null;this.UseCustomTopicFileExtension=false;this.CustomTopicFileExtension=null;this.GlossaryUrl=null;this.SearchFilterSetUrl=null;this.SyncTOC=null;this.DefaultSkin=null;this.IsAutoMerged=false;this.LanguageUrl=null;this.BreakpointsUrl=null;this.IsResponsive=false;(function(){})();this.Load=function(I){MadCap.Utilities.Xhr.Load(n,true,function(X){var P=0;function L(){P++;if(P==l.length){I()}}function Y(ab,Z){if(l.length>0){for(var aa=0;aa<l.length;aa++){l[aa].Load(ab)}}else{Z()}}c=X!=null;if(!c){I();return}this.TargetType=X.documentElement.getAttribute("TargetType");this.DefaultStartTopic=X.documentElement.getAttribute("DefaultUrl");this.InPreviewMode=MadCap.Dom.GetAttributeBool(X.documentElement,"InPreviewMode",false);this.LiveHelpOutputId=X.documentElement.getAttribute("LiveHelpOutputId");this.LiveHelpServer=X.documentElement.getAttribute("LiveHelpServer");this.LiveHelpEnabled=this.LiveHelpOutputId!=null;this.MoveContentToRoot=MadCap.Dom.GetAttributeBool(X.documentElement,"MoveOutputContentToRoot",false);var N=MadCap.Dom.GetAttributeBool(X.documentElement,"ServerEnabled",false);this.IsWebHelpPlus=(this.TargetType=="WebHelpPlus"||N)&&MadCap.String.StartsWith(document.location.protocol,"http",false);var V=MadCap.Dom.GetAttributeBool(X.documentElement,"MakeFileLowerCase",false);var J="";if(!this.MoveContentToRoot){J="Content/"}if(V){J=J.toLowerCase()}this.ContentFolder=J;this.UseCustomTopicFileExtension=MadCap.Dom.GetAttributeBool(X.documentElement,"UseCustomTopicFileExtension",false);this.CustomTopicFileExtension=MadCap.Dom.GetAttribute(X.documentElement,"CustomTopicFileExtension");this.GlossaryUrl=E(X,"Glossary");this.TocUrl=E(X,"Toc");this.BrowseSequencesUrl=E(X,"BrowseSequence");this.IndexUrl=E(X,"Index");this.SearchFilterSetUrl=E(X,"SearchFilterSet");this.LanguageUrl=e+"Data/Language.js";this.BreakpointsUrl=e+"Data/Breakpoints.js";this.HasBrowseSequences=X.documentElement.getAttribute("BrowseSequence")!=null;this.HasToc=X.documentElement.getAttribute("Toc")!=null;H.call(this,X);this.DefaultSkin=this.GetSkin($(X.documentElement).attr("SkinName"));this.IsResponsive=MadCap.String.ToBool(this.DefaultSkin.EnableResponsiveOutput,this.IsResponsive);this.SyncTOC=MadCap.String.ToBool(this.DefaultSkin.AutoSyncTOC,false);this.DisplayCommunitySearchResults=MadCap.String.ToBool(this.DefaultSkin.DisplayCommunitySearchResults,true);this.CommunitySearchResultsCount=MadCap.String.ToInt(this.DefaultSkin.CommunitySearchResultsCount,3);var Q=X.getElementsByTagName("Subsystems");if(Q.length>0&&Q[0].getElementsByTagName("Url").length>0){var W=X.getElementsByTagName("Subsystems")[0].getElementsByTagName("Url");for(var O=0;O<W.length;O++){var S=W[O];if(!S){continue}var K=S.getAttribute("Source");var M=K.substring(0,K.lastIndexOf("/")+1);var U=S.getAttribute("TocPath");var R=S.getAttribute("BrowseSequencePath");var T=new MadCap.WebHelp.HelpSystem(this,e+M,e+M+"Data/HelpSystem.xml",U,R);l.push(T)}}this.LoadBreakpoints(function(){d.LoadLanguage(function(){if(!d.IsAutoMerged&&d.IsWebHelpPlus){MadCap.Utilities.Xhr.CallWebService(d.GetPath()+"Service/Service.asmx/GetSubsystems",true,function(aa,Z){$.each(aa.documentElement.childNodes,function(ab,ac){if(ac.nodeName=="Subsystems"){$.each(ac.childNodes,function(ag,ah){if(ah.nodeName=="Url"){var af=ah.getAttribute("Source");var ad=af.substring(0,af.lastIndexOf("/")+1);if(ad){var ae=new MadCap.WebHelp.HelpSystem(d,e+ad,e+ad+"Data/HelpSystem.xml",null,null);ae.IsAutoMerged=true;l.push(ae)}}})}});Y(L,I)})}else{Y(L,I)}})})},null,this)};this.GetExists=function(){return c};this.GetMasterHelpsystem=function(){var I=this;for(var J=I.GetParentSubsystem();J!=null;J=J.GetParentSubsystem()){I=J}return I};this.GetParentSubsystem=function(){return r};this.GetPath=function(){return e};this.GetAbsolutePath=function(){if(o==null){var I=new MadCap.Utilities.Url(e);o=I.IsAbsolute?I.FullPath:new MadCap.Utilities.Url(document.location.href).Path}return o};this.GetContentPath=function(){return e+this.ContentFolder};this.GetSkin=function(I){return u.GetItem(I)};this.GetTocPath=function(I){return I=="toc"?w:k};this.GetFullTocPath=function(I,K){var L=this.GetHelpSystem(K);if(L==null){return null}var J=new Object();J.tocPath=this.GetTocPath(I);L.ComputeTocPath(I,J);return J.tocPath};this.ComputeTocPath=function(I,J){if(r){var K=this.GetTocPath(I);if(!MadCap.String.IsNullOrEmpty(K)){J.tocPath=J.tocPath?K+"|"+J.tocPath:K}r.ComputeTocPath(I,J)}};this.GetHelpSystem=function(J){var K=null;for(var I=0;I<l.length;I++){K=l[I].GetHelpSystem(J);if(K!=null){return K}}if(MadCap.String.StartsWith(J,e,false)){return this}return null};this.GetSubsystem=function(I){return l[I]};this.GetMergedAliasIDs=function(I){p.Load(function(){function O(Q){for(var P=0,R=Q.length;P<R;P++){N[N.length]=Q[P]}L++;if(L==M+1){I(N)}}var N=new Array();var M=l.length;var L=0;var K=p.GetIDs();O(K);for(var J=0;J<M;J++){l[J].GetMergedAliasIDs(O)}})};this.GetMergedAliasNames=function(I){p.Load(function(){function N(Q){for(var P=0,R=Q.length;P<R;P++){J[J.length]=Q[P]}L++;if(L==M+1){I(J)}}var J=new Array();var M=l.length;var L=0;var O=p.GetNames();N(O);for(var K=0,M=l.length;K<M;K++){l[K].GetMergedAliasNames(N)}})};this.LookupCSHID=function(J,I){p.Load(function(){function K(Q){if(P){return}M++;if(Q.Found){P=true;I(Q);return}if(M==N){I(O)}}var O=p.LookupID(J);if(O.Found){O.Topic=d.GetPath()+O.Topic;I(O);return}if(l.length==0){I(O);return}var P=false;var M=0;for(var L=0,N=l.length;L<N;L++){l[L].LookupCSHID(J,K)}})};this.GetTocFile=function(){return G};this.GetBrowseSequenceFile=function(){return s};this.IsMerged=function(){return(l.length>0)};this.IsRoot=function(){return r==null};this.LoadLanguage=function(K,I){var J=this;require([this.LanguageUrl],function(L){J.Language=L;K.call(I,L)})};this.LoadBreakpoints=function(K,I){if(this.IsResponsive&&this.IsRoot()){var J=this;require([this.BreakpointsUrl],function(L){J.Breakpoints=L;K.call(I,L)})}else{K.call(I,null)}};this.LoadConcepts=function(I){if(A){I();return}MadCap.Utilities.Xhr.Load(e+"Data/Concepts.xml",true,function(S){A=new MadCap.Utilities.Dictionary();var L=S.documentElement;for(var N=0;N<L.childNodes.length;N++){var Q=L.childNodes[N];if(Q.nodeType!=1){continue}var K=Q.getAttribute("Term").toLowerCase();var R=new Array();for(var M=0;M<Q.childNodes.length;M++){var O=Q.childNodes[M];if(O.nodeType!=1){continue}var P=O.getAttribute("Title");var J=O.getAttribute("Link");J=e+((J.charAt(0)=="/")?J.substring(1,J.length):J);R[R.length]={Title:P,Link:J}}A.Add(K,R)}I()},null,null)};this.LoadAllConcepts=function(I){function N(){K++;if(K==L+1){I()}}var K=0;var L=l.length;this.LoadConcepts(N);for(var J=0;J<L;J++){var M=l[J];if(!M.GetExists()){N();continue}M.LoadConcepts(N)}};this.GetConceptsLinks=function(M,I,L){if(this.IsWebHelpPlus){function N(W,T){var V=new Array();var P=W.documentElement.getElementsByTagName("Url");var R=P.length;for(var S=0;S<R;S++){var Q=P[S];var U=Q.getAttribute("Title");var O=Q.getAttribute("Source");O=e+((O.charAt(0)=="/")?O.substring(1,O.length):O);V[V.length]={Title:U,Link:O}}I(V,L)}MadCap.Utilities.Xhr.CallWebService(e+"Service/Service.asmx/GetTopicsForConcepts?Concepts="+M,true,N)}else{var J=null;M=M.replace("\\;","%%%%%");if(M==""){J=new Array();I(J,L)}var K=M.split(";");this.GetConceptsLinksLocal(K,function(O){I(O,L)})}};this.GetConceptsLinksLocal=function(P,I){function L(R){for(var Q=0;Q<R.length;Q++){J[J.length]=R[Q]}M++;if(M==O){I(J)}}var M=0;var O=P.length;var J=new Array();for(var K=0;K<P.length;K++){var N=P[K];N=N.replace("%%%%%",";");N=N.toLowerCase();this.GetConceptLinksLocal(N,L)}};this.GetConceptLinksLocal=function(J,I){this.LoadConcepts(function(){function N(R){z(K,R);O++;if(O==P){F.Add(J,K);var S=$.extend(true,[],K);I(S)}}var K=F.GetItem(J);if(K!=null){var M=$.extend(true,[],K);I(M);return}K=A.GetItem(J);if(!K){K=new Array(0)}var O=0;var P=0;for(var L=0;L<l.length;L++){var Q=l[L];if(!Q.GetExists()){continue}P++}if(P==0){I(K);return}for(var L=0;L<l.length;L++){var Q=l[L];if(!Q.GetExists()){continue}Q.GetConceptLinksLocal(J,N)}})};this.LoadToc=function(K,L,I){var J=this;var M=J[K];if(typeof M!=="undefined"){L.call(I,M)}else{this.GetToc(K,function(N){L.call(I,N)})}};this.GetToc=function(L,I){var J=this;var K=this[L+"Url"];require([K],function(Q){if(typeof Q=="undefined"){I(Q);return}J[L]=Q;Q.type=L;Q.helpSystem=J;Q.chunks=[];Q.entries=[];Q.nodes={};var N=new MadCap.Utilities.Url(K).ToFolder();for(var T=0;T<Q.numchunks;T++){Q.chunks[T]={path:N.AddFile(Q.prefix+T+".js").FullPath,loaded:false}}var P=Q.tree;var U={};Q.automerge=Q.tree;while(P!=null){P.toc=Q;P.childrenLoaded=false;Q.nodes[P.i]=P;if(typeof P.m!=="undefined"){U[P.m]=P}if(typeof P.a!=="undefined"){Q.automerge=P}if(typeof P.n!=="undefined"){for(var S=0;S<P.n.length;S++){P.n[S].parent=P;if(S<P.n.length-1){P.n[S].next=P.n[S+1]}if(S>0){P.n[S].previous=P.n[S-1]}}}P=B(P)}var O=[];var R=false;for(var S=0;S<l.length;S++){var M=l[S];if(M.GetExists()){if(!M.IsAutoMerged){M.MergeNode=U[S]}else{R=true}if(M.IsAutoMerged||typeof M.MergeNode!=="undefined"){O.push(M)}}else{f(U[S])}}if(!R&&Q.automerge.a=="replace"){f(Q.automerge)}if(O.length==0){I(Q);return}MadCap.Utilities.AsyncForeach(O,function(V,W){i(Q,V,W)},function(){I(Q)})})};function f(M){var K=M.parent;var L=M.previous;var J=M.next;if(L){L.next=J;M.previous=null}if(J){J.previous=L;M.next=null}if(K){var I=M.parent.n.indexOf(M);K.n.splice(I,1);M.parent=null}}function B(J){var I=null;if(typeof J.n!="undefined"){I=J.n[0]}else{if(typeof J.next!="undefined"){I=J.next}else{I=J;while(typeof I.parent!="undefined"){if(typeof I.parent.next!="undefined"){I=I.parent.next;break}else{I=I.parent}}if(typeof I.parent=="undefined"){I=null}}}return I}function j(J){var I=null;if(typeof J.previous!="undefined"){I=J.previous;while(typeof I.n!=="undefined"&&I.n.length>0){I=I.n[I.n.length-1]}}else{if(typeof J.parent!="undefined"){I=J.parent}}return I}function y(O,N){var M="";var L=-1;var K=null;if(O.n&&O.n.length>0){M=O.toc.entries[O.i].title;if(N){M=encodeURIComponent(M)}L=0}else{L=O.parent.n.indexOf(O)+1}if(M.length>0){M+="|"}M+=("_____"+L);for(var I=O.parent;I&&typeof I.i!=="undefined";I=I.parent){if(M==null){M=""}if(M.length>0){M="|"+M}var J=I.toc.entries[I.i].title;if(N){J=encodeURIComponent(J)}M=J+M}return M}function i(J,K,I){K.GetToc(J.type,function(O){if(typeof O=="undefined"){I();return}var N=K.IsAutoMerged?J.automerge:K.MergeNode;var V=O.tree;if(typeof V.n!=="undefined"){var M=N.r==1||(K.IsAutoMerged&&N.a=="replace");var T=M||(K.IsAutoMerged&&(N.a=="before-head"||N.a=="after-head"));var P=M||(K.IsAutoMerged&&(N.a=="before-head"||N.a=="after-tail"));var U=P?N.parent:N;if(typeof U.n=="undefined"){U.n=[]}var Q=P?U.n.indexOf(N)+(T?0:1):T?0:U.n.length;var L=V.n.length;for(var R=0;R<L;R++){V.n[R].parent=U;U.n.splice(Q+R,0,V.n[R])}if(M){U.n.splice(Q+L,1)}if(Q>0){U.n[Q].previous=U.n[Q-1];U.n[Q-1].next=U.n[Q]}var S=Q+L-(M?1:0)-1;if(S>=0&&S+1<U.n.length){U.n[S].next=U.n[S+1];U.n[S+1].previous=U.n[S]}if(K.IsAutoMerged){J.automerge=U.n[Q+L-1];J.automerge.a="after-tail"}}I()})}this.LoadTocChunk=function(K,I,J){require([K.chunks[I].path],function(L){if(!K.chunks[I].loaded){for(var N in L){for(var M=0;M<L[N].i.length;M++){K.entries[L[N].i[M]]={link:N,title:L[N].t[M],bookmark:L[N].b[M]}}}K.chunks[I].loaded=true}if(J){J(L)}})};this.GetTocEntryHref=function(T,M){var L=T.toc;var P=L.entries[T.i];var S=P.link+P.bookmark;var K=null;if(typeof T.m=="undefined"&&S!="___"){var J=null;var O=new MadCap.Utilities.Url(S);var I=L.helpSystem;var N=I.GetPath();var R=I.GetMasterHelpsystem().GetContentPath();if(!O.IsAbsolute){if(!MadCap.String.IsNullOrEmpty(N)){var O=new MadCap.Utilities.Url(N).CombinePath(S);J=O.ToRelative(R)}else{J=O.ToRelative("/"+R)}}else{J=O}if(typeof T.f!="undefined"){if(J.IsAbsolute){K=J.FullPath}else{K=R+J.FullPath}}else{K="#"+J.FullPath}}if(K!=null&&M){var Q=y(T,true);K+=encodeURIComponent("?"+M+"Path="+Q)}return K};this.FindTocNode=function(K,I,J){d.FindNode("Toc",K,I,J)};this.FindBrowseSequenceNode=function(K,I,J){d.FindNode("BrowseSequences",K,I,J)};this.FindNode=function(I,K,J,L){d.LoadToc(I,function(R){var N=new MadCap.Utilities.Url(d.GetMasterHelpsystem().GetContentPath());var O=J;var Q=0;var M;if(!J.IsAbsolute){var O=!MadCap.String.IsNullOrEmpty(N.FullPath)?N.CombinePath(J):J;O=O.ToRelative(d.GetPath());O=new MadCap.Utilities.Url("/"+O.FullPath)}for(var P=1;P<R.chunkstart.length;P++){if(R.chunkstart[P]<=O.PlainPath){Q++}}d.LoadTocChunk(R,Q,function(S){var U=S[O.PlainPath];if(typeof U!=="undefined"){var V=null;if(!M){M=R.nodes[U.i[0]]}if(K){for(var T=0;T<U.i.length;T++){if(y(R.nodes[U.i[T]],false)==K){V=U.i[T];break}}}else{for(var T=0;T<U.i.length;T++){if(U.b[T].toLowerCase()==O.Fragment.toLowerCase()){V=U.i[T];break}}}if(V!=null){L(R.nodes[V]);return}}if(l.length>0){MadCap.Utilities.AsyncForeach(l,function(W,X){W.FindNode(I,K,J,function(Y){if(typeof Y!=="undefined"){L(Y);return}X()})},function(){L(M)})}else{L(M)}})})};this.LoadGlossary=function(K,I){var J=this;this.GetGlossary(function(L){J.Glossary=L;K.call(I,L)})};this.GetGlossary=function(I){require([this.GlossaryUrl],function(J){function L(){N++;if(N==O){I(J)}}if(typeof J=="undefined"){I(J);return}var N=0;var O=0;J.chunks=[];var M=new MadCap.Utilities.Url(d.GlossaryUrl).ToFolder();for(var Q=0;Q<J.numchunks;Q++){J.chunks.push(M.AddFile(J.prefix+Q+".js").FullPath)}for(var K=0;K<l.length;K++){var P=l[K];if(!P.GetExists()){continue}O++}if(O==0){I(J);return}for(var K=0;K<l.length;K++){var P=l[K];if(!P.GetExists()){continue}a(J,P,L)}})};this.LoadIndex=function(K,I){if(typeof this.Index!=="undefined"){K.call(I,this.Index);return}var J=this;this.GetIndex(function(L){J.Index=L;K.call(I,L)})};this.GetIndex=function(I){require([this.IndexUrl],function(K){function J(){N++;if(N==O){I(K)}}if(typeof K=="undefined"){I(K);return}var N=0;var O=0;K.chunks=[];var M=new MadCap.Utilities.Url(d.IndexUrl).ToFolder().ToRelative(document.location.href);for(var Q=0;Q<K.numchunks;Q++){K.chunks.push(M.AddFile(K.prefix+Q+".js").FullPath)}for(var L=0;L<l.length;L++){var P=l[L];if(!P.GetExists()){continue}O++}if(O==0){I(K);return}for(var L=0;L<l.length;L++){var P=l[L];if(!P.GetExists()){continue}C(K,P,J)}})};this.LoadRootIndexEntry=function(I,J){if(I.loaded){if(J){J(I)}return}this.LoadIndex(function(K){var L=typeof I.c=="number"?[I.c]:I.c;MadCap.Utilities.AsyncForeach(L,function(O,N){var M=K.chunks[O];require([M],function(P){var R=P[I.t];var Q=new MadCap.Utilities.Url(M).ToFolder().ToFolder().FullPath;if(MadCap.String.EndsWith(Q,"/")){Q=Q.slice(0,-1)}d.SetIndexEntryRoot(R,Q);d.MergeIndexEntries(I,R);N()})},function(){d.LoadIndexEntry(I);if(J){J(I)}})})};this.SetIndexEntryRoot=function(J,I){if(J.l){$.each(J.l,function(K,L){L.root=I})}if(J.e){$.each(J.e,function(K,L){d.SetIndexEntryRoot(L,I)})}};this.LoadIndexEntry=function(J){if(J.l){var I=[];$.each(J.l,function(L,K){var M={Title:K.t,Link:d.GetIndexLinkPath(K)};I[I.length]=M});J.linkList=d.SortLinkList(I)}if(J.e){$.each(J.e,function(K,L){d.LoadIndexEntry(L)})}J.loaded=true};this.GetIndexLinkPath=function(J){var L=J.root+J.u;if(MadCap.String.StartsWith(L,"/")){L=L.substring(1)}var I=new MadCap.Utilities.Url(d.GetMasterHelpsystem().GetAbsolutePath());var K=new MadCap.Utilities.Url(document.location.href);if(I.Path.toLowerCase()==K.Path.toLowerCase()){L=I.AddFile(L).ToRelative(I.Path+d.GetMasterHelpsystem().GetContentPath()).FullPath}return L};this.MergeIndexEntries=function(J,I){if(I.l){if(typeof J.l=="undefined"){J.l=I.l}else{J.l=J.l.concat(I.l)}}if(I.r){if(typeof J.r=="undefined"){J.r=I.r}else{if(J.r=="SeeAlso"||I.r=="SeeAlso"){J.r="SeeAlso"}}if(typeof J.f=="undefined"){J.f=I.f}else{var L=J.f.split(";");var K=I.f.split(";");$.each(K,function(N,M){if($.inArray(L,M)){L.push(M)}});L.sort(function(P,N){var O=P.toLowerCase();var M=N.toLowerCase();return O<M?-1:O>M?1:0});J.f=L.join("; ")}}if(I.e){if(typeof J.e=="undefined"){J.e={}}$.each(I.e,function(M,N){if(typeof J.e[M]!=="undefined"){d.MergeIndexEntries(J.e[M],N)}else{J.e[M]=N}})}};this.FindIndexEntry=function(J,I){d.LoadIndex(function(K){if(!K.entries){K.entries={};$.each(K.terms,function(O,P){K.entries[P.t]=P})}var M=J.split(":");var N=M.length;var L=K.entries[M[0]];if(L){d.LoadRootIndexEntry(L,function(P){var Q=P;for(var O=1;O<N;O++){Q=Q.e[M[O]];if(!Q){break}}if(I){I(P,Q)}})}else{if(I){I()}}})};this.SortLinkList=function(I){I.sort(function(K,J){var M=K.Title.toLowerCase();var L=J.Title.toLowerCase();return M<L?-1:M>L?1:0});return I};this.GetSearchDBs=function(I){var J=new Array();MadCap.Utilities.Xhr.Load(e+"Data/Search.xml",true,function(O){function L(Q){if(Q!=null){for(var P=0;P<Q.length;P++){J[J.length]=Q[P]}}M++;if(M==N){I(J)}}var M=0;var N=l.length;var K=new MadCap.WebHelp.Search.SearchDB(this);J[J.length]=K;K.Load("Data/Search.xml",function(){var P=MadCap.Dom.GetAttributeBool(O.documentElement,"PreMerged",false);if(P||N==0){I(J)}else{for(var Q=0;Q<N;Q++){var R=l[Q];if(!R.GetExists()){L(null);continue}R.GetSearchDBs(L)}}})},null,this)};this.GetConcepts=function(){return A};this.GetSearchFilters=function(){return q};this.ParseSearchFilterDoc=function(R){filterMap=new MadCap.Utilities.Dictionary();if(R!=null){var K=R.getElementsByTagName("SearchFilter");for(var O=0;O<K.length;O++){var J=K[O];var I=J.getAttribute("Name");if(!J.getAttribute("Concepts")){continue}var L=J.getAttribute("Concepts").split(";");var Q=new MadCap.Utilities.Dictionary();filterMap.Add(I,Q);for(var N=0,P=L.length;N<P;N++){var M=MadCap.String.Trim(L[N]).toLowerCase();Q.Add(M,true)}}}return filterMap};this.LoadSearchFilters=function(I){function J(K){q=this.ParseSearchFilterDoc(K);I(q)}if(this.SearchFilterSetUrl==null||q!=null){I(q);return}MadCap.Utilities.Xhr.Load(this.SearchFilterSetUrl,true,J,null,this)};this.LoadMergedSearchFilters=function(I){function P(Q){if(Q!=null){Q.ForEach(function(S,T){var R=J.GetItem(S);if(R!=null){T.ForEach(function(V,U){R.AddUnique(V,U)})}else{J.Add(S,T)}return true})}M++;if(M==N+1){I(J)}}var J=new MadCap.Utilities.Dictionary();if(!this.IsWebHelpPlus){var M=0;var N=l.length;this.LoadSearchFilters(P);for(var L=0;L<N;L++){var O=l[L];if(!O.GetExists()){P(null);continue}O.LoadSearchFilters(P)}}else{var K=this;MadCap.Utilities.Xhr.CallWebService(e+"Service/Service.asmx/GetSearchFilters",true,function(R,Q){var S=K.ParseSearchFilterDoc(R);I(S)})}};this.AdvanceTopic=function(I,N,M,J,K){var L=null;d.FindNode(I,M,J,function(P){if(P){function O(R,Q){R=Q=="next"?B(R):j(R);if(R&&typeof R.i!=="undefined"){d.LoadTocChunk(R.toc,R.c,function(S){var U=R.toc.entries[R.i];var T=d.GetTocEntryHref(R,I);if(T){if(MadCap.String.StartsWith(T,"#")){T=T.substring(1)}K(T)}else{O(R,Q)}})}}O(P,N)}})};this.SetBrowseSequencePath=function(J,I){var K=$(".current-topic-index-button");if(J!=null){this.FindBrowseSequenceNode(J,I,function(L){if(L&&L.parent){K.removeClass("disabled");$(".sequence-index").text(L.parent.n.indexOf(L)+1);$(".sequence-total").text(L.parent.n.length)}else{K.addClass("disabled")}})}else{K.addClass("disabled")}};function E(L,J){var K=L.documentElement.getAttribute(J);if(K==null){return null}var I=new MadCap.Utilities.Url(e);if(!I.IsAbsolute){return e+K}return I.AddFile(K).ToRelative(document.location.href).FullPath}function H(X){var Y=$("CatapultSkin",X.documentElement);for(var T=0,O=Y.length;T<O;T++){var U=Y[T];var P=$(U);var R=P.attr("Name");var W={};for(var S=0,M=U.attributes.length;S<M;S++){var V=U.attributes[S];W[V.name]=V.value}var N=P.children();for(var S=0,M=N.length;S<M;S++){var I=N[S];var K=I.nodeName;var L={};W[K]=L;for(var Q=0,J=I.attributes.length;Q<J;Q++){var V=I.attributes[Q];L[V.name]=V.value}}u.Add(R,W)}}function x(K,L){if(K.nodeName.toLowerCase()=="madcap:glossarychunkref"){var N=$(K);var I=N.attr("src");if(!MadCap.String.IsNullOrEmpty(I)){var J=new MadCap.Utilities.Url(L).CombinePath("../../Data/").CombinePath(I);N.attr("src","../"+J.FullPath)}}else{var M=K.getElementsByTagName("a")[0];var I=$(M).attr("href");if(!MadCap.String.IsNullOrEmpty(I)){var J=new MadCap.Utilities.Url(L).CombinePath("../../Content/").CombinePath(I);$(M).attr("href","../"+J.FullPath)}}}function g(M){for(var K=0;K<M.childNodes.length;K++){var I=M.childNodes[K];if(I.nodeName=="Entries"){for(var J=0;J<I.childNodes.length;J++){g(I.childNodes[J])}}else{if(I.nodeName=="Links"){for(var J=0;J<I.childNodes.length;J++){if(I.childNodes[J].nodeType==1){var L=MadCap.Dom.GetAttribute(I.childNodes[J],"Link");L=e+((L.charAt(0)=="/")?L.substring(1,L.length):L);I.childNodes[J].setAttribute("Link",L)}}}}}}function z(J,I){if(!I){return}for(var K=0;K<I.length;K++){J[J.length]=I[K]}}function a(J,K,I){K.GetGlossary(function(P){if(typeof P=="undefined"){I();return}J.chunks=J.chunks.concat(P.chunks);for(var O=0,M=0;O<J.terms.length&&M<P.terms.length;){var N=J.terms[O];var L=P.terms[M];var S=N.t;var Q=L.t;if(S.toLowerCase()==Q.toLowerCase()){O++;M++}else{if(S.toLowerCase()>Q.toLowerCase()){L.c+=J.numchunks;J.terms.splice(O,0,L);M++}else{O++}}}for(;M<P.terms.length;M++){var R=P.terms[M];R.c+=J.numchunks;J.terms.push(R)}J.numchunks=J.chunks.length;I()})}function C(K,J,I){J.GetIndex(function(Q){if(typeof Q=="undefined"){I();return}K.chunks=K.chunks.concat(Q.chunks);for(var O=0,N=0;O<K.terms.length&&N<Q.terms.length;){var S=K.terms[O];var R=Q.terms[N];var M=S.s||S.t;var L=R.s||R.t;if(M==L&&S.t==R.t){if(typeof S.c=="number"){S.c=[S.c]}var P=R.c;if(typeof R.c=="number"){P=[R.c]}$.each(P,function(V,U){S.c.push(U+K.numchunks)});S.$=(S.$===1&&R.$===1)?1:0;O++;N++}else{if(M.toLowerCase()>L.toLowerCase()||(M.toLowerCase()==L.toLowerCase()&&S.t.toLowerCase()>R.t.toLowerCase())){R.c+=K.numchunks;K.terms.splice(O,0,R);N++}else{O++}}}for(;N<Q.terms.length;N++){var T=Q.terms[N];T.c+=K.numchunks;K.terms.push(T)}K.numchunks=K.chunks.length;I()})}};(function(){var a=null;MadCap.WebHelp.HelpSystem.GetHelpSystem=function(){return a};MadCap.WebHelp.HelpSystem.LoadHelpSystem=function(c,b){a=new MadCap.WebHelp.HelpSystem(null,null,c,null,null);a.Load(function(){b(a)})}})();MadCap.WebHelp.TocFile=function(r,l){var b=this;var h=r;var e=l;var c=false;var i=null;var n=new Array();var j=null;var o=null;var a=new Array();(function(){})();this.Init=function(t){if(c){if(t!=null){t()}return}if(t!=null){n.push(t)}var v=null;if(l==MadCap.WebHelp.TocFile.TocType.Toc){v="Toc.xml"}else{if(l==MadCap.WebHelp.TocFile.TocType.BrowseSequence){v="BrowseSequences.xml"}}this.LoadToc(h.GetPath()+"Data/"+v,u);function u(w){c=true;i=w.documentElement;g()}};this.LoadToc=function(u,t){if(e==MadCap.WebHelp.TocFile.TocType.Toc&&h.IsWebHelpPlus){MadCap.Utilities.Xhr.CallWebService(h.GetPath()+"Service/Service.asmx/GetToc",true,w,null)}else{if(e==MadCap.WebHelp.TocFile.TocType.BrowseSequence&&h.IsWebHelpPlus){MadCap.Utilities.Xhr.CallWebService(h.GetPath()+"Service/Service.asmx/GetBrowseSequences",true,w,null)}else{var v=(u.indexOf("/")==-1)?h.GetPath()+"Data/"+u:u;MadCap.Utilities.Xhr.Load(v,false,w,null,null)}}function w(y,x){if(!y||!y.documentElement){if(t!=null){t(y)}return}if(t!=null){t(y)}}};this.LoadChunk=function(u,v,t){var w=(v.indexOf("/")==-1)?h.GetPath()+"Data/"+v:v;MadCap.Utilities.Xhr.Load(v,true,x,null,null);function x(E,z){if(!E||!E.documentElement){if(t!=null){t(u)}return}u.removeAttribute("Chunk");var y=E.documentElement;for(var B=0,D=y.childNodes.length;B<D;B++){var A=y.childNodes[B];if(A.nodeType!=1){continue}var C=null;if(typeof(E.importNode)=="function"){C=E.importNode(A,true)}else{C=A.cloneNode(true)}u.appendChild(C)}if(t!=null){t(u)}}};this.LoadMerge=function(y,t){var x=MadCap.Dom.GetAttributeInt(y,"MergeHint",-1);if(x==-1){t(y,false,null,null);return}y.removeAttribute("MergeHint");var A=k(y);var u=A.GetSubsystem(x);var v=MadCap.Dom.GetAttributeBool(y,"ReplaceMergeNode",false);if(!v){y.setAttribute("ownerHelpSystemIndex",a.length)}a[a.length]=u;var z=u.GetPath()+"Data/"+(e==MadCap.WebHelp.TocFile.TocType.Toc?"Toc.xml":"BrowseSequences.xml");var B=MadCap.Utilities.Xhr.Load(z,true,w);function w(N,K){if(!N||!N.documentElement){if(t!=null){t(y,false,null,null)}return}var G=N.documentElement;var J=null;var H=true;var D=null;var E=null;var L=y.ownerDocument;for(var I=0,F=G.childNodes.length;I<F;I++){var C=G.childNodes[I];if(C.nodeType!=1){continue}var M=null;if(typeof(L.importNode)=="function"){M=L.importNode(C,true)}else{M=C.cloneNode(true)}if(v){M.setAttribute("ownerHelpSystemIndex",a.length-1);if(H){H=false;y.parentNode.replaceChild(M,y);D=M;E=D}else{J.parentNode.insertBefore(M,J.nextSibling);E=M}J=M}else{y.appendChild(M)}}if(t!=null){t(y,v,D,E)}}};this.AdvanceTopic=function(x,w,u,v){this.GetTocNode(w,u,t);function t(y){if(y==null){v(null);return}var z=null;q(x,y,A);function A(E){var B=null;if(E!=null){B=MadCap.Dom.GetAttribute(E,"Link");B=B.substring("/".length);var H=new MadCap.Utilities.Url(B);var G=null;if(e==MadCap.WebHelp.TocFile.TocType.Toc){G="TocPath"}else{if(e==MadCap.WebHelp.TocFile.TocType.BrowseSequence){G="BrowseSequencePath"}}var D=m(E,false);var C=H.ToQuery(G+"="+encodeURIComponent(D));B=C.FullPath;var F=k(E);B=F.GetPath()+B;v(B)}else{v(B)}}}};this.GetRootNode=function(u){this.Init(t);function t(){u(i)}};this.GetTocNode=function(v,t,x){this.Init(w);function w(){j=v;o=t;var F=(v=="")?new Array(0):v.split("|");var B=-1;if(F.length>0){var z=F[F.length-1];if(MadCap.String.StartsWith(z,"_____")){B=parseInt(z.substring("_____".length));F.splice(F.length-1,1)}}var H=i;for(var D=0,A=F.length;D<A;D++){if(y(H)){return}if(u(H)){return}H=d(H,decodeURIComponent(F[D]))}if(H==null){x(null);return}if(y(H)){return}if(u(H)){return}if(B>=0){if(B==0){C=H}else{C=$(H).children("TocEntry")[B-1]}}else{var E=k(H);var G=t.ToRelative(new MadCap.Utilities.Url(E.GetPath()));var C=s(H,G.FullPath.toLowerCase(),true);if(!C){C=s(H,G.PlainPath.toLowerCase(),false)}}j=null;o=null;x(C)}function y(z){var A=MadCap.Dom.GetAttribute(z,"Chunk");if(A!=null){b.LoadChunk(z,A,function(B){b.GetTocNode(j,o,x)});return true}return false}function u(z){var A=$(z).attr("MergeHint")||-1;if(A>=0){b.LoadMerge(z,function(B){b.GetTocNode(j,o,x)});return true}return false}};this.GetEntrySequenceIndex=function(u,t,w){this.GetTocNode(u,t,v);function v(y){var x=-1;if(y!=null){x=f(y)}w(x)}};this.GetIndexTotalForEntry=function(u,t,w){this.GetTocNode(u,t,v);function v(y){var z=-1;if(y!=null){var x=y;while(x.parentNode!=i){x=x.parentNode}z=MadCap.Dom.GetAttributeInt(x,"DescendantCount",-1)}w(z)}};function g(){for(var t=0,u=n.length;t<u;t++){n[t]()}}function d(u,w){var t=null;for(var v=0;v<u.childNodes.length;v++){if(u.childNodes[v].nodeName=="TocEntry"&&MadCap.Dom.GetAttribute(u.childNodes[v],"Title")==w){t=u.childNodes[v];break}}return t}function s(v,t,x){var y=null;var B=MadCap.Dom.GetAttribute(v,"Link");if(B!=null){B=B.substring("/".length);B=B.replace(/%20/g," ");B=B.toLowerCase()}if(B==t){y=v}else{for(var w=0;w<v.childNodes.length;w++){var z=v.childNodes[w];if(z.nodeType!=1){continue}var A=MadCap.Dom.GetAttribute(z,"Link");if(A==null){continue}A=A.substring("/".length);A=A.replace(/%20/g," ");A=A.toLowerCase();if(!x){var C=A.indexOf("#");if(C!=-1){A=A.substring(0,C)}var u=A.indexOf("?");if(u!=-1){A=A.substring(0,u)}}if(A==t){y=z;break}}}return y}function q(w,t,x){if(w=="previous"){v(t)}else{if(w=="next"){z(t)}}function A(F){var B=null;if(F!=null){var E=MadCap.Dom.GetAttribute(F,"Link");if(E==null){q(w,F,x);return}var C=new MadCap.Utilities.Url(E);var D=C.Extension.toLowerCase();var G=h.GetMasterHelpsystem();if(G.UseCustomTopicFileExtension){if(D!=G.CustomTopicFileExtension){q(w,F,x);return}}else{if(D!="htm"&&D!="html"){q(w,F,x);return}}B=F}x(B)}function v(E){function F(H){var G=p(H,"TocEntry");if(G==null){D=H}else{D=G;if(y(G,F)){return}if(u(G,C)){return}}A(D)}function C(H,I,J,G){if(I){F(G)}else{F(H)}}var D=null;for(var B=E.previousSibling;B!=null;B=B.previousSibling){if(B.nodeName=="TocEntry"){D=B;break}}if(D!=null){if(y(D,F)){return}if(u(D,C)){return}F(D);return}else{if(E.parentNode.nodeType==1){D=E.parentNode}}A(D)}function z(D){function E(H){var G=$(H).children("TocEntry")[0];for(var F=H;F!=null&&G==null;F=F.parentNode){G=$(F).next("TocEntry")[0]}A(G)}function C(G,H,I,F){if(H){A(I);return}E(G)}var B=null;if(y(D,E)){return}if(u(D,C)){return}E(D)}function y(C,B){var D=MadCap.Dom.GetAttribute(C,"Chunk");if(D!=null){b.LoadChunk(C,D,B);return true}return false}function u(C,B){var D=$(C).attr("MergeHint")||-1;if(D>=0){b.LoadMerge(C,B);return true}return false}}function p(t,w){var v=$(t).children(w+":last")[0];if(v!=null){var u=p(v,w);if(u!=null){return u}return v}return null}function k(u){var w=null;var t=u;while(true){if(t==t.ownerDocument.documentElement){w=h;break}var v=MadCap.Dom.GetAttributeInt(t,"ownerHelpSystemIndex",-1);if(v>=0){w=a[v];break}t=t.parentNode}return w}function m(u){var x="";var w=-1;var v=$(u).children("TocEntry")[0];if(v!=null){x=encodeURIComponent(MadCap.Dom.GetAttribute(u,"Title"));w=0}else{w=$(u).index()+1}if(x.length>0){x+="|"}x+=("_____"+w);for(var t=u.parentNode;t!=null&&t.parentNode.nodeType==1;t=t.parentNode){if(x==null){x=""}if(x.length>0){x="|"+x}x=encodeURIComponent(MadCap.Dom.GetAttribute(t,"Title"))+x}return x}function f(w){if(w.parentNode==w.ownerDocument.documentElement){return 0}var v=0;var z=MadCap.Dom.GetAttribute(w,"Link");if(z!=null){v++}for(var t=w.previousSibling;t!=null;t=t.previousSibling){if(t.nodeType!=1){continue}var y=MadCap.Dom.GetAttributeInt(t,"DescendantCount",0);v+=y;var z=MadCap.Dom.GetAttribute(t,"Link");if(z!=null){var u=new MadCap.Utilities.Url(z);var x=u.Extension.toLowerCase();if(x=="htm"||x=="html"){v++}}}return v+f(w.parentNode)}};MadCap.WebHelp.TocFile.TocType={Toc:0,BrowseSequence:1};MadCap.WebHelp.AliasFile=function(h,a,e){var d=null;var f=a;var i=null;var g=null;(function(){})();this.Load=function(j){MadCap.Utilities.Xhr.Load(h,true,function k(l){if(l){d=l.documentElement}j()})};this.GetIDs=function(){var j=new Array();c();g.ForEach(function(k,l){j[j.length]=k;return true});return j};this.GetNames=function(){var j=new Array();c();i.ForEach(function(k,l){j[j.length]=k;return true});return j};this.LookupID=function(o){var l=false;var j=null;var m=null;if(o){if(typeof(o)=="string"&&o.indexOf(".")!=-1){var k=o.indexOf("|");if(k!=-1){j=o.substring(0,k);m=o.substring(k+1)}else{j=o}l=true}else{var n=b(o);if(n!=null){l=true;j=n.Topic;m=n.Skin}}}else{l=true}if(j){j=f.ContentFolder+j}return{Found:l,Topic:j,Skin:m}};function b(k){var j=null;c();if(i!=null){if(typeof(k)=="string"){j=i.GetItem(k);if(j==null){j=g.GetItem(k)}}else{if(typeof(k)=="number"){j=g.GetItem(k.toString())}}}return j}function c(){if(i==null){if(d){i=new MadCap.Utilities.Dictionary();g=new MadCap.Utilities.Dictionary();var p=d.getElementsByTagName("Map");for(var m=0;m<p.length;m++){var k=p[m].getAttribute("Link");var o=p[m].getAttribute("Skin");var l={Topic:k,Skin:o};var j=p[m].getAttribute("Name");if(j!=null){i.Add(j,l)}var n=p[m].getAttribute("ResolvedId");if(n!=null){g.Add(n,l)}}}}}};MadCap.WebHelp.IndexEntry=function(g,f){var e=MadCap.Dom.GetChildNodeByTagName(g,"Links",0).childNodes;var d=e.length;var b=0;this.Term=MadCap.Dom.GetAttribute(g,"Term");this.IndexLinks=new Array();this.Level=f;this.GeneratedReferenceType=MadCap.Dom.GetAttribute(g,"GeneratedReferenceType");for(var c=0;c<d;c++){var a=e[c];if(a.nodeType!=1){continue}this.IndexLinks[b]=new MadCap.WebHelp.IndexLink(a);b++}};MadCap.WebHelp.IndexLink=function(a){this.Title=MadCap.Dom.GetAttribute(a,"Title");this.Link=MadCap.Dom.GetAttribute(a,"Link")};/*
 * Copyright MadCap Software
 * http://www.madcapsoftware.com/
 *
 * v10.2.2.0
 */
(function(){if(MadCap.Dom.Dataset(document.documentElement,"mcRuntimeFileType")!="Default"){return}var w;var G=true;var g=null;function Y(az){MadCap.DEBUG.Log.AddLine(window.name+"onload");MadCap.DEBUG.Log.AddLine(window.name+"hash: "+document.location.hash);MadCap.DEBUG.Log.AddLine(window.name+"search: "+document.location.search);if($.browser.msie&&$.browser.version<=9){var ax=$("#search-field");if(ax.css("direction")=="rtl"){ax.css({"border-top-left-radius":ax.css("border-top-right-radius"),"border-top-right-radius":ax.css("border-top-left-radius"),"border-bottom-left-radius":ax.css("border-bottom-right-radius"),"border-bottom-right-radius":ax.css("border-bottom-left-radius")})}var aB=$("#contentBody");if(aB.css("direction")=="rtl"){aB.css({"border-top-left-radius":aB.css("border-top-right-radius"),"border-top-right-radius":aB.css("border-top-left-radius")})}}$("input, textarea").placeholder();$(".tabs .tabs-nav li").click(o);$("#home").click(y);$(".search-submit").click(function(aC){V(true)});$("#search-field").keypress(function(aC){if(aC.which!=13){return}V(true);aC.preventDefault()});$("#search-field-sidebar").keypress(function(aC){if(aC.which!=13){return}V(false);aC.preventDefault()});$(".search-filter").click(function(aD){$(this).addClass("open");if(window.PIE){$(".search-submit-wrapper").each(function(){PIE.detach(this);PIE.attach(this)})}var aC=$(".search-filter-content",this);aC.fadeIn(200);aC.css("max-height",$(window).height()-aC.offset().top)});var aA=null;$(".search-filter").mouseenter(function(aC){clearTimeout(aA)});$(".search-filter").mouseleave(function(aD){var aC=$(this);var aE=$(".search-filter-content",this);aA=setTimeout(function(){aE.fadeOut(200,function(){aC.removeClass("open")})},500)});$(".search-filter-content").click(ap);$("#navigationResizeBar").mousedown(Z);$("#show-hide-navigation").click(z);M(parseInt($("#navigation").css("width")));var ay=$("title");ay.attr("data-title",document.title);$("#topic").load(function(){ae(0);MadCap.Utilities.CrossFrame.PostMessageRequest(frames.topic,"get-title",null,function(aD){var aC=ay.attr("data-title");var aE=aC;if(!MadCap.String.IsNullOrEmpty(aC)){aE+=" - "}document.title=aE+aD[0]});MadCap.Utilities.CrossFrame.PostMessageRequest(frames.topic,"get-topic-id",null,function(aC){aw=aC[0];if(aw!=null){am()}})});$(".print-button").click(function(aC){MadCap.Utilities.CrossFrame.PostMessageRequest(frames.topic,"print")});$(".expand-all-button").click(function(aD){var aC=$(this);if(aC.hasClass("expand-all-button")){MadCap.Utilities.CrossFrame.PostMessageRequest(frames.topic,"expand-all")}else{if(aC.hasClass("collapse-all-button")){MadCap.Utilities.CrossFrame.PostMessageRequest(frames.topic,"collapse-all")}}A(this)});$(".remove-highlight-button").click(function(aC){MadCap.Utilities.CrossFrame.PostMessageRequest(frames.topic,"remove-highlight")});$(".previous-topic-button").click(function(aC){T()});$(".next-topic-button").click(function(aC){v()});g=$(document).find(".tab")[0];MadCap.WebHelp.HelpSystem.LoadHelpSystem("Data/HelpSystem.xml",function(aD){ah=aD;if(ah.LiveHelpEnabled){W=new MadCap.WebHelp.FeedbackController(ah.LiveHelpServer);W.Init(function(){if(W.PulseActive){$(document.documentElement).addClass("pulse-active");M(parseInt($("#navigation").css("width")))}if(W.FeedbackActive){$(document.documentElement).addClass("feedback-active");l()}})}if(!MadCap.String.IsNullOrEmpty(ah.DefaultSkin.Tabs)){s()}if(document.location.hash.length>1){ai()}else{C(ah.DefaultStartTopic)}Q(ah.DefaultSkin);G=ah.IsResponsive=="undefined"?G:ah.IsResponsive;if(G){var aC=ah.Breakpoints;w=aC.Tablet}else{$("html").addClass("web")}if($(window).innerWidth()<=w&&G){y()}ah.LoadMergedSearchFilters(function(aK){if(aK==null||aK.GetLength()==0){if(window.PIE){$(".search-submit-wrapper").each(function(){PIE.attach(this)})}$("#SearchTab").closest("div").empty();return}$(".search-filter-wrapper").show();if(window.PIE){$(".search-filter, .search-submit-wrapper").each(function(){PIE.attach(this)})}var aE=[];aK.ForEach(function(aM,aN){aE.push(aM);return true});aE.sort();if($(".search-bar").css("display")=="none"){$("#SearchTab").closest(".tab").remove();return}var aH=$("#search ul");for(var aI=0,aJ=aE.length;aI<aJ;aI++){$(".search-filter-content ul").append($("<li></li>").text(aE[aI]));var aL=$("<li/>");aL.addClass("SearchFilterEntry tree-node tree-node-leaf");var aG=$('<div class="SearchFilter" />');var aF=$('<span class="label" />');aF.text(aE[aI]);aG.append(aF);aL.append(aG);aH.append(aL)}$(".SearchFilter").click(aa)});an(az)})}function aa(az){var ax=$(az.target).closest(".SearchFilterEntry");$(".SearchFilterEntry.tree-node-selected").removeClass("tree-node-selected");if(ax.hasClass("SearchFilterEntry")){ax.addClass("tree-node-selected");var ay=ax.find(".SearchFilter").text();$(".search-filter span").text(ay);$searchField=$("#search-field-sidebar");if(!$searchField.attr("data-placeholder")){$searchField.attr("data-placeholder",$searchField.attr("placeholder"))}$searchField.attr("placeholder",$searchField.attr("data-placeholder")+" "+ay);ap(az)}}var al={};function B(az,ax,ay){if(!ay){ay="Don't call this twice without a uniqueId"}if(al[ay]){clearTimeout(al[ay])}al[ay]=setTimeout(az,ax)}var a=$(window).innerWidth();var u=$(window).height();function an(ax){B(function(){var az=$(window).innerWidth();if(G){if(az>w){$("#navigation").removeAttr("role");$("body").removeClass("active");$("html").addClass("web");if(a<=w){y()}if(g){var aA=$(g);if(!aA.hasClass("active")){var ay=aA.find("li");var aB=$(ay[0]);aB.removeClass("tabs-nav-inactive");aB.addClass("tabs-nav-active");aA.addClass("active")}}else{if(!g&&$(document).find(".tab.active").length==0){g=$($(document).find(".tab")[0]);E("Toc",g)}}}else{if($("#navigation").attr("role")!=="undefined"){$("#navigation").attr("role","complementary")}$("html").removeClass("web")}if(a>w&&az<=w||a==az&&a<=w&&u==$(window).height()){var aA=$(".tab.active");g=aA.length&&aA.find("li").text()!="SearchTab"?$(".tab.active"):g;$(".tab .tabs-nav-active").removeClass("tabs-nav-active");$(".tabs-nav li").addClass("tabs-nav-inactive");$(".tab.active").removeClass("active")}if(a>w&&az<=w||a<=w&&az>w){at($(window).innerWidth())}}M(parseInt($("#navigation").css("width")));a=az;u=$(window).height()},50,"FireOnce")}function at(az){var aA=$(document.documentElement).hasClass("left-layout")?"left":$(document.documentElement).hasClass("right-layout")?"right":"left";var aD=$("#navigation");var aC=$("#contentBody");var aF=$("#navigationResizeBar");var aB=!aD.attr("style")||!aC.attr("style");var ay=!aD.attr("data-mc-last-width")||!aC.attr("data-mc-last-width");if(aB&&ay){return}if(az>w){var aE=aD.attr("data-mc-last-width");if(aE){aD.css("width",aE);var ax=aC.attr("data-mc-last-width");if(ax){aC.css(aA,ax)}}}else{var aE=aD.css("width");if(aE){aD.attr("data-mc-last-width",aE);aD.removeAttr("style");var ax=aC.css(aA);if(ax){aC.attr("data-mc-last-width",ax)}aC.removeAttr("style")}}}function q(ax){MadCap.DEBUG.Log.AddLine(window.name+"onhashchange: "+document.location.hash);if(document.location.hash.length>1){ai()}else{C(ah.DefaultStartTopic)}}function l(){$(".star-buttons").click(L);J();$(".buttons").on("click",".login-button",function(ax){I=new MadCap.Feedback.LoginDialog(W,W.PulseEnabled?"pulse":"new");if(!W.PulseEnabled){$(I).bind("closed",function(){J()})}I.Show()});$(".buttons").on("click",".edit-user-profile-button",function(ax){if(W.PulseEnabled){document.location.hash="pulse-#!streams/"+W.PulseUserGuid+"/settings"}else{I=new MadCap.Feedback.LoginDialog(W,"edit");$(I).bind("closed",function(){J()});I.Show()}})}function V(ay){var ax=$("#search-field").val();if(!ay){ax=$("#search-field-sidebar").val()}ax=MadCap.Utilities.Url.StripInvalidCharacters(ax);if(!MadCap.String.IsNullOrEmpty(ax)){if(MadCap.IsSafari()){ax=encodeURIComponent(ax)}document.location.hash="search-"+ax}else{document.location.hash=""}}function ap(ay){var az=null;if($("#search-field").is(":visible")){az=$(ay.target).text();$(this).prev().text(az)}else{az=$(".SearchFilter.active")&&$(".SearchFilter.active").length?$(".SearchFilter.active").text():$.trim($(".search-filter li").first().text())}if($("#searchPane").is(":visible")){var ax=$("#search-field").val();if(MadCap.String.IsNullOrEmpty(ax)){return}h(ax)}}function h(aA,aD,aB,aC,ay){var ax=$(window).innerWidth()<=w&&$(".SearchFilter.active")&&$(".SearchFilter.active").length?$.trim($(".SearchFilter.active").text()):$.trim($(".search-filter span").text());var az=$.trim($(".search-filter li").first().text());if(typeof aD=="undefined"){aD=true}if(typeof aB=="undefined"){aB=ah.DisplayCommunitySearchResults}if(typeof aC=="undefined"){aC=ah.CommunitySearchResultsCount}if(typeof ay=="undefined"){ay=0}if(ax==az){ax=null}$("#resultList").remove();ac("search");if(aD){n(aA,ax,function(aE){if(aB){e(aA,ax,aC,ay,function(aF){H(aA,aE,aF)})}else{H(aA,aE,null)}})}else{if(aB){e(aA,ax,aC,ay,function(aE){H(aA,null,aE)})}}$("body").removeClass("active")}function n(aA,ay,ax){if(f==null){f=new MadCap.WebHelp.SearchPane(ah)}var az=$("#searchPane").addClass("loading");f.Init(function(){f.StartSearch(decodeURIComponent(aA),ay,function(aC){var aB=O(aC);az.removeClass("loading");if(ax!=null){ax(aB)}},null)})}function e(aC,aA,az,ay,ax){if(f==null){f=new MadCap.WebHelp.SearchPane(ah)}var aB=$("#searchPane").addClass("loading");f.Init(function(){f.StartPulseSearch(aC,az,ay,function(aD){aB.removeClass("loading");if(ax!=null){ax(aD)}})})}function O(aG){var aL=[];for(var aK=0,aF=aG.GetLength();aK<aF;aK++){var aH=aG.GetResult(aK);var ax=aH.SearchDB;var aO=null;var aJ=null;var aA=null;if(!ah.IsWebHelpPlus){var aC=aH.Entry;var ay=aC.TopicID;var aD=MadCap.WebHelp.SearchPane.SearchDBs[ax];aO=aD.URLTitles[ay]?aD.URLTitles[ay]:"";aA=aD.URLAbstracts[ay];var aI=aD.HelpSystem.GetPath();var aM=aD.URLSources[ay];var aB=MadCap.String.StartsWith(aM,"/subsystems/",false);var aN=!MadCap.String.IsNullOrEmpty(aI)||aB;if(aN&&!ah.MoveContentToRoot){aI="../"+aI}if(!aB){aI+="Data/"}aJ=new MadCap.Utilities.Url(aI).CombinePath(aM);if(!aN&&!ah.MoveContentToRoot){aJ=aJ.ToRelative(ah.ContentFolder)}}else{aO=aH.Title;aA=aH.AbstractText;var aE=new MadCap.Utilities.Url(aH.Link);var az=new MadCap.Utilities.Url(document.location.pathname);if(!MadCap.String.EndsWith(document.location.pathname,"/")){az=az.ToFolder()}az=az.CombinePath(ah.ContentFolder);aJ=aE.ToRelative(az)}aL[aL.length]={Title:aO,Link:aJ.FullPath,AbstractText:aA}}return aL}function H(a0,aU,aG){var aE=$("#results-heading")[0];var aD=(aU!=null?aU.length:0);var aN=aD+(aG!=null?aG.TotalRecords:0);$(".query",aE).text('"'+decodeURIComponent(a0)+'"');$(".total-results",aE).text(aN);var aQ=document.createElement("ul");aQ.setAttribute("id","resultList");if(aU==null){aQ.setAttribute("class","communitySearch")}if(aG!=null&&aG.Activities.length>0){var aP=document.createElement("li");aP.setAttribute("id","community-results");aQ.appendChild(aP);var aH=document.createElement("h3");aH.setAttribute("class","title");var aT=document.createElement("a");aT.setAttribute("href","#communitysearch-"+a0);aT.appendChild(document.createTextNode("Community Results"));aH.appendChild(aT);var aB=document.createElement("span");aB.appendChild(document.createTextNode(" ("+aG.TotalRecords+")"));aH.appendChild(aB);var aK=document.createElement("ul");aK.setAttribute("id","communityResultList");aP.appendChild(aH);aP.appendChild(aK);var az=new Date();var aA=new Date(az.getUTCFullYear(),az.getUTCMonth(),az.getUTCDate(),az.getUTCHours(),az.getUTCMinutes(),az.getUTCSeconds());for(var aY=0;aY<aG.Activities.length;aY++){var a3=aG.Activities[aY];var aJ=document.createElement("li");aK.appendChild(aJ);var aR=document.createElement("a");aR.setAttribute("class","activityText");aR.setAttribute("href","#pulse-#!streams/"+a3.FeedId+"/activities/"+a3.Id);aR.appendChild(document.createTextNode(a3.Text));var aZ=document.createElement("div");aZ.setAttribute("class","activityInfo");var aF=document.createElement("a");aF.setAttribute("class","activityCreator");aF.setAttribute("href","#pulse-#!streams/"+a3.CreatedBy+"/activities");aF.appendChild(document.createTextNode(a3.CreatedByDisplayName));var aW=document.createElement("span");aW.appendChild(document.createTextNode(" to "));var aM=a3.FeedUrl!=null?"#"+a3.FeedUrl:"#pulse-#!streams/"+a3.FeedId+"/activities";var aO=document.createElement("a");aO.setAttribute("class","activityFeed");aO.setAttribute("href",aM);aO.appendChild(document.createTextNode(a3.FeedName));var a1=new MadCap.Utilities.DateTime(a3.PostedUtc);var aS=new MadCap.Utilities.TimeSpan(a1.Date,aA);var aV=document.createElement("span");aV.setAttribute("class","activityTime");aV.appendChild(document.createTextNode(aS.ToDurationString()));aZ.appendChild(aF);aZ.appendChild(aW);aZ.appendChild(aO);aZ.appendChild(aV);aJ.appendChild(aR);aJ.appendChild(aZ)}}if(aU!=null){for(var aY=0;aY<aU.length;aY++){var aL=aU[aY];var a4=aL.Title;var aI=aL.Link;var ax=aL.AbstractText;var aP=document.createElement("li");aQ.appendChild(aP);var aH=document.createElement("h3");$(aH).addClass("title");aP.appendChild(aH);var a2=document.createElement("a");a2.setAttribute("href","#"+aI+"?Highlight="+a0);a2.appendChild(document.createTextNode(a4));aH.appendChild(a2);if(ax!=null){var aX=document.createElement("div");$(aX).addClass("description");aX.appendChild(document.createTextNode(ax));aP.appendChild(aX)}var ay=document.createElement("div");$(ay).addClass("url");aP.appendChild(ay);var aC=document.createElement("cite");aC.appendChild(document.createTextNode(aI));ay.appendChild(aC)}}$(aQ).appendTo($("#searchPane"));if(ah.LiveHelpEnabled){W.LogSearch(ah.LiveHelpOutputId,null,aD,null,a0)}}function Z(ay){MadCap.DEBUG.Log.AddLine("nav resizeBar : mousedown");if($(ay.target).attr("id")=="show-hide-navigation"){return}if($(this).hasClass("nav-closed")){return}var ax=document.createElement("div");ax.setAttribute("id","mousemove-sheet");document.body.appendChild(ax);$(document).mousemove(j);$(document).mouseup(k);$(document).bind("selectstart",ag);ay.preventDefault()}function ag(ax){return false}function j(az){MadCap.DEBUG.Log.AddLine("nav resizeBar : mousemove : "+az.pageX);var ax=$(document.documentElement).hasClass("left-layout")?"left":$(document.documentElement).hasClass("right-layout")?"right":"left";var ay=az.pageX;if(ax=="right"){ay=window.innerWidth-az.pageX}c(ay)}function k(ay){MadCap.DEBUG.Log.AddLine("nav resizeBar : mouseup");$(document).off("mousemove",j);$(document).off("mouseup",k);$(document).off("selectstart",ag);var ax=$("#mousemove-sheet")[0];window.setTimeout(function(){ax.parentNode.removeChild(ax)},1)}function c(ay){var ax=$(document.documentElement).hasClass("left-layout")?"left":$(document.documentElement).hasClass("right-layout")?"right":"left";if(ax=="left"){if(ay<175||ay>(window.innerWidth*0.85)){return}}else{if(ax=="right"){if(ay<(window.innerWidth*0.15)||ay>(window.innerWidth-175)){return}}}M(ay);$("#navigationResizeBar").css(ax,ay+"px");$("#navigation").css("width",ay+"px");$("#contentBody").css(ax,(ay+5)+"px")}function M(aA){var az=$(".tabs-nav li");$.each(az,function(aC,aD){var aB=$(aD);if(aB.hasClass("tab-collapsed")){aB.removeClass("tab-collapsed")}});if(aA<aq()+4){for(var ay=az.length-1;ay>=0;ay--){var ax=$(az[ay]);ax.addClass("tab-collapsed");if(aA>aq()+18){break}}}}function aq(){var ay=0;var ax=$(".tabs-nav li");ax.each(function(aA,az){var aB=$(az);if(aB.is(":visible")){ay+=parseInt(aB.css("width"))}});return ay}function y(){var ay=$(document).find(".tab");for(var ax=0;ax<ay.length;ax++){var az=$(ay[ax]);az.show();az.removeClass("active")}$("#search-sidebar").removeClass("index").removeClass("glossary");$(".tabs-nav-active").removeClass("tabs-nav-active");$(".tabs-nav li").addClass("tabs-nav-inactive");$(".responsive-link-list").remove()}function z(ax){var ay=$("#navigation");if(!ay.hasClass("nav-closed")){i("hide")}else{i("show")}}function i(aA){var ax=$(document.documentElement).hasClass("left-layout")?"left":$(document.documentElement).hasClass("right-layout")?"right":"left";var aC=$("#navigation");var ay=$("#navigationResizeBar");var aB=$("#contentBody");if(aA=="show"){ay.css(ax,ay.attr("data-mc-last-width"));var az=aB.attr("data-mc-last-width");if(az==aB.css("left")){az=aC.innerWidth()+ay.innerWidth()+1;aB.attr("data-mc-last-width",az+"px")}else{aB.css(ax,az)}aC.removeClass("nav-closed");ay.removeClass("nav-closed");aB.removeClass("nav-closed");if(G){at($(window).innerWidth())}}else{if(aA=="hide"){aB.attr("data-mc-last-width",aB.css(ax));aB.removeAttr("style");ay.attr("data-mc-last-width",ay.css(ax));ay.css(ax,0);aC.attr("data-mc-last-width",aC.css("width"));aC.addClass("nav-closed");ay.addClass("nav-closed");aB.addClass("nav-closed")}}}function ai(){if(document.location.hash.length==0){return}var az=MadCap.Utilities.Url.StripInvalidCharacters(document.location.hash);if(MadCap.String.IsNullOrEmpty(az)){document.location.hash="";return}var aA=az.substring(1);aA=decodeURIComponent(aA);aA=MadCap.Utilities.Url.StripInvalidCharacters(aA);if(MadCap.String.Contains(aA,"cshid=")||MadCap.String.Contains(aA,"searchQuery=")||MadCap.String.Contains(aA,"skinName=")){ao();return}else{if(MadCap.String.StartsWith(aA,"search-")){var ay=aA.substring("search-".length);$("#search-field").val(ay);$("#search-field-sidebar").val(ay);h(ay);return}else{if(MadCap.String.StartsWith(aA,"communitysearch-")){var ay=aA.substring("communitysearch-".length);$("#search-field").val(ay);$("#search-field-sidebar").val(ay);h(ay,false,true,-1,0);return}else{if(MadCap.String.StartsWith(aA,"pulse-")){var ax=aA.substring("pulse-".length);p(ax);return}}}}X(aA)}function X(az){var aB=new MadCap.Utilities.Url(az);if(aB.IsAbsolute){var aA=aB.Query.indexOf("?");var ay=aB.Query.lastIndexOf("?");var ax="";if(aA!=ay){ax=aB.Query.substr(aA,ay)}if(aB.FullPath.indexOf("http://")!=0){az=ah.ContentFolder+aB.ToNoQuery().FullPath+(MadCap.String.IsNullOrEmpty(ax)?"":ax)}else{az=aB.ToNoQuery().FullPath+(MadCap.String.IsNullOrEmpty(ax)?"":ax)}}else{az=ah.ContentFolder+aB.ToNoQuery().FullPath}C(az)}function C(aF){$(document.documentElement).addClass("has-topic");ac("topic");try{frames.topic.location.replace(aF)}catch(az){document.getElementById("topic").src=aF}var ax=new MadCap.Utilities.Url(decodeURIComponent(document.location.href));var aC=null,aE=null,aB=null;if(!MadCap.String.IsNullOrEmpty(ax.Fragment)&&ax.Fragment.length>1){aE=ax.QueryMap.GetItem("TocPath");if(aE!=null){aC="Toc"}else{aB=ax.QueryMap.GetItem("BrowseSequencesPath");if(aB!=null){aC="BrowseSequences"}}if(ax.HashMap.GetItem("cshid")==null){var aA=ax.Query.indexOf("?");var ay=ax.Query.lastIndexOf("?");var aD="";if(aA!=ay){aD=ax.Query.substr(aA,ay)}ax=new MadCap.Utilities.Url(ax.Fragment.substr(1));if(!MadCap.String.IsNullOrEmpty(aD)){ax.Query=aD}}}else{ax=new MadCap.Utilities.Url(ah.DefaultStartTopic).ToRelative(ah.GetContentPath())}ah.SetBrowseSequencePath(aB,ax);if(ah.SyncTOC){MadCap.Utilities.CrossFrame.PostMessageRequest(parent,"sync-toc",[aC,aC=="Toc"?aE:aB,ax.FullPath],null)}}function p(ax){$(document.documentElement).removeClass("has-topic");ac("pulse");var ay=ax.substring(ax.indexOf("#"));MadCap.Utilities.CrossFrame.PostMessageRequest(frames["community-frame-html5"],"pulse-hash-changed",[ay]);W.Init(function(){if(W.PulseActive){frames.pulse.location.replace(W.PulseServer+ay)}})}function ao(){var aD=document.location.hash.substring(1);var aE=new MadCap.Utilities.Dictionary();var aA=aD.split("&");$(aA).each(function(aG,aH){var aF=aA[aG].split("=");aE.Add(aF[0].toLowerCase(),aF[1])});var az=aE.GetItem("searchQuery".toLowerCase());if(az!=null){$("#search-field").val(decodeURIComponent(az));$("#search-field-sidebar").val(decodeURIComponent(az));var ay=MadCap.String.ToBool(aE.GetItem("firstPick".toLowerCase()),false);if(ay){n(az,null,function(aF){if(aF.length>=1){X(aF[0].Link)}})}else{h(az)}}else{var aC=aE.GetItem("cshid");if(aC!=null){ak=aC;ah.LookupCSHID(aC,function(aG){if(aG.Found){C(aG.Topic)}else{C(ah.DefaultStartTopic)}var aF=aE.GetItem("skinName".toLowerCase())||aG.Skin;if(aF!=null){var aH=ah.GetSkin(aF);b(aH)}});return}else{C(ah.DefaultStartTopic)}}var ax=aE.GetItem("skinName".toLowerCase());if(ax!=null){var aB=ah.GetSkin(ax);b(aB)}}function af(){if(document.location.hash.indexOf("#pulse-")!=0){return""}return document.location.hash.substring("#pulse-".length)}function b(aI){Q(aI);if(MadCap.String.IsNullOrEmpty(aI.Tabs)){$("#navigation").remove();$("#navigationResizeBar").remove();$(document.documentElement).removeClass("left-layout").removeClass("right-layout")}else{if(aI.WebHelpOptions!=null&&aI.WebHelpOptions.HideNavigationOnStartup!=null&&(MadCap.String.ToBool(aI.WebHelpOptions.HideNavigationOnStartup,false))){i("hide")}if(aI.NavigationPanePosition!=null&&aI.NavigationPanePosition=="Right"){$(document.documentElement).removeClass("left-layout").addClass("right-layout")}if(aI.NavigationPaneWidth!=null){var aH=MadCap.String.ToInt(aI.NavigationPaneWidth,300);c(aH)}var aE=aI.Tabs.split(",");var aC=["TOC","Index","Glossary","BrowseSequences","Community"];var aA=$(".tabs");for(var aB=0,ay=aC.length;aB<ay;aB++){var az=aC[aB];if($.inArray(az,aE)>=0){continue}if(az=="TOC"){az="Toc"}var aG=$("#"+az+"Tab");if(aG.length==0){continue}var ax=aA.children(".tabs-nav").children("li").index(aG);var aF=aA.children(".tabs-panels").children(":eq("+ax+")");aG.remove();aF.remove()}var aD=aI.DefaultTab;if(aD=="TOC"){aD="Toc"}E(aD,aA);S(aD)}if(aI.Toolbar!=null&&MadCap.String.IsNullOrEmpty(aI.Toolbar.Buttons)){$(".buttons").remove();$("#contentBody").addClass("no-buttons")}if(aI.DisplaySearchBar=="false"){$(".search-bar").hide()}}function ac(ax){$("#topic").css("display",ax=="topic"?"block":"none");$("#pulse").css("display",ax=="pulse"?"block":"none");$("#searchPane").css("display",ax=="search"?"block":"none")}var m=null;function o(aD){var ax=$(this).attr("id");var az=ax.substring(0,ax.length-"Tab".length);m=az;E(az,$(this).closest(".tabs"));if($(window).innerWidth()<=w&&G){var aB=$(document).find(".tab");for(var aA=0;aA<aB.length;aA++){var aC=$(aB[aA]);if(!aC.hasClass("active")){aC.hide()}else{aC.show()}}var ay=$("#search-sidebar");var aE=az.toLowerCase();ay.removeClass("index").removeClass("glossary");if(aE=="index"||aE=="glossary"){ay.addClass(aE)}}S(az)}function E(az,aC){var ay=$(".tabs-nav-active",aC);var aA=$("#"+az+"Tab");var aB=ay.closest(".tab");var ax=aA.closest(".tab");ay.removeClass("tabs-nav-active");$(".tabs-nav li").addClass("tabs-nav-inactive");if(aB!=null){aB.removeClass("active")}aA.removeClass("tabs-nav-inactive");aA.addClass("tabs-nav-active");if(ax!=null){ax.addClass("active")}if(G&&az!="Search"){g=$(".tab.active")}else{g=null}}function s(){var ax=ah.DefaultSkin.DefaultTab;if(ax=="TOC"){S("Toc")}else{S(ax)}}function S(ax){var ay=null;if(ax=="Toc"){ay=av()}else{if(ax=="Index"){ay=U()}else{if(ax=="Glossary"){ay=D()}else{if(ax=="BrowseSequences"){ay=d()}else{if(ax=="Community"){ay=au()}}}}}if(ay||(ay&&G&&$(window).innerWidth()>w)){E(ax,ay)}}function av(){if(R!=null){return}var ax=$("#toc");ax.addClass("loading");R=new MadCap.WebHelp.TocPane("Toc",ah,ax[0]);R.Init(function(){ax.removeClass("loading")});return ax.parent()}function U(){if(ad!=null){return}var ax=$("#index");ax.addClass("loading");ad=new MadCap.WebHelp.IndexPane(ah);ad.Init($("#index .index-wrapper")[0],function(){ax.removeClass("loading")});return ax.parent()}function D(){if(K!=null){return}var ax=$("#glossary");ax.addClass("loading");K=new MadCap.WebHelp.GlossaryPane(ah);K.Init(ax[0],function(){ax.removeClass("loading")});return ax.parent()}function d(){if(ar!=null){return}var ax=$("#browseSequences");ax.addClass("loading");ar=new MadCap.WebHelp.TocPane("BrowseSequences",ah,ax[0]);ar.Init(function(){ax.removeClass("loading")});return ax.parent()}function au(){if(F){return}F=true;var ax=$("#community-frame-html5");W.Init(function(){if(W.PulseActive){ax.attr("src",W.PulseServer+"streams/my")}});return $pane.parent()}function Q(aK){var aL=MadCap.String.ToBool(aK.UseBrowserDefaultSize,false);if(aL){return}var aA=MadCap.String.ToInt(aK.Top,0);var aI=MadCap.String.ToInt(aK.Left,0);var aJ=MadCap.String.ToInt(aK.Bottom,0);var ay=MadCap.String.ToInt(aK.Right,0);var aB=MadCap.String.ToInt(aK.Width,800);var aC=MadCap.String.ToInt(aK.Height,600);var ax=aK.Anchors;if(ax){var aE=(ax.indexOf("Top")>-1)?true:false;var az=(ax.indexOf("Left")>-1)?true:false;var aH=(ax.indexOf("Bottom")>-1)?true:false;var aD=(ax.indexOf("Right")>-1)?true:false;var aF=(ax.indexOf("Width")>-1)?true:false;var aG=(ax.indexOf("Height")>-1)?true:false}if(az&&aD){aB=screen.availWidth-(aI+ay)}else{if(!az&&aD){aI=screen.availWidth-(aB+ay)}else{if(aF){aI=(screen.availWidth/2)-(aB/2)}}}if(aE&&aH){aC=screen.availHeight-(aA+aJ)}else{if(!aE&&aH){aA=screen.availHeight-(aC+aJ)}else{if(aG){aA=(screen.availHeight/2)-(aC/2)}}}if(window==top){window.resizeTo(aB,aC);window.moveTo(aI,aA)}}function am(){$(".star-buttons").addClass("loading");W.GetAverageRating(aw,function(ay,ax){$(".star-buttons").removeClass("loading");ae(ay)})}function ae(aB){var ax=$(".star-buttons");var aE=$(".star-button",ax);var aD=aE.length;var aC=Math.ceil(aB*aD/100);aE.css("opacity",0);for(var az=0;az<aD;az++){var aA=aE[az];var ay=$(aA);window.setTimeout((function(aG,aF){return function(){if(aG<=aC-1){P(aF[0],2)}else{P(aF[0],1)}aF.animate({opacity:1})}})(az,ay),az*50)}}function L(aA){var ax=$(aA.target);if(aA.target.tagName=="IMG"){ax=ax.closest(".star-button")}if(ax.hasClass("star-button")){var az=$(".star-button",this).length;var ay=(ax.index()+1)*100/az;W.SubmitRating(aw,ay,null,function(){am()})}}function r(ax){ab(ax,function(ay){if(ay){document.location.hash=ay}})}function T(){r("previous")}function v(){r("next")}function ab(ay,ax){MadCap.Utilities.CrossFrame.PostMessageRequest(frames.topic,"get-topic-url",null,function(aE){var aB=new MadCap.Utilities.Url(decodeURIComponent(aE[0]));var aA=new MadCap.Utilities.Url(decodeURIComponent(document.location.href));var aC=aA.QueryMap.GetItem("TocPath");var aD=aA.QueryMap.GetItem("BrowseSequencesPath");aA=aA.ToPlainPath();if(!aA.IsFolder){aA=aA.ToFolder()}var az=aA.CombinePath(ah.GetMasterHelpsystem().GetContentPath());aB=aB.ToRelative(az);if(aD!=null){ah.AdvanceTopic("BrowseSequences",ay,aD,aB,ax)}else{ah.AdvanceTopic("Toc",ay,aC,aB,ax)}})}function x(){MadCap.Utilities.CrossFrame.PostMessageRequest(frames.topic,"get-bs-path",null,function(aE){function aB(aF){var aG=$(".current-topic-index-button");if(aF==-1){aG.addClass("disabled");return}aG.removeClass("disabled");$(".sequence-index").text(aF);ay.GetIndexTotalForEntry(aA,ax,function(aH){$(".sequence-total").text(aH)})}var aA=aE[0];var ax=new MadCap.Utilities.Url(decodeURIComponenet(aE[1]));var aD=new MadCap.Utilities.Url(decodeURIComponent(document.location.href));aD=new MadCap.Utilities.Url(aD.PlainPath);var az=MadCap.String.EndsWith(aD.FullPath,"/")?aD:aD.ToFolder();ax=ax.ToRelative(az);if(aA!=null){var aC=ah.GetFullTocPath("browsesequences",ax.FullPath);if(aC){aA=aA?aC+"|"+aA:aC}}if(MadCap.String.IsNullOrEmpty(aA)||MadCap.String.StartsWith(aA,"_____")){aB(-1);return}var ay=ah.GetBrowseSequenceFile();ay.GetEntrySequenceIndex(aA,ax,aB)})}function A(ax){var aA=$(ax);var ay=aA.attr("data-current-state")||"1";var az=ay=="1"?2:1;P(ax,az)}function P(ay,aB){var aC=$(ay);var az=aB==1?2:1;var aA=aC.attr("data-state"+aB+"-class");var ax=aC.attr("data-state"+az+"-class");aC.attr("data-current-state",aB);aC.removeClass(ax).addClass(aA);aC.attr("title",aC.attr("data-state"+aB+"-title"))}function J(){N=W.GetUserGuid();var ax=$(".login-button");if(ax.length==0){ax=$(".edit-user-profile-button")}P(ax[0],N==null?1:2)}function aj(){if(I!=null){I.Hide(true)}}function t(aA){var az=$("body");var ay=$("html").hasClass("left-layout");var ax=az.hasClass("active");if(ay){if(aA=="left"&&ax){az.removeClass("active")}else{if(aA=="right"){az.addClass("active")}}}else{if(aA=="right"&&ax){az.removeClass("active")}else{if(aA=="left"){az.addClass("active")}}}}MadCap.Utilities.CrossFrame.AddMessageHandler(function(aF,aC,aQ,aR,ax){var aL={Handled:false,FireResponse:true};if(aF=="get-href"){aQ[aQ.length]=document.location.href;aL.Handled=true;aL.FireResponse=true}if(aF=="get-return-url"){var aB=new MadCap.Utilities.Url(document.location.href);var aP=null;if(aB.Fragment.length>1){var aO=new MadCap.Utilities.Url(aB.Fragment.substring(1));aP=aB.QueryMap.GetItem("returnUrl")}aQ[aQ.length]=aP;aL.Handled=true;aL.FireResponse=true}else{if(aF=="navigate"){var aK=aC[0];if(aK){document.location.hash=MadCap.Utilities.Url.StripInvalidCharacters(aK)}aL.Handled=true;aL.FireResponse=true}else{if(aF=="navigate-topic"){var aK=aC[0];var aO=new MadCap.Utilities.Url(aK);if(aO.IsAbsolute){var aA=new MadCap.Utilities.Url(document.location.href);aA=new MadCap.Utilities.Url(aA.PlainPath);var aJ=MadCap.String.EndsWith(aA.FullPath,"/")?aA:aA.ToFolder();var aG=aJ.CombinePath(ah.ContentFolder);aO=aO.ToRelative(aG)}if(aO.FullPath){document.location.hash=MadCap.Utilities.Url.StripInvalidCharacters(aO.FullPath)}aL.Handled=true}else{if(aF=="navigate-home"){var aB=new MadCap.Utilities.Url(document.location.href);document.location.href=aB.PlainPath;aL.Handled=true}else{if(aF=="navigate-pulse"){var aK=aC[0];if(document.location.hash.length>1&&aK){var aN=aK.toLowerCase();if(aN==="feedback/account/register"||aK.toLowerCase()==="forgotpassword"){var aB=new MadCap.Utilities.Url(document.location.hash.substring(1));var aP=aB.QueryMap.GetItem("returnUrl");if(aP!=null){aP=escape(aP)}else{aP=document.location.hash.substring(1)}aK+="?returnUrl="+aP}}if(aK){document.location.hash="pulse-"+MadCap.Utilities.Url.StripInvalidCharacters(aK)}aL.Handled=true}else{if(aF=="navigate-previous"){T();aL.Handled=true}else{if(aF=="navigate-next"){v();aL.Handled=true}else{if(aF=="login-user"||aF=="login-pulse"){if(N==null){var aI=aF=="login-pulse"?"pulse":"new";I=new MadCap.Feedback.LoginDialog(W,aI);if(aI=="new"){$(I).bind("closed",function(){J();aQ[aQ.length]=N;MadCap.Utilities.CrossFrame._PostMessageResponse(aR,aF,aQ.length>0?aQ:null,ax)})}I.Show();aL.Handled=true;aL.FireResponse=false}else{aQ[aQ.length]=N;aL.Handled=true;aL.FireResponse=true}}else{if(aF=="get-csh-id"){aQ[aQ.length]=ak;aL.Handled=true;aL.FireResponse=true}else{if(aF=="get-user-guid"){aQ[aQ.length]=N;aL.Handled=true;aL.FireResponse=true}else{if(aF=="get-topic-path-by-stream-id"){var aD=aC[0];W.GetTopicPathByStreamID(aD,function(aT){aQ[aQ.length]=aT;MadCap.Utilities.CrossFrame._PostMessageResponse(aR,aF,aQ.length>0?aQ:null,ax)},null,null);aL.Handled=true;aL.FireResponse=false}else{if(aF=="get-topic-path-by-page-id"){var az=aC[0];W.GetTopicPathByPageID(az,function(aT){aQ[aQ.length]=aT;MadCap.Utilities.CrossFrame._PostMessageResponse(aR,aF,aQ.length>0?aQ:null,ax)},null,null);aL.Handled=true;aL.FireResponse=false}else{if(aF=="hash-changed"){var aH=aC[0];aH=aH.substring(1);history.pushState(null,null,document.location.pathname+document.location.hash+"$"+aH);aL.Handled=true;aL.FireResponse=false}else{if(aF=="forward-ajax-open-success"){var aS=aC[0];var aM=parseInt(aC[1]);var aE=aC[2];ac("pulse");MadCap.Utilities.CrossFrame.PostMessageRequest(frames.pulse,"ajax-open-success",[aS,aM,aE]);aL.Handled=true;aL.FireResponse=false}else{if(aF=="get-pulse-hash"){var ay="";if(document.location.hash.indexOf("#pulse-")==0){ay=document.location.hash.substring("#pulse-".length)}aQ[aQ.length]=ay;aL.Handled=true;aL.FireResponse=true}else{if(aF=="login-complete"||aF=="logout-complete"){MadCap.Utilities.CrossFrame.PostMessageRequest(frames.pulse,"reload");MadCap.Utilities.CrossFrame.PostMessageRequest(frames["community-frame-html5"],"reload");MadCap.Utilities.CrossFrame.PostMessageRequest(frames.topic,"reload-pulse");aj();J();aL.Handled=true;aL.FireResponse=false}else{if(aF=="close-login-dialog"){aj();aL.Handled=true;aL.FireResponse=false}else{if(aF=="set-pulse-login-id"){if(W!=null){W.PulseUserGuid=aC[0]}J();aL.Handled=true;aL.FireResponse=false}else{if(aF=="touch-swipe"){t(aC[0]);aL.Handled=true;aL.FireResponse=false}else{if(aF=="get-parent-window-width"){aQ[aQ.length]=$(window).innerWidth();aL.Handled=true;aL.FireResponse=true}}}}}}}}}}}}}}}}}}}}return aL},null);$(Y);$(window).resize(an);$(window).hashchange(q);var R=null;var ad=null;var f=null;var K=null;var ar=null;var F=null;var ah=null;var W=null;var aw=null;var N=null;var ak=null;var I=null})();/*
* Copyright MadCap Software
* http://www.madcapsoftware.com/
*
* v10.0.0.0
*/
(function(){if(MadCap.Dom.Dataset(document.documentElement,"mcRuntimeFileType")!="Default"){return}MadCap.WebHelp=MadCap.CreateNamespace("WebHelp");var b=window.external&&window.external.attached&&window.external.attached();MadCap.WebHelp.TocPane=function(d,h,g){var e=this;this._Init=false;this._RuntimeFileType=d;this._HtmlNodeID=d=="Toc"?"toc":"browseSequences";this._ContainerEl=g;this._HelpSystem=h;this._TocFile=this._RuntimeFileType=="Toc"?this._HelpSystem.GetTocFile():this._HelpSystem.GetBrowseSequenceFile();this._LoadedNodes=[];var f=null;var c=null;MadCap.Utilities.CrossFrame.AddMessageHandler(this.OnMessage,this);this._Initializing=false;this._InitOnCompleteFuncs=new Array();this.TreeNode_Click=function(p){var q=p.target;var t=$(q).closest("li")[0];if(t==null){return}var s=$(t);var l=s.hasClass("tree-node-leaf");if(!l){s.toggleClass("tree-node-expanded").toggleClass("tree-node-collapsed")}var j=s.find("> div img");var r=j.attr("data-mc-alt2");var o=j.attr("alt");if(r!=""){j.attr("alt",r);j.attr("data-mc-alt2",o)}var u=s.find("> div a");if(u[0]!=null){var i=u.attr("href");if(!MadCap.String.IsNullOrEmpty(i)){e._SelectNode(t)}if(u[0]!=q){var n=u.attr("target");if(!MadCap.String.IsNullOrEmpty(i)){if(n!=null){window.open(i,n)}else{document.location.href=i}}}}var k=e._LoadedNodes[s.attr("data-mc-id")];if(!k.childrenLoaded){var m=$("<ul/>");m.addClass("tree inner");if(b){m.attr("data-mc-style","Navigation Panel Item")}e.LoadTocChildren(k,m,function(){s.append(m)})}if(l){$("body").removeClass("active")}}};var a=MadCap.WebHelp.TocPane;a.prototype.OnMessage=function(i,f,h){var g={Handled:false,FireResponse:true};if(i=="sync-toc"){var c=f[0];var e=f[1];var d=new MadCap.Utilities.Url(f[2]);if(c==null||c==this._RuntimeFileType){this.SyncTOC(e,d);g.Handled=true}}return g};a.prototype.Init=function(c){if(this._Init){if(c!=null){c()}return}if(c!=null){this._InitOnCompleteFuncs.push(c)}if(this._Initializing){return}this._Initializing=true;var d=$(this._ContainerEl);d.click(this.TreeNode_Click);var e=this;d.attr("data-mc-chunk","Data/"+this._RuntimeFileType+".xml");this.CreateToc(this._ContainerEl,function(){e._Init=true;for(var f=0;f<e._InitOnCompleteFuncs.length;f++){e._InitOnCompleteFuncs[f]()}})};a.prototype.CreateToc=function(e,c){var f=true;if(this._RuntimeFileType=="Toc"){f=this._HelpSystem.HasToc}else{f=this._HelpSystem.HasBrowseSequences}if(!f){if(c!=null){c()}return}var d=this;d._HelpSystem.LoadToc(this._RuntimeFileType,function(i,h){var g=$("<ul/>");g.addClass("tree");if(b){g.attr("data-mc-style","Navigation Panel Item")}d.LoadTocChildren(i.tree,g,function(){var j=$(d._ContainerEl);j.append(g);this._Init=true;if(c!=null){c()}})},null)};a.prototype.LoadTocChildren=function(j,g,c){var h=typeof j.n!=="undefined"?j.n.length:0;var d=0;if(h==0){j.childrenLoaded=true}if(j.childrenLoaded){if(c){c()}return}for(var f=0;f<h;f++){var e=j.n[f];var k=$("<li/>");k.addClass("tree-node tree-node-collapsed");g.append(k);this.LoadTocNode(e,k,function(){d++;if(d==h){j.childrenLoaded=true;if(c!=null){c()}}})}};a.prototype.LoadTocNode=function(f,e,c){var d=this;var g=f.toc;this._HelpSystem.LoadTocChunk(g,f.c,function(p){var n=$("<div/>");var i=false;if(typeof f.w!=="undefined"&&f.w==1){n.append("<span class='new-indicator'></span>");i=true}var o=$('<span class="label" />');var q=g.entries[f.i];var l=typeof f.f!="undefined";var j=d._HelpSystem.GetTocEntryHref(f,l?null:d._RuntimeFileType);var k=$("<a/>");if(l){k.attr("target",f.f)}if(j!=null){k.attr("href",j)}else{k.attr("href","javascript:void(0);")}k.text(q.title);if(typeof f.s!="undefined"){e.addClass(f.s)}if(typeof f.n=="undefined"||f.n.length==0){e.removeClass("tree-node-collapsed");e.addClass("tree-node-leaf")}var r="default";var m=d._HelpSystem.Language;for(className in m){if(e.hasClass(className)){r=className;break}}var h=$("<img/>");h.attr("src","Skins/Default/Stylesheets/Images/transparent.gif");h.addClass("toc-icon");if(i){h.attr("alt",m[r]["MarkAsNewIconAlternateText"])}else{if(e.hasClass("tree-node-leaf")){h.attr("alt",m[r]["TopicIconAlternateText"])}else{h.attr("alt",m[r]["ClosedBookIconAlternateText"]);h.attr("data-mc-alt2",m[r]["OpenBookIconAlternateText"])}}if(h.prop("src")!=""){k.prepend(h)}o.append(k);n.append(o);f.el=e;e.append(n);e.attr("data-mc-id",d._LoadedNodes.length);d._LoadedNodes.push(f);if(c!=null){c()}})};a.prototype.SyncTOC=function(e,d){var c=this;var f=$(".tree-node-selected a",this._ContainerEl);if(f.length>0){var g=f[0];if(g.href===document.location.href){return}}this.Init(function(){function j(l){if(typeof l!=="undefined"&&l!=null){var k=[];var m=l;while(typeof m!=="undefined"&&!m.childrenLoaded){k.unshift(m);m=m.parent}MadCap.Utilities.AsyncForeach(k,function(q,p){var o=$(q.el);var n=$("<ul/>");n.addClass("tree inner");c.LoadTocChildren(q,n,function(){o.append(n);p()})},function(){var n=l.el[0];c._UnhideNode(n);c._SelectNode(n)})}}function h(k){c._HelpSystem.FindNode(c._RuntimeFileType,e,k,function(m){if(!m){if(!MadCap.String.IsNullOrEmpty(k.Fragment)||!MadCap.String.IsNullOrEmpty(k.Query)){var l=new MadCap.Utilities.Url(k.PlainPath);c._HelpSystem.FindNode(c._RuntimeFileType,e,l,j)}}else{j(m)}})}var i=d.HashMap.GetItem("cshid");if(i!=null){c._HelpSystem.LookupCSHID(i,function(l){var k=l.Found?new MadCap.Utilities.Url(l.Topic).ToRelative(c._HelpSystem.GetContentPath()):new MadCap.Utilities.Url(c._HelpSystem.DefaultStartTopic);h(k)})}else{h(d)}})};a.prototype._UnhideNode=function(c){var e=MadCap.Dom.GetAncestorNodeByTagName(c,"li",this._ContainerEl);while(e!=null){var d=$(e);d.removeClass("tree-node-collapsed");d.addClass("tree-node-expanded");e=MadCap.Dom.GetAncestorNodeByTagName(e,"li",this._ContainerEl)}};a.prototype.NavigateTopic=function(f){var g=$(".tree-node-selected",this._ContainerEl)[0];if(g==null){g=$(".tree-node",this._ContainerEl)[0]}if(this.NeedsCreateToc(g)){var e=this;this.CreateToc(g,function(){e.NavigateTopic(f)});return}var c=f=="previous"?this._GetPrevious(g):this._GetNext(g);if(c==null){return}this._SelectNode(c);var d=$("> div a",c)[0];if(d!=null){document.location.href=$(d).attr("href")}this._UnhideNode(c)};a.prototype._SelectNode=function(d){var c=$(d);$(".tree-node-selected",this._ContainerEl).removeClass("tree-node-selected");c.addClass("tree-node-selected");c.scrollintoview()};a.prototype._GetNext=function(e){var d=$(e);if(d.find(".tree-node").length>0){return d.find(".tree-node")[0]}if(d.next(".tree-node").length>0){return d.next(".tree-node")[0]}var c=d;while(true){var f=$(c.parent().closest(".tree-node",this._ContainerEl));if(f.length==0){break}if(f.next(".tree-node").length>0){return f.next(".tree-node")[0]}c=f}return null};a.prototype._GetPrevious=function(e){var d=$(e);var c=d.prev(".tree-node");if(c.length==0){if(d.parent().closest(".tree-node",this._ContainerEl).length>0){return d.parent().closest(".tree-node",this._ContainerEl)[0]}else{return null}}if(c.find(".tree-node").length>0){return c.find(".tree-node").last()[0]}return c[0]}})();/*
* Copyright MadCap Software
* http://www.madcapsoftware.com/
*
* v10.0.0.0
*/
(function(){if(MadCap.Dom.Dataset(document.documentElement,"mcRuntimeFileType")!="Default"){return}MadCap.WebHelp=MadCap.CreateNamespace("WebHelp");var a;MadCap.WebHelp.IndexPane=function(e){var c=this;this._Init=false;this._ContainerEl=null;this._HelpSystem=e;this._EntryHeight=-1;this._IndexEntryCount=0;this._IndexEntries=Object.create(null);this._IndexDivs=new Array();this._XmlDoc=null;this._Chunks=null;this._AlphaMap=new MadCap.Utilities.Dictionary();this._LiCached=null;this._SeePrefix=null;this._SeeAlsoPrefix=null;if(this._HelpSystem.IsResponsive){var d=this._HelpSystem.Breakpoints;a=d.Tablet}this.GetPath=function(f,g){return MadCap.String.IsNullOrEmpty(f)?new MadCap.Utilities.Url(g).ToRelative("/Content/").FullPath:"../"+new MadCap.Utilities.Url(f+g).FullPath};this.LoadRootEntry=function(g,f){var i=$(g);var h=i.data("entry");c._HelpSystem.LoadRootIndexEntry(h,function(k){if(k.e&&!k.childrenLoaded){var j=$("<ul/>");j.addClass("tree inner");c.LoadEntries(j,k.e);i.append(j)}k.childrenLoaded=true;i.data("entry",k);if(f){f(k,i)}})};this.LoadEntries=function(i,f){var h=this;if(!$.isArray(f)){var g=[];$.each(f,function(j,k){if(!k.t){k.t=j}g.push(k)});g.sort(function(k,j){var m=(k.s||k.t).toLowerCase();var l=(j.s||j.t).toLowerCase();return m<l?-1:m>l?1:0});f=g}$.each(f,function(r,w){var s=$("<li/>");s.addClass("IndexEntry tree-node tree-node-collapsed");var m=w.t;var p=w.r=="See";var j=w.r=="SeeAlso";var k=$("<div/>");k.addClass("IndexTerm");var u=$("<span/>").addClass("label");k.append(u);var v=true;if(p){m=h._SeePrefix+": "+w.f;k.addClass("see");w.seeAlsoLinks=[w.f]}else{if(j){m=h._SeeAlsoPrefix+": ";w.seeAlsoLinks=[];seeAlsoLinks=w.f.split("; ");if(seeAlsoLinks.length>1){var l=$("<a/>").text(m);u.append(l);for(var o=0;o<seeAlsoLinks.length;o++){var t=seeAlsoLinks[o];var q=$("<a/>").addClass("seeAlsoLink").text(t);u.append(q);w.seeAlsoLinks.push(t);if(o<seeAlsoLinks.length-1){u.append("; ")}}v=false}else{m+=w.f;w.seeAlsoLinks.push(w.f)}k.addClass("see-also")}}if(v){var l=$("<a/>").text(m);u.append(l)}s.append(k);w.isRoot=typeof w.$!=="undefined";if(w.e){var n=$("<ul/>");n.addClass("tree inner");h.LoadEntries(n,w.e);s.append(n)}else{if(w.$===1||!w.isRoot){s.removeClass("tree-node-collapsed");s.addClass("tree-node-leaf")}}i.append(s);w.el=s[0];s.data("entry",w);if(!p&&!j){if(typeof h._IndexEntries[m]=="undefined"){h._IndexEntries[m]=[w]}else{h._IndexEntries[m].push(w)}}})};this.FindEntry=function(g,f){c._HelpSystem.FindIndexEntry(g,function(h,i){if(!i){return}c.LoadRootEntry(h.el,function(){if(f){f(i)}})})};this.SelectEntry=function(j,n,k,l,o){$(".tree-node-selected",c._ContainerEl).removeClass("tree-node-selected");k.addClass("tree-node-selected");if(!n){return}MadCap.TopicHelpers.RemoveLinkListTrees();var m=j.pageY-l.offset().top;var f=j.pageX-l.offset().left;if(n.r&&!o){var i=$(".seeAlsoLink",k).index(j.target);var h=n.seeAlsoLinks[0];if(i>=0){h=n.seeAlsoLinks[i]}h=h.replace(", ",":");this.FindEntry(h,function(p){k=$(p.el);$container=$(window).innerWidth()>a?$(c._ContainerEl).parent():$("#navigation");c._UnhideNode(k[0]);c.SelectEntry(j,p,k,l,true);$container.animate({scrollTop:$container.scrollTop()+k.offset().top-$container.offset().top})});return}else{if(n.linkList&&n.linkList.length>1&&!o){var g=$(window).innerWidth()>a||!this._HelpSystem.IsResponsive;if(g){MadCap.TopicHelpers.CreateLinkListPopup(n.linkList,c._ContainerEl,m,f,this,"#")}else{MadCap.TopicHelpers.CreateLinkListTree(n.linkList,k,this,"#",function(p){c.TreeNode_Click(p);MadCap.TopicHelpers.Item_Click.call(this,[p])})}MadCap.Utilities.PreventDefault(j);j.stopPropagation()}else{if(n.linkList&&n.linkList.length==1){document.location.href="#"+n.linkList[0].Link}}}if(k.hasClass("tree-node-expanded")&&!o){k.removeClass("tree-node-expanded");k.addClass("tree-node-collapsed")}else{if(k.hasClass("tree-node-collapsed")){k.removeClass("tree-node-collapsed");k.addClass("tree-node-expanded")}}};this.TreeNode_Click=function(i){var f=MadCap.Dom.GetAncestorNodeByTagName(i.target,"li");if(f==null){return}if($(i.target).closest(".link-list-popup").length>0){return}var h=$(this);var j=$(f);MadCap.Utilities.PreventDefault(i);var g=j.data("entry");if(!j.hasClass("IndexEntryLink")&&(!g||g.isRoot)){c.LoadRootEntry(f,function(k,l){c.SelectEntry(i,k,l,h)})}else{c.SelectEntry(i,g,j,h)}};this.Search=function(){var f=this.value.toLowerCase();c._Terms.each(function(){var g=$(this);var h=g.parent().parent();var i=g.text().toLowerCase().indexOf(f)!=-1;h.css("display",i?"block":"none");g.removeHighlight("highlightIndex");if(i){g.highlight(f,"highlightIndex")}})}};var b=MadCap.WebHelp.IndexPane;b.prototype.Init=function(f,c){if(this._Init){if(c!=null){c()}return}var e=this;e._ContainerEl=f;var d=$(this._ContainerEl.parentNode);this._SeePrefix=d.attr("data-see-prefix")||"See";this._SeeAlsoPrefix=d.attr("data-see-also-prefix")||"See Also";e._HelpSystem.LoadIndex(function(i,h){var g=$("<ul/>");g.addClass("tree");e.LoadEntries(g,i.terms);var k=$(e._ContainerEl);k.click(e.TreeNode_Click);k.append(g);var j=$("#search-index");j.bind("keyup",e.Search);$("#responsive-search-index").bind("keyup",e.Search);e._Terms=$(".IndexEntry a",this._ContainerEl);e._Init=true;if(c!=null){c()}},null)};b.prototype._UnhideNode=function(d){var c=MadCap.Dom.GetAncestorNodeByTagName(d,"li",this._ContainerEl);while(c!=null){var e=$(c);e.removeClass("tree-node-collapsed");e.addClass("tree-node-expanded");c=MadCap.Dom.GetAncestorNodeByTagName(c,"li",this._ContainerEl)}}})();/*
* Copyright MadCap Software
* http://www.madcapsoftware.com/
*
* v10.0.0.0
*/
(function(){if(MadCap.Dom.Dataset(document.documentElement,"mcRuntimeFileType")!="Default"){return}MadCap.WebHelp=MadCap.CreateNamespace("WebHelp");MadCap.WebHelp.GlossaryPane=function(c){var b=this;this._Init=false;this._ContainerEl=null;this._HelpSystem=c;MadCap.Utilities.CrossFrame.AddMessageHandler(this.OnMessage,this);this.TreeNode_Click=function(j){var d=MadCap.Dom.GetAncestorNodeByTagName(j.target,"li");if(d==null){return}var l=$(d);var i=$("a",l);var h=i.text();var k=l.attr("data-chunk");var f=b._HelpSystem.Glossary.chunks[k];var g=new MadCap.Utilities.Url(f).ToFolder().ToFolder().FullPath;if(MadCap.String.EndsWith(g,"/")){g=g.slice(0,-1)}MadCap.Utilities.PreventDefault(j);require([f],function(n){var o=n[h];$(".tree-node-selected",b._ContainerEl).removeClass("tree-node-selected");l.addClass("tree-node-selected");var e=$(".GlossaryPageTerm",d);if(!MadCap.String.IsNullOrEmpty(o.d)&&!e.hasClass("MCDropDownHead")){e.addClass("MCDropDownHead MCDropDownHotSpot");var s=$("<div/>");s.addClass("GlossaryPageDefinition MCDropDownBody");s.append(o.d);l.append(e);l.append(s);var p=new MadCap.TopicHelpers.DropDownControl(l[0]);p.Init(false);p.Open(true)}if(!MadCap.String.IsNullOrEmpty(o.l)){var m=i.attr("href");if(MadCap.String.IsNullOrEmpty(m)){var q=MadCap.String.IsNullOrEmpty(g)?new MadCap.Utilities.Url(o.l).ToRelative("/Content/").FullPath:"../"+new MadCap.Utilities.Url(g+o.l).FullPath;m=encodeURI(q);i.attr("href",m)}document.location.href="#"+m}else{if(l.hasClass("tree-node-expanded")){l.removeClass("tree-node-expanded");l.addClass("tree-node-collapsed")}else{if(l.hasClass("tree-node-collapsed")){l.removeClass("tree-node-collapsed");l.addClass("tree-node-expanded");if($("li",l.parent()).last()[0]==l[0]){var r=$(b._ContainerEl);r.animate({scrollTop:r[0].scrollHeight},500)}}}}})};this.Search=function(){var d=this.value.toLowerCase();b._Terms.each(function(){var e=$(this);var f=e.parent().parent();var g=e.text().toLowerCase().indexOf(d)!=-1;f.css("display",g?"block":"none");e.removeHighlight("highlightGlossary");if(g){e.highlight(d,"highlightGlossary")}})}};var a=MadCap.WebHelp.GlossaryPane;a.prototype.OnMessage=function(e,b,d){var c={Handled:false,FireResponse:true};return c};a.prototype.Init=function(d,b){if(this._Init){if(b!=null){b()}return}var c=this;c._ContainerEl=d;c._HelpSystem.LoadGlossary(function(f,k){var h=$("<ul/>");h.addClass("tree");for(var g=0;g<f.terms.length;g++){var m=f.terms[g];var l=$("<li/>");l.addClass("GlossaryPageEntry tree-node tree-node-collapsed");l.attr("data-chunk",m.c);var e=$("<div/>");e.addClass("GlossaryPageTerm");e.append('<span class="label"><a>'+m.t+"</a></span>");l.append(e);h.append(l)}var n=$(c._ContainerEl);n.click(c.TreeNode_Click);n.append(h);var j=$("#search-glossary");j.bind("keyup",c.Search);$("#responsive-search-glossary").bind("keyup",c.Search);c._Terms=$(".GlossaryPageTerm a",c._ContainerEl);c._Init=true;if(b!=null){b()}},null)};a.prototype._SelectNode=function(b){$(".tree-node-selected",this._ContainerEl).removeClass("tree-node-selected");$(b).addClass("tree-node-selected")}})();(function(){if(MadCap.Dom.Dataset(document.documentElement,"mcRuntimeFileType")!="Default"){return}var b=(function(){var j={ational:"ate",tional:"tion",enci:"ence",anci:"ance",izer:"ize",bli:"ble",alli:"al",entli:"ent",eli:"e",ousli:"ous",ization:"ize",ation:"ate",ator:"ate",alism:"al",iveness:"ive",fulness:"ful",ousness:"ous",aliti:"al",iviti:"ive",biliti:"ble",logi:"log"},g={icate:"ic",ative:"",alize:"al",iciti:"ic",ical:"ic",ful:"",ness:""},k="[^aeiou]",m="[aeiouy]",d=k+"[^aeiouy]*",i=m+"[aeiou]*",h="^("+d+")?"+i+d,e="^("+d+")?"+i+d+"("+i+")?$",f="^("+d+")?"+i+d+i+d,l="^("+d+")?"+m;return function(s){s=s.toLowerCase();var n,u,t,v,q,p,o,c=s;if(s.length<3){return s.toLowerCase()}t=s.substr(0,1);if(t=="y"){s=t.toUpperCase()+s.substr(1)}v=/^(.+?)(ss|i)es$/;q=/^(.+?)([^s])s$/;if(v.test(s)){s=s.replace(v,"$1$2")}else{if(q.test(s)){s=s.replace(q,"$1$2")}}v=/^(.+?)eed$/;q=/^(.+?)(ed|ing)$/;if(v.test(s)){var r=v.exec(s);v=new RegExp(h);if(v.test(r[1])){v=/.$/;s=s.replace(v,"")}}else{if(q.test(s)){var r=q.exec(s);n=r[1];q=new RegExp(l);if(q.test(n)){s=n;q=/(at|bl|iz)$/;p=new RegExp("([^aeiouylsz])\\1$");o=new RegExp("^"+d+m+"[^aeiouwxy]$");if(q.test(s)){s=s+"e"}else{if(p.test(s)){v=/.$/;s=s.replace(v,"")}else{if(o.test(s)){s=s+"e"}}}}}}v=/^(.+?)y$/;if(v.test(s)){var r=v.exec(s);n=r[1];v=new RegExp(l);if(v.test(n)){s=n+"i"}}v=/^(.+?)(ational|tional|enci|anci|izer|bli|alli|entli|eli|ousli|ization|ation|ator|alism|iveness|fulness|ousness|aliti|iviti|biliti|logi)$/;if(v.test(s)){var r=v.exec(s);n=r[1];u=r[2];v=new RegExp(h);if(v.test(n)){s=n+j[u]}}v=/^(.+?)(icate|ative|alize|iciti|ical|ful|ness)$/;if(v.test(s)){var r=v.exec(s);n=r[1];u=r[2];v=new RegExp(h);if(v.test(n)){s=n+g[u]}}v=/^(.+?)(al|ance|ence|er|ic|able|ible|ant|ement|ment|ent|ou|ism|ate|iti|ous|ive|ize)$/;q=/^(.+?)(s|t)(ion)$/;if(v.test(s)){var r=v.exec(s);n=r[1];v=new RegExp(f);if(v.test(n)){s=n}}else{if(q.test(s)){var r=q.exec(s);n=r[1]+r[2];q=new RegExp(f);if(q.test(n)){s=n}}}v=/^(.+?)e$/;if(v.test(s)){var r=v.exec(s);n=r[1];v=new RegExp(f);q=new RegExp(e);p=new RegExp("^"+d+m+"[^aeiouwxy]$");if(v.test(n)||(q.test(n)&&!(p.test(n)))){s=n}}v=/ll$/;q=new RegExp(f);if(v.test(s)&&q.test(s)){v=/.$/;s=s.replace(v,"")}if(t=="y"){s=t.toLowerCase()+s.substr(1)}return s.toLowerCase()}})();var a=MadCap.CreateNamespace("WebHelp.Search");a.Stemmer=b})();/*
* Copyright MadCap Software
* http://www.madcapsoftware.com/
*
* v10.0.0.0
*/
(function(){if(MadCap.Dom.Dataset(document.documentElement,"mcRuntimeFileType")!="Default"){return}var a=MadCap.CreateNamespace("WebHelp.Search");a.Tokenizer=function(){var j="";var g=-1;var d=new Array();this.Tokenize=function(o){var n=null;j=o;g=-1;for(var m=0;n=l();m++){d[m]=n}return d};function i(m){if(!m){return false}else{if(m=='"'){return false}else{if(m=="+"){return false}else{if(m=="^"){return false}else{if(m=="|"){return false}else{if(m=="&"){return false}else{if(m=="("){return false}else{if(m==")"){return false}else{if(e(m)){return false}else{return true}}}}}}}}}}function e(m){if(!m){return false}else{if(m==" "){return true}else{if(m.charCodeAt(0)==12288){return true}else{return false}}}}function f(){return j.charAt(g+1)}function h(){g++}function k(){var m="";for(;;){var n=f();if(!n){return(m=="")?null:m}if(n=="\\"){h();if(!f()){return null}h();continue}if(n=='"'){h();break}else{h();m+=n}}return m}function l(){var q=f();var n=null;var m="";if(!q){n=null}else{if(e(q)){for(q=f();e(q);q=f()){h();m+=q}n=new a.Token(m,a.Token.WhiteSpace)}else{if(q=="("){h();n=new a.Token(q,a.Token.LeftParen)}else{if(q==")"){h();n=new a.Token(q,a.Token.RightParen)}else{if(q=="^"){h();n=new a.Token(q,a.Token.Subtract)}else{if(q=="+"||q=="&"){h();n=new a.Token(q,a.Token.And)}else{if(q=="|"){h();n=new a.Token(q,a.Token.Or)}else{if(q=="!"){h();n=new a.Token(q,a.Token.Not)}else{if(q=='"'){h();var p=k();if(MadCap.String.Contains(p,a.Tokenizer.Connectors)){p=p.replace(a.Tokenizer.ConnectorRegex," ");p=$.trim(p)}n=new a.Token(p,(p==null)?a.Token.Error:a.Token.Phrase)}else{for(q=f();i(q);q=f()){h();m+=q}if(m=="and"||m=="AND"){n=new a.Token(m,a.Token.And)}else{if(m=="or"||m=="OR"){n=new a.Token(m,a.Token.Or)}else{if(m=="not"||m=="NOT"){n=new a.Token(m,a.Token.Not)}else{var o=a.Token.Word;if(MadCap.WebHelp.SearchPane.SearchDBs[0].SearchType=="NGram"){o=a.Token.Phrase}if(MadCap.String.Contains(m,a.Tokenizer.Connectors)){m=m.replace(a.Tokenizer.ConnectorRegex," ");m=$.trim(m);n=new a.Token(m,a.Token.Phrase)}else{n=new a.Token(m,o)}}}}}}}}}}}}}return n}};a.Tokenizer.Connectors=[".",",","'","/",":",";","\\","-","*","<",">","!","@"];a.Tokenizer.ConnectorRegex=new RegExp("["+a.Tokenizer.Connectors.join("")+"]","g");a.Token=function(d,f){var e=d;var g=f;this.GetTokenText=function(){return e};this.GetType=function(){return g}};var c=a.Token;c.Eof=0;c.Error=1;c.WhiteSpace=2;c.Phrase=3;c.Word=4;c.RightParen=5;c.LeftParen=6;c.Not=7;c.Subtract=8;c.And=9;c.Or=10;c.ImplicitOr=11;a.Parser=function(h){var j=this;var l=h;var e=-1;var i=new a.Tokenizer();var d=i.Tokenize(l);this.GetStemMap=function(n){function r(){x++;if(x==p){for(var I=0;I<d.length;I++){var D=d[I];if(D.GetType()==a.Token.Word){var E=D.GetTokenText();var B=new MadCap.Utilities.Dictionary();z.Add(E,B);for(var H=0;H<MadCap.WebHelp.SearchPane.SearchDBs.length;H++){var C=MadCap.WebHelp.SearchPane.SearchDBs[H];if(C.SearchType=="NGram"){for(var G=0;G<E.length-C.NGramSize+1;G++){var A=E.substring(G,G+C.NGramSize);var F=a.Stemmer(A);C.LookupPhrases(F,B)}}else{var F=a.Stemmer(E);C.LookupPhrases(F,B)}}}else{if(D.GetType()==a.Token.Phrase){var E=D.GetTokenText();var B=new MadCap.Utilities.Dictionary();B.Add(E,true);z.Add(E,B)}}}n(z)}}var x=0;var p=0;var z=new MadCap.Utilities.Dictionary();for(var y=0;y<d.length;y++){var s=d[y];if(s.GetType()==a.Token.Word){var t=s.GetTokenText();for(var w=0;w<MadCap.WebHelp.SearchPane.SearchDBs.length;w++){var q=MadCap.WebHelp.SearchPane.SearchDBs[w];if(q.SearchType=="NGram"){for(var v=0;v<t.length-q.NGramSize+1;v++){p++}}else{p++}}}else{if(s.GetType()==a.Token.Phrase){p++}}}for(var y=0;y<d.length;y++){var s=d[y];if(s.GetType()==a.Token.Word){var t=s.GetTokenText();for(var w=0;w<MadCap.WebHelp.SearchPane.SearchDBs.length;w++){var q=MadCap.WebHelp.SearchPane.SearchDBs[w];if(q.SearchType=="NGram"){for(var v=0;v<t.length-q.NGramSize+1;v++){var o=t.substring(v,v+q.NGramSize);var u=a.Stemmer(o);q.LoadChunk(u,r)}}else{var u=a.Stemmer(t);q.LoadChunk(u,r)}}}else{if(s.GetType()==a.Token.Phrase){r()}}}};this.ParseExpression=function(){var o=k();g();if(f()==a.Token.Eof){return o}else{if(f()==a.Token.And||f()==a.Token.Or||f()==a.Token.Subtract){m();var n=new a.Node(d[e],o,this.ParseExpression());return n}else{if(f()==a.Token.Word||f()==a.Token.Phrase||f()==a.Token.Not||f()==a.Token.LeftParen){var n=new a.Node(new a.Token(o.GetToken().GetTokenText()+" "+d[e+1].GetTokenText(),a.Token.ImplicitOr),o,this.ParseExpression());return n}else{if(f()==a.Token.RightParen){return o}}}}throw gInvalidTokenLabel};function m(){e++}function k(){g();if(f()==a.Token.Word){m();return new a.Node(d[e],null,null)}else{if(f()==a.Token.Phrase){m();return new a.Node(d[e],null,null)}else{if(f()==a.Token.Not){m();return new a.Node(d[e],k(),null)}else{if(f()==a.Token.LeftParen){m();var n=d[e];var o=new a.Node(n,j.ParseExpression(),null);if(f()!=a.Token.RightParen){throw"Missing right paren ')'."}m();return o}}}}throw gInvalidTokenLabel}function f(){if(d[e+1]==null){return a.Token.Eof}else{return d[e+1].GetType()}}function g(){for(;f()==a.Token.WhiteSpace;){m()}}};a.Node=function(f,g,e){var d=f;var i=g;var h=e;this.Evaluate=function(m,l,j){var o=d.GetType();if(o==a.Token.Word){this.EvaluateWord(m,l,j);return}else{if(o==a.Token.Phrase){this.EvaluatePhrase(m,l,j);return}else{if(o==a.Token.And||o==a.Token.ImplicitOr||o==a.Token.Or||o==a.Token.Subtract){var p=d.GetType()==a.Token.ImplicitOr;var n=d.GetType()==a.Token.ImplicitOr||d.GetType()==a.Token.Or;i.Evaluate(p,n,function(q){h.Evaluate(false,false,function(r){if(d.GetType()==a.Token.And){j(q.ToIntersection(r,m,l))}else{if(d.GetType()==a.Token.ImplicitOr){r.PromotePhrases(q,d);q.ToUnion(r,m,l);j(q)}else{if(d.GetType()==a.Token.Or){q.ToUnion(r,m,l);j(q)}else{if(d.GetType()==a.Token.Subtract){j(q.ToDifference(r,m,l))}}}}})});return}else{if(o==a.Token.LeftParen){if(i){i.Evaluate(m,l,j);return}j(new a.QueryResultSet());return}else{if(o==a.Token.Not){function k(w){var q=w;var u=new a.QueryResultSet();for(var v=0;v<MadCap.WebHelp.SearchPane.SearchDBs.length;v++){var r=MadCap.WebHelp.SearchPane.SearchDBs[v];for(var t=0;t<r.URLSources.length;t++){var A=false;var y=null;for(var s=0;s<q.GetLength();s++){y=q.GetResult(s);if(y.Entry.TopicID==t&&y.SearchDB==v){A=true;break}}if(!A){var x=new a.Entry(0,t,-1);var z=new a.QueryResult(v,x,0,null);u.Add(z,m,l,false)}}}j(u)}if(i){i.Evaluate(m,l,k)}else{k(new a.QueryResultSet())}return}}}}}};this.EvaluateWord=function(t,u,k){function q(){s++;if(s==n){w.ForEach(function(D,E){for(var C=0;C<MadCap.WebHelp.SearchPane.SearchDBs.length;C++){var y=MadCap.WebHelp.SearchPane.SearchDBs[C];if(y.SearchType=="NGram"){for(var A=0;A<D.length-y.NGramSize+1;A++){var z=D.substring(A,A+y.NGramSize);y.LookupStem(v,z,C,t,u)}}else{y.LookupStem(v,D,C,t,u)}for(var A=0,B=v.GetLength();A<B;A++){var x=v.GetResult(A);if(x.ParentPhraseName==l){x.Ranking=x.Ranking+1000}else{if(x.ParentPhraseName.toLowerCase()==l.toLowerCase()){x.Ranking=x.Ranking+500}}if(w.GetLength()>0&&m==0){x.Ranking=x.Ranking+50}}m++}return true});k(v)}}var s=0;var n=0;var l=d.GetTokenText();var w=new MadCap.Utilities.Dictionary();var p=a.Stemmer(l);w.Add(l,true);w.Add(p,true);for(var r=0;r<MadCap.WebHelp.SearchPane.SearchDBs.length;r++){var o=MadCap.WebHelp.SearchPane.SearchDBs[r];if(o.SynonymFile!=null){o.SynonymFile.AddSynonymStems(l,p,w)}if(o.DownloadedSynonymFile!=null){o.DownloadedSynonymFile.AddSynonymStems(l,p,w)}}var v=new a.QueryResultSet();var m=0;w.ForEach(function(A,B){for(var z=0;z<MadCap.WebHelp.SearchPane.SearchDBs.length;z++){var x=MadCap.WebHelp.SearchPane.SearchDBs[z];if(x.SearchType=="NGram"){for(var y=0;y<A.length-x.NGramSize+1;y++){n++}}else{n++}}return true});w.ForEach(function(B,C){for(var A=0;A<MadCap.WebHelp.SearchPane.SearchDBs.length;A++){var x=MadCap.WebHelp.SearchPane.SearchDBs[A];if(x.SearchType=="NGram"){for(var z=0;z<B.length-x.NGramSize+1;z++){var y=B.substring(z,z+x.NGramSize);x.LoadChunk(y,q)}}else{x.LoadChunk(B,q)}}return true})};this.EvaluatePhrase=function(v,w,k){function p(){u++;if(u==m){for(var B=0;B<t.length;B++){var A=t[B];var z=new a.QueryResultSet();var D=new MadCap.Utilities.Dictionary();var C=a.Stemmer(A);D.Add(C,true);D.ForEach(function(I,J){for(var H=0;H<MadCap.WebHelp.SearchPane.SearchDBs.length;H++){var E=MadCap.WebHelp.SearchPane.SearchDBs[H];if(E.SearchType=="NGram"){for(var G=0;G<I.length-E.NGramSize+1;G++){var F=I.substring(G,G+E.NGramSize);E.LookupStem(z,F,H,true,w)}}else{E.LookupStem(z,I,H,true,w)}}return true});if(!y){y=z;continue}var j=y.ToPhrases(z,d,true,w);if(j.GetLength()==0){k(j);return}y=j}if(!y){y=new a.QueryResultSet()}k(y)}}var u=0;var m=0;var l=d.GetTokenText();var t=a.SplitPhrase(l);var y=null;for(var s=0;s<t.length;s++){var q=t[s];var x=new MadCap.Utilities.Dictionary();var o=a.Stemmer(q);x.Add(o,true);for(var r=0;r<MadCap.WebHelp.SearchPane.SearchDBs.length;r++){var n=MadCap.WebHelp.SearchPane.SearchDBs[r];if(n.SynonymFile!=null){n.SynonymFile.AddSynonymStems(l,o,x)}if(n.DownloadedSynonymFile!=null){n.DownloadedSynonymFile.AddSynonymStems(l,o,x)}}}for(var s=0;s<t.length;s++){var q=t[s];var x=new MadCap.Utilities.Dictionary();var o=a.Stemmer(q);x.Add(o,true);x.ForEach(function(C,D){for(var B=0;B<MadCap.WebHelp.SearchPane.SearchDBs.length;B++){var z=MadCap.WebHelp.SearchPane.SearchDBs[B];if(z.SearchType=="NGram"){for(var A=0;A<C.length-z.NGramSize+1;A++){m++}}else{m++}}return true})}for(var s=0;s<t.length;s++){var q=t[s];var x=new MadCap.Utilities.Dictionary();var o=a.Stemmer(q);x.Add(o,true);x.ForEach(function(D,E){for(var C=0;C<MadCap.WebHelp.SearchPane.SearchDBs.length;C++){var z=MadCap.WebHelp.SearchPane.SearchDBs[C];if(z.SearchType=="NGram"){for(var B=0;B<D.length-z.NGramSize+1;B++){var A=D.substring(B,B+z.NGramSize);z.LoadChunk(A,p)}}else{z.LoadChunk(D,p)}}return true})}};this.GetToken=function(){return d}};a.Entry=function(f,d,e){this.Rank=f;this.TopicID=d;this.Word=e};a.QueryResult=function(f,d,g,e){this.SearchDB=f;this.Entry=d;this.Ranking=g;this.ParentPhraseName=e};a.QueryResultSet=function(){this.mResults=new Array();this.mWordMap=new MadCap.Utilities.Dictionary();this.mPhraseMap=new MadCap.Utilities.Dictionary();this.mTopicMap=new MadCap.Utilities.Dictionary()};var b=a.QueryResultSet;b.prototype.Add=function(e,j,h,k){this.mResults[this.mResults.length]=e;var d=e.SearchDB;var i=e.Entry;if(j){var g=d+"_"+i.TopicID+"_"+i.Word;this.mWordMap.Add(g,e)}if(h){var g=e.ParentPhraseName+"_"+d+"_"+i.TopicID+"_"+i.Word;this.mPhraseMap.Add(g,true)}if(k){var g=d+"_"+i.TopicID;var f=this.mTopicMap.GetItem(g);if(!f){f=new Array();this.mTopicMap.Add(g,f)}f[f.length]=this.mResults.length-1}};b.prototype.AddAllUnique=function(h,l,n){var m=h.GetLength();for(var j=0;j<m;j++){var q=h.GetResult(j);var o=q.Entry;var f=q.SearchDB;var e=q.ParentPhraseName;var g=o.Rank;var k=o.TopicID;var d=o.Word;var p=e+"_"+f+"_"+k+"_"+d;if(this.mPhraseMap.GetItem(p)){continue}this.Add(q,l,n,false)}};b.prototype.Compact=function(){var e=new Array();for(var d=0;d<this.mResults.length;d++){if(this.mResults[d]){e[e.length]=this.mResults[d]}}this.mResults=e};b.prototype.GetLength=function(){return this.mResults.length};b.prototype.GetResult=function(d){return this.mResults[d]};b.prototype.GetWordMap=function(){return this.mWordMap};b.prototype.RemoveAt=function(d){this.mResults[d]=null};b.prototype.RemoveTopicId=function(n){var h=n.Entry.TopicID;var d=n.SearchDB;var j=d+"_"+h;var e=this.mTopicMap.GetItem(j);if(e){for(var f=0;f<e.length;f++){var m=this.mResults[e[f]];var k=m.Entry;var g=d+"_"+h+"_"+k.Word;var l=m.ParentPhraseName+"_"+d+"_"+h+"_"+k.Word;this.mWordMap.Remove(g);this.mPhraseMap.Remove(l);this.mTopicMap.Remove(j);this.RemoveAt(e[f])}}};b.prototype.ShallowClone=function(g,f,h){var e=new b();for(var d=0;d<this.mResults.length;d++){e.Add(this.mResults[d],g,f,h)}return e};b.prototype.SortByRank=function(){this.mResults.sort(this.CompareRank)};b.prototype.ToDifference=function(e,g,f){var h=this.ShallowClone(g,f,true);for(var d=0;d<e.GetLength();d++){h.RemoveTopicId(e.GetResult(d))}h.Compact();return h};b.prototype.ToIntersection=function(d,h,k){var f=new b();var j=new MadCap.Utilities.Dictionary();var g=new MadCap.Utilities.Dictionary();for(var e=0;e<this.mResults.length;e++){var m=this.mResults[e];var l=m.SearchDB+"_"+m.Entry.TopicID;j.Add(l,true)}for(var e=0;e<d.GetLength();e++){var m=d.GetResult(e);var l=m.SearchDB+"_"+m.Entry.TopicID;g.Add(l,true)}for(var e=0;e<this.mResults.length;e++){var m=this.mResults[e];var l=m.SearchDB+"_"+m.Entry.TopicID;if(g.GetItem(l)){f.Add(m,h,k,false)}}for(var e=0;e<d.GetLength();e++){var l=d.GetResult(e).SearchDB+"_"+d.GetResult(e).Entry.TopicID;if(j.GetItem(l)){f.Add(d.GetResult(e),h,k,false)}}return f};b.prototype.ToMerged=function(){var e=new b();var k=new MadCap.Utilities.Dictionary();for(var g=0,j=this.mResults.length;g<j;g++){var d=this.mResults[g];var f=d.SearchDB+"_"+this.mResults[g].Entry.TopicID;var h=k.GetItem(f);if(h){h.Ranking=h.Ranking+d.Ranking;continue}k.Add(f,d);e.Add(d,false,false,false)}return e};b.prototype.ToPhrases=function(e,d,i,g){if(!e){var f=new b();return f}var h=this.FindAdjacentEntries(e,d,i,g);return h};b.prototype.ToUnion=function(d,f,e){this.AddAllUnique(d,f,e)};b.prototype.CompareRank=function(e,d){var h=e.Ranking;var g=d.Ranking;var f=g-h;return f};b.prototype.FindAdjacentEntries=function(n,k,e,h){var p=new b();var d=a.SplitPhrase(k.GetTokenText());var l=new MadCap.Utilities.Dictionary();for(var q=0;q<d.length;q++){l.Add(d[q],true)}var v=n.GetWordMap();for(var r=0;r<this.mResults.length;r++){var m=this.mResults[r];var f=m.Entry;var g=m.SearchDB;var s=f.Rank;var o=f.TopicID;var t=f.Word;var w=g+"_"+o+"_"+(parseInt(t)+1);var u=v.GetItem(w);if(u){if(l.GetItem(u.ParentPhraseName)&&l.GetItem(m.ParentPhraseName)){u.Ranking=m.Ranking+10000}else{u.Ranking=m.Ranking+1000}p.Add(u,e,h,false)}}return p};b.prototype.PromotePhrases=function(m,h){var f=a.SplitPhrase(h.GetTokenText());var e=new MadCap.Utilities.Dictionary();for(var k=0;k<f.length;k++){e.Add(f[k],true)}var q=m.GetWordMap();for(var n=0;n<this.mResults.length;n++){var t=this.mResults[n];var r=t.Entry;var g=t.SearchDB;var l=r.Rank;var p=r.TopicID;var d=r.Word;var s=g+"_"+p+"_"+(parseInt(d)-1);var o=q.GetItem(s);if(o){if(e.GetItem(o.ParentPhraseName)&&e.GetItem(t.ParentPhraseName)){o.Ranking=t.Ranking+10000}else{o.Ranking=t.Ranking+1000}}}};a.SplitPhrase=function(g){var f=null;var d=MadCap.WebHelp.SearchPane.SearchDBs[0];if(d.SearchType=="NGram"){f=new Array(Math.max(0,g.length-(d.NGramSize+1)));for(var e=0;e<g.length-d.NGramSize+1;e++){f[e]=g.substring(e,e+d.NGramSize)}}else{f=g.split(" ")}return f}})();/*
* Copyright MadCap Software
* http://www.madcapsoftware.com/
*
* v10.0.0.0
*/
(function(){if(MadCap.Dom.Dataset(document.documentElement,"mcRuntimeFileType")!="Default"){return}MadCap.WebHelp=MadCap.CreateNamespace("WebHelp");MadCap.WebHelp.SearchPane=function(f){this._Init=false;this._HelpSystem=f;this._FeedbackController=null;this._Parser=null;this._Filters=null;this._FullSet=null;this._MergedSet=null;this._FilteredSet=null;this._Highlight="";this._DownloadedSynonymXmlDocRootNode=null};var c=MadCap.WebHelp.SearchPane;c.SearchDBs=new Array();c.prototype.Init=function(f){if(this._Init){if(f){f()}return}var i=this;if(this._HelpSystem.LiveHelpEnabled){this._FeedbackController=new MadCap.WebHelp.FeedbackController(this._HelpSystem.LiveHelpServer);this._FeedbackController.Init(function(){if(i._FeedbackController.FeedbackActive){i._FeedbackController.GetSynonymsFile(i._HelpSystem.LiveHelpOutputId,null,function(l,j){var k=MadCap.Utilities.Xhr.LoadXmlString(l);if(k!=null){i._DownloadedSynonymXmlDocRootNode=k.documentElement}h()},null)}else{h()}})}else{h()}function h(){if(!i._HelpSystem.IsWebHelpPlus){i._HelpSystem.GetSearchDBs(g)}else{g(null)}}function g(j){c.SearchDBs=j;i._Filters=new b.Filters(i._HelpSystem);i._Filters.Load(function(){i._Init=true;if(f){f()}})}};c.prototype.ApplySearchFilter=function(g,f){if(!this._HelpSystem.IsWebHelpPlus){this._FilteredSet=this._Filters.ApplyFilter(this._MergedSet,g);if(this._FilteredSet!=null){this._FilteredSet.SortByRank()}if(f!=null){f(this._FilteredSet)}}};c.prototype.StartSearch=function(h,g,f){if(MadCap.String.IsNullOrEmpty(MadCap.String.Trim(h))){return}if(!this._HelpSystem.IsWebHelpPlus){this.DoSearch(h,g,f)}else{this.DoSearchWebHelpPlus(h,g,f)}};c.prototype.StartPulseSearch=function(i,h,g,f){if(MadCap.String.IsNullOrEmpty(MadCap.String.Trim(i))){return}if(this._FeedbackController&&this._FeedbackController.PulseActive){this._FeedbackController.GetPulseSearchResults(this._HelpSystem.LiveHelpOutputId,i,h,g,f)}else{if(f!=null){f()}}};c.prototype.DoSearch=function(k,i,f){this._Parser=new b.Parser(k);var g=null;try{g=this._Parser.ParseExpression()}catch(j){alert("Ensure that the search string is properly formatted.");f()}if(!g){return}if(this._DownloadedSynonymXmlDocRootNode!=null&&c.SearchDBs[0].DownloadedSynonymFile==null){c.SearchDBs[0].DownloadedSynonymFile=new b.SynonymFile(this._DownloadedSynonymXmlDocRootNode)}var h=this;g.Evaluate(false,false,function(l){h._FullSet=l;if(h._FullSet){h._MergedSet=h._FullSet.ToMerged();h.ApplySearchFilter(i,function(m){if(f!=null){f(m)}})}})};c.prototype.DoSearchWebHelpPlus=function(m,k,h){function g(y,t){var w=new b.SearchResultSet();var p=y.getElementsByTagName("Result");var s=p.length;for(var q=0;q<s;q++){var x=p[q];var o=MadCap.Dom.GetAttributeInt(x,"Rank",-1);var v=x.getAttribute("Title");var u=x.getAttribute("Link");var n=x.getAttribute("AbstractText");if(MadCap.String.IsNullOrEmpty(v)){v=x.getAttribute("Filename")}var r=new b.SearchResult(o,v,u,unescape(n));w.Add(r)}h(w)}MadCap.Utilities.Xhr.CallWebService("Service/Service.asmx/GetSearchResults?SearchString="+encodeURIComponent(m)+"&FilterName="+encodeURIComponent(k),true,g,null);var l=m.split(" ");var f=true;this._Highlight="?Highlight=";for(var j=0;j<l.length;j++){if(!f){this._Highlight+="||"}else{f=false}this._Highlight+=l[j]}};var b=MadCap.CreateNamespace("WebHelp.Search");MadCap.WebHelp.Search.SearchDB=function(f){this.URLSources=new Array();this.URLTitles=new Array();this.URLAbstracts=new Array();this.SearchDB=new MadCap.Utilities.Dictionary();this.HelpSystem=f;this.SearchType=null;this.NGramSize=0;this.SynonymFile=null;this.DownloadedSynonymFile=null;this.LoadChunkCompleteFuncs=new MadCap.Utilities.Dictionary()};var a=b.SearchDB;a.prototype.Load=function(g,f){MadCap.Utilities.Xhr.Load(this.HelpSystem.GetPath()+"Data/Synonyms.xml",true,function(h){if(h!=null){this.SynonymFile=new b.SynonymFile(h.documentElement)}this._LoadSearchDB(this.HelpSystem.GetPath()+g,f)},null,this)};a.prototype.LookupPhrases=function(h,g){var f=this.SearchDB.GetItem(h);if(f){f.ForEach(function(i,j){g.Add(i,true);return true})}};a.prototype.LookupStem=function(h,k,j,i,g){var f=this.SearchDB.GetItem(k);if(f){f.ForEach(function(o,r){var m=r;for(var n=0,q=m.length;n<q;n++){var p=m[n];var l=new b.QueryResult(j,p,p.Rank,o);h.Add(l,i,g,false)}return true})}};a.prototype._LoadSearchDB=function(g,f){MadCap.Utilities.Xhr.Load(g,true,function(p){var H=MadCap.Dom.GetChildNodeByTagName(p.documentElement,"urls",0).getElementsByTagName("Url");var E=p.getElementsByTagName("stem");var B=p.documentElement;this.SearchType=B.getAttribute("SearchType");this.NGramSize=parseInt(MadCap.Dom.GetAttribute(B,"NGramSize",0));for(var F=0;F<H.length;F++){var m=H[F];this.URLSources[F]=MadCap.Dom.GetAttribute(m,"Source");this.URLTitles[F]=MadCap.Dom.GetAttribute(m,"Title");this.URLAbstracts[F]=MadCap.Dom.GetAttribute(m,"Abstract")}for(var F=0;F<E.length;F++){var o=E[F];var G=o.getAttribute("n");var u=o.getAttribute("chunk");if(u){this.SearchDB.Add(G,u)}else{var I=o.getElementsByTagName("phr");var h=new MadCap.Utilities.Dictionary();this.SearchDB.Add(G,h);for(var D=0;D<I.length;D++){var y=I[D];var A=y.getAttribute("n");var x=y.getElementsByTagName("ent");var q=new Array(x.length);h.Add(A,q);for(var C=0;C<x.length;C++){var n=x[C];var z=parseInt(n.getAttribute("r"));var v=parseInt(n.getAttribute("t"));var s=parseInt(n.getAttribute("w"));var l=new b.Entry(z,v,s);q[C]=l}}}}f()},null,this)};a.prototype.LoadChunk=function(i,f){var h=this.SearchDB.GetItem(i);if(typeof h=="string"){var g=this.LoadChunkCompleteFuncs.GetItem(h);if(g!=null){g.push(f)}else{g=[f];this.LoadChunkCompleteFuncs.Add(h,g);MadCap.Utilities.Xhr.Load(this.HelpSystem.GetPath()+"Data/"+h,true,function(p){var C=p.getElementsByTagName("stem");for(var D=0;D<C.length;D++){var n=C[D];var E=n.getAttribute("n");var F=n.getElementsByTagName("phr");var l=new MadCap.Utilities.Dictionary();this.SearchDB.Add(E,l);for(var B=0;B<F.length;B++){var x=F[B];var z=x.getAttribute("n");var v=x.getElementsByTagName("ent");var q=new Array(v.length);l.Add(z,q);for(var A=0;A<v.length;A++){var o=v[A];var y=parseInt(o.getAttribute("r"));var u=parseInt(o.getAttribute("t"));var s=parseInt(o.getAttribute("w"));var m=new b.Entry(y,u,s);q[A]=m}}}for(var D=0;D<g.length;D++){g[D]()}this.LoadChunkCompleteFuncs.Remove(h)},null,this)}}else{f()}};b.SearchResult=function(i,h,g,f){this.Rank=i;this.Title=h;this.Link=g;this.AbstractText=f};b.SearchResultSet=function(){this._Results=new Array()};var e=b.SearchResultSet;e.prototype.Add=function(f){this._Results[this._Results.length]=f};e.prototype.GetResult=function(f){return this._Results[f]};e.prototype.GetLength=function(){return this._Results.length};b.Filters=function(g){var f=g;this.Load=function(h){f.LoadMergedSearchFilters(function(i){f.LoadAllConcepts(function(){h()})},null,null)};this.ApplyFilter=function(t,r){if(!t){return null}var l=new b.QueryResultSet();if(r==null){for(var s=0,n=t.GetLength();s<n;s++){l.Add(t.GetResult(s),false,false,false)}}else{for(var s=0,n=t.GetLength();s<n;s++){var v=t.GetResult(s);var o=v.SearchDB;var p=c.SearchDBs[o];var k=parseInt(v.Entry.TopicID);var j=p.URLSources[k];var q=p.HelpSystem.GetPath()+j.substring("../".length,j.length);var h=p.HelpSystem.GetSearchFilters();if(h==null){continue}var m=h.GetItem(r);if(m==null){continue}var u=p.HelpSystem.GetConcepts();m.ForEach(function(x,z){var i=u.GetItem(x);if(i!=null){for(var w=0,A=i.length;w<A;w++){var y=new MadCap.Utilities.Url(i[w].Link);if(y.PlainPath==q){l.Add(v,false,false,false);return false}}}return true})}}return l}};b.SynonymFile=function(f){this.WordToStem=new MadCap.Utilities.Dictionary();this.Directionals=new MadCap.Utilities.Dictionary();this.DirectionalStems=new MadCap.Utilities.Dictionary();this.DirectionalStemSources=new MadCap.Utilities.Dictionary();this.Groups=new MadCap.Utilities.Dictionary();this.GroupStems=new MadCap.Utilities.Dictionary();this.GroupStemSources=new MadCap.Utilities.Dictionary();this.LoadSynonymFile(f)};var d=b.SynonymFile;d.prototype.LoadSynonymFile=function(F){var E=MadCap.Dom.GetChildNodeByTagName(F,"Groups",0);var m=MadCap.Dom.GetChildNodeByTagName(F,"Directional",0);if(m!=null){var p=m.childNodes.length;for(var B=0;B<p;B++){var o=m.childNodes[B];if(o.nodeName=="DirectionalSynonym"){var z=MadCap.Dom.GetAttribute(o,"From");var n=MadCap.Dom.GetAttribute(o,"To");var s=MadCap.Dom.GetAttributeBool(o,"Stem",false);var h=MadCap.Dom.GetAttribute(o,"FromStem");var q=MadCap.Dom.GetAttribute(o,"ToStem");if(s){if(h==null){h=b.Stemmer(z)}}if(q==null){q=b.Stemmer(n)}if(z!=null&&n!=null){if(s){this.DirectionalStemSources.Add(z,q);this.DirectionalStems.Add(h,q);this.WordToStem.Add(z,h);this.WordToStem.Add(n,q)}else{this.Directionals.Add(z,q);this.WordToStem.Add(n,q)}}}}}if(E!=null){var p=E.childNodes.length;for(var B=0;B<p;B++){var o=E.childNodes[B];if(o.nodeName=="SynonymGroup"){var w=new Array();var x=new Array();var s=MadCap.Dom.GetAttributeBool(o,"Stem",false);var u=o.childNodes.length;for(var A=0;A<u;A++){var D=o.childNodes[A];if(D.nodeType!=1){continue}w.push(D.firstChild.nodeValue)}for(var A=0;A<u;A++){var D=o.childNodes[A];if(D.nodeType!=1){continue}var G=MadCap.Dom.GetAttribute(D,"Stem");if(G==null){G=b.Stemmer(D.firstChild.nodeValue)}this.WordToStem.Add(D.firstChild.nodeValue,G);x.push(G)}var v=w.length;for(var A=0;A<v;A++){var C=w[A];var g=x[A];for(var y=0;y<v;y++){var f=w[y];if(s){var t=this.GroupStemSources.GetItem(C);if(t==null){t=new MadCap.Utilities.Dictionary();this.GroupStemSources.Add(C,t)}t.Add(f,g)}else{var t=this.GroupStemSources.GetItem(C);if(t==null){t=new MadCap.Utilities.Dictionary();this.Groups.Add(C,t)}t.Add(f,g)}}}var r=x.length;for(var A=0;A<r;A++){var g=x[A];for(var y=0;y<r;y++){var l=x[y];var t=this.GroupStems.GetItem(g);if(t==null){t=new MadCap.Utilities.Dictionary();this.GroupStems.Add(g,t)}t.Add(l,g)}}}}}};d.prototype.AddSynonymStems=function(f,j,h){var g=this.Directionals.GetItem(f);if(g!=null){h.AddUnique(g)}g=this.DirectionalStems.GetItem(j);if(g!=null){h.AddUnique(g)}var i=this.Groups.GetItem(f);if(i!=null){i.ForEach(function(k,l){h.AddUnique(k);return true})}i=this.GroupStems.GetItem(j);if(i!=null){i.ForEach(function(k,l){h.AddUnique(k);return true})}}})();/*
* Copyright MadCap Software
* http://www.madcapsoftware.com/
*
* v10.0.0.0
*/
(function(){if(MadCap.Dom.Dataset(document.documentElement,"mcRuntimeFileType")!="Topic"){return}MadCap.CreateNamespace("TopicHelpers");var C=MadCap.TopicHelpers;var E;C.Expand=function(H){var I=new C.ExpandingControl(H.parentNode);I.Toggle()};C.DropDown=function(H){var I=new C.DropDownControl(H.parentNode.parentNode);I.Toggle()};C.Toggle=function(H){var I=new C.TogglerControl(H);I.Toggle()};C.ThumbPopup_Click=function(H){var I=C.ShowThumbnailPopup(H,this,"click");if(H.preventDefault){H.preventDefault()}};C.ThumbPopup_Hover=function(H){var I=C.ShowThumbnailPopup(H,this,"mouseleave")};C.ShowThumbnailPopup=function(ai,aj,ae){var ad=10;var Y=1;var U=10;var L=$(aj).children("img")[0];var X=parseInt(MadCap.Dom.Dataset(L,"mcWidth"));var R=parseInt(MadCap.Dom.Dataset(L,"mcHeight"));var H=R/X;var ag=document.documentElement.clientWidth-((ad+Y+U)*2);var ac=document.documentElement.clientHeight-((ad+Y+U)*2);if(R>ac){R=ac;X=R/H}if(X>ag){X=ag;R=X*H}var ah=$(L).offset().top;var al=$(L).offset().left;var ao=MadCap.Dom.GetAttribute(aj,"href");var ab=MadCap.Dom.GetAttribute(aj,"data-mc-popup-alt");var W=R+((Y+U)*2);var T=X+((Y+U)*2);var S=(ah+(L.offsetHeight/2))-(W/2);var O=(al+(L.offsetWidth/2))-(T/2);var N=MadCap.Dom.GetScrollPosition();var Z=N.Y;var J=Z+document.documentElement.clientHeight;var ak=N.X;var I=ak+document.documentElement.clientWidth;var P=Z+ad;var aa=ak+ad;var Q=J-ad;var K=I-ad;if(S<P){S=P}if(O<aa){O=aa}if(S+W>Q){S=Q-W}if(O+T>K){O=K-T}var M=$("<div></div>");M.addClass("MCPopupContainer");var af=document.createElement("img");$(af).addClass("MCPopupFullImage");af.setAttribute("src",ao);af.setAttribute("alt",ab);af.setAttribute("tabindex","0");M.bind(ae,function(){MadCap.DEBUG.Log.AddLine(ae);M.animate({top:an,left:V},200,function(){M.remove()});$(af).animate({width:L.offsetWidth,height:L.offsetHeight},200);$(am).animate({opacity:0},200,function(){C.RemoveBackgroundTint()})});M.bind("keydown",function(ap){var ap=ap||window.event;if(ap.keyCode!=27&&ap.keyCode!=13){return}M.remove();C.RemoveBackgroundTint()});M.append(af);document.body.appendChild(M[0]);var an=ah-(Y+U);var V=al-(Y+U);M.css({top:an,left:V}).animate({top:S,left:O},200);$(af).css({width:L.offsetWidth,height:L.offsetHeight}).animate({width:X,height:R},200);var am=C.AddBackgroundTint();$(am).animate({opacity:0.5},200);af.focus()};C.HelpControl_Click=function(I){var H=this;C.GetHelpControlLinks(this,function(P){var J=new MadCap.Utilities.Url(document.location.href);for(var K=P.length-1;K>=0;K--){var N=P[K];var L=new MadCap.Utilities.Url(N.Link);if(L.FullPath==J.FullPath){P.Remove(K)}L=L.ToRelative(J);N.Link=L.FullPath}if(!$(H).hasClass("MCHelpControl-Related")){P.sort(function(R,Q){return R.Title.localeCompare(Q.Title)})}var M=new MadCap.Utilities.Dictionary();for(var K=P.length-1;K>=0;K--){var N=P[K];var L=N.Link;if(M.GetItem(L)){P.Remove(K);continue}M.Add(N.Link,true)}var O=C.CreateLinkListPopup(P,document.body,I.pageY,I.pageX,H)},null);I.preventDefault();I.stopPropagation()};C.GetHelpControlLinks=function(N,R){var Q=new Array();var J=$(N);if(!v.InPreviewMode){if(j()){var M=J.attr("data-mc-keywords");if(M!=null){if(M==""){R(Q)}var P=M.split(";");MadCap.Utilities.AsyncForeach(P,function(S,T){v.FindIndexEntry(S,function(U,V){if(V!=null&&V.linkList){Q=Q.concat(V.linkList)}T()})},function(){R(v.SortLinkList(Q))});return}else{var L=J.attr("data-mc-concepts");if(L!=null){v.GetConceptsLinks(L,R);return}}}}var I=J.attr("data-mc-topics");if(I!=null){topicPairs=I.split("||");if(topicPairs==""){R(Q)}for(var O=0,K=topicPairs.length;O<K;O++){var H=topicPairs[O].split("|");Q[Q.length]={Title:H[0],Link:H[1]}}}R(Q)};C.Hyperlink_Onclick=function(L){var K=$(this);if(K.hasClass("MCTopicPopup")||K.hasClass("MCPopupThumbnailLink")||K.hasClass("MCHelpControl")||K.hasClass("reply-comment-button")){return}var H=MadCap.Dom.GetAttribute(this,"href");if(H==null||MadCap.String.StartsWith(H,"http:")||MadCap.String.StartsWith(H,"https:")){return}var J=MadCap.Dom.GetAttribute(this,"target");if(J!=null){return}if(j()){var I=new MadCap.Utilities.Url(document.location.href);if(MadCap.String.StartsWith(H,"#")){I=new MadCap.Utilities.Url(I.PlainPath+H)}else{if(MadCap.String.Contains(H,"javascript")){return}else{I=I.ToFolder().CombinePath(H)}}MadCap.Utilities.CrossFrame.PostMessageRequest(parent,"navigate-topic",[I.FullPath],null);L.preventDefault()}};C.ScrollToBookmark=function(J){var H=$("#"+J);if(H.length==0){H=$("[name = '"+J+"']")}if(H.length>0){if(u(H[0])){var I=H.offset().top;$("html, body").animate({scrollTop:I})}}};$(l);$(window).resize(k);$(window).hashchange(G);function k(H){f()}function f(){var H=$(".feedback-comments-wrapper");if(v.IsResponsive){MadCap.Utilities.CrossFrame.PostMessageRequest(parent,"get-parent-window-width",null,function(J){var I=parseInt(J[0]);if(I<=E){if(!H.hasClass("responsive")){H.addClass("responsive")}}else{if(H.hasClass("responsive")){H.removeClass("responsive")}}})}else{if(H.hasClass("responsive")){H.removeClass("responsive")}}}function l(P){$("input, textarea").placeholder();if(MadCap.Slideshow){MadCap.Slideshow.Init()}if(document.location.hash.length>0){var J=new MadCap.Utilities.Url(document.location.hash.substring(1));A(J.ToNoQuery().FullPath)}if(j()||b()){$(".MCWebHelpFramesetLink").hide()}$(document).on("click","a, area",MadCap.TopicHelpers.Hyperlink_Onclick);$(".MCPopupThumbnailPopup").click(MadCap.TopicHelpers.ThumbPopup_Click);$(".MCPopupThumbnailHover").mouseover(MadCap.TopicHelpers.ThumbPopup_Hover);var L=$("a.MCHelpControl").click(MadCap.TopicHelpers.HelpControl_Click);$(".print-button").click(function(R){window.print()});$(".expand-all-button").click(function(S){var R=$(this);if(R.hasClass("expand-all-button")){C.TextEffectControl.ExpandAll("open")}else{if(R.hasClass("collapse-all-button")){C.TextEffectControl.ExpandAll("close")}}z(this)});$(".remove-highlight-button").click(function(R){r()});$(".previous-topic-button").click(function(R){MadCap.Utilities.CrossFrame.PostMessageRequest(parent,"navigate-previous")});$(".next-topic-button").click(function(R){MadCap.Utilities.CrossFrame.PostMessageRequest(parent,"navigate-next")});if(MadCap.String.Contains(navigator.userAgent,"iphone",false)){window.scrollTo(0,1)}if(MadCap.IsIOS()){var I=$("<div id='ios-wrapper'></div>").appendTo(document.body);var O=I[0];for(var N=document.body.childNodes.length-2;N>=0;N--){var M=document.body.childNodes[N];O.insertBefore(M,O.firstChild)}}w();var Q=parent;if(b()){Q=parent.parent}var K=$(document.documentElement).attr("data-mc-path-to-help-system");var H=new MadCap.Utilities.Url(document.location.href).CombinePath(K).ToFolder().CombinePath("Data/HelpSystem.xml");v=new MadCap.WebHelp.HelpSystem(null,null,H.FullPath,null,null);v.Load(function(){B();if(v.IsResponsive){var R=v.Breakpoints;E=R.Tablet}if(v.LiveHelpEnabled){q=new MadCap.WebHelp.FeedbackController(v.LiveHelpServer);q.Init(function(){if(q.FeedbackActive){MadCap.Utilities.CrossFrame.PostMessageRequest(parent,"get-csh-id",null,function(S){var T=S!=null?S[0]:null;if(c!=null){q.LogTopic(c,T,function(){var U=$(".feedback-comments-wrapper");if(!b()){if(!q.PulseEnabled){U.removeClass("hidden");t=$("#new-comment-form").attr("data-comment-length-exceeded-message")||"The maximum comment length was exceeded by {n} characters.";q.GetAnonymousEnabled(v.LiveHelpOutputId,function(W){D=W;if(W){$(document.documentElement).addClass("feedback-anonymous-enabled")}});var V=MadCap.Utilities.Store.getItem("LiveHelpUsername");$(".username").val(V);$(".comment-submit").click(p);$(".feedback-comments-wrapper .comments").on("click",".reply-comment-button",m);a()}else{if(q.PulseActive){o(function(W){if(W){var X=q.PulseServer+W;i(X)}else{q.GetPulseStreamID(c,function(Y){if(Y=="00000000-0000-0000-0000-000000000000"){return}var Z=q.PulseServer+"streams/"+Y+"/activities?frame=stream";i(Z)})}})}}}})}})}});f()}})}function G(I){var H=new MadCap.Utilities.Url(document.location.href);if(!MadCap.String.IsNullOrEmpty(H.Fragment)){var J=H.Fragment.substring(1);J=MadCap.Utilities.Url.StripInvalidCharacters(J);C.ScrollToBookmark(J)}}function A(H){H=MadCap.Utilities.Url.StripInvalidCharacters(H);var I=$("[name='"+H+"']");if(I.length>0){u(I[0])}}function j(){return window.name=="topic"}function b(){return window.name=="MCPopup"}function z(H){var M=$(H);var K=M.attr("data-state1-class");var I=M.attr("data-state2-class");var J=M.attr("data-current-state")||"1";var L=J=="1"?"2":"1";M.attr("data-current-state",L);M.toggleClass(K).toggleClass(I);M.attr("title",M.attr("data-state"+L+"-title"))}function B(){MadCap.Utilities.CrossFrame.PostMessageRequest(parent,"get-href",null,function(K){if(K){var I=new MadCap.Utilities.Url(decodeURIComponent(K[0]));var H=new MadCap.Utilities.Url(I.Fragment.substring(1));var J=I.QueryMap.GetItem("BrowseSequencesPath");v.SetBrowseSequencePath(J,H)}})}function p(K){var H=$(this).closest(".comment-form-wrapper");var J=null;var O=H.children(".username-field").val();var I=H.children(".subject-field").val();var N=H.find(".body-field").val();var L=null;var M=H.parent();if(M.hasClass("comment")){L=M.attr("data-mc-comment-id")}y(O,I,N,L)}function y(M,I,L,K){if(D){MadCap.Utilities.Store.setItem("LiveHelpUsername",M);try{q.AddComment(c,null,M,I,L,K,a)}catch(H){var J=t.replace(/{n}/g,H.Data.ExceedAmount);alert(J)}}else{MadCap.Utilities.CrossFrame.PostMessageRequest(parent,"login-user",null,function(Q){var P=Q[0];if(P!=null){try{q.AddComment(c,P,M,I,L,K,a)}catch(N){var O=t.replace(/{n}/g,N.Data.ExceedAmount);alert(O)}}})}}function m(I){I.preventDefault();var J=$(this).closest(".comment");if(J.children(".comment-form-wrapper")[0]!=null){return}var H=$("#new-comment-form").clone();H.attr("id",null);H.children(".comment-submit").click(p);J.children(".buttons").after(H);H.hide().slideDown()}function a(){MadCap.Utilities.CrossFrame.PostMessageRequest(parent,"get-user-guid",null,function(I){var H=I[0];q.GetTopicComments(c,H,null,function(J){var L=MadCap.Utilities.Xhr.LoadXmlString(J);var K=$(".comments");K.children().not(".mc-template").remove();s(L.documentElement,K)})})}function s(S,P){var R=$(S).children("Comment");var H=$(".comments .comment.mc-template");for(var O=0,K=R.length;O<K;O++){var T=$(R[O]);var N=T.attr("User");var Q=T.attr("DateUTC")||T.attr("Date");var L=T.attr("Subject");var J=T.attr("CommentID");var I=T.children("Body").text();var M=H.clone();M.removeClass("mc-template");M.attr("data-mc-comment-id",J);$(".username",M).text(N);$(".timestamp",M).text(Q);$(".subject",M).text(L);$(".body",M).text(I);$(P).append(M);s(T.children("Comments")[0],M)}}function o(H){MadCap.Utilities.CrossFrame.PostMessageRequest(parent,"get-href",null,function(L){var I=null;if(L){var K=new MadCap.Utilities.Url(decodeURIComponent(L[0]));var J=new MadCap.Utilities.Url(K.Fragment.substring(1));I=K.QueryMap.GetItem("PulsePath")}H(I)})}function i(J){var H=$(".feedback-comments-wrapper");H.empty();var I=$("<iframe name='topiccomments-html5' class='pulse-frame pulse-loading' title='Topic Comments' frameborder='0'></iframe>");I.appendTo(H);if(!($.browser.msie&&parseInt($.browser.version,10)===7)){I.attr("onload","this.className='pulse-frame';")}I.attr("src",J);H.removeClass("hidden")}function r(){for(var H=1;H<=10;H++){$("body").removeHighlight("mc-highlightSearch"+H)}}var x=Array("a","an","the","to","of","is","for","and","or","do","be","by","he","she","on","in","at","it","not","no","are","as","but","her","his","its","non","only","than","that","then","they","this","we","were","which","with","you","into","about","after","all","also","been","can","come","from","had","has","have","me","made","many","may","more","most","near","over","some","such","their","there","these","under","use","was","when","where","against","among","became","because","between","during","each","early","found","however","include","late","later","med","other","several","through","until","who","your");function w(){function H(I){if(typeof I.nextElementSibling=="undefined"){return I.nextSibling==null||I.nextSibling.nodeType==1?I.nextSibling:H(I.nextSibling)}else{return I.nextElementSibling}}MadCap.Utilities.CrossFrame.PostMessageRequest(parent,"get-href",null,function(Q){if(Q){var J=new MadCap.Utilities.Url(decodeURIComponent(Q[0]));var M=J.QueryMap.GetItem("Highlight");if(MadCap.String.IsNullOrEmpty(M)){return}var N=M.match(/"[^"]*"/g);if(N!=null){for(var O=0;O<N.length;O++){M=M.replace(N[O],"")}}var R=M.replace('"',"").split(" ");for(var P=0;P<R.length;P++){if(R[P]==""){R.splice(R[P],1);P--}}if(N!=null){for(var O=0;O<N.length;O++){R.push(N[O].replace(/"/g,""))}}for(var P=0;P<R.length;P++){if($.inArray(R[P].toLowerCase(),x)!=-1){R.splice(P,1);P--}}for(var S=0;S<R.length;S++){var K=Array("*[class*='MCExpandingBody']","*[class*='MCDropDownHotSpot']","*[data-mc-target-name]");for(var U=0;U<K.length;U++){var I=$(K[U]);for(var L=0;L<I.length;L++){var T=H(I[L].parentElement);if((I[L].textContent!=null&&I[L].textContent.toLowerCase().indexOf(R[S].toLowerCase())>=0)||(T!=null&&T.textContent!=null&&T.textContent.toLowerCase().indexOf(R[S].toLowerCase())>=0)){u(U!=2?I[L]:I[L].firstChild)}}}$("body").highlight(R[S],"mc-highlightSearch"+(S+1))}}})}function h(K,I,H,J){if(K==""){return}g(document.body,K,I,H,J);if(e&&e.offsetTop>document.documentElement.clientHeight){document.documentElement.scrollTop=e.offsetTop}}function d(K){for(var J=K.childNodes.length-1;J>=1;J--){var H=K.childNodes[J];var I=H.previousSibling;if(H.nodeType==3&&I.nodeType==3){I.nodeValue=I.nodeValue+H.nodeValue;K.removeChild(H)}}for(var J=0;J<K.childNodes.length;J++){d(K.childNodes[J])}}function g(T,K,L,R,Q){var W=null;if(Q=="NGram"){W=new RegExp(K,"g"+(R?"":"i"))}else{var I=K.replace(/([*^$+?.()[\]{}|\\])/g,"\\$1");W=new RegExp("(^|\\s|[.,;!#$/:?'\"()[\\]{}|=+*_\\-\\\\])"+I+"($|\\s|[.,;!#$/:?'\"()[\\]{}|=+*_\\-\\\\])","g"+(R?"":"i"))}for(var O=T.childNodes.length-1;O>=0;O--){var J=T.childNodes[O];g(J,K,L,R,Q);if(J.nodeType!=3||J.parentNode.nodeName=="SCRIPT"){continue}var N=J;var V=N.nodeValue;for(var P=W.exec(V);P!=null;P=W.exec(V)){var S=P.index+(Q=="NGram"?0:P[1].length);var H=S+K.length;var U=document.createElement("span");U.className="highlight";U.style.fontWeight="bold";U.style.backgroundColor=L.split(",")[0];U.style.color=L.split(",")[1];var M=document.createElement("span");M.className="SearchHighlight"+(F+1);M.appendChild(document.createTextNode(V.substring(S,H)));U.appendChild(M);N.nodeValue=V.substring(0,S);N.parentNode.insertBefore(U,N.nextSibling);N.parentNode.insertBefore(document.createTextNode(V.substring(H,V.length)),U.nextSibling);N=N.nextSibling.nextSibling;V=N.nodeValue;if(e==null||U.offsetTop<e.offsetTop){e=U}u(U)}}}function u(I){var O=false;for(var N=I.parentNode;N.nodeName!="BODY";N=N.parentNode){var R=$(N);if(R.hasClass("MCExpanding")){var K=C.TextEffectControl.FindControl(R[0]);if(K==null){K=new MadCap.TopicHelpers.ExpandingControl(N)}K.Open(true);O=true}else{if(R.hasClass("MCDropDown")){var K=C.TextEffectControl.FindControl(R[0]);if(K==null){K=new MadCap.TopicHelpers.DropDownControl(N)}K.Open(true);O=true}else{var L=$(N).attr("data-mc-target-name");if(L!=null){var Q=MadCap.Dom.GetElementsByClassName("MCToggler",null,document.body);for(var M=0,H=Q.length;M<H;M++){var P=$(Q[M]).attr("data-mc-targets").split(";");var S=false;for(var J=0;J<P.length;J++){if(P[J]==L){S=true;break}}if(!S){continue}var K=C.TextEffectControl.FindControl(Q[M]);if(K==null){K=new MadCap.TopicHelpers.TogglerControl(Q[M])}K.Open(true);O=true;break}}}}}return O}MadCap.Utilities.CrossFrame.AddMessageHandler(function(M,I,L){var K={Handled:false,FireResponse:true};if(M=="print"){window.focus();window.print();K.Handled=true}else{if(M=="expand-all"){C.TextEffectControl.ExpandAll("open");K.Handled=true}else{if(M=="collapse-all"){C.TextEffectControl.ExpandAll("close");K.Handled=true}else{if(M=="get-topic-id"){L[L.length]=c;K.Handled=true}else{if(M=="get-topic-url"){L[L.length]=document.location.href;K.Handled=true}else{if(M=="remove-highlight"){r();K.Handled=true}else{if(M=="get-bs-path"){var H=new MadCap.Utilities.Url(document.location.href);var J=H.QueryMap.GetItem("BrowseSequencePath");if(J==null){J=MadCap.Dom.Dataset(document.documentElement,"mcBrowseSequencePath")}L[L.length]=J;L[L.length]=H.FullPath;K.Handled=true}else{if(M=="reload-pulse"){MadCap.Utilities.CrossFrame.PostMessageRequest(frames["topiccomments-html5"],"reload");K.Handled=true}else{if(M=="logout-complete"){MadCap.Utilities.CrossFrame.PostMessageRequest(parent,"logout-complete");K.Handled=true}else{if(M=="set-pulse-login-id"){if(q!=null){q.PulseUserGuid=I[0]}MadCap.Utilities.CrossFrame.PostMessageRequest(parent,"set-pulse-login-id",I);K.Handled=true}}}}}}}}}}return K},null);var n=new Array("#ffff66,#000000","#a0ffff,#000000","#99ff99,#000000","#ff9999,#000000","#ff66ff,#000000","#880000,#ffffff","#00aa00,#ffffff","#886800,#ffffff","#004699,#ffffff","#990099,#ffffff");var F=0;var e=null;var v=null;var q=null;var D=false;var c=MadCap.Dom.Dataset(document.documentElement,"mcLiveHelp");var t=null})();

//    Syntax:
//    function MadCap.OpenHelp(id, skinName, searchQuery, firstPick)
//
//    id          - Identifier that was created in Flare. This can be either the identifier name or value. The topic and skin
//                  that is associated with the id will be used. If no skin is associated with the id, skinName will be used.
//                  Alternatively, id may contain a topic path. In this case, the specified topic will be loaded with the skin
//                  that is specified in skinName. Specify null to use the help system's default starting topic.
//    skinName    - This is a string indicating the name of the skin to use when opening the help system. Specify null to use
//                  the default skin or to use the skin that is associated with id. If a skin is associated with id AND a skin
//                  is specified in skinName, skinName will take precedence.
//    searchQuery - This is a string indicating the search query used when opening the help system. If a search query is specified,
//                  the help system will start with the search pane open and the search query executed. Specify null to open
//                  the help system without a search query.
//    firstPick   - This is a boolean indicating whether to automatically open the topic from the first search result that is
//                  returned by the search query (see searchQuery parameter). Use null if no search query was specified.
//
//    Examples:
//
//    In the following example, topic and skin associated with "FILE_NEW" will be used:
//    MadCap.OpenHelp('FILE_NEW', null, null, null);
//
//    In the following example, topic associated with "FILE_NEW" will be used. "BlueSkin" will override the skin associated with "FILE_NEW":
//    MadCap.OpenHelp('FILE_NEW', 'BlueSkin', null, null);
//
//    In the following example, topic and skin associated with identifier value 1 will be used:
//    MadCap.OpenHelp(1, null, null, null);
//
//    In the following example, topic associated with identifier value 1 will be used. "BlueSkin" will override the skin associated with identifier value 1:
//    MadCap.OpenHelp(1, 'BlueSkin', null, null);
//
//    In the following example, "Company/Employees.htm" will be used with the default skin:
//    MadCap.OpenHelp('Company/Employees.htm', null, null, null);
//
//    In the following example, both the default topic and skin will be used:
//    MadCap.OpenHelp(null, null, null, null);
//
//    In the following example, the default topic will be used with "BlueSkin":
//    MadCap.OpenHelp(null, 'BlueSkin', null, null);
//
//    In the following example, both the default topic and skin will be used. The help system will be started with the search pane
//    displaying the search results for the query 'quarterly report'. The topic from the first result will not be opened:
//    MadCap.OpenHelp(null, null, 'quarterly report', false);
//
//    In the following example, both the default topic and skin will be used. The help system will be started with the search pane
//    displaying the search results for the query 'quarterly report'. The topic from the first result will be opened:
//    MadCap.OpenHelp(null, null, 'quarterly report', true);

(function ()
{
var helpSystemName = "Webhelp.htm";

    MadCap.OpenHelp = function (id, skinName, searchQuery, firstPick, pathToHelpSystem)
    {
        var cshFileName = helpSystemName.substring(0, helpSystemName.lastIndexOf(".")) + ".js";
        var webHelpPath = null;
        var webHelpFile = null;
        var cshFileUrl = new MadCap.Utilities.Url(helpSystemName);

        if (pathToHelpSystem == null)
        {
            var scriptNodes = document.getElementsByTagName("script");
            var found = false;

            for (var i = 0; i < scriptNodes.length; i++)
            {
                var src = scriptNodes[i].src;
                var srcUrl = new MadCap.Utilities.Url(MadCap.String.Trim(src));

                if (srcUrl.NameWithExtension.toLowerCase() == cshFileName.toLowerCase())
                {
                    var locUrl = new MadCap.Utilities.Url(document.location.href).ToFolder();

                    webHelpPath = locUrl.AddFile(srcUrl);
                    webHelpPath = webHelpPath.ToFolder();

                    found = true;

                    break;
                }
            }

            if (!found)
                throw "CSH failed: could not find MadCap CSH script in page.";
        }
        else
        {
            webHelpPath = new MadCap.Utilities.Url(pathToHelpSystem);
        }

        webHelpFile = webHelpPath.AddFile(cshFileUrl);

        var webHelpPath = webHelpFile.ToFolder().FullPath;
        var helpSystemFile = webHelpPath + "Data/HelpSystem.xml";
        var helpSystem = new MadCap.WebHelp.HelpSystem(null, null, helpSystemFile, null, null);

        helpSystem.Load(function ()
        {
            helpSystem.LookupCSHID(id, function (idInfo)
            {
                function OnGetSkinComplete()
                {
                    var cshString = webHelpFile.FullPath;

                    if (id)
                        cshString += "#cshid=" + id;

                    if (skinName)
                    {
                        if (cshString.indexOf("#") != -1)
                            cshString += "&";
                        else
                            cshString += "#";

                        cshString += "skinName=" + skinName;
                    }

                    if (searchQuery)
                    {
                        if (cshString.indexOf("#") != -1)
                            cshString += "&";
                        else
                            cshString += "#";

                        cshString += "searchQuery=" + searchQuery;

                        if (firstPick)
                            cshString += "&firstPick=true";
                    }

                    var win = window.open(cshString, "_MCWebHelpCSH", browserOptions + size);

                    // Bug 32051: Windows 7 64-bit is returning null from the call to window.open().
                    if (win != null)
                        win.focus();
                }

                skinName = skinName || idInfo.Skin;

                // Browser setup options

                var browserOptions = "";
                var size = "";

                if (skinName)
                {
                    var skin = helpSystem.GetSkin(skinName);

                    if (skin)
                    {
                        var useDefault = MadCap.String.ToBool(skin.UseDefaultBrowserSetup, false);

                        if (!useDefault)
                        {
                            var toolbar = "no";
                            var menu = "no";
                            var locationBar = "no";
                            var statusBar = "no";
                            var resizable = "no";
                            var setup = skin.BrowserSetup;

                            if (setup)
                            {
                                toolbar = (setup.indexOf("Toolbar") > -1) ? "yes" : "no";
                                menu = (setup.indexOf("Menu") > -1) ? "yes" : "no";
                                locationBar = (setup.indexOf("LocationBar") > -1) ? "yes" : "no";
                                statusBar = (setup.indexOf("StatusBar") > -1) ? "yes" : "no";
                                resizable = (setup.indexOf("Resizable") > -1) ? "yes" : "no";
                            }

                            browserOptions = "toolbar=" + toolbar + ", menubar=" + menu + ", location=" + locationBar + ", status=" + statusBar + ", resizable=" + resizable;
                        }

                        var windowSize = LoadSize(skin);

                        if (windowSize)
                            size = ", top=" + windowSize.topPx + ", left=" + windowSize.leftPx + ", width=" + windowSize.widthPx + ", height=" + windowSize.heightPx;
                    }

                    OnGetSkinComplete();
                }
                else
                {
                    OnGetSkinComplete();
                }
            });
        });
    }

    function LoadSize(skin)
    {
        var useDefaultSize = MadCap.String.ToBool(skin.UseBrowserDefaultSize, false);

        if (useDefaultSize)
            return null;

        var topPx = MadCap.String.ToInt(skin.Top, 0);
        var leftPx = MadCap.String.ToInt(skin.Left, 0);
        var bottomPx = MadCap.String.ToInt(skin.Bottom, 0);
        var rightPx = MadCap.String.ToInt(skin.Right, 0);
        var widthPx = MadCap.String.ToInt(skin.Width, 800);
        var heightPx = MadCap.String.ToInt(skin.Height, 600);

        var anchors = skin.Anchors;

        if (anchors)
        {
            var aTop = (anchors.indexOf("Top") > -1) ? true : false;
            var aLeft = (anchors.indexOf("Left") > -1) ? true : false;
            var aBottom = (anchors.indexOf("Bottom") > -1) ? true : false;
            var aRight = (anchors.indexOf("Right") > -1) ? true : false;
            var aWidth = (anchors.indexOf("Width") > -1) ? true : false;
            var aHeight = (anchors.indexOf("Height") > -1) ? true : false;
        }

        if (aLeft && aRight)
            widthPx = screen.width - (leftPx + rightPx);
        else if (!aLeft && aRight)
            leftPx = screen.width - (widthPx + rightPx);
        else if (aWidth)
            leftPx = (screen.width / 2) - (widthPx / 2);

        if (aTop && aBottom)
            heightPx = screen.height - (topPx + bottomPx);
        else if (!aTop && aBottom)
            topPx = screen.height - (heightPx + bottomPx);
        else if (aHeight)
            topPx = (screen.height / 2) - (heightPx / 2);

        //

        var windowSize = {};
        windowSize.topPx = topPx;
        windowSize.leftPx = leftPx;
        windowSize.widthPx = widthPx;
        windowSize.heightPx = heightPx;

        return windowSize;
    }
})();
